-- MariaDB dump 10.19  Distrib 10.5.22-MariaDB, for Linux (x86_64)
--
-- Host: localhost    Database: heat
-- ------------------------------------------------------
-- Server version	10.5.22-MariaDB

/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
/*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
/*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
/*!40101 SET NAMES utf8mb4 */;
/*!40103 SET @OLD_TIME_ZONE=@@TIME_ZONE */;
/*!40103 SET TIME_ZONE='+00:00' */;
/*!40014 SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0 */;
/*!40014 SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0 */;
/*!40101 SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='NO_AUTO_VALUE_ON_ZERO' */;
/*!40111 SET @OLD_SQL_NOTES=@@SQL_NOTES, SQL_NOTES=0 */;

--
-- Table structure for table `event`
--

DROP TABLE IF EXISTS `event`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `event` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `uuid` varchar(36) DEFAULT NULL,
  `stack_id` varchar(36) NOT NULL,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `resource_action` varchar(255) DEFAULT NULL,
  `resource_status` varchar(255) DEFAULT NULL,
  `resource_name` varchar(255) DEFAULT NULL,
  `physical_resource_id` varchar(255) DEFAULT NULL,
  `resource_status_reason` varchar(255) DEFAULT NULL,
  `resource_type` varchar(255) DEFAULT NULL,
  `resource_properties` blob DEFAULT NULL,
  `rsrc_prop_data_id` int(11) DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `uuid` (`uuid`),
  KEY `stack_id` (`stack_id`),
  KEY `ev_rsrc_prop_data_ref` (`rsrc_prop_data_id`),
  CONSTRAINT `ev_rsrc_prop_data_ref` FOREIGN KEY (`rsrc_prop_data_id`) REFERENCES `resource_properties_data` (`id`),
  CONSTRAINT `event_ibfk_1` FOREIGN KEY (`stack_id`) REFERENCES `stack` (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=2805 DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `event`
--

LOCK TABLES `event` WRITE;
/*!40000 ALTER TABLE `event` DISABLE KEYS */;
INSERT INTO `event` VALUES (1,'02028839-965b-4d99-9c43-322f922cf676','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:34',NULL,'CREATE','IN_PROGRESS','overcloud','4a12592d-7930-4580-a032-c1f97514e693','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2,'31d0b944-2daa-4f2c-9da5-90d761dc28d7','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:36',NULL,'CREATE','IN_PROGRESS','NetworkerRoleUserData','overcloud-NetworkerRoleUserData-yz6tr64svgtx','state changed','OS::TripleO::Networker::NodeUserData',NULL,NULL),(3,'b10b97ef-910d-4ef7-8ac2-3d0658bae125','718a7593-c293-45cb-96cf-185b4ed3fdd7','2026-06-09 08:01:36',NULL,'CREATE','IN_PROGRESS','overcloud-NetworkerRoleUserData-yz6tr64svgtx','718a7593-c293-45cb-96cf-185b4ed3fdd7','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(4,'db09faa6-8315-4774-9528-bae72ebc3226','718a7593-c293-45cb-96cf-185b4ed3fdd7','2026-06-09 08:01:36',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-NetworkerRoleUserData-yz6tr64svgtx-userdata-4vtupdzwj7ol','state changed','OS::Heat::MultipartMime',NULL,NULL),(5,'75bafb7f-1592-4fe7-8ed5-f2d1f78f9d5a','718a7593-c293-45cb-96cf-185b4ed3fdd7','2026-06-09 08:01:36',NULL,'CREATE','COMPLETE','userdata','51ec2d2b-994c-4cbc-92bc-02b1460a30a6','state changed','OS::Heat::MultipartMime',NULL,NULL),(6,'91ad0a37-30b8-4920-88bb-8ef7b766af11','718a7593-c293-45cb-96cf-185b4ed3fdd7','2026-06-09 08:01:36',NULL,'CREATE','COMPLETE','overcloud-NetworkerRoleUserData-yz6tr64svgtx','718a7593-c293-45cb-96cf-185b4ed3fdd7','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(7,'4e4205f1-c402-467d-adf5-e319622e90a8','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:37',NULL,'CREATE','IN_PROGRESS','ServiceNetMap','overcloud-ServiceNetMap-zjadyof4tx74','state changed','OS::TripleO::ServiceNetMap',NULL,NULL),(8,'34ed0ca4-a94c-400e-9ee9-4b6bce439e8a','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:37',NULL,'CREATE','COMPLETE','NetworkerRoleUserData','718a7593-c293-45cb-96cf-185b4ed3fdd7','state changed','OS::TripleO::Networker::NodeUserData',NULL,NULL),(9,'eb5484d4-f552-4fe8-a845-8d6e24a24e74','e67697ee-6049-4346-a98c-34a30937465a','2026-06-09 08:01:37',NULL,'CREATE','IN_PROGRESS','overcloud-ServiceNetMap-zjadyof4tx74','e67697ee-6049-4346-a98c-34a30937465a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(10,'20789c8d-4b81-4c09-b11f-fa9154f5cb86','e67697ee-6049-4346-a98c-34a30937465a','2026-06-09 08:01:37',NULL,'CREATE','IN_PROGRESS','ServiceNetMapValue','overcloud-ServiceNetMap-zjadyof4tx74-ServiceNetMapValue-doixt74hfkft','state changed','OS::Heat::Value',NULL,2),(11,'5fc4bf06-130b-436a-9cf8-280ead3513f0','e67697ee-6049-4346-a98c-34a30937465a','2026-06-09 08:01:37',NULL,'CREATE','COMPLETE','ServiceNetMapValue','overcloud-ServiceNetMap-zjadyof4tx74-ServiceNetMapValue-doixt74hfkft','state changed','OS::Heat::Value',NULL,2),(12,'7ad7c133-bb09-4087-a61e-ee145d20f61c','e67697ee-6049-4346-a98c-34a30937465a','2026-06-09 08:01:37',NULL,'CREATE','COMPLETE','overcloud-ServiceNetMap-zjadyof4tx74','e67697ee-6049-4346-a98c-34a30937465a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(13,'59b0bf40-85cb-4112-af36-b7db5e4e4520','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:38',NULL,'CREATE','IN_PROGRESS','CloudNames','overcloud-CloudNames-wkjc54kajlzx','state changed','OS::Heat::Value',NULL,3),(14,'8a5e52fd-79db-427e-91a6-1fabf63d37fc','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:38',NULL,'CREATE','COMPLETE','CloudNames','overcloud-CloudNames-wkjc54kajlzx','state changed','OS::Heat::Value',NULL,3),(15,'fbb934a0-3f99-4a3c-a5a7-792c0aee24be','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:38',NULL,'CREATE','COMPLETE','ServiceNetMap','e67697ee-6049-4346-a98c-34a30937465a','state changed','OS::TripleO::ServiceNetMap',NULL,NULL),(16,'a6b0df69-bfc3-44e4-bd96-50ad2214934f','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:38',NULL,'CREATE','IN_PROGRESS','CellControllerServiceNetMapLower','overcloud-CellControllerServiceNetMapLower-rmszi4m7zepa','state changed','OS::Heat::Value',NULL,6),(17,'7525ef2f-5ffd-4f75-a8fb-f0a1523b4195','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:38',NULL,'CREATE','COMPLETE','CellControllerServiceNetMapLower','overcloud-CellControllerServiceNetMapLower-rmszi4m7zepa','state changed','OS::Heat::Value',NULL,6),(18,'c49a213a-158c-4d56-b845-be543e6ba42c','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:38',NULL,'CREATE','IN_PROGRESS','ObjectStorageServiceNetMapLower','overcloud-ObjectStorageServiceNetMapLower-ciffwzshjyjm','state changed','OS::Heat::Value',NULL,7),(19,'74392b5f-8280-4029-9a44-fba4eb31fdc9','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:38',NULL,'CREATE','COMPLETE','ObjectStorageServiceNetMapLower','overcloud-ObjectStorageServiceNetMapLower-ciffwzshjyjm','state changed','OS::Heat::Value',NULL,7),(20,'63bc6931-1656-4eb3-9fe7-6fe934217a7f','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:39',NULL,'CREATE','IN_PROGRESS','CephStorageRoleUserData','overcloud-CephStorageRoleUserData-l2i6kva55es3','state changed','OS::TripleO::CephStorage::NodeUserData',NULL,NULL),(21,'85756c96-595b-4e0e-9549-85f24cded1c7','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:39',NULL,'CREATE','IN_PROGRESS','CellControllerComputeServiceNetMapLower','overcloud-CellControllerComputeServiceNetMapLower-57lf4nce3k76','state changed','OS::Heat::Value',NULL,10),(22,'c9b56c92-59b6-4164-b486-3760722bf0e5','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:39',NULL,'CREATE','COMPLETE','CellControllerComputeServiceNetMapLower','overcloud-CellControllerComputeServiceNetMapLower-57lf4nce3k76','state changed','OS::Heat::Value',NULL,10),(23,'e5156d4f-8a11-4b38-97cf-e75085824399','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:39',NULL,'CREATE','IN_PROGRESS','ControllerServiceNetMapLower','overcloud-ControllerServiceNetMapLower-hztbc7acnogw','state changed','OS::Heat::Value',NULL,11),(24,'9a1af19b-6285-4961-91f0-193c2a8df699','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:39',NULL,'CREATE','IN_PROGRESS','BlockStorageServiceNetMapLower','overcloud-BlockStorageServiceNetMapLower-m7ot4atlnklr','state changed','OS::Heat::Value',NULL,13),(25,'6cb6376c-9a1f-4364-9cac-300464174972','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:39',NULL,'CREATE','COMPLETE','ControllerServiceNetMapLower','overcloud-ControllerServiceNetMapLower-hztbc7acnogw','state changed','OS::Heat::Value',NULL,11),(26,'a56340c1-c7c9-4cf4-a875-5ab664e6faa6','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:39',NULL,'CREATE','COMPLETE','BlockStorageServiceNetMapLower','overcloud-BlockStorageServiceNetMapLower-m7ot4atlnklr','state changed','OS::Heat::Value',NULL,13),(27,'e4677831-eb15-4cfb-99a7-538d145c1286','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:39',NULL,'CREATE','IN_PROGRESS','ComputeServiceNetMapLower','overcloud-ComputeServiceNetMapLower-y6mk2wj6slvw','state changed','OS::Heat::Value',NULL,18),(28,'eb0cdc5b-ad80-4812-b803-b058e92641a6','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:39',NULL,'CREATE','COMPLETE','ComputeServiceNetMapLower','overcloud-ComputeServiceNetMapLower-y6mk2wj6slvw','state changed','OS::Heat::Value',NULL,18),(29,'7c6d9a1e-20a1-4028-9e9e-284a3e6e202e','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:39',NULL,'CREATE','IN_PROGRESS','NetworkerServiceNetMapLower','overcloud-NetworkerServiceNetMapLower-ar4ctk4gkkrc','state changed','OS::Heat::Value',NULL,15),(30,'c42c94ce-6e76-4f91-b765-def383a48a1b','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:39',NULL,'CREATE','IN_PROGRESS','ControlVirtualIP','overcloud-ControlVirtualIP-4lzpdwcoa3kp','state changed','OS::TripleO::Network::Ports::ControlPlaneVipPort',NULL,19),(31,'f956c110-5fee-4dae-9058-3b9fb09defd4','06f98bf2-18f8-4b14-91cf-8bb4e125ae3c','2026-06-09 08:01:39',NULL,'CREATE','IN_PROGRESS','overcloud-CephStorageRoleUserData-l2i6kva55es3','06f98bf2-18f8-4b14-91cf-8bb4e125ae3c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(32,'6f76a28a-f4a7-481b-8684-8290c4fc9895','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:39',NULL,'CREATE','IN_PROGRESS','CephStorageServiceNetMapLower','overcloud-CephStorageServiceNetMapLower-jk2tkpu3cymk','state changed','OS::Heat::Value',NULL,20),(33,'d99f472b-aa17-476f-abbc-911090d1d9f5','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:39',NULL,'CREATE','COMPLETE','NetworkerServiceNetMapLower','overcloud-NetworkerServiceNetMapLower-ar4ctk4gkkrc','state changed','OS::Heat::Value',NULL,15),(34,'a45b01a1-485f-462c-b904-ab34cd6c75d0','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:39',NULL,'CREATE','COMPLETE','CephStorageServiceNetMapLower','overcloud-CephStorageServiceNetMapLower-jk2tkpu3cymk','state changed','OS::Heat::Value',NULL,20),(35,'e4ebc55a-2c50-42e1-b531-7fb634bd5ebb','06f98bf2-18f8-4b14-91cf-8bb4e125ae3c','2026-06-09 08:01:39',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-CephStorageRoleUserData-l2i6kva55es3-userdata-uudndefheam4','state changed','OS::Heat::MultipartMime',NULL,NULL),(36,'b6d0d21e-af18-4ba7-b69d-49cd7a115f85','978f96f0-40c1-47b8-89e7-dd5abbfa328b','2026-06-09 08:01:39',NULL,'CREATE','IN_PROGRESS','overcloud-ControlVirtualIP-4lzpdwcoa3kp','978f96f0-40c1-47b8-89e7-dd5abbfa328b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(37,'b2427dbc-910a-4b3c-a915-c655dc8a69d8','06f98bf2-18f8-4b14-91cf-8bb4e125ae3c','2026-06-09 08:01:39',NULL,'CREATE','COMPLETE','userdata','ada6436c-f0b0-4cc9-b5fa-90bdc4b03e77','state changed','OS::Heat::MultipartMime',NULL,NULL),(38,'d770fddd-ff35-4620-bfd0-ddc0bd163284','06f98bf2-18f8-4b14-91cf-8bb4e125ae3c','2026-06-09 08:01:39',NULL,'CREATE','COMPLETE','overcloud-CephStorageRoleUserData-l2i6kva55es3','06f98bf2-18f8-4b14-91cf-8bb4e125ae3c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(39,'59e5d0e2-fb78-4b01-acc9-f97bb620facd','978f96f0-40c1-47b8-89e7-dd5abbfa328b','2026-06-09 08:01:39',NULL,'CREATE','COMPLETE','overcloud-ControlVirtualIP-4lzpdwcoa3kp','978f96f0-40c1-47b8-89e7-dd5abbfa328b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(40,'2aaf228f-0877-4095-9459-5b13413ae77d','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:40',NULL,'CREATE','IN_PROGRESS','DeploymentServerBlacklistDict','overcloud-DeploymentServerBlacklistDict-ajlhx33jrvo5','state changed','OS::Heat::Value',NULL,24),(41,'ed3d2cdc-6cf9-49bc-a5c2-f094bca84dc1','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:40',NULL,'CREATE','COMPLETE','DeploymentServerBlacklistDict','overcloud-DeploymentServerBlacklistDict-ajlhx33jrvo5','state changed','OS::Heat::Value',NULL,24),(42,'beaa7879-b5ed-4694-bcfb-c140b6113954','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:40',NULL,'CREATE','COMPLETE','CephStorageRoleUserData','06f98bf2-18f8-4b14-91cf-8bb4e125ae3c','state changed','OS::TripleO::CephStorage::NodeUserData',NULL,NULL),(43,'a88459db-1b70-4d40-a7d6-5d44e97af3b5','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:40',NULL,'CREATE','COMPLETE','ControlVirtualIP','978f96f0-40c1-47b8-89e7-dd5abbfa328b','state changed','OS::TripleO::Network::Ports::ControlPlaneVipPort',NULL,19),(44,'d0814338-4bf2-4454-82f6-1941c8a88b57','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:41',NULL,'CREATE','IN_PROGRESS','Networks','overcloud-Networks-zz24jr7jfbjs','state changed','OS::TripleO::Network',NULL,28),(45,'65ebc34f-4f8a-49a7-8573-b8577815f159','b5aa7f87-85ce-49b5-a818-c9c761b4cea9','2026-06-09 08:01:41',NULL,'CREATE','IN_PROGRESS','overcloud-Networks-zz24jr7jfbjs','b5aa7f87-85ce-49b5-a818-c9c761b4cea9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(46,'d01b8035-7d40-4b7e-abcb-497ab649c350','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:41',NULL,'CREATE','IN_PROGRESS','BlockStorageRoleUserData','overcloud-BlockStorageRoleUserData-7snfiur3isom','state changed','OS::TripleO::BlockStorage::NodeUserData',NULL,NULL),(47,'b5b3cf29-07ac-4dd7-b748-cfdfbcf82cf5','b5aa7f87-85ce-49b5-a818-c9c761b4cea9','2026-06-09 08:01:41',NULL,'CREATE','IN_PROGRESS','NetworkCidrMap','overcloud-Networks-zz24jr7jfbjs-NetworkCidrMap-4fshf4qpljzt','state changed','OS::Heat::Value',NULL,29),(48,'57eaba17-1fbb-4316-aa8b-ece22a8da766','b5aa7f87-85ce-49b5-a818-c9c761b4cea9','2026-06-09 08:01:41',NULL,'CREATE','COMPLETE','NetworkCidrMap','overcloud-Networks-zz24jr7jfbjs-NetworkCidrMap-4fshf4qpljzt','state changed','OS::Heat::Value',NULL,29),(49,'593c8d9b-ad6a-4f13-a434-5a79bd531298','cb210dc4-2c21-4668-92a2-d79744c5ab95','2026-06-09 08:01:41',NULL,'CREATE','IN_PROGRESS','overcloud-BlockStorageRoleUserData-7snfiur3isom','cb210dc4-2c21-4668-92a2-d79744c5ab95','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(50,'19c14409-39a3-45f1-afb1-4c67354dce12','cb210dc4-2c21-4668-92a2-d79744c5ab95','2026-06-09 08:01:41',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-BlockStorageRoleUserData-7snfiur3isom-userdata-zcw2355hv6q2','state changed','OS::Heat::MultipartMime',NULL,NULL),(51,'ef50f6c4-c6a9-4509-885a-40b83f415c96','cb210dc4-2c21-4668-92a2-d79744c5ab95','2026-06-09 08:01:41',NULL,'CREATE','COMPLETE','userdata','72a218d1-7b26-4d36-a418-0c064f4c9fea','state changed','OS::Heat::MultipartMime',NULL,NULL),(52,'a30addaf-5631-464c-b79f-56300d96bef8','cb210dc4-2c21-4668-92a2-d79744c5ab95','2026-06-09 08:01:41',NULL,'CREATE','COMPLETE','overcloud-BlockStorageRoleUserData-7snfiur3isom','cb210dc4-2c21-4668-92a2-d79744c5ab95','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(53,'1fd2a803-be47-4c8b-8c0d-59d43a7abace','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:42',NULL,'CREATE','IN_PROGRESS','CellControllerRoleUserData','overcloud-CellControllerRoleUserData-ae5s25xxwajo','state changed','OS::TripleO::CellController::NodeUserData',NULL,NULL),(54,'814ff079-707f-490f-b3b6-c008536a87ac','b5aa7f87-85ce-49b5-a818-c9c761b4cea9','2026-06-09 08:01:42',NULL,'CREATE','IN_PROGRESS','NetworkAttributesMap','overcloud-Networks-zz24jr7jfbjs-NetworkAttributesMap-fa2p3pathada','state changed','OS::Heat::Value',NULL,30),(55,'abf48d04-7b1d-4b04-af46-84fb43b654e4','b5aa7f87-85ce-49b5-a818-c9c761b4cea9','2026-06-09 08:01:42',NULL,'CREATE','COMPLETE','NetworkAttributesMap','overcloud-Networks-zz24jr7jfbjs-NetworkAttributesMap-fa2p3pathada','state changed','OS::Heat::Value',NULL,30),(56,'a4594e63-6c85-4221-8ca0-204c8d6c43df','1fef1d99-0696-474b-9a61-081c967c7587','2026-06-09 08:01:42',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerRoleUserData-ae5s25xxwajo','1fef1d99-0696-474b-9a61-081c967c7587','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(57,'65a97501-c92a-4bae-92c5-48aa751dd540','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:42',NULL,'CREATE','COMPLETE','BlockStorageRoleUserData','cb210dc4-2c21-4668-92a2-d79744c5ab95','state changed','OS::TripleO::BlockStorage::NodeUserData',NULL,NULL),(58,'fee85d0b-85d3-442f-a28f-0741ab7d97e1','1fef1d99-0696-474b-9a61-081c967c7587','2026-06-09 08:01:42',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-CellControllerRoleUserData-ae5s25xxwajo-userdata-letegahvzzjc','state changed','OS::Heat::MultipartMime',NULL,NULL),(59,'a4b9cb85-6aba-456a-b908-8283932034b7','1fef1d99-0696-474b-9a61-081c967c7587','2026-06-09 08:01:42',NULL,'CREATE','COMPLETE','userdata','fb0c4c91-51db-4707-ad64-0bdbea529365','state changed','OS::Heat::MultipartMime',NULL,NULL),(60,'d3356a17-b7f9-4b07-bd1c-b8fc0675f7cd','1fef1d99-0696-474b-9a61-081c967c7587','2026-06-09 08:01:42',NULL,'CREATE','COMPLETE','overcloud-CellControllerRoleUserData-ae5s25xxwajo','1fef1d99-0696-474b-9a61-081c967c7587','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(61,'be528558-e409-4e10-8bd5-fe09ea03183e','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:43',NULL,'CREATE','IN_PROGRESS','NodeTimesyncUserData','overcloud-NodeTimesyncUserData-6mflpsy3ghvq','state changed','OS::TripleO::NodeTimesyncUserData',NULL,NULL),(62,'cb2c9098-5ccc-4917-a4d3-05fef46c5b26','b5aa7f87-85ce-49b5-a818-c9c761b4cea9','2026-06-09 08:01:43',NULL,'CREATE','IN_PROGRESS','NetworkExtraConfig','overcloud-Networks-zz24jr7jfbjs-NetworkExtraConfig-6pufqkuyjafj','state changed','OS::TripleO::Network::ExtraConfig',NULL,NULL),(63,'7d279cab-6b7e-44f0-8299-25cf42fb5ccc','b5aa7f87-85ce-49b5-a818-c9c761b4cea9','2026-06-09 08:01:43',NULL,'CREATE','COMPLETE','NetworkExtraConfig','64f1a1ed-46bf-44c2-ab95-945b5dfa5af1','state changed','OS::TripleO::Network::ExtraConfig',NULL,NULL),(64,'74ba61a2-3b83-4ec4-b65b-5318b8c3d238','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:43',NULL,'CREATE','COMPLETE','CellControllerRoleUserData','1fef1d99-0696-474b-9a61-081c967c7587','state changed','OS::TripleO::CellController::NodeUserData',NULL,NULL),(65,'74a88d68-ac36-4561-977c-1f0dff643115','6a2a011f-d504-4751-9467-179419d482b3','2026-06-09 08:01:43',NULL,'CREATE','IN_PROGRESS','overcloud-NodeTimesyncUserData-6mflpsy3ghvq','6a2a011f-d504-4751-9467-179419d482b3','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(66,'40e75b23-3cc2-439a-ac34-8537785c2853','6a2a011f-d504-4751-9467-179419d482b3','2026-06-09 08:01:43',NULL,'CREATE','IN_PROGRESS','timesync_sync','overcloud-NodeTimesyncUserData-6mflpsy3ghvq-timesync_sync-vtot4o63hvlv','state changed','OS::Heat::SoftwareConfig',NULL,33),(67,'3fa34839-afa1-4830-b2b4-2a974febdb6d','6a2a011f-d504-4751-9467-179419d482b3','2026-06-09 08:01:43',NULL,'CREATE','COMPLETE','timesync_sync','6dac88cb-271f-4a9d-8144-529eecb9c60d','state changed','OS::Heat::SoftwareConfig',NULL,33),(68,'c856e3e5-5b69-4065-849e-24a69d1fb6ba','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:44',NULL,'CREATE','IN_PROGRESS','ComputeRoleUserData','overcloud-ComputeRoleUserData-lsnzmrfiu7qk','state changed','OS::TripleO::Compute::NodeUserData',NULL,NULL),(69,'dcd86f2c-5d5a-4a5d-8962-3420478c342f','b5aa7f87-85ce-49b5-a818-c9c761b4cea9','2026-06-09 08:01:44',NULL,'CREATE','IN_PROGRESS','NetworkIpVersionMap','overcloud-Networks-zz24jr7jfbjs-NetworkIpVersionMap-vzz4qxwig5r5','state changed','OS::Heat::Value',NULL,34),(70,'95f869ba-3fc0-4c64-8d8c-2152ab0c4768','b5aa7f87-85ce-49b5-a818-c9c761b4cea9','2026-06-09 08:01:44',NULL,'CREATE','COMPLETE','NetworkIpVersionMap','overcloud-Networks-zz24jr7jfbjs-NetworkIpVersionMap-vzz4qxwig5r5','state changed','OS::Heat::Value',NULL,34),(71,'1d8f6fca-dba9-4ca4-b9b6-ef785f17d41a','b5aa7f87-85ce-49b5-a818-c9c761b4cea9','2026-06-09 08:01:44',NULL,'CREATE','COMPLETE','overcloud-Networks-zz24jr7jfbjs','b5aa7f87-85ce-49b5-a818-c9c761b4cea9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(72,'216d6bc3-0073-4243-96ba-a02ecb9dd93e','0fbccaf0-9b66-4568-8c2b-166f4e89f968','2026-06-09 08:01:44',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeRoleUserData-lsnzmrfiu7qk','0fbccaf0-9b66-4568-8c2b-166f4e89f968','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(73,'75916b7f-a771-4161-9c84-8d3680577daa','0fbccaf0-9b66-4568-8c2b-166f4e89f968','2026-06-09 08:01:44',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-ComputeRoleUserData-lsnzmrfiu7qk-userdata-k2456v2ki2sk','state changed','OS::Heat::MultipartMime',NULL,NULL),(74,'ef0808df-d4ec-4aba-b2a8-15cf2ba03444','0fbccaf0-9b66-4568-8c2b-166f4e89f968','2026-06-09 08:01:44',NULL,'CREATE','COMPLETE','userdata','29fd56df-a15e-4229-aeb5-8d65e8788cf5','state changed','OS::Heat::MultipartMime',NULL,NULL),(75,'d5664b95-dd3a-4ede-88ab-736b33ea2622','6a2a011f-d504-4751-9467-179419d482b3','2026-06-09 08:01:44',NULL,'CREATE','IN_PROGRESS','timesync_chrony','overcloud-NodeTimesyncUserData-6mflpsy3ghvq-timesync_chrony-7og24xhzlxkp','state changed','OS::Heat::SoftwareConfig',NULL,35),(76,'5dfcb3cd-2096-4d2c-b5b8-b1457b4292e1','0fbccaf0-9b66-4568-8c2b-166f4e89f968','2026-06-09 08:01:44',NULL,'CREATE','COMPLETE','overcloud-ComputeRoleUserData-lsnzmrfiu7qk','0fbccaf0-9b66-4568-8c2b-166f4e89f968','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(77,'3879936c-6346-48b8-a7de-3d9822aa7327','6a2a011f-d504-4751-9467-179419d482b3','2026-06-09 08:01:44',NULL,'CREATE','COMPLETE','timesync_chrony','b8507f4c-5935-4b3a-9893-0ff2e5fdbe4f','state changed','OS::Heat::SoftwareConfig',NULL,35),(78,'cc8d14df-d451-4656-bbaf-d0a16e819d98','6a2a011f-d504-4751-9467-179419d482b3','2026-06-09 08:01:44',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-NodeTimesyncUserData-6mflpsy3ghvq-userdata-c6gau4dbf6ji','state changed','OS::Heat::MultipartMime',NULL,36),(79,'98c53816-4acb-4225-8e9e-62625639a3a6','6a2a011f-d504-4751-9467-179419d482b3','2026-06-09 08:01:44',NULL,'CREATE','COMPLETE','userdata','fdefb147-dc62-4e69-911f-1e92ed4d95bb','state changed','OS::Heat::MultipartMime',NULL,36),(80,'6ba497a6-f062-4e16-b08d-ea7ad37a5f00','6a2a011f-d504-4751-9467-179419d482b3','2026-06-09 08:01:44',NULL,'CREATE','COMPLETE','overcloud-NodeTimesyncUserData-6mflpsy3ghvq','6a2a011f-d504-4751-9467-179419d482b3','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(81,'4b6ca1ae-5fa8-439e-a8f4-180ae2fb439a','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:45',NULL,'CREATE','COMPLETE','Networks','b5aa7f87-85ce-49b5-a818-c9c761b4cea9','state changed','OS::TripleO::Network',NULL,28),(82,'2bb9eaf9-6978-4445-8dcb-2993d9c9125b','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:45',NULL,'CREATE','IN_PROGRESS','NodeAdminUserData','overcloud-NodeAdminUserData-ffzfqvtrybh4','state changed','OS::TripleO::NodeAdminUserData',NULL,NULL),(83,'0636cdfd-3673-44e7-a3c0-bc2e8777c305','81c78446-516c-420e-a6ac-0881ae738320','2026-06-09 08:01:45',NULL,'CREATE','IN_PROGRESS','overcloud-NodeAdminUserData-ffzfqvtrybh4','81c78446-516c-420e-a6ac-0881ae738320','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(84,'0f81c3bf-6816-40ea-ae16-3607234ec0cb','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:45',NULL,'CREATE','IN_PROGRESS','StorageVirtualIP','overcloud-StorageVirtualIP-dkphugv5whvo','state changed','OS::TripleO::Network::Ports::StorageVipPort',NULL,40),(85,'a6873ec2-cd3c-40b9-ac49-71f1af4da2b1','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:45',NULL,'CREATE','COMPLETE','ComputeRoleUserData','0fbccaf0-9b66-4568-8c2b-166f4e89f968','state changed','OS::TripleO::Compute::NodeUserData',NULL,NULL),(86,'f1b9eaeb-bfa6-4853-b9c1-8b88368fe887','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:45',NULL,'CREATE','COMPLETE','NodeTimesyncUserData','6a2a011f-d504-4751-9467-179419d482b3','state changed','OS::TripleO::NodeTimesyncUserData',NULL,NULL),(87,'c5c2265d-9738-4694-8169-99d00845f2df','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:45',NULL,'CREATE','IN_PROGRESS','BlockStorageNetworkConfig','overcloud-BlockStorageNetworkConfig-kjtohmlojtlv','state changed','OS::TripleO::BlockStorage::Net::SoftwareConfig',NULL,NULL),(88,'aa6e4041-2d94-40ce-8f5b-64e8de41ccc1','a7fea693-f109-4861-ad76-e85832c74aa6','2026-06-09 08:01:45',NULL,'CREATE','IN_PROGRESS','overcloud-StorageVirtualIP-dkphugv5whvo','a7fea693-f109-4861-ad76-e85832c74aa6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(89,'c86d10ad-ff55-460a-89da-d7f111a71207','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:45',NULL,'CREATE','COMPLETE','BlockStorageNetworkConfig','37dd1919-ec9b-4f54-adbb-08bad0e2f34f','state changed','OS::TripleO::BlockStorage::Net::SoftwareConfig',NULL,NULL),(90,'9d75c928-ff2b-4edb-abae-2782e192f3b9','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:45',NULL,'CREATE','IN_PROGRESS','PublicVirtualIP','overcloud-PublicVirtualIP-wbk3cp7mj63a','state changed','OS::TripleO::Network::Ports::ExternalVipPort',NULL,41),(91,'4bd7ad3e-d23e-4bac-9000-78d3362f869a','81c78446-516c-420e-a6ac-0881ae738320','2026-06-09 08:01:45',NULL,'CREATE','IN_PROGRESS','user_config','overcloud-NodeAdminUserData-ffzfqvtrybh4-user_config-tohgbgibpyyg','state changed','OS::Heat::CloudConfig',NULL,43),(92,'fed39297-b84b-4897-93e5-49858d8acddd','81c78446-516c-420e-a6ac-0881ae738320','2026-06-09 08:01:45',NULL,'CREATE','COMPLETE','user_config','cc5e797f-eb8d-42ae-bab2-155fb6f554f6','state changed','OS::Heat::CloudConfig',NULL,43),(93,'51d621dd-b5d7-4812-be01-7a7af2c5a854','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:45',NULL,'CREATE','IN_PROGRESS','ComputeNetworkConfig','overcloud-ComputeNetworkConfig-52jl4km2szba','state changed','OS::TripleO::Compute::Net::SoftwareConfig',NULL,NULL),(94,'922d68b9-c12d-47d7-b976-e377adc1e929','81c78446-516c-420e-a6ac-0881ae738320','2026-06-09 08:01:45',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-NodeAdminUserData-ffzfqvtrybh4-userdata-xxaanv3ihfmh','state changed','OS::Heat::MultipartMime',NULL,44),(95,'b2153530-dbcb-49d8-8289-da41862c3909','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:45',NULL,'CREATE','IN_PROGRESS','ObjectStorageNetworkConfig','overcloud-ObjectStorageNetworkConfig-drhird5g3k25','state changed','OS::TripleO::ObjectStorage::Net::SoftwareConfig',NULL,NULL),(96,'188caf87-11ba-4e45-b8ef-a34b3a8985ff','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:45',NULL,'CREATE','IN_PROGRESS','CellControllerComputeNetworkConfig','overcloud-CellControllerComputeNetworkConfig-5igbwyu6j5fz','state changed','OS::TripleO::CellControllerCompute::Net::SoftwareConfig',NULL,NULL),(97,'ad16704a-c708-4542-99ea-1ee34867c50c','a7fea693-f109-4861-ad76-e85832c74aa6','2026-06-09 08:01:45',NULL,'CREATE','COMPLETE','overcloud-StorageVirtualIP-dkphugv5whvo','a7fea693-f109-4861-ad76-e85832c74aa6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(98,'53fe047d-bd6b-4bfd-a855-c634a353fa06','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:45',NULL,'CREATE','IN_PROGRESS','NetIpVersionMapValue','overcloud-NetIpVersionMapValue-ktqfx3qrjvzg','state changed','OS::Heat::Value',NULL,46),(99,'4efc94d2-2ea7-43f9-a661-01d68166cc47','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:45',NULL,'CREATE','IN_PROGRESS','NetworkerNetworkConfig','overcloud-NetworkerNetworkConfig-lexhkdz36go2','state changed','OS::TripleO::Networker::Net::SoftwareConfig',NULL,NULL),(100,'65dded73-4451-409e-b284-67daa5bfabed','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:45',NULL,'CREATE','IN_PROGRESS','ControllerNetworkConfig','overcloud-ControllerNetworkConfig-tmm5rmbpkbqo','state changed','OS::TripleO::Controller::Net::SoftwareConfig',NULL,NULL),(101,'cdc34384-e3ee-4c6e-a060-21c69a2c3009','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:45',NULL,'CREATE','COMPLETE','ObjectStorageNetworkConfig','39e41dcd-c772-4c09-a356-30f33637f4a3','state changed','OS::TripleO::ObjectStorage::Net::SoftwareConfig',NULL,NULL),(102,'bf03efe5-feab-4040-91de-241b7d9f45c5','81c78446-516c-420e-a6ac-0881ae738320','2026-06-09 08:01:45',NULL,'CREATE','COMPLETE','userdata','c0ddb838-0988-491c-81ea-11011b1a5af7','state changed','OS::Heat::MultipartMime',NULL,44),(103,'2ee3866a-5aef-41ec-bebd-d59d197afdda','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:45',NULL,'CREATE','COMPLETE','NetworkerNetworkConfig','064dec20-ea60-4d2b-8956-c24e7a0103f2','state changed','OS::TripleO::Networker::Net::SoftwareConfig',NULL,NULL),(104,'43c3b8fa-a614-4322-af79-9bca1b10c95b','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:45',NULL,'CREATE','COMPLETE','ControllerNetworkConfig','35b91b0e-1a7d-428c-89e1-5eb1758f603b','state changed','OS::TripleO::Controller::Net::SoftwareConfig',NULL,NULL),(105,'553cceb4-e6af-4dae-85e9-3a415121963f','77037518-60bc-4d5b-8ae4-e5ba43d974da','2026-06-09 08:01:45',NULL,'CREATE','IN_PROGRESS','overcloud-PublicVirtualIP-wbk3cp7mj63a','77037518-60bc-4d5b-8ae4-e5ba43d974da','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(106,'c250782f-9f22-4782-bb96-551106073306','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:45',NULL,'CREATE','IN_PROGRESS','CephStorageNetworkConfig','overcloud-CephStorageNetworkConfig-totwnjxldmlz','state changed','OS::TripleO::CephStorage::Net::SoftwareConfig',NULL,NULL),(107,'600a7515-eec2-4c36-9ddf-00f7af2beac0','81c78446-516c-420e-a6ac-0881ae738320','2026-06-09 08:01:45',NULL,'CREATE','COMPLETE','overcloud-NodeAdminUserData-ffzfqvtrybh4','81c78446-516c-420e-a6ac-0881ae738320','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(108,'7fc10043-9fb6-468f-a68f-e808afb68b01','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:45',NULL,'CREATE','COMPLETE','ComputeNetworkConfig','86d624bd-5455-4ff3-b503-0ab6d880c8db','state changed','OS::TripleO::Compute::Net::SoftwareConfig',NULL,NULL),(109,'2b643a7b-22a7-4326-9e4f-7e03ddb273ac','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:45',NULL,'CREATE','COMPLETE','NetIpVersionMapValue','overcloud-NetIpVersionMapValue-ktqfx3qrjvzg','state changed','OS::Heat::Value',NULL,46),(110,'ecd40f9a-b713-441f-b87f-3a257a5aa6e3','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:45',NULL,'CREATE','COMPLETE','CephStorageNetworkConfig','d37286a0-5bc7-44e1-b5af-4b1fa704b80b','state changed','OS::TripleO::CephStorage::Net::SoftwareConfig',NULL,NULL),(111,'d1b26f0a-d067-4cba-bed8-1ab934c6bdca','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:45',NULL,'CREATE','IN_PROGRESS','InternalApiVirtualIP','overcloud-InternalApiVirtualIP-56f33gwn4ejf','state changed','OS::TripleO::Network::Ports::InternalApiVipPort',NULL,47),(112,'bb91ed08-bcaf-495b-b502-17cd5efd2238','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:45',NULL,'CREATE','IN_PROGRESS','StorageMgmtVirtualIP','overcloud-StorageMgmtVirtualIP-vul4q5kqyxct','state changed','OS::TripleO::Network::Ports::StorageMgmtVipPort',NULL,48),(113,'023aafc3-a884-4e9f-881a-fb77ab91883a','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:45',NULL,'CREATE','COMPLETE','CellControllerComputeNetworkConfig','8a8e5481-2b4e-4f39-b886-c5d215b79e7c','state changed','OS::TripleO::CellControllerCompute::Net::SoftwareConfig',NULL,NULL),(114,'ade79f48-8acd-454e-84cc-4df326dfd568','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:46',NULL,'CREATE','IN_PROGRESS','CellControllerNetworkConfig','overcloud-CellControllerNetworkConfig-pdis6ccya4hr','state changed','OS::TripleO::CellController::Net::SoftwareConfig',NULL,NULL),(115,'3313f7a4-7338-4c70-bd30-73dcd69deeb1','77037518-60bc-4d5b-8ae4-e5ba43d974da','2026-06-09 08:01:46',NULL,'CREATE','COMPLETE','overcloud-PublicVirtualIP-wbk3cp7mj63a','77037518-60bc-4d5b-8ae4-e5ba43d974da','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(116,'edda8fe2-d94c-4efc-8268-afca32e46a80','76bea45f-9eda-4aeb-ac6f-77d810796bcf','2026-06-09 08:01:46',NULL,'CREATE','IN_PROGRESS','overcloud-InternalApiVirtualIP-56f33gwn4ejf','76bea45f-9eda-4aeb-ac6f-77d810796bcf','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(117,'3319f817-10a3-4c90-9066-87ccbce89037','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:46',NULL,'CREATE','COMPLETE','CellControllerNetworkConfig','12c9c590-4317-495d-a8df-111f1ad75099','state changed','OS::TripleO::CellController::Net::SoftwareConfig',NULL,NULL),(118,'1c9ed2cd-466f-420c-907d-7ba70f1709cb','1d233aae-9792-4293-8063-2d840eb6d633','2026-06-09 08:01:46',NULL,'CREATE','IN_PROGRESS','overcloud-StorageMgmtVirtualIP-vul4q5kqyxct','1d233aae-9792-4293-8063-2d840eb6d633','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(119,'b3db1e24-4823-4976-b5e8-bd562fc462c4','76bea45f-9eda-4aeb-ac6f-77d810796bcf','2026-06-09 08:01:46',NULL,'CREATE','COMPLETE','overcloud-InternalApiVirtualIP-56f33gwn4ejf','76bea45f-9eda-4aeb-ac6f-77d810796bcf','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(120,'29916e10-6c2f-40a0-8eaa-7123d8f43082','1d233aae-9792-4293-8063-2d840eb6d633','2026-06-09 08:01:46',NULL,'CREATE','COMPLETE','overcloud-StorageMgmtVirtualIP-vul4q5kqyxct','1d233aae-9792-4293-8063-2d840eb6d633','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(121,'4e44a9ea-04e5-49c2-b60a-698328bd92e4','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:46',NULL,'CREATE','IN_PROGRESS','NetCidrMapValue','overcloud-NetCidrMapValue-uegrnnozaw6f','state changed','OS::Heat::Value',NULL,50),(122,'7497081a-0bfe-48ca-b144-4102bca15c5c','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:46',NULL,'CREATE','COMPLETE','NetCidrMapValue','overcloud-NetCidrMapValue-uegrnnozaw6f','state changed','OS::Heat::Value',NULL,50),(123,'80411499-3ce1-4fce-aba0-0cdc9f72b674','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:46',NULL,'CREATE','IN_PROGRESS','CellControllerComputeRoleUserData','overcloud-CellControllerComputeRoleUserData-plshn2yxmlr5','state changed','OS::TripleO::CellControllerCompute::NodeUserData',NULL,NULL),(124,'6cb52f49-4e78-41b6-a561-64461fe58d2d','8bee7a35-2d4d-481f-ab9a-5f024da98ac4','2026-06-09 08:01:46',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerComputeRoleUserData-plshn2yxmlr5','8bee7a35-2d4d-481f-ab9a-5f024da98ac4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(125,'eb311653-52d6-48c8-ad5b-6e8e964b703c','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:46',NULL,'CREATE','COMPLETE','NodeAdminUserData','81c78446-516c-420e-a6ac-0881ae738320','state changed','OS::TripleO::NodeAdminUserData',NULL,NULL),(126,'7a445c87-acf8-40c6-895f-7a7ec788d9b0','8bee7a35-2d4d-481f-ab9a-5f024da98ac4','2026-06-09 08:01:46',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-CellControllerComputeRoleUserData-plshn2yxmlr5-userdata-v6ikdbfpyjbf','state changed','OS::Heat::MultipartMime',NULL,NULL),(127,'5ed60f96-4306-4906-a44e-f042167151df','8bee7a35-2d4d-481f-ab9a-5f024da98ac4','2026-06-09 08:01:46',NULL,'CREATE','COMPLETE','userdata','43fe359f-3596-4463-8b31-9f328ee997cb','state changed','OS::Heat::MultipartMime',NULL,NULL),(128,'ecf5db61-748f-4744-804e-322a6c20060a','8bee7a35-2d4d-481f-ab9a-5f024da98ac4','2026-06-09 08:01:46',NULL,'CREATE','COMPLETE','overcloud-CellControllerComputeRoleUserData-plshn2yxmlr5','8bee7a35-2d4d-481f-ab9a-5f024da98ac4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(129,'8f15a8ae-44b4-4b08-a52a-d7abea3f32ef','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:46',NULL,'CREATE','COMPLETE','StorageVirtualIP','a7fea693-f109-4861-ad76-e85832c74aa6','state changed','OS::TripleO::Network::Ports::StorageVipPort',NULL,40),(130,'d15af07a-f360-42b3-88d9-294adf7611a4','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:47',NULL,'CREATE','COMPLETE','PublicVirtualIP','77037518-60bc-4d5b-8ae4-e5ba43d974da','state changed','OS::TripleO::Network::Ports::ExternalVipPort',NULL,41),(131,'62203b5c-7784-4849-a94c-db108008f7a5','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:47',NULL,'CREATE','COMPLETE','InternalApiVirtualIP','76bea45f-9eda-4aeb-ac6f-77d810796bcf','state changed','OS::TripleO::Network::Ports::InternalApiVipPort',NULL,47),(132,'525aa072-2ea4-4b90-98b4-602519cf0460','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:47',NULL,'CREATE','COMPLETE','StorageMgmtVirtualIP','1d233aae-9792-4293-8063-2d840eb6d633','state changed','OS::TripleO::Network::Ports::StorageMgmtVipPort',NULL,48),(133,'d1fab66f-c40b-4d01-a39e-411abe21f730','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:47',NULL,'CREATE','IN_PROGRESS','ControllerRoleUserData','overcloud-ControllerRoleUserData-b5r2mm4sgvr2','state changed','OS::TripleO::Controller::NodeUserData',NULL,NULL),(134,'89414fe1-8b08-4d43-82b4-26c8286819de','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:47',NULL,'CREATE','IN_PROGRESS','VipMap','overcloud-VipMap-ronvog7x7263','state changed','OS::TripleO::Network::Ports::NetVipMap',NULL,58),(135,'99db8de8-ce51-4877-baec-5d1d004affb0','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:47',NULL,'CREATE','COMPLETE','CellControllerComputeRoleUserData','8bee7a35-2d4d-481f-ab9a-5f024da98ac4','state changed','OS::TripleO::CellControllerCompute::NodeUserData',NULL,NULL),(136,'ef820f40-dabc-4f8d-b406-1db2d0f7195f','c10d5339-aef7-4d59-aae3-e8060e071522','2026-06-09 08:01:47',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerRoleUserData-b5r2mm4sgvr2','c10d5339-aef7-4d59-aae3-e8060e071522','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(137,'118432f4-15ce-40f9-a99d-a0c82df24116','79d5bfd4-91d1-4c95-9e69-18b1361bb101','2026-06-09 08:01:47',NULL,'CREATE','IN_PROGRESS','overcloud-VipMap-ronvog7x7263','79d5bfd4-91d1-4c95-9e69-18b1361bb101','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(138,'5f4c71fc-ede9-4b65-98b2-2505de970110','c10d5339-aef7-4d59-aae3-e8060e071522','2026-06-09 08:01:47',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-ControllerRoleUserData-b5r2mm4sgvr2-userdata-jjphpbwhriuq','state changed','OS::Heat::MultipartMime',NULL,NULL),(139,'fcb5ebdf-3774-44ff-80d0-b3ef8b0dd8de','c10d5339-aef7-4d59-aae3-e8060e071522','2026-06-09 08:01:47',NULL,'CREATE','COMPLETE','userdata','fb2cce07-1203-4ef7-89b3-bb3adc44ac34','state changed','OS::Heat::MultipartMime',NULL,NULL),(140,'aa66b84d-bab9-4270-a5b3-022ee0b8b68e','c10d5339-aef7-4d59-aae3-e8060e071522','2026-06-09 08:01:47',NULL,'CREATE','COMPLETE','overcloud-ControllerRoleUserData-b5r2mm4sgvr2','c10d5339-aef7-4d59-aae3-e8060e071522','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(141,'2dab6aac-03a7-4f23-9151-052ea784309a','79d5bfd4-91d1-4c95-9e69-18b1361bb101','2026-06-09 08:01:47',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-VipMap-ronvog7x7263-NetIpMapValue-oofnegpkxk6o','state changed','OS::Heat::Value',NULL,60),(142,'7ffde7f7-c90e-4479-bc1d-34bf9be3de02','79d5bfd4-91d1-4c95-9e69-18b1361bb101','2026-06-09 08:01:47',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-VipMap-ronvog7x7263-NetIpMapValue-oofnegpkxk6o','state changed','OS::Heat::Value',NULL,60),(143,'2cf43a7c-56f6-45b4-86c8-95c37178f695','79d5bfd4-91d1-4c95-9e69-18b1361bb101','2026-06-09 08:01:47',NULL,'CREATE','COMPLETE','overcloud-VipMap-ronvog7x7263','79d5bfd4-91d1-4c95-9e69-18b1361bb101','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(144,'525ec121-7e3c-4e6d-b89c-8a6d79975bb8','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:48',NULL,'CREATE','IN_PROGRESS','NodeUserData','overcloud-NodeUserData-ytixztea7fek','state changed','OS::TripleO::NodeUserData',NULL,NULL),(145,'407304ce-df7f-41e3-88d2-34e82379f8ef','b74f5ef1-47cf-472a-aea9-2cad1abb4552','2026-06-09 08:01:48',NULL,'CREATE','IN_PROGRESS','overcloud-NodeUserData-ytixztea7fek','b74f5ef1-47cf-472a-aea9-2cad1abb4552','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(146,'20faa29e-1ba0-434f-b7d0-b23fa5ac112a','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:48',NULL,'CREATE','COMPLETE','ControllerRoleUserData','c10d5339-aef7-4d59-aae3-e8060e071522','state changed','OS::TripleO::Controller::NodeUserData',NULL,NULL),(147,'7601e008-0442-4c62-b2a9-94b0bc2b136c','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:48',NULL,'CREATE','COMPLETE','VipMap','79d5bfd4-91d1-4c95-9e69-18b1361bb101','state changed','OS::TripleO::Network::Ports::NetVipMap',NULL,58),(148,'6d18cea0-3cbe-43ce-a472-3b4f04c1b7e5','b74f5ef1-47cf-472a-aea9-2cad1abb4552','2026-06-09 08:01:48',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-NodeUserData-ytixztea7fek-userdata-a63jqkjnjmoo','state changed','OS::Heat::MultipartMime',NULL,NULL),(149,'f669c0ab-5257-499d-a7ac-1ea79a1e2f6f','b74f5ef1-47cf-472a-aea9-2cad1abb4552','2026-06-09 08:01:48',NULL,'CREATE','COMPLETE','userdata','9be21182-8d4b-4419-a909-776986c880d2','state changed','OS::Heat::MultipartMime',NULL,NULL),(150,'0582eb39-042f-4021-b8b7-dc6e8dbc5d3e','b74f5ef1-47cf-472a-aea9-2cad1abb4552','2026-06-09 08:01:48',NULL,'CREATE','COMPLETE','overcloud-NodeUserData-ytixztea7fek','b74f5ef1-47cf-472a-aea9-2cad1abb4552','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(151,'70ce926a-165f-4e81-8e66-e6323122ba2b','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:48',NULL,'CREATE','IN_PROGRESS','EndpointMap','overcloud-EndpointMap-qhndgz6jd7al','state changed','OS::TripleO::EndpointMap',NULL,64),(152,'68907a81-aec5-4cdd-9318-b74695dcd682','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:48',NULL,'CREATE','IN_PROGRESS','VipHosts','overcloud-VipHosts-hjodvtitbzeg','state changed','OS::Heat::Value',NULL,65),(153,'2b13250d-edaf-47c0-80ac-2430e4db5b5c','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:48',NULL,'CREATE','COMPLETE','VipHosts','overcloud-VipHosts-hjodvtitbzeg','state changed','OS::Heat::Value',NULL,65),(154,'e70bfb6d-732d-49c8-bffd-758c7dbdb12b','a86c1f82-a8ed-4413-8163-a2d968a4c9e9','2026-06-09 08:01:48',NULL,'CREATE','IN_PROGRESS','overcloud-EndpointMap-qhndgz6jd7al','a86c1f82-a8ed-4413-8163-a2d968a4c9e9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(155,'d35eaa98-17d8-42d9-8b5a-7ccfad944fc3','a86c1f82-a8ed-4413-8163-a2d968a4c9e9','2026-06-09 08:01:48',NULL,'CREATE','COMPLETE','overcloud-EndpointMap-qhndgz6jd7al','a86c1f82-a8ed-4413-8163-a2d968a4c9e9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(156,'72dc68d7-76c1-4c24-8f8a-b2e3de02ff31','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:49',NULL,'CREATE','IN_PROGRESS','ObjectStorageRoleUserData','overcloud-ObjectStorageRoleUserData-ieknkugqsbmi','state changed','OS::TripleO::ObjectStorage::NodeUserData',NULL,NULL),(157,'2da9e9eb-1071-4355-b9cc-2a86b199b3ff','48f984e5-3e3a-4bc7-bd27-d19371cd62f5','2026-06-09 08:01:49',NULL,'CREATE','IN_PROGRESS','overcloud-ObjectStorageRoleUserData-ieknkugqsbmi','48f984e5-3e3a-4bc7-bd27-d19371cd62f5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(158,'89c90de8-9bf9-4eb9-8928-06fd01448005','48f984e5-3e3a-4bc7-bd27-d19371cd62f5','2026-06-09 08:01:49',NULL,'CREATE','IN_PROGRESS','userdata','overcloud-ObjectStorageRoleUserData-ieknkugqsbmi-userdata-crxhhp7xjkw7','state changed','OS::Heat::MultipartMime',NULL,NULL),(159,'347f0acf-2afc-4066-af57-4de87cf10cc5','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:49',NULL,'CREATE','COMPLETE','NodeUserData','b74f5ef1-47cf-472a-aea9-2cad1abb4552','state changed','OS::TripleO::NodeUserData',NULL,NULL),(160,'7e790784-4026-4e36-a1ee-d107e71b8aa7','48f984e5-3e3a-4bc7-bd27-d19371cd62f5','2026-06-09 08:01:49',NULL,'CREATE','COMPLETE','userdata','487326fe-ed47-478a-839b-4a28f207bb5c','state changed','OS::Heat::MultipartMime',NULL,NULL),(161,'b43904ef-32e7-43f7-b754-0d367e20ec18','48f984e5-3e3a-4bc7-bd27-d19371cd62f5','2026-06-09 08:01:49',NULL,'CREATE','COMPLETE','overcloud-ObjectStorageRoleUserData-ieknkugqsbmi','48f984e5-3e3a-4bc7-bd27-d19371cd62f5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(162,'869371fa-2d14-4842-b57a-9253564980d6','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:49',NULL,'CREATE','IN_PROGRESS','ControllerUserData','overcloud-ControllerUserData-n3jniaiskg4n','state changed','OS::Heat::MultipartMime',NULL,67),(163,'e981d6d5-7d06-4c41-928f-b1b87d1b36eb','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:49',NULL,'CREATE','IN_PROGRESS','CellControllerUserData','overcloud-CellControllerUserData-l3gbeojxkuwv','state changed','OS::Heat::MultipartMime',NULL,68),(164,'5906532f-afcd-4f9a-8bcc-2016fc49ccd2','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:49',NULL,'CREATE','IN_PROGRESS','NetworkerUserData','overcloud-NetworkerUserData-zytbr4qz2nfs','state changed','OS::Heat::MultipartMime',NULL,69),(165,'2464df90-f5ab-4e4a-a36f-924a3ecf5ff0','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:49',NULL,'CREATE','IN_PROGRESS','ComputeUserData','overcloud-ComputeUserData-tift2nwu3m6c','state changed','OS::Heat::MultipartMime',NULL,72),(166,'62d87da1-1d27-4769-8063-aa7a3c477ee6','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:49',NULL,'CREATE','COMPLETE','EndpointMap','a86c1f82-a8ed-4413-8163-a2d968a4c9e9','state changed','OS::TripleO::EndpointMap',NULL,64),(167,'e5d6ac81-e2e1-41bc-8fcc-a4f54700c9b1','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:49',NULL,'CREATE','IN_PROGRESS','CellControllerComputeUserData','overcloud-CellControllerComputeUserData-wt2lf2l4qnaa','state changed','OS::Heat::MultipartMime',NULL,71),(168,'5ff44a0f-304a-4626-8ddc-838ed9f5d35e','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:49',NULL,'CREATE','IN_PROGRESS','BlockStorageUserData','overcloud-BlockStorageUserData-tx3qfv7k6ik5','state changed','OS::Heat::MultipartMime',NULL,73),(169,'8c2b1ebc-5fdd-4d69-9698-47a5fd325b1f','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:49',NULL,'CREATE','IN_PROGRESS','CephStorageUserData','overcloud-CephStorageUserData-iawcqhxzqbo5','state changed','OS::Heat::MultipartMime',NULL,74),(170,'794edfce-18bb-43fc-b1ce-3efc062be07a','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:49',NULL,'CREATE','COMPLETE','CellControllerUserData','458f3087-e178-44ac-977c-99fa108e940d','state changed','OS::Heat::MultipartMime',NULL,68),(171,'805433a0-fc6f-4cc7-8675-b35a73f4e8fa','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:49',NULL,'CREATE','COMPLETE','ControllerUserData','b74197e3-9bcb-489a-b936-03e4334eb275','state changed','OS::Heat::MultipartMime',NULL,67),(172,'49c68614-5222-4571-9679-93f2752d2ece','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:49',NULL,'CREATE','COMPLETE','NetworkerUserData','20dfbe44-49f9-48fb-84f6-48a8291f818a','state changed','OS::Heat::MultipartMime',NULL,69),(173,'8375160a-748d-401f-87be-57ae31ec9418','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:50',NULL,'CREATE','COMPLETE','ComputeUserData','760f3ad1-1a88-4792-87fe-934d5912fd27','state changed','OS::Heat::MultipartMime',NULL,72),(174,'ce1cd95f-2a75-4ee6-b9cc-20f34a411374','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:50',NULL,'CREATE','COMPLETE','CephStorageUserData','a452b0af-124e-453d-809d-ad316c2c33ef','state changed','OS::Heat::MultipartMime',NULL,74),(175,'3e188f0f-29af-4e18-bbc1-f55cefdd5d1e','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:50',NULL,'CREATE','IN_PROGRESS','EndpointMapData','overcloud-EndpointMapData-mfju3gmu3h64','state changed','OS::Heat::Value',NULL,76),(176,'d931b88a-725b-4866-acd5-f6a68e390210','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:50',NULL,'CREATE','COMPLETE','CellControllerComputeUserData','1e6fa1d6-eb70-4c18-b931-de5f78ffed0d','state changed','OS::Heat::MultipartMime',NULL,71),(177,'e492668f-c10b-4ab1-bedf-d52883deff3a','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:50',NULL,'CREATE','COMPLETE','EndpointMapData','overcloud-EndpointMapData-mfju3gmu3h64','state changed','OS::Heat::Value',NULL,76),(178,'168f05dd-1f91-4e54-acb4-353d5f0e1963','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:50',NULL,'CREATE','COMPLETE','BlockStorageUserData','4f3ec13c-4a86-43df-9629-ada91c87ff68','state changed','OS::Heat::MultipartMime',NULL,73),(179,'044f2504-c074-427c-b9dd-f34ca2543a0a','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:50',NULL,'CREATE','IN_PROGRESS','CellControllerComputeServiceChain','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf','state changed','OS::TripleO::CellControllerComputeServices',NULL,77),(180,'94729464-4ad9-4da9-affd-8536e1ed8be5','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:50',NULL,'CREATE','COMPLETE','ObjectStorageRoleUserData','48f984e5-3e3a-4bc7-bd27-d19371cd62f5','state changed','OS::TripleO::ObjectStorage::NodeUserData',NULL,NULL),(181,'be887418-f81d-433f-b5e7-5fb490ed1647','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:50',NULL,'CREATE','IN_PROGRESS','ObjectStorageServiceChain','overcloud-ObjectStorageServiceChain-ratn4mpywxcl','state changed','OS::TripleO::ObjectStorageServices',NULL,78),(182,'18dab7d3-16c3-4614-9958-c5ccfe69256e','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:50',NULL,'CREATE','IN_PROGRESS','CellControllerServiceChain','overcloud-CellControllerServiceChain-7ualui2rffsh','state changed','OS::TripleO::CellControllerServices',NULL,79),(183,'0b70102d-737e-4332-9e0a-37a980b85ce8','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:50',NULL,'CREATE','IN_PROGRESS','ControllerServiceChain','overcloud-ControllerServiceChain-rvcxrx4tyxu2','state changed','OS::TripleO::ControllerServices',NULL,80),(184,'52ae0bd3-0966-4dd3-a43b-28d8b527cd10','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:50',NULL,'CREATE','IN_PROGRESS','BlockStorageServiceChain','overcloud-BlockStorageServiceChain-42trwkc5c77f','state changed','OS::TripleO::BlockStorageServices',NULL,81),(185,'31a48581-7da6-4d40-80cb-e620e86fa619','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:50',NULL,'CREATE','IN_PROGRESS','ComputeServiceChain','overcloud-ComputeServiceChain-xrxe3cz66s6g','state changed','OS::TripleO::ComputeServices',NULL,83),(186,'c6be0d45-fe62-42cf-bfbd-a216a34659c4','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:50',NULL,'CREATE','IN_PROGRESS','ObjectStorageUserData','overcloud-ObjectStorageUserData-f7ku5c3eig4h','state changed','OS::Heat::MultipartMime',NULL,84),(187,'0ede036e-2c4c-4046-a3c9-4483477cb216','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:50',NULL,'CREATE','IN_PROGRESS','overcloud-BlockStorageServiceChain-42trwkc5c77f','2470f591-2ecb-487b-872e-f3141cbae41e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(188,'d48b7aaf-9a8b-4fd2-aefe-123c93b78f41','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:50',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerServiceChain-7ualui2rffsh','bd6ed836-8c74-4942-b7b0-47ad18762295','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(189,'c078186d-264d-494b-aea5-0290d65b382e','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:50',NULL,'CREATE','IN_PROGRESS','overcloud-ObjectStorageServiceChain-ratn4mpywxcl','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(190,'45401f9f-abc5-42d9-9447-9e0c1ce8f674','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:50',NULL,'CREATE','IN_PROGRESS','CephStorageServiceChain','overcloud-CephStorageServiceChain-wa27clgf4qef','state changed','OS::TripleO::CephStorageServices',NULL,85),(191,'180b272e-0880-4932-a7a5-050af7a49109','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:51',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf','655485fd-051a-46e8-88c4-6a7f45ec9e83','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(192,'55067037-747c-4275-a09f-41dd09f1bd38','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:01:51',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g','5de0861a-4a69-4d7f-8b96-db5a25b8c838','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(193,'bfaa359b-d82a-40a6-abfd-d6fb570b4fb9','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:51',NULL,'CREATE','IN_PROGRESS','NetworkerServiceChain','overcloud-NetworkerServiceChain-6b74jmawyvfk','state changed','OS::TripleO::NetworkerServices',NULL,86),(194,'8a76c4fe-e1f4-4cc0-9d61-cafe00f5f72f','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:01:51',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2','14758e60-8013-4d42-8d8b-6640437712eb','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(195,'098d66bb-f8b9-409a-acfb-3e18ee097cf1','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:51',NULL,'CREATE','COMPLETE','ObjectStorageUserData','41a08d9f-6527-484f-bb04-498f0c2878a4','state changed','OS::Heat::MultipartMime',NULL,84),(196,'e38f87e1-dfee-4fd3-a719-de86c263c0dc','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:51',NULL,'CREATE','IN_PROGRESS','overcloud-CephStorageServiceChain-wa27clgf4qef','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(197,'8a2a06a2-0c61-4bcf-9cb6-be12150a0f3c','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:51',NULL,'CREATE','IN_PROGRESS','overcloud-NetworkerServiceChain-6b74jmawyvfk','64cedc04-99c8-452c-b61e-4a8873d9e5f7','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(198,'a94a6863-a8eb-4768-9197-d28eb8638828','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:51',NULL,'CREATE','IN_PROGRESS','ServiceChain','overcloud-CellControllerServiceChain-7ualui2rffsh-ServiceChain-prodfjl2fd3v','state changed','OS::Heat::ResourceChain',NULL,88),(199,'51beae60-bac3-41b8-95c2-a73924724887','521c8b0b-94be-4272-96b7-664c9314af45','2026-06-09 08:01:51',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerServiceChain-7ualui2rffsh-ServiceChain-prodfjl2fd3v','521c8b0b-94be-4272-96b7-664c9314af45','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(200,'7231dff7-f290-4b7f-bff4-c5fcb2c74498','521c8b0b-94be-4272-96b7-664c9314af45','2026-06-09 08:01:51',NULL,'CREATE','COMPLETE','overcloud-CellControllerServiceChain-7ualui2rffsh-ServiceChain-prodfjl2fd3v','521c8b0b-94be-4272-96b7-664c9314af45','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(201,'5693f440-c031-488f-a7f5-f4657b381b61','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:52',NULL,'CREATE','IN_PROGRESS','ServiceChain','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-ServiceChain-gouw5z6bocwl','state changed','OS::Heat::ResourceChain',NULL,89),(202,'86cc3cc3-4f9a-4776-9120-f86c2e76915e','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:52',NULL,'CREATE','IN_PROGRESS','ServiceChain','overcloud-BlockStorageServiceChain-42trwkc5c77f-ServiceChain-kd6xn2j3djht','state changed','OS::Heat::ResourceChain',NULL,90),(203,'e5ef757b-f88d-4558-8e7e-34d03dc4bc10','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:01:52',NULL,'CREATE','IN_PROGRESS','ServiceChain','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf','state changed','OS::Heat::ResourceChain',NULL,91),(204,'8a18b378-c6f4-4281-bb32-69a69edf91fc','a2a67fa4-00fb-4e46-9185-277453cb2997','2026-06-09 08:01:52',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-ServiceChain-gouw5z6bocwl','a2a67fa4-00fb-4e46-9185-277453cb2997','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(205,'877254fd-b69d-4968-b934-d91aa386a110','6642bc6a-4068-47a7-96f6-61195a13f851','2026-06-09 08:01:52',NULL,'CREATE','IN_PROGRESS','overcloud-BlockStorageServiceChain-42trwkc5c77f-ServiceChain-kd6xn2j3djht','6642bc6a-4068-47a7-96f6-61195a13f851','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(206,'e7ef1d4a-768e-429e-bebd-cad07049dcfe','a2a67fa4-00fb-4e46-9185-277453cb2997','2026-06-09 08:01:52',NULL,'CREATE','COMPLETE','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-ServiceChain-gouw5z6bocwl','a2a67fa4-00fb-4e46-9185-277453cb2997','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(207,'a3cf96de-ec9a-4504-8e41-cc09ef1c7885','6642bc6a-4068-47a7-96f6-61195a13f851','2026-06-09 08:01:52',NULL,'CREATE','COMPLETE','overcloud-BlockStorageServiceChain-42trwkc5c77f-ServiceChain-kd6xn2j3djht','6642bc6a-4068-47a7-96f6-61195a13f851','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(208,'af332b27-5600-44a8-b071-c7d01b025be7','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:52',NULL,'CREATE','IN_PROGRESS','ServiceChain','overcloud-NetworkerServiceChain-6b74jmawyvfk-ServiceChain-foqdgx46p2gm','state changed','OS::Heat::ResourceChain',NULL,92),(209,'4dd4400f-5280-44e5-be19-61f2a78dbd4d','67f4e6f9-50db-4470-b4de-cef0f0be71cb','2026-06-09 08:01:52',NULL,'CREATE','IN_PROGRESS','overcloud-NetworkerServiceChain-6b74jmawyvfk-ServiceChain-foqdgx46p2gm','67f4e6f9-50db-4470-b4de-cef0f0be71cb','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(210,'6a31b976-438d-4d1b-88b3-0a6446434741','67f4e6f9-50db-4470-b4de-cef0f0be71cb','2026-06-09 08:01:52',NULL,'CREATE','COMPLETE','overcloud-NetworkerServiceChain-6b74jmawyvfk-ServiceChain-foqdgx46p2gm','67f4e6f9-50db-4470-b4de-cef0f0be71cb','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(211,'9e7b0119-bf21-4aaa-a16e-225e5e7545f5','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:52',NULL,'CREATE','IN_PROGRESS','ServiceChain','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-ServiceChain-ics6tdrwd7kd','state changed','OS::Heat::ResourceChain',NULL,93),(212,'0c5b48f6-7796-4526-9997-df3fefbb8e26','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:01:52',NULL,'CREATE','IN_PROGRESS','ServiceChain','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy','state changed','OS::Heat::ResourceChain',NULL,94),(213,'36b47036-d39f-42bd-ba8a-98723776632f','c5ed80ae-2ce2-48a9-bbba-287b854732c8','2026-06-09 08:01:52',NULL,'CREATE','IN_PROGRESS','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-ServiceChain-ics6tdrwd7kd','c5ed80ae-2ce2-48a9-bbba-287b854732c8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(214,'1843c0cd-5566-44a1-b02d-4e763f5ef023','c5ed80ae-2ce2-48a9-bbba-287b854732c8','2026-06-09 08:01:52',NULL,'CREATE','COMPLETE','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-ServiceChain-ics6tdrwd7kd','c5ed80ae-2ce2-48a9-bbba-287b854732c8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(215,'8a918738-fe2d-4f66-b8ad-202aa22b1174','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:52',NULL,'CREATE','COMPLETE','ServiceChain','521c8b0b-94be-4272-96b7-664c9314af45','state changed','OS::Heat::ResourceChain',NULL,88),(216,'f90d7cbb-87e6-4575-af1a-4505e13077ca','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:52',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','overcloud-CellControllerServiceChain-7ualui2rffsh-AnsibleGroupVars-pfymgiej3qzb','state changed','OS::Heat::Value',NULL,95),(217,'19a17470-4915-4ae7-a803-8937c1da63bf','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:52',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','overcloud-CellControllerServiceChain-7ualui2rffsh-PostUpgradeTasks-ud5lt4fwupe5','state changed','OS::Heat::Value',NULL,96),(218,'de35d7dd-cb19-462c-a6a2-f7ee4d4965db','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:52',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','overcloud-CellControllerServiceChain-7ualui2rffsh-UpgradeTasks-apydny2org65','state changed','OS::Heat::Value',NULL,97),(219,'8ed41ef3-fbdb-470a-9b76-5411b8513646','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:52',NULL,'CREATE','COMPLETE','AnsibleGroupVars','overcloud-CellControllerServiceChain-7ualui2rffsh-AnsibleGroupVars-pfymgiej3qzb','state changed','OS::Heat::Value',NULL,95),(220,'c8da2a25-a366-4598-b7a1-25d4481449f6','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:52',NULL,'CREATE','COMPLETE','PostUpgradeTasks','overcloud-CellControllerServiceChain-7ualui2rffsh-PostUpgradeTasks-ud5lt4fwupe5','state changed','OS::Heat::Value',NULL,96),(221,'7394501e-bc49-4b33-8a2f-ab9de9db612d','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:52',NULL,'CREATE','COMPLETE','UpgradeTasks','overcloud-CellControllerServiceChain-7ualui2rffsh-UpgradeTasks-apydny2org65','state changed','OS::Heat::Value',NULL,97),(222,'11d7fe4d-fa4e-45e2-b469-4d5583ad576e','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:52',NULL,'CREATE','IN_PROGRESS','UpdateTasks','overcloud-CellControllerServiceChain-7ualui2rffsh-UpdateTasks-nzklnv3ppzss','state changed','OS::Heat::Value',NULL,98),(223,'50a66d26-3c6e-4676-bd4e-060847667f20','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:52',NULL,'CREATE','COMPLETE','UpdateTasks','overcloud-CellControllerServiceChain-7ualui2rffsh-UpdateTasks-nzklnv3ppzss','state changed','OS::Heat::Value',NULL,98),(224,'8f0035ee-1d24-4ede-8504-4bccfa74e16b','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:52',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','overcloud-CellControllerServiceChain-7ualui2rffsh-PreDeployStepTasks-herjedh5l6sx','state changed','OS::Heat::Value',NULL,99),(225,'ff926505-5ed7-4f60-a099-74c13e2a215f','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','KollaConfig','overcloud-CellControllerServiceChain-7ualui2rffsh-KollaConfig-l35hlorqndep','state changed','OS::Heat::Value',NULL,100),(226,'696d211e-e1ab-4858-886e-be5732f170a1','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','overcloud-CellControllerServiceChain-7ualui2rffsh-UpgradeBatchTasks-iowahoxw7xxb','state changed','OS::Heat::Value',NULL,101),(227,'a3626dd6-e5ae-41df-9c84-e138a3780c7b','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:53',NULL,'CREATE','COMPLETE','PreDeployStepTasks','overcloud-CellControllerServiceChain-7ualui2rffsh-PreDeployStepTasks-herjedh5l6sx','state changed','OS::Heat::Value',NULL,99),(228,'7aafb4c3-fe81-4828-9373-bdfdeca6e4b6','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:53',NULL,'CREATE','COMPLETE','KollaConfig','overcloud-CellControllerServiceChain-7ualui2rffsh-KollaConfig-l35hlorqndep','state changed','OS::Heat::Value',NULL,100),(229,'5c906ed8-5940-488c-8246-e90039315e7b','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','DockerConfig','overcloud-CellControllerServiceChain-7ualui2rffsh-DockerConfig-pzcs7v2uyut5','state changed','OS::Heat::Value',NULL,102),(230,'7abbac03-3f86-4cb4-9b29-5d9facb3684e','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:53',NULL,'CREATE','COMPLETE','DockerConfig','overcloud-CellControllerServiceChain-7ualui2rffsh-DockerConfig-pzcs7v2uyut5','state changed','OS::Heat::Value',NULL,102),(231,'7e72d5ac-85bb-4231-8c88-b8eb1f535676','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:53',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','overcloud-CellControllerServiceChain-7ualui2rffsh-UpgradeBatchTasks-iowahoxw7xxb','state changed','OS::Heat::Value',NULL,101),(232,'0856f031-1440-4e67-9f7a-aa0d92678438','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','overcloud-CellControllerServiceChain-7ualui2rffsh-ExternalDeployTasks-gvj7oqym4zqi','state changed','OS::Heat::Value',NULL,103),(233,'54018ec3-524f-47bc-8665-3aea3fac0733','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:53',NULL,'CREATE','COMPLETE','ExternalDeployTasks','overcloud-CellControllerServiceChain-7ualui2rffsh-ExternalDeployTasks-gvj7oqym4zqi','state changed','OS::Heat::Value',NULL,103),(234,'e218a476-6e9e-4273-923d-5254db7c6715','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','overcloud-CellControllerServiceChain-7ualui2rffsh-IpaRegistrationTasks-n2tjlg5qy3ty','state changed','OS::Heat::Value',NULL,104),(235,'b1e762de-4340-4024-9c58-37463733ab72','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','overcloud-CellControllerServiceChain-7ualui2rffsh-ContainerPuppetTasks-xbggoqel2fbh','state changed','OS::Heat::Value',NULL,105),(236,'01bdb87e-7be1-4013-83f4-47d8334ef0fa','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:53',NULL,'CREATE','COMPLETE','ServiceChain','a2a67fa4-00fb-4e46-9185-277453cb2997','state changed','OS::Heat::ResourceChain',NULL,89),(237,'b54996e3-8867-415f-a2be-fc1ececbeb84','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:53',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','overcloud-CellControllerServiceChain-7ualui2rffsh-IpaRegistrationTasks-n2tjlg5qy3ty','state changed','OS::Heat::Value',NULL,104),(238,'6771ef48-c6ed-4316-a75b-074865c882dc','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:53',NULL,'CREATE','COMPLETE','ServiceChain','6642bc6a-4068-47a7-96f6-61195a13f851','state changed','OS::Heat::ResourceChain',NULL,90),(239,'09bb0eff-0a5f-4c02-b5f1-ffb17e7bcbd3','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:53',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','overcloud-CellControllerServiceChain-7ualui2rffsh-ContainerPuppetTasks-xbggoqel2fbh','state changed','OS::Heat::Value',NULL,105),(240,'dd10d24f-900f-4a5b-bfb0-4703653b8fb3','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','overcloud-CellControllerServiceChain-7ualui2rffsh-ServiceServerMetadataHook-wigmkl5pe2cd','state changed','OS::TripleO::CellControllerServiceServerMetadataHook',NULL,106),(241,'9cf9d153-0010-40fc-b5ab-d6094427412a','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','overcloud-CellControllerServiceChain-7ualui2rffsh-PostUpdateTasks-qiac6k4pbr4y','state changed','OS::Heat::Value',NULL,107),(242,'47d556f3-5a84-4b20-8047-fcbcc4da29fa','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','overcloud-CellControllerServiceChain-7ualui2rffsh-PreUpgradeRollingTasks-cftkpsw2jtgk','state changed','OS::Heat::Value',NULL,108),(243,'6bd09397-9db8-4a9d-8c2b-283f455fdcff','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:53',NULL,'CREATE','COMPLETE','PostUpdateTasks','overcloud-CellControllerServiceChain-7ualui2rffsh-PostUpdateTasks-qiac6k4pbr4y','state changed','OS::Heat::Value',NULL,107),(244,'a503a023-5754-47e1-9259-7b8f25110722','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','overcloud-BlockStorageServiceChain-42trwkc5c77f-KeystoneResourcesConfigs-2tbi2s3g42ws','state changed','OS::Heat::Value',NULL,109),(245,'7e30e20f-e53a-46f1-a2ef-9b039e99ff33','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','overcloud-CellControllerServiceChain-7ualui2rffsh-ServiceConfigSettings-gxxtbma2z7ue','state changed','OS::Heat::Value',NULL,110),(246,'025d9e8a-6361-43d9-8353-a2558b48712c','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-AnsibleGroupVars-lbtex22xbz2e','state changed','OS::Heat::Value',NULL,111),(247,'d471c42c-007f-445d-a19b-09abdce7a7da','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:53',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','overcloud-BlockStorageServiceChain-42trwkc5c77f-KeystoneResourcesConfigs-2tbi2s3g42ws','state changed','OS::Heat::Value',NULL,109),(248,'0662f24c-b335-490d-a1c5-eecf857a8743','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:53',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','overcloud-CellControllerServiceChain-7ualui2rffsh-PreUpgradeRollingTasks-cftkpsw2jtgk','state changed','OS::Heat::Value',NULL,108),(249,'16de73fb-0c56-47a3-ac37-f4ded2d66bb4','952ec8fb-746e-4a07-ba18-6c3668ae84f9','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerServiceChain-7ualui2rffsh-ServiceServerMetadataHook-wigmkl5pe2cd','952ec8fb-746e-4a07-ba18-6c3668ae84f9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(250,'98f2c34b-2c24-473f-9cd0-472136a4028b','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-PostUpdateTasks-crdokbelhi6b','state changed','OS::Heat::Value',NULL,113),(251,'bda6b497-2e4c-430a-9bb7-1c65bbc678bc','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','overcloud-BlockStorageServiceChain-42trwkc5c77f-ExternalUpdateTasks-ivozzr7wppnp','state changed','OS::Heat::Value',NULL,114),(252,'33520dd6-1c27-4816-8b99-4ff9eda82ddb','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-PreUpgradeRollingTasks-n2mpdxj6p5o2','state changed','OS::Heat::Value',NULL,115),(253,'2e6d1b1c-0e2a-4bdb-bc8b-c33fe2d25d17','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:53',NULL,'CREATE','COMPLETE','ServiceConfigSettings','overcloud-CellControllerServiceChain-7ualui2rffsh-ServiceConfigSettings-gxxtbma2z7ue','state changed','OS::Heat::Value',NULL,110),(254,'1049656a-3262-4e89-8441-e0e4fd0e1322','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','overcloud-CellControllerServiceChain-7ualui2rffsh-DockerConfigScripts-decqmhibiubo','state changed','OS::Heat::Value',NULL,116),(255,'de793661-bd2e-4564-8926-101cf202f969','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:53',NULL,'CREATE','COMPLETE','AnsibleGroupVars','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-AnsibleGroupVars-lbtex22xbz2e','state changed','OS::Heat::Value',NULL,111),(256,'00a65db8-53aa-4417-9f2e-a692c63783b7','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','overcloud-BlockStorageServiceChain-42trwkc5c77f-UpgradeBatchTasks-sxkhf5yajxzr','state changed','OS::Heat::Value',NULL,118),(257,'458818c4-d5b4-4e7b-b278-41686d00fbcd','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-PuppetStepConfig-ggojkkqwlevj','state changed','OS::Heat::Value',NULL,119),(258,'97365a1b-3d59-4bdc-8502-153fc75caa2c','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','overcloud-BlockStorageServiceChain-42trwkc5c77f-ExternalUpgradeTasks-uo6hhwrkdu37','state changed','OS::Heat::Value',NULL,121),(259,'4c027f8f-99b6-42f0-b1ab-3b77b2bc5771','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:53',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','overcloud-BlockStorageServiceChain-42trwkc5c77f-ExternalUpdateTasks-ivozzr7wppnp','state changed','OS::Heat::Value',NULL,114),(260,'b077babd-89f6-4fab-9bf6-11c1f3ddee45','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:53',NULL,'CREATE','COMPLETE','PostUpdateTasks','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-PostUpdateTasks-crdokbelhi6b','state changed','OS::Heat::Value',NULL,113),(261,'51d62708-86fe-455a-8de1-c800beb19058','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','overcloud-CellControllerServiceChain-7ualui2rffsh-DeployStepsTasks-duumghcjpgh7','state changed','OS::Heat::Value',NULL,120),(262,'9f6ce3d7-2554-4935-ba54-89748a53f99e','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:53',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-PreUpgradeRollingTasks-n2mpdxj6p5o2','state changed','OS::Heat::Value',NULL,115),(263,'65b3cb31-693a-4a0b-8235-f283817f2802','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:53',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','overcloud-BlockStorageServiceChain-42trwkc5c77f-UpgradeBatchTasks-sxkhf5yajxzr','state changed','OS::Heat::Value',NULL,118),(264,'66f94cda-8cf3-4160-9bca-dfead3ce12c7','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:53',NULL,'CREATE','COMPLETE','DockerConfigScripts','overcloud-CellControllerServiceChain-7ualui2rffsh-DockerConfigScripts-decqmhibiubo','state changed','OS::Heat::Value',NULL,116),(265,'2a40e763-ba5a-461a-8217-d8c13e2263fb','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-ExternalUpdateTasks-2lcxtain5fgb','state changed','OS::Heat::Value',NULL,122),(266,'c7f43dbb-009f-4429-85a5-1bc1d80adc35','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:53',NULL,'CREATE','COMPLETE','PuppetStepConfig','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-PuppetStepConfig-ggojkkqwlevj','state changed','OS::Heat::Value',NULL,119),(267,'ab550915-9473-4c60-bf21-862b9f988052','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','overcloud-CellControllerServiceChain-7ualui2rffsh-PuppetStepConfig-ty4rg7gdypqa','state changed','OS::Heat::Value',NULL,125),(268,'dc898216-e933-42a5-8644-1bf5b306952e','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','overcloud-BlockStorageServiceChain-42trwkc5c77f-DockerPuppetTasks-hls7wi4ikjkf','state changed','OS::Heat::Value',NULL,128),(269,'33834de0-1173-4d59-a2b8-77a222459dea','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:53',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','overcloud-BlockStorageServiceChain-42trwkc5c77f-ExternalUpgradeTasks-uo6hhwrkdu37','state changed','OS::Heat::Value',NULL,121),(270,'fd8283e0-cc13-4194-b7ec-47accc074dc0','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','ServiceChain','overcloud-CephStorageServiceChain-wa27clgf4qef-ServiceChain-n2mppwtquf32','state changed','OS::Heat::ResourceChain',NULL,112),(271,'5781082b-d14c-40ef-8b9a-fe64bcf7abc7','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','ScaleTasks','overcloud-BlockStorageServiceChain-42trwkc5c77f-ScaleTasks-qrwi2qkkusao','state changed','OS::Heat::Value',NULL,127),(272,'81e24708-ac3a-4b50-aa60-9acb3a10c04e','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:53',NULL,'CREATE','COMPLETE','DeployStepsTasks','overcloud-CellControllerServiceChain-7ualui2rffsh-DeployStepsTasks-duumghcjpgh7','state changed','OS::Heat::Value',NULL,120),(273,'62ee6f59-517c-4853-97bd-961865db0eb2','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','overcloud-CellControllerServiceChain-7ualui2rffsh-ExternalUpdateTasks-vzzxqlq4isto','state changed','OS::Heat::Value',NULL,117),(274,'a4aea21b-b022-42ef-a9c3-72780537c860','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:53',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-ExternalUpdateTasks-2lcxtain5fgb','state changed','OS::Heat::Value',NULL,122),(275,'13acb813-d741-44ab-baf2-4c390ce28dc6','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-KeystoneResourcesConfigs-rv7echtqajuq','state changed','OS::Heat::Value',NULL,130),(276,'52565ac7-9fee-4123-817c-dcd32d2d5013','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:53',NULL,'CREATE','COMPLETE','DockerPuppetTasks','overcloud-BlockStorageServiceChain-42trwkc5c77f-DockerPuppetTasks-hls7wi4ikjkf','state changed','OS::Heat::Value',NULL,128),(277,'31b995f7-ff07-425a-8e8e-737d111b9d2a','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','DockerConfig','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-DockerConfig-gcpdxyjdo5rx','state changed','OS::Heat::Value',NULL,131),(278,'a5820090-82c7-48e7-98be-b63634ca72f2','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','overcloud-BlockStorageServiceChain-42trwkc5c77f-PreDeployStepTasks-uh47qhoge36q','state changed','OS::Heat::Value',NULL,133),(279,'8607c4f2-f633-4830-81a1-82234079f977','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:53',NULL,'CREATE','COMPLETE','ServiceChain','67f4e6f9-50db-4470-b4de-cef0f0be71cb','state changed','OS::Heat::ResourceChain',NULL,92),(280,'e17ad104-9cd8-467f-adb1-74a10629a917','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-HostFirewallTasks-4wa6nv3jlem6','state changed','OS::Heat::Value',NULL,132),(281,'fa71ec91-6bca-4571-a37d-2f8eab2be89d','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','FirewallRules','overcloud-CellControllerServiceChain-7ualui2rffsh-FirewallRules-s3a7zz3hjexe','state changed','OS::Heat::Value',NULL,123),(282,'2481f69f-1ad5-47e8-8442-043cff02e485','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','overcloud-CellControllerServiceChain-7ualui2rffsh-HostPrepTasks-nwu4hhn4ljej','state changed','OS::Heat::Value',NULL,124),(283,'e3e82573-a9a1-450a-91b9-f1cfedf0d54a','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','overcloud-CellControllerServiceChain-7ualui2rffsh-KeystoneResourcesConfigs-y7qosak4gmku','state changed','OS::Heat::Value',NULL,126),(284,'a74fbb3d-f4aa-47f4-a945-b9c7295b01b1','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:53',NULL,'CREATE','COMPLETE','ScaleTasks','overcloud-BlockStorageServiceChain-42trwkc5c77f-ScaleTasks-qrwi2qkkusao','state changed','OS::Heat::Value',NULL,127),(285,'eb1fc7a5-2b4c-48bf-bad8-3cb011a381b0','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','PuppetConfig','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-PuppetConfig-phz3gdruy7om','state changed','OS::Heat::Value',NULL,135),(286,'6af1e756-4b6e-49b7-8559-25cf26319010','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:53',NULL,'CREATE','COMPLETE','PuppetStepConfig','overcloud-CellControllerServiceChain-7ualui2rffsh-PuppetStepConfig-ty4rg7gdypqa','state changed','OS::Heat::Value',NULL,125),(287,'dfff2c99-e664-4536-ba8d-8d2f2a5f4547','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','overcloud-CellControllerServiceChain-7ualui2rffsh-ExternalUpgradeTasks-eh3prjnlpoq2','state changed','OS::Heat::Value',NULL,129),(288,'51aad463-25ec-43d8-b410-322b048b1cbb','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:53',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-KeystoneResourcesConfigs-rv7echtqajuq','state changed','OS::Heat::Value',NULL,130),(289,'fddb82e5-5ec1-4eec-a919-6272c64d3a1c','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','overcloud-CellControllerServiceChain-7ualui2rffsh-DockerPuppetTasks-poys5msffkpr','state changed','OS::Heat::Value',NULL,137),(290,'38a33e93-4afb-4d3a-9496-ec55f101e9b8','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:53',NULL,'CREATE','COMPLETE','HostFirewallTasks','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-HostFirewallTasks-4wa6nv3jlem6','state changed','OS::Heat::Value',NULL,132),(291,'c3403214-e206-4c54-ab25-f0197b754bf8','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','KollaConfig','overcloud-BlockStorageServiceChain-42trwkc5c77f-KollaConfig-v27wkkpzvaah','state changed','OS::Heat::Value',NULL,138),(292,'753c86da-91a4-4df5-913f-9c832f415db0','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:53',NULL,'CREATE','COMPLETE','DockerConfig','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-DockerConfig-gcpdxyjdo5rx','state changed','OS::Heat::Value',NULL,131),(293,'7b15f592-5436-451f-819a-ee7bb79e62af','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:53',NULL,'CREATE','COMPLETE','PreDeployStepTasks','overcloud-BlockStorageServiceChain-42trwkc5c77f-PreDeployStepTasks-uh47qhoge36q','state changed','OS::Heat::Value',NULL,133),(294,'e95e002f-6935-4a12-8924-fcda169fbc76','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:53',NULL,'CREATE','COMPLETE','PuppetConfig','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-PuppetConfig-phz3gdruy7om','state changed','OS::Heat::Value',NULL,135),(295,'31d01435-673c-47ae-a4fe-8876382482af','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-ServiceServerMetadataHook-aiakyl2teuck','state changed','OS::TripleO::CellControllerComputeServiceServerMetadataHook',NULL,140),(296,'45af6eb0-2b2d-4ee5-a8fc-1e276af83c1b','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-UpgradeTasks-ewnnqgqoxthm','state changed','OS::Heat::Value',NULL,141),(297,'73a56091-9424-49f0-a45d-da56c41d7396','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','PuppetConfig','overcloud-CellControllerServiceChain-7ualui2rffsh-PuppetConfig-etuff7bb5cii','state changed','OS::Heat::Value',NULL,143),(298,'8066ca35-9606-4bcf-bed2-8e0c1b95cd42','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:53',NULL,'CREATE','COMPLETE','ServiceChain','c5ed80ae-2ce2-48a9-bbba-287b854732c8','state changed','OS::Heat::ResourceChain',NULL,93),(299,'76b2d7da-ff1e-4725-9b51-6c3efb806941','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','ScaleTasks','overcloud-CellControllerServiceChain-7ualui2rffsh-ScaleTasks-5w3f2ls6qzoa','state changed','OS::Heat::Value',NULL,142),(300,'70421958-6844-4e04-bbba-16b4932e20a2','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:53',NULL,'CREATE','COMPLETE','KollaConfig','overcloud-BlockStorageServiceChain-42trwkc5c77f-KollaConfig-v27wkkpzvaah','state changed','OS::Heat::Value',NULL,138),(301,'bafd252f-f94d-4001-935a-418e5d4a536f','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:53',NULL,'CREATE','COMPLETE','DockerPuppetTasks','overcloud-CellControllerServiceChain-7ualui2rffsh-DockerPuppetTasks-poys5msffkpr','state changed','OS::Heat::Value',NULL,137),(302,'386a91be-a799-4118-b664-e3edfc9a0dd2','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-GlobalConfigSettings-4udqirxe3hph','state changed','OS::Heat::Value',NULL,144),(303,'9c02b7ac-7646-4c03-8c1a-c9e6ef98a21e','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','overcloud-BlockStorageServiceChain-42trwkc5c77f-PostUpdateTasks-vdp43a4dpqin','state changed','OS::Heat::Value',NULL,148),(304,'d8946df7-1e67-4b7e-b224-9711895c2807','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','overcloud-CellControllerServiceChain-7ualui2rffsh-GlobalConfigSettings-agcsg4qdkymy','state changed','OS::Heat::Value',NULL,134),(305,'dac2c279-290c-4379-aa2c-6aa5a4f17485','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','overcloud-CellControllerServiceChain-7ualui2rffsh-HostFirewallTasks-ew7i7del5amo','state changed','OS::Heat::Value',NULL,136),(306,'1d178e5f-e516-40f3-b1e1-2ec2d9b714b6','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:53',NULL,'CREATE','COMPLETE','UpgradeTasks','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-UpgradeTasks-ewnnqgqoxthm','state changed','OS::Heat::Value',NULL,141),(307,'0caa71ad-f195-4fa0-8d1e-e69e28b3a2a2','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','overcloud-CellControllerServiceChain-7ualui2rffsh-FirewallFrontendRules-25olvyizh2gw','state changed','OS::Heat::Value',NULL,149),(308,'3c29ae83-2aab-4b3e-9302-6cccb743dab1','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-DockerPuppetTasks-sshm5zioh7ux','state changed','OS::Heat::Value',NULL,151),(309,'a01a871a-6d8e-4b36-bc1c-23aa5001e6f4','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','ScaleTasks','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-ScaleTasks-rpbr4alwuw3u','state changed','OS::Heat::Value',NULL,139),(310,'e92986a5-b747-453f-9db8-0016913dbd3c','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:53',NULL,'CREATE','COMPLETE','ScaleTasks','overcloud-CellControllerServiceChain-7ualui2rffsh-ScaleTasks-5w3f2ls6qzoa','state changed','OS::Heat::Value',NULL,142),(311,'aebfae68-436c-4113-8172-e049a9a72d2b','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:53',NULL,'CREATE','COMPLETE','PuppetConfig','overcloud-CellControllerServiceChain-7ualui2rffsh-PuppetConfig-etuff7bb5cii','state changed','OS::Heat::Value',NULL,143),(312,'4ba9afa8-659a-4a28-a19c-060d2697e87f','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','FirewallRules','overcloud-BlockStorageServiceChain-42trwkc5c77f-FirewallRules-fzn3mgt2w2eq','state changed','OS::Heat::Value',NULL,152),(313,'23517621-0280-42d4-a776-4b41383a897c','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:53',NULL,'CREATE','COMPLETE','GlobalConfigSettings','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-GlobalConfigSettings-4udqirxe3hph','state changed','OS::Heat::Value',NULL,144),(314,'920a6f35-70f2-4795-bf32-cd6afe78df39','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:53',NULL,'CREATE','COMPLETE','PostUpdateTasks','overcloud-BlockStorageServiceChain-42trwkc5c77f-PostUpdateTasks-vdp43a4dpqin','state changed','OS::Heat::Value',NULL,148),(315,'37735b41-25bb-48bb-b40a-0ac241903dd6','952ec8fb-746e-4a07-ba18-6c3668ae84f9','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','IncomingMetadataSettings','overcloud-CellControllerServiceChain-7ualui2rffsh-ServiceServerMetadataHook-wigmkl5pe2cd-IncomingMetadataSettings-5fipghehl5p4','state changed','OS::Heat::Value',NULL,154),(316,'87cb6adc-2289-4329-b7f3-86eadd0ca04e','1f3875d6-1b70-4384-b85a-f9a242de6c1c','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-ServiceServerMetadataHook-aiakyl2teuck','1f3875d6-1b70-4384-b85a-f9a242de6c1c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(317,'cb19d592-2ec1-4c22-ab2a-1cdcbee90355','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','overcloud-BlockStorageServiceChain-42trwkc5c77f-ContainerPuppetTasks-7wdftm2telhi','state changed','OS::Heat::Value',NULL,153),(318,'1aebd7c4-aa58-4a60-ab42-00bd5871a552','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:53',NULL,'CREATE','COMPLETE','DockerPuppetTasks','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-DockerPuppetTasks-sshm5zioh7ux','state changed','OS::Heat::Value',NULL,151),(319,'a6045f33-0fb7-4384-a4b7-67e3849140cc','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','overcloud-CellControllerServiceChain-7ualui2rffsh-MonitoringSubscriptionsConfig-yo45ic42zxrm','state changed','OS::Heat::Value',NULL,146),(320,'2cb801c3-1f55-44a3-a34d-6604b10a2c40','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','UpdateTasks','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-UpdateTasks-ewlx4f2cwto2','state changed','OS::Heat::Value',NULL,155),(321,'9d2dfde0-fc71-4199-a2e6-91922f995ccb','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','ServiceNames','overcloud-CellControllerServiceChain-7ualui2rffsh-ServiceNames-vcfqs7cbrhyn','state changed','OS::Heat::Value',NULL,147),(322,'d53949f0-11c4-41ae-aa50-494266366d37','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','overcloud-CellControllerServiceChain-7ualui2rffsh-ExternalPostDeployTasks-boqwccouay3r','state changed','OS::Heat::Value',NULL,150),(323,'b6ff50d8-ad48-4184-8b09-7d41066c8836','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:53',NULL,'CREATE','COMPLETE','FirewallFrontendRules','overcloud-CellControllerServiceChain-7ualui2rffsh-FirewallFrontendRules-25olvyizh2gw','state changed','OS::Heat::Value',NULL,149),(324,'8407d1d4-f16e-434e-bbaa-58dbdf7b0fe3','bc819c66-005b-4a60-82a3-cac05a30c76e','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','overcloud-CephStorageServiceChain-wa27clgf4qef-ServiceChain-n2mppwtquf32','bc819c66-005b-4a60-82a3-cac05a30c76e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(325,'572d0af1-9175-4874-a720-bccec7604a52','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','overcloud-BlockStorageServiceChain-42trwkc5c77f-AnsibleGroupVars-npj7miwymiov','state changed','OS::Heat::Value',NULL,157),(326,'da77d341-a623-4654-8263-1d897f547567','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:53',NULL,'CREATE','COMPLETE','FirewallRules','overcloud-BlockStorageServiceChain-42trwkc5c77f-FirewallRules-fzn3mgt2w2eq','state changed','OS::Heat::Value',NULL,152),(327,'95baa940-1eb1-4deb-87ef-96d4192879e1','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-KeystoneResourcesConfigs-sl6hioop7t3l','state changed','OS::Heat::Value',NULL,159),(328,'f202fe5b-4190-42a1-99c6-eee692dbcaa1','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:53',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','overcloud-BlockStorageServiceChain-42trwkc5c77f-ContainerPuppetTasks-7wdftm2telhi','state changed','OS::Heat::Value',NULL,153),(329,'8d146314-5932-4934-8626-cd574987369f','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:53',NULL,'CREATE','IN_PROGRESS','KollaConfig','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-KollaConfig-s6tmkizuwy3a','state changed','OS::Heat::Value',NULL,158),(330,'76b2c36c-3f2b-4601-ab67-c25b4048671b','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','FirewallRules','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-FirewallRules-73vpkqvc6jks','state changed','OS::Heat::Value',NULL,160),(331,'b4c87723-ad6b-4284-a56a-8a8f335142a9','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','FirewallRules','overcloud-CellControllerServiceChain-7ualui2rffsh-FirewallRules-s3a7zz3hjexe','state changed','OS::Heat::Value',NULL,123),(332,'74bb0490-9dca-43a3-8bca-34787ab4d7e6','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','overcloud-CellControllerServiceChain-7ualui2rffsh-KeystoneResourcesConfigs-y7qosak4gmku','state changed','OS::Heat::Value',NULL,126),(333,'b07960dd-5706-4fc3-a249-9f7121f00b6c','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','UpdateTasks','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-UpdateTasks-ewlx4f2cwto2','state changed','OS::Heat::Value',NULL,155),(334,'17303cac-f435-402b-9254-0686bb7b880e','bc819c66-005b-4a60-82a3-cac05a30c76e','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','overcloud-CephStorageServiceChain-wa27clgf4qef-ServiceChain-n2mppwtquf32','bc819c66-005b-4a60-82a3-cac05a30c76e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(335,'5ba5ab20-b8ea-4592-a40d-1cd7277c97ff','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','overcloud-BlockStorageServiceChain-42trwkc5c77f-UpgradeTasks-qamhhg7dqcq6','state changed','OS::Heat::Value',NULL,163),(336,'cbb19566-a715-4801-b98a-10df2edbf365','952ec8fb-746e-4a07-ba18-6c3668ae84f9','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','IncomingMetadataSettings','overcloud-CellControllerServiceChain-7ualui2rffsh-ServiceServerMetadataHook-wigmkl5pe2cd-IncomingMetadataSettings-5fipghehl5p4','state changed','OS::Heat::Value',NULL,154),(337,'50b4f766-43c0-4b3b-9f21-e033a4f67330','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','overcloud-CellControllerServiceChain-7ualui2rffsh-ExternalUpgradeTasks-eh3prjnlpoq2','state changed','OS::Heat::Value',NULL,129),(338,'c1430fd5-666b-44ea-b742-2f8bbc241e43','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-KeystoneResourcesConfigs-sl6hioop7t3l','state changed','OS::Heat::Value',NULL,159),(339,'40580657-3ab9-420f-a1d2-4ee184038fb5','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','AnsibleGroupVars','overcloud-BlockStorageServiceChain-42trwkc5c77f-AnsibleGroupVars-npj7miwymiov','state changed','OS::Heat::Value',NULL,157),(340,'89790733-b42b-46f5-8a60-e593cdaa0286','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','HostPrepTasks','overcloud-CellControllerServiceChain-7ualui2rffsh-HostPrepTasks-nwu4hhn4ljej','state changed','OS::Heat::Value',NULL,124),(341,'36f5ee90-6d5a-40f0-8e83-504e3ca579e1','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','overcloud-NetworkerServiceChain-6b74jmawyvfk-ExternalUpgradeTasks-7tjmun2ivlla','state changed','OS::Heat::Value',NULL,166),(342,'28c46ec8-77cc-4332-9300-16be221c08a6','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','FirewallRules','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-FirewallRules-73vpkqvc6jks','state changed','OS::Heat::Value',NULL,160),(343,'8d70dc39-80cc-4b8d-99b5-729f9209206c','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','ServiceNames','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-ServiceNames-2uqwshkd6hd6','state changed','OS::Heat::Value',NULL,164),(344,'5e0f4afa-17cd-4cfa-855d-f9a207956c88','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','overcloud-CellControllerServiceChain-7ualui2rffsh-ExternalUpdateTasks-vzzxqlq4isto','state changed','OS::Heat::Value',NULL,117),(345,'b30f1d6a-9501-4f70-9f7d-80e3f2fa92ec','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','overcloud-BlockStorageServiceChain-42trwkc5c77f-DeployStepsTasks-xrf4xyuzrbql','state changed','OS::Heat::Value',NULL,156),(346,'82b81fa1-dc24-457a-ac12-a61a27ee0ebf','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-HostFirewallTasks-sm7aipoif7d6','state changed','OS::Heat::Value',NULL,168),(347,'101434a1-e5df-4369-8848-7a996826dd2d','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','UpgradeTasks','overcloud-BlockStorageServiceChain-42trwkc5c77f-UpgradeTasks-qamhhg7dqcq6','state changed','OS::Heat::Value',NULL,163),(348,'9ec089d7-fdbd-4f7d-910f-e9ed7d55252e','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','overcloud-BlockStorageServiceChain-42trwkc5c77f-GlobalConfigSettings-vtfbj4dpsxuk','state changed','OS::Heat::Value',NULL,167),(349,'fcd05e3a-4a21-4caa-a10a-2e7a1ccb38b7','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','KollaConfig','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-KollaConfig-s6tmkizuwy3a','state changed','OS::Heat::Value',NULL,158),(350,'ef3b24a3-977e-4e41-af4b-d90a2ba7b361','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','PuppetConfig','overcloud-NetworkerServiceChain-6b74jmawyvfk-PuppetConfig-3775qtqpwjsg','state changed','OS::Heat::Value',NULL,171),(351,'f9c810d3-2d7c-4ee3-b0f1-f15c01244cbd','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','overcloud-NetworkerServiceChain-6b74jmawyvfk-GlobalConfigSettings-obehmmmx2brs','state changed','OS::Heat::Value',NULL,170),(352,'c2de1e04-9cc2-4d40-bce4-843051f8fb30','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','HostFirewallTasks','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-HostFirewallTasks-sm7aipoif7d6','state changed','OS::Heat::Value',NULL,168),(353,'648408ef-8563-41d7-83a5-a0dbc6b5863b','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-FirewallFrontendRules-so37p77lr6da','state changed','OS::Heat::Value',NULL,172),(354,'f9f3df92-352a-4f76-81d0-52f7332d6090','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','overcloud-BlockStorageServiceChain-42trwkc5c77f-PreUpgradeRollingTasks-6hrzxwwy67gk','state changed','OS::Heat::Value',NULL,173),(355,'7ad50343-740d-40fa-b3b8-675e055ae850','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','overcloud-BlockStorageServiceChain-42trwkc5c77f-HostFirewallTasks-erouhefquute','state changed','OS::Heat::Value',NULL,161),(356,'545f0a1b-178a-4bee-ba74-473671a1d2b2','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','overcloud-NetworkerServiceChain-6b74jmawyvfk-ExternalUpgradeTasks-7tjmun2ivlla','state changed','OS::Heat::Value',NULL,166),(357,'76389dc2-0592-4e55-a141-b94755f72232','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','PuppetConfig','overcloud-NetworkerServiceChain-6b74jmawyvfk-PuppetConfig-3775qtqpwjsg','state changed','OS::Heat::Value',NULL,171),(358,'0060ed62-7139-4e06-aead-32b2ae59205e','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-PostUpgradeTasks-visngvxy6vdz','state changed','OS::Heat::Value',NULL,174),(359,'9d6ea9a4-0c96-45ff-9b48-dec1317b7977','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','overcloud-BlockStorageServiceChain-42trwkc5c77f-ExternalDeployTasks-wbkkrkzw2het','state changed','OS::Heat::Value',NULL,177),(360,'d63269ea-013d-4551-8350-4db67058b1be','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','ServiceNames','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-ServiceNames-2uqwshkd6hd6','state changed','OS::Heat::Value',NULL,164),(361,'0799a308-e01f-4421-9f92-1fa23026215c','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-PreDeployStepTasks-fneb3yvvymkm','state changed','OS::Heat::Value',NULL,175),(362,'1bc31d6f-088f-4544-9676-a9cf4fa8777c','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-ExternalPostDeployTasks-lrjbfpb5zxwl','state changed','OS::Heat::Value',NULL,162),(363,'a6eb0fa7-5ce6-40c9-9f49-38cf072dda3d','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','GlobalConfigSettings','overcloud-BlockStorageServiceChain-42trwkc5c77f-GlobalConfigSettings-vtfbj4dpsxuk','state changed','OS::Heat::Value',NULL,167),(364,'77934059-280d-4715-93a8-227d774e768c','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','overcloud-BlockStorageServiceChain-42trwkc5c77f-PreUpgradeRollingTasks-6hrzxwwy67gk','state changed','OS::Heat::Value',NULL,173),(365,'3836b3d8-4514-43e6-b2e6-602b4e3e0109','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','HostFirewallTasks','overcloud-CellControllerServiceChain-7ualui2rffsh-HostFirewallTasks-ew7i7del5amo','state changed','OS::Heat::Value',NULL,136),(366,'4c9f9ac2-a9e2-4af6-8999-108c6c7b67f7','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','overcloud-NetworkerServiceChain-6b74jmawyvfk-DockerConfigScripts-z52k7e5fsbbp','state changed','OS::Heat::Value',NULL,178),(367,'80333f84-47b1-4a6b-8278-e4ce5533094c','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-ServiceServerMetadataHook-oosig2olyexo','state changed','OS::TripleO::ObjectStorageServiceServerMetadataHook',NULL,181),(368,'1a3d3f1b-f48b-4258-9cea-f32f653f41be','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','ExternalDeployTasks','overcloud-BlockStorageServiceChain-42trwkc5c77f-ExternalDeployTasks-wbkkrkzw2het','state changed','OS::Heat::Value',NULL,177),(369,'25c84ba4-338f-48ee-84fc-162e82c40741','76704e88-86e6-482c-bf6c-6e25173f798c','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy','76704e88-86e6-482c-bf6c-6e25173f798c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(370,'4ea32064-8bc8-43cd-99ab-9020ca6b215e','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-ExternalUpgradeTasks-vc72zxsmzctc','state changed','OS::Heat::Value',NULL,165),(371,'e4a6319a-60e4-400c-a460-04d3638f1d92','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-GlobalConfigSettings-rvtbyk2xudsn','state changed','OS::Heat::Value',NULL,183),(372,'47e69e21-7d04-4804-a00c-9b248e94eb4c','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-ServiceConfigSettings-3mlesnol4764','state changed','OS::Heat::Value',NULL,179),(373,'80525bef-9d3d-4e35-b22f-d7e9ebd27a6b','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','UpdateTasks','overcloud-BlockStorageServiceChain-42trwkc5c77f-UpdateTasks-gefxo2cpzjbc','state changed','OS::Heat::Value',NULL,169),(374,'3c30abf7-7596-4549-94d9-31fa44cb5032','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','FirewallFrontendRules','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-FirewallFrontendRules-so37p77lr6da','state changed','OS::Heat::Value',NULL,172),(375,'31ff8e3e-c654-4b42-a60a-c634419bd0df','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','PreDeployStepTasks','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-PreDeployStepTasks-fneb3yvvymkm','state changed','OS::Heat::Value',NULL,175),(376,'b62d70ca-9e17-45a9-9154-1e343ee31d40','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','GlobalConfigSettings','overcloud-NetworkerServiceChain-6b74jmawyvfk-GlobalConfigSettings-obehmmmx2brs','state changed','OS::Heat::Value',NULL,170),(377,'9d083bf9-1523-4b46-b29e-ffb67b8b109a','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-ExternalUpgradeTasks-dlb676hc6dwv','state changed','OS::Heat::Value',NULL,188),(378,'5380fc3f-b478-48b7-9650-1010939104b0','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','GlobalConfigSettings','overcloud-CellControllerServiceChain-7ualui2rffsh-GlobalConfigSettings-agcsg4qdkymy','state changed','OS::Heat::Value',NULL,134),(379,'bf480698-ff14-432d-8070-69e17afa180f','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','overcloud-BlockStorageServiceChain-42trwkc5c77f-ServiceConfigSettings-5wlxec3rl6py','state changed','OS::Heat::Value',NULL,184),(380,'2da91386-8b1e-442a-af56-042c6aed2caa','952ec8fb-746e-4a07-ba18-6c3668ae84f9','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','IndividualServices','overcloud-CellControllerServiceChain-7ualui2rffsh-ServiceServerMetadataHook-wigmkl5pe2cd-IndividualServices-s4wbpdme2h36','state changed','OS::Heat::Value',NULL,186),(381,'4a006d99-34e9-4cba-8918-ee60fa29854a','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-ExternalDeployTasks-fm2zymzpvrbs','state changed','OS::Heat::Value',NULL,187),(382,'a852db96-8085-4f82-b9e5-f4baaf6e308c','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','GlobalConfigSettings','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-GlobalConfigSettings-rvtbyk2xudsn','state changed','OS::Heat::Value',NULL,183),(383,'465908a4-8a88-4725-9ceb-016f4f217dfa','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','overcloud-CellControllerServiceChain-7ualui2rffsh-MonitoringSubscriptionsConfig-yo45ic42zxrm','state changed','OS::Heat::Value',NULL,146),(384,'ea134f66-587d-4974-9293-de9228e73c0d','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','overcloud-BlockStorageServiceChain-42trwkc5c77f-DockerConfigScripts-otpig4yxsxss','state changed','OS::Heat::Value',NULL,192),(385,'44a00c69-3ea1-4032-abcc-52a9c036acd8','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','PostUpgradeTasks','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-PostUpgradeTasks-visngvxy6vdz','state changed','OS::Heat::Value',NULL,174),(386,'84511033-6eb2-473a-a616-80baed69e63e','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-ExternalUpgradeTasks-dlb676hc6dwv','state changed','OS::Heat::Value',NULL,188),(387,'a437b552-5644-4bc5-b3f7-836f220a6a35','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','DockerConfigScripts','overcloud-NetworkerServiceChain-6b74jmawyvfk-DockerConfigScripts-z52k7e5fsbbp','state changed','OS::Heat::Value',NULL,178),(388,'6eec65e0-5355-4966-b5e2-0698a0a81522','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','overcloud-BlockStorageServiceChain-42trwkc5c77f-ExternalPostDeployTasks-r74isao22b5c','state changed','OS::Heat::Value',NULL,189),(389,'7a11fcc8-f745-41f1-9823-3ca792764fd1','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','ScaleTasks','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-ScaleTasks-rpbr4alwuw3u','state changed','OS::Heat::Value',NULL,139),(390,'14e20c1a-7f44-4be4-b7e8-7fc301d62241','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','overcloud-BlockStorageServiceChain-42trwkc5c77f-PostUpgradeTasks-h2uwhkbhwye6','state changed','OS::Heat::Value',NULL,190),(391,'917092ac-150a-41c6-a99a-b450f7beb704','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','DockerConfigScripts','overcloud-BlockStorageServiceChain-42trwkc5c77f-DockerConfigScripts-otpig4yxsxss','state changed','OS::Heat::Value',NULL,192),(392,'ba3b109f-46f9-42fd-a8d9-9fabd72a333e','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-PuppetStepConfig-rjazyu5k6uj3','state changed','OS::Heat::Value',NULL,176),(393,'25f41cd2-af7c-4b03-9a58-23d5696d29f6','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','KollaConfig','overcloud-NetworkerServiceChain-6b74jmawyvfk-KollaConfig-adelgh4hdwql','state changed','OS::Heat::Value',NULL,195),(394,'64eec48a-cf58-4acf-afde-cd84d5db698c','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-HostPrepTasks-anc3kj6lq2hv','state changed','OS::Heat::Value',NULL,194),(395,'f7c8bf3d-bf99-46e7-98d9-d6043950f516','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','overcloud-BlockStorageServiceChain-42trwkc5c77f-FirewallFrontendRules-gdrezgsx345i','state changed','OS::Heat::Value',NULL,199),(396,'70200ea8-61dc-4b22-b8d7-378abde6ed6d','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','ServiceConfigSettings','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-ServiceConfigSettings-3mlesnol4764','state changed','OS::Heat::Value',NULL,179),(397,'fca53383-d775-4694-9046-70e10c8b4385','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','KollaConfig','overcloud-NetworkerServiceChain-6b74jmawyvfk-KollaConfig-adelgh4hdwql','state changed','OS::Heat::Value',NULL,195),(398,'47631747-98ba-4d13-8217-618b55d75b8d','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','overcloud-BlockStorageServiceChain-42trwkc5c77f-PuppetStepConfig-l4g2l6f5rbj2','state changed','OS::Heat::Value',NULL,182),(399,'e3428950-6a43-490e-8d72-f2b3f04a18e4','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','ServiceConfigSettings','overcloud-BlockStorageServiceChain-42trwkc5c77f-ServiceConfigSettings-5wlxec3rl6py','state changed','OS::Heat::Value',NULL,184),(400,'50a4d01a-4819-45c9-b942-ee53275117d0','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','ExternalDeployTasks','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-ExternalDeployTasks-fm2zymzpvrbs','state changed','OS::Heat::Value',NULL,187),(401,'02217d84-86f1-4e6e-b442-82e0000a0930','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','FirewallFrontendRules','overcloud-BlockStorageServiceChain-42trwkc5c77f-FirewallFrontendRules-gdrezgsx345i','state changed','OS::Heat::Value',NULL,199),(402,'5d4318f1-24a4-419c-b6d3-65577b255609','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-ServiceConfigSettings-phscsivhm5mi','state changed','OS::Heat::Value',NULL,193),(403,'0ea2a893-45bf-4cc2-bccd-3a6eb5b16ad1','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','overcloud-BlockStorageServiceChain-42trwkc5c77f-IpaRegistrationTasks-26i4ifkbxx4l','state changed','OS::Heat::Value',NULL,197),(404,'1e1347dc-94a9-4dcd-9c9e-3b72ace997d2','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','PostUpgradeTasks','overcloud-BlockStorageServiceChain-42trwkc5c77f-PostUpgradeTasks-h2uwhkbhwye6','state changed','OS::Heat::Value',NULL,190),(405,'bb5e23a0-dee6-4ac8-94e9-7fbeff3e6435','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','overcloud-NetworkerServiceChain-6b74jmawyvfk-PreUpgradeRollingTasks-pk7vwkyo5vvl','state changed','OS::Heat::Value',NULL,198),(406,'0d2e52e9-07ff-4e29-a0bd-2506716ad73b','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','ScaleTasks','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-ScaleTasks-3eiszypizt3n','state changed','OS::Heat::Value',NULL,200),(407,'51c04009-6724-4fa0-af8e-ba53cb7890e9','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','overcloud-NetworkerServiceChain-6b74jmawyvfk-PreDeployStepTasks-ex5tdct2axdv','state changed','OS::Heat::Value',NULL,205),(408,'54d80ceb-53ad-4f2f-ab07-138dc1460994','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-MonitoringSubscriptionsConfig-g6prfdjz3cqe','state changed','OS::Heat::Value',NULL,202),(409,'504b69d7-ce89-4d88-a369-dffc8b3b55ba','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','HostPrepTasks','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-HostPrepTasks-anc3kj6lq2hv','state changed','OS::Heat::Value',NULL,194),(410,'7d6611bb-9c3f-47df-afde-d75d50df0207','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','PreDeployStepTasks','overcloud-NetworkerServiceChain-6b74jmawyvfk-PreDeployStepTasks-ex5tdct2axdv','state changed','OS::Heat::Value',NULL,205),(411,'89b5c41b-89da-4571-8c06-9b1ee415709d','952ec8fb-746e-4a07-ba18-6c3668ae84f9','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','IndividualServices','overcloud-CellControllerServiceChain-7ualui2rffsh-ServiceServerMetadataHook-wigmkl5pe2cd-IndividualServices-s4wbpdme2h36','state changed','OS::Heat::Value',NULL,186),(412,'05126522-43ff-4d32-b0e0-7082f125bccf','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-AnsibleGroupVars-zdilzsby5tkl','state changed','OS::Heat::Value',NULL,208),(413,'333f5c27-414e-4bba-bdaf-43cf0e1d6b2f','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','overcloud-CellControllerServiceChain-7ualui2rffsh-ExternalPostDeployTasks-boqwccouay3r','state changed','OS::Heat::Value',NULL,150),(414,'e457b1dc-37c8-4866-b577-c47cad1d3825','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','DeployStepsTasks','overcloud-BlockStorageServiceChain-42trwkc5c77f-DeployStepsTasks-xrf4xyuzrbql','state changed','OS::Heat::Value',NULL,156),(415,'ac2ea25d-57b5-49a7-850d-885f6585ed04','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','DockerConfig','overcloud-BlockStorageServiceChain-42trwkc5c77f-DockerConfig-ics74ehuxlu2','state changed','OS::Heat::Value',NULL,185),(416,'1bdd4c1c-9855-4473-b1ec-a71f0d8535a9','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','overcloud-BlockStorageServiceChain-42trwkc5c77f-IpaRegistrationTasks-26i4ifkbxx4l','state changed','OS::Heat::Value',NULL,197),(417,'7672b92e-c7fb-45e9-8fc6-86631dadd6a5','1f3875d6-1b70-4384-b85a-f9a242de6c1c','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','IncomingMetadataSettings','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-ServiceServerMetadataHook-aiakyl2teuck-IncomingMetadataSettings-qi77cbzdiunp','state changed','OS::Heat::Value',NULL,209),(418,'4f46ca96-6257-4f62-92db-e9f3722ffc90','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','ServiceNames','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-ServiceNames-idtjur7p67mt','state changed','OS::Heat::Value',NULL,204),(419,'e1f8ba69-58ea-4369-8f15-66ca5198f92d','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','overcloud-BlockStorageServiceChain-42trwkc5c77f-ExternalPostDeployTasks-r74isao22b5c','state changed','OS::Heat::Value',NULL,189),(420,'48be7f8c-1300-4dbe-9c84-2ce4d15b61f8','1f3875d6-1b70-4384-b85a-f9a242de6c1c','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','IncomingMetadataSettings','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-ServiceServerMetadataHook-aiakyl2teuck-IncomingMetadataSettings-qi77cbzdiunp','state changed','OS::Heat::Value',NULL,209),(421,'d3147a6d-ba45-406f-84c8-2e1448ed8ac1','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','ServiceNames','overcloud-CellControllerServiceChain-7ualui2rffsh-ServiceNames-vcfqs7cbrhyn','state changed','OS::Heat::Value',NULL,147),(422,'4fad6210-dcf0-406e-9f34-e4d1ee520a70','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-MonitoringSubscriptionsConfig-g6prfdjz3cqe','state changed','OS::Heat::Value',NULL,202),(423,'e392f7ac-addd-468b-86d1-86e781c4d7d3','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-MonitoringSubscriptionsConfig-rakq34qhghb6','state changed','OS::Heat::Value',NULL,191),(424,'4a1d9b9e-45d7-466d-bb57-d0f621779a87','1f3875d6-1b70-4384-b85a-f9a242de6c1c','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','CompactServices','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-ServiceServerMetadataHook-aiakyl2teuck-CompactServices-x3rhlzuvdkei','state changed','OS::Heat::Value',NULL,213),(425,'c93b9361-391d-4ea4-8690-215244a2154a','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-UpgradeBatchTasks-gjj4rr3clq4q','state changed','OS::Heat::Value',NULL,212),(426,'d3e41557-5a5a-479f-a796-57def6221180','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','ServiceChain','bc819c66-005b-4a60-82a3-cac05a30c76e','state changed','OS::Heat::ResourceChain',NULL,112),(427,'3bd58f3a-2a33-4cf5-8f4a-99d6335fd91f','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','ServiceConfigSettings','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-ServiceConfigSettings-phscsivhm5mi','state changed','OS::Heat::Value',NULL,193),(428,'734e2f01-07b8-4b84-8fa8-a54a798c5cac','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','AnsibleGroupVars','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-AnsibleGroupVars-zdilzsby5tkl','state changed','OS::Heat::Value',NULL,208),(429,'3357e4cf-5ba7-4a18-b124-624a45e03080','1f3875d6-1b70-4384-b85a-f9a242de6c1c','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','CompactServices','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-ServiceServerMetadataHook-aiakyl2teuck-CompactServices-x3rhlzuvdkei','state changed','OS::Heat::Value',NULL,213),(430,'26270bc9-d33e-4df2-9c53-a0ff62ee44bb','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','overcloud-NetworkerServiceChain-6b74jmawyvfk-IpaRegistrationTasks-onpsub73dehz','state changed','OS::Heat::Value',NULL,216),(431,'0a6f3e6f-e436-4579-ac8f-6dfb355ed580','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','ServiceNames','overcloud-BlockStorageServiceChain-42trwkc5c77f-ServiceNames-t5f4ni3n5sil','state changed','OS::Heat::Value',NULL,210),(432,'536f78d2-a8c0-4ced-9a1a-ec3a130c2aa2','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','ScaleTasks','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-ScaleTasks-3eiszypizt3n','state changed','OS::Heat::Value',NULL,200),(433,'3fbe3202-ec89-4f3c-940e-3b3ccead2505','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-UpgradeBatchTasks-gjj4rr3clq4q','state changed','OS::Heat::Value',NULL,212),(434,'dedfb4e9-d93c-45f9-a0ff-461739c645d7','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','ServiceNames','overcloud-NetworkerServiceChain-6b74jmawyvfk-ServiceNames-o4gflexqmolu','state changed','OS::Heat::Value',NULL,219),(435,'a4b2684d-733d-44f0-94ed-39ec31863bac','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-IpaRegistrationTasks-5zhqk6qyhjkn','state changed','OS::Heat::Value',NULL,220),(436,'7528afbf-bd4a-4325-9b03-f18689025a1b','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','overcloud-NetworkerServiceChain-6b74jmawyvfk-IpaRegistrationTasks-onpsub73dehz','state changed','OS::Heat::Value',NULL,216),(437,'5606ab04-5f3e-4b8d-b702-643a27a6f7c3','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','overcloud-NetworkerServiceChain-6b74jmawyvfk-PreUpgradeRollingTasks-pk7vwkyo5vvl','state changed','OS::Heat::Value',NULL,198),(438,'5bcaa748-7ba6-4e6d-aa45-30813b670036','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','DockerConfig','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-DockerConfig-guqutbyue5bs','state changed','OS::Heat::Value',NULL,215),(439,'d9b1ea25-0e07-4930-9e06-7744295867d6','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','ServiceNames','overcloud-NetworkerServiceChain-6b74jmawyvfk-ServiceNames-o4gflexqmolu','state changed','OS::Heat::Value',NULL,219),(440,'f5ab0909-438c-45a8-aba0-bdc1f6767dc6','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-DockerConfigScripts-xahumrlpkbsv','state changed','OS::Heat::Value',NULL,218),(441,'14ae24aa-0a9b-4129-9635-a980fed1e33f','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','ServiceNames','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-ServiceNames-idtjur7p67mt','state changed','OS::Heat::Value',NULL,204),(442,'af8456a5-29e2-418d-9bd3-6849730c4283','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-IpaRegistrationTasks-5zhqk6qyhjkn','state changed','OS::Heat::Value',NULL,220),(443,'940effe3-a5f6-467b-a365-fb914dfc7d67','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-PreDeployStepTasks-xcncf5kfqacs','state changed','OS::Heat::Value',NULL,222),(444,'540ffee3-33d9-4bd1-9ddd-29b377c61580','1f3875d6-1b70-4384-b85a-f9a242de6c1c','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','IndividualServices','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-ServiceServerMetadataHook-aiakyl2teuck-IndividualServices-keqgd6f4szlv','state changed','OS::Heat::Value',NULL,221),(445,'4fa3a29e-d180-4ace-a16c-3d9317c3f8bf','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','ServiceNames','overcloud-BlockStorageServiceChain-42trwkc5c77f-ServiceNames-t5f4ni3n5sil','state changed','OS::Heat::Value',NULL,210),(446,'18f9a26f-f3f2-4f52-ae0d-abd43b394b77','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','overcloud-NetworkerServiceChain-6b74jmawyvfk-ServiceServerMetadataHook-erem4lyu4kqi','state changed','OS::TripleO::NetworkerServiceServerMetadataHook',NULL,223),(447,'20d1dfb1-e245-4a0b-86e9-10323eb8146c','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:54',NULL,'CREATE','COMPLETE','PreDeployStepTasks','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-PreDeployStepTasks-xcncf5kfqacs','state changed','OS::Heat::Value',NULL,222),(448,'8e7e7f74-bf81-4bfb-b808-a51ee3223870','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-ContainerPuppetTasks-mo3sng4n6phh','state changed','OS::Heat::Value',NULL,196),(449,'f602bacb-85d9-4f8d-803a-51c76b83ec9a','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:54',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-DockerConfigScripts-u5drspix6okn','state changed','OS::Heat::Value',NULL,226),(450,'646c1432-4ec1-4377-8e51-48bd07ec7154','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:55',NULL,'CREATE','COMPLETE','DockerConfig','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-DockerConfig-guqutbyue5bs','state changed','OS::Heat::Value',NULL,215),(451,'84d52576-c2b4-4822-a3d6-080a4e350476','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:55',NULL,'CREATE','COMPLETE','DockerConfigScripts','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-DockerConfigScripts-u5drspix6okn','state changed','OS::Heat::Value',NULL,226),(452,'682d0bd7-69be-418a-9f82-bcf2bef469d9','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:55',NULL,'CREATE','COMPLETE','HostFirewallTasks','overcloud-BlockStorageServiceChain-42trwkc5c77f-HostFirewallTasks-erouhefquute','state changed','OS::Heat::Value',NULL,161),(453,'0558400c-e166-40d0-bec0-ca15d926233c','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:55',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-FirewallFrontendRules-y3v6bj4dljba','state changed','OS::Heat::Value',NULL,224),(454,'fddbd031-2d41-4887-a43e-b22531d4060c','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:55',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-ExternalPostDeployTasks-lrjbfpb5zxwl','state changed','OS::Heat::Value',NULL,162),(455,'ce7004fa-4600-4b92-9863-c4b5b5c30031','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:55',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','overcloud-BlockStorageServiceChain-42trwkc5c77f-ServiceServerMetadataHook-ad6srcttp6hf','state changed','OS::TripleO::BlockStorageServiceServerMetadataHook',NULL,206),(456,'d9ac837c-e0c0-42ef-a715-ca0e3d16a402','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:55',NULL,'CREATE','IN_PROGRESS','FirewallRules','overcloud-NetworkerServiceChain-6b74jmawyvfk-FirewallRules-xxph5ylarpav','state changed','OS::Heat::Value',NULL,203),(457,'c08642c5-c313-4ce7-9146-efa925aa8178','952ec8fb-746e-4a07-ba18-6c3668ae84f9','2026-06-09 08:01:55',NULL,'CREATE','IN_PROGRESS','CompactServices','overcloud-CellControllerServiceChain-7ualui2rffsh-ServiceServerMetadataHook-wigmkl5pe2cd-CompactServices-wdkbhe66k3kh','state changed','OS::Heat::Value',NULL,207),(458,'0a420762-9c23-48e9-b294-2493e48e6665','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:55',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-ExternalUpgradeTasks-vc72zxsmzctc','state changed','OS::Heat::Value',NULL,165),(459,'4b8fbca5-ff44-4831-8c0d-74bc2342369b','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:55',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-IpaRegistrationTasks-hdwkwepvujw6','state changed','OS::Heat::Value',NULL,228),(460,'8a7a0dec-ae12-4e73-a734-e9e9f789018b','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:55',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-DockerPuppetTasks-xsai66qlaklg','state changed','OS::Heat::Value',NULL,229),(461,'f6e2d190-efc2-4b97-b33c-80897a6a7560','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:55',NULL,'CREATE','COMPLETE','DockerConfigScripts','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-DockerConfigScripts-xahumrlpkbsv','state changed','OS::Heat::Value',NULL,218),(462,'bafbc423-3620-45af-afc3-2849001ba5f3','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:55',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-UpgradeTasks-7ea57fzijr2g','state changed','OS::Heat::Value',NULL,227),(463,'44face77-e31d-4f22-b2f9-d8fa5dc9d467','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:55',NULL,'CREATE','IN_PROGRESS','PuppetConfig','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-PuppetConfig-maiq2wrcwzfh','state changed','OS::Heat::Value',NULL,230),(464,'f6d6381e-1157-4af4-a5ab-a4d04fc4c9ce','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:55',NULL,'CREATE','COMPLETE','UpdateTasks','overcloud-BlockStorageServiceChain-42trwkc5c77f-UpdateTasks-gefxo2cpzjbc','state changed','OS::Heat::Value',NULL,169),(465,'a174027c-29a2-494f-92c1-2766889fb753','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:55',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-IpaRegistrationTasks-hdwkwepvujw6','state changed','OS::Heat::Value',NULL,228),(466,'a2447ab2-6625-4260-a90a-16aa0c4ac98d','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:55',NULL,'CREATE','COMPLETE','PuppetConfig','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-PuppetConfig-maiq2wrcwzfh','state changed','OS::Heat::Value',NULL,230),(467,'036866b8-ccbc-40ee-97e9-e3dffa34a713','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:55',NULL,'CREATE','COMPLETE','DockerPuppetTasks','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-DockerPuppetTasks-xsai66qlaklg','state changed','OS::Heat::Value',NULL,229),(468,'d075e049-72bb-42e6-b833-efe474c11ff5','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:55',NULL,'CREATE','IN_PROGRESS','PuppetConfig','overcloud-BlockStorageServiceChain-42trwkc5c77f-PuppetConfig-3rq22ktbpi6b','state changed','OS::Heat::Value',NULL,211),(469,'2871dda8-a928-4307-9535-93a804f4f7da','1f3875d6-1b70-4384-b85a-f9a242de6c1c','2026-06-09 08:01:55',NULL,'CREATE','COMPLETE','IndividualServices','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-ServiceServerMetadataHook-aiakyl2teuck-IndividualServices-keqgd6f4szlv','state changed','OS::Heat::Value',NULL,221),(470,'dd170159-6b16-4f47-b190-787421eccb95','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:55',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-UpgradeBatchTasks-ikw7a6an5onm','state changed','OS::Heat::Value',NULL,234),(471,'f76094a2-ea9b-4db3-9978-7f527314405c','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:55',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-DeployStepsTasks-stbbn4qyswex','state changed','OS::Heat::Value',NULL,233),(472,'49454690-083e-4aa3-910e-1fdbfacd1c24','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:55',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-UpgradeBatchTasks-ikw7a6an5onm','state changed','OS::Heat::Value',NULL,234),(473,'0ce7582f-b3eb-48f8-aaa0-fbf67e0dafe6','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:55',NULL,'CREATE','COMPLETE','DeployStepsTasks','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-DeployStepsTasks-stbbn4qyswex','state changed','OS::Heat::Value',NULL,233),(474,'da3bb967-7e4b-4e3c-a878-4a6f5a2af10c','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:55',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-ContainerPuppetTasks-z2wpbr26cjxy','state changed','OS::Heat::Value',NULL,239),(475,'63188896-1b11-43f0-88dd-56fa7ac1158e','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:55',NULL,'CREATE','IN_PROGRESS','KollaConfig','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-KollaConfig-tl37k63adxrh','state changed','OS::Heat::Value',NULL,240),(476,'cc2c4e0f-5cb9-4d6a-91fb-f72b55b496f2','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:55',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','overcloud-BlockStorageServiceChain-42trwkc5c77f-MonitoringSubscriptionsConfig-prc3nzy6q7jp','state changed','OS::Heat::Value',NULL,225),(477,'12b0804c-f3cf-4ec2-ac39-247942182f55','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:55',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-ContainerPuppetTasks-z2wpbr26cjxy','state changed','OS::Heat::Value',NULL,239),(478,'5fd876a4-5f7a-4bd5-9968-8d5fa3d96def','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:55',NULL,'CREATE','IN_PROGRESS','FirewallRules','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-FirewallRules-jgyaafj5rp2d','state changed','OS::Heat::Value',NULL,237),(479,'37f098b1-1970-429d-a87f-8d5992f51cd2','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:55',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-PreUpgradeRollingTasks-dy43uwx2nosn','state changed','OS::Heat::Value',NULL,232),(480,'3a350327-0b09-43b6-9d4c-24e1a40733d3','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:55',NULL,'CREATE','COMPLETE','UpgradeTasks','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-UpgradeTasks-7ea57fzijr2g','state changed','OS::Heat::Value',NULL,227),(481,'4615a478-28c7-4639-a775-27086f0e28c9','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:55',NULL,'CREATE','COMPLETE','FirewallFrontendRules','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-FirewallFrontendRules-y3v6bj4dljba','state changed','OS::Heat::Value',NULL,224),(482,'b9f2912a-a4eb-4eef-a3c3-e74cfb5a17a2','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:55',NULL,'CREATE','COMPLETE','PuppetStepConfig','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-PuppetStepConfig-rjazyu5k6uj3','state changed','OS::Heat::Value',NULL,176),(483,'d67e0476-f08a-48f0-9f73-9aab64f5c32c','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:55',NULL,'CREATE','COMPLETE','PuppetStepConfig','overcloud-BlockStorageServiceChain-42trwkc5c77f-PuppetStepConfig-l4g2l6f5rbj2','state changed','OS::Heat::Value',NULL,182),(484,'e3314616-8544-4e4f-a966-af7dfaa01171','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:55',NULL,'CREATE','COMPLETE','KollaConfig','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-KollaConfig-tl37k63adxrh','state changed','OS::Heat::Value',NULL,240),(485,'b627357c-fc5b-4715-9b1f-28e242b7e936','1f3875d6-1b70-4384-b85a-f9a242de6c1c','2026-06-09 08:01:55',NULL,'CREATE','COMPLETE','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-ServiceServerMetadataHook-aiakyl2teuck','1f3875d6-1b70-4384-b85a-f9a242de6c1c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(486,'144123d1-0c85-475e-8aa4-92724d26a39e','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:55',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-PostUpdateTasks-azabjwd5lsvh','state changed','OS::Heat::Value',NULL,244),(487,'e5b9d9a6-0036-4836-8f06-36824bc89bdb','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:55',NULL,'CREATE','COMPLETE','DockerConfig','overcloud-BlockStorageServiceChain-42trwkc5c77f-DockerConfig-ics74ehuxlu2','state changed','OS::Heat::Value',NULL,185),(488,'0f14f298-b812-41e5-a14c-538f5112922f','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:01:55',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf','5268a897-7d28-46be-87ec-d35196b6744d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(489,'70ba824d-750b-45a4-b72c-2c336de8a3a2','6c6a2aae-c170-4679-9397-c8b4e1ba65e7','2026-06-09 08:01:55',NULL,'CREATE','IN_PROGRESS','overcloud-NetworkerServiceChain-6b74jmawyvfk-ServiceServerMetadataHook-erem4lyu4kqi','6c6a2aae-c170-4679-9397-c8b4e1ba65e7','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(490,'8df4bf2d-6c22-4c6e-94c5-f20bdb4e7719','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:55',NULL,'CREATE','COMPLETE','FirewallRules','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-FirewallRules-jgyaafj5rp2d','state changed','OS::Heat::Value',NULL,237),(491,'80c27d81-c4fc-47f5-995e-d196a85ff956','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:55',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-PreUpgradeRollingTasks-dy43uwx2nosn','state changed','OS::Heat::Value',NULL,232),(492,'87352c54-f084-4576-aacc-b9652efb3f88','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:55',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','overcloud-BlockStorageServiceChain-42trwkc5c77f-HostPrepTasks-3edrtvmgh2db','state changed','OS::Heat::Value',NULL,231),(493,'61eb20db-3c40-48b4-acc8-b8e9e8c68ed7','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:55',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','overcloud-NetworkerServiceChain-6b74jmawyvfk-ExternalDeployTasks-r3xe67e2jy5a','state changed','OS::Heat::Value',NULL,249),(494,'7318aaf8-7332-47d0-ab21-7fec7e468823','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:55',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','overcloud-NetworkerServiceChain-6b74jmawyvfk-ExternalPostDeployTasks-ghvhmcmxg2uz','state changed','OS::Heat::Value',NULL,246),(495,'747f655c-48cf-49ba-9645-9253abe07f47','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:55',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-MonitoringSubscriptionsConfig-rakq34qhghb6','state changed','OS::Heat::Value',NULL,191),(496,'b6eb403b-7384-4ba4-85f5-9a547620821a','b926babc-6e5b-4a21-a090-8d3084454abe','2026-06-09 08:01:55',NULL,'CREATE','IN_PROGRESS','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-ServiceServerMetadataHook-oosig2olyexo','b926babc-6e5b-4a21-a090-8d3084454abe','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(497,'a6732592-55c6-4b63-b072-acdd0fb19126','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:55',NULL,'CREATE','COMPLETE','PostUpdateTasks','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-PostUpdateTasks-azabjwd5lsvh','state changed','OS::Heat::Value',NULL,244),(498,'5701709e-1371-468d-9a24-0729bcffc510','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:55',NULL,'CREATE','COMPLETE','ExternalDeployTasks','overcloud-NetworkerServiceChain-6b74jmawyvfk-ExternalDeployTasks-r3xe67e2jy5a','state changed','OS::Heat::Value',NULL,249),(499,'1c89e1ee-fc1a-4427-8166-c53d62b395fd','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:55',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','overcloud-CephStorageServiceChain-wa27clgf4qef-AnsibleGroupVars-b4ugnv5qogm5','state changed','OS::Heat::Value',NULL,250),(500,'a3f5a857-2ac7-44fc-8d8e-fa009ec785cf','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:55',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-DeployStepsTasks-774kgsyfxoz7','state changed','OS::Heat::Value',NULL,236),(501,'669fb3f5-0cc3-4498-8286-2b29344273fa','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:55',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-PostUpgradeTasks-ykmoeyknxra7','state changed','OS::Heat::Value',NULL,235),(502,'5560d9e4-424c-40a7-93a5-c5d60a8466ab','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:55',NULL,'CREATE','COMPLETE','AnsibleGroupVars','overcloud-CephStorageServiceChain-wa27clgf4qef-AnsibleGroupVars-b4ugnv5qogm5','state changed','OS::Heat::Value',NULL,250),(503,'237a4b94-4d1a-42e5-97ad-8e11aef522a2','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:55',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-ExternalPostDeployTasks-uhimbak5gb2o','state changed','OS::Heat::Value',NULL,243),(504,'ce1ec9bb-f19a-44c8-a65c-e3625d917326','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:55',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-ExternalUpdateTasks-kjozdh3lmhfw','state changed','OS::Heat::Value',NULL,242),(505,'59302e12-2e04-491b-8bdc-63ef7ed0a8db','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:55',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-ExternalDeployTasks-j32gtrglclex','state changed','OS::Heat::Value',NULL,241),(506,'ed1be600-562c-4467-9c2c-3f4243b5c3dd','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:55',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-ContainerPuppetTasks-mo3sng4n6phh','state changed','OS::Heat::Value',NULL,196),(507,'7415eb93-5649-40d9-8bf9-3f5df9e0f661','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:55',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','overcloud-NetworkerServiceChain-6b74jmawyvfk-ExternalPostDeployTasks-ghvhmcmxg2uz','state changed','OS::Heat::Value',NULL,246),(508,'d6763d89-dd67-40f7-862e-42d9491e6819','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:55',NULL,'CREATE','IN_PROGRESS','UpdateTasks','overcloud-NetworkerServiceChain-6b74jmawyvfk-UpdateTasks-dqxocwo7f4bl','state changed','OS::Heat::Value',NULL,252),(509,'4bd1834e-9ed2-4217-831d-2f34e0b737df','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:55',NULL,'CREATE','IN_PROGRESS','ScaleTasks','overcloud-NetworkerServiceChain-6b74jmawyvfk-ScaleTasks-dhyqiyva67o4','state changed','OS::Heat::Value',NULL,254),(510,'9d747136-05b1-4bc2-bfb7-58027e380a5c','952ec8fb-746e-4a07-ba18-6c3668ae84f9','2026-06-09 08:01:55',NULL,'CREATE','COMPLETE','CompactServices','overcloud-CellControllerServiceChain-7ualui2rffsh-ServiceServerMetadataHook-wigmkl5pe2cd-CompactServices-wdkbhe66k3kh','state changed','OS::Heat::Value',NULL,207),(511,'fc3fd1aa-fa54-430e-a36d-7a72206124e8','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:55',NULL,'CREATE','IN_PROGRESS','UpdateTasks','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-UpdateTasks-nqlnzj45bcrh','state changed','OS::Heat::Value',NULL,245),(512,'7afe9f2a-21c2-4aa1-895a-0cc6c9c8fb9d','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:55',NULL,'CREATE','COMPLETE','FirewallRules','overcloud-NetworkerServiceChain-6b74jmawyvfk-FirewallRules-xxph5ylarpav','state changed','OS::Heat::Value',NULL,203),(513,'8ea8099d-7011-40ce-a6c0-be4b46346423','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:55',NULL,'CREATE','COMPLETE','ScaleTasks','overcloud-NetworkerServiceChain-6b74jmawyvfk-ScaleTasks-dhyqiyva67o4','state changed','OS::Heat::Value',NULL,254),(514,'e6533324-00a7-478a-a1f2-4d390451d872','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:55',NULL,'CREATE','COMPLETE','UpdateTasks','overcloud-NetworkerServiceChain-6b74jmawyvfk-UpdateTasks-dqxocwo7f4bl','state changed','OS::Heat::Value',NULL,252),(515,'c72b9cef-940b-496b-876f-8cc8c6d91617','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:55',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','overcloud-NetworkerServiceChain-6b74jmawyvfk-ContainerPuppetTasks-omxnffkumdr6','state changed','OS::Heat::Value',NULL,255),(516,'5dd16dae-fadd-409d-b7cc-216e3c226180','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:55',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','overcloud-NetworkerServiceChain-6b74jmawyvfk-ContainerPuppetTasks-omxnffkumdr6','state changed','OS::Heat::Value',NULL,255),(517,'9f48400a-17d3-4e9a-a684-be2c46e9ad76','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:55',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','overcloud-NetworkerServiceChain-6b74jmawyvfk-MonitoringSubscriptionsConfig-y4qdgm5n73tn','state changed','OS::Heat::Value',NULL,248),(518,'34b4475f-89e9-4f76-95f0-cc8bbb0b6e87','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:55',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','overcloud-CephStorageServiceChain-wa27clgf4qef-UpgradeBatchTasks-jqwkxcqoc6j2','state changed','OS::Heat::Value',NULL,257),(519,'69a4a0af-7549-46c1-a48e-7dd239d083f1','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:55',NULL,'CREATE','IN_PROGRESS','DockerConfig','overcloud-NetworkerServiceChain-6b74jmawyvfk-DockerConfig-2qqzavrf6ikn','state changed','OS::Heat::Value',NULL,256),(520,'4a3d72fe-fb2a-4647-a638-118b3d9de090','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:55',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-HostPrepTasks-ikjyagp7v37j','state changed','OS::Heat::Value',NULL,247),(521,'06f27cc2-04d4-4a22-b77f-094a4074ec3a','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:55',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','overcloud-NetworkerServiceChain-6b74jmawyvfk-PuppetStepConfig-jrleqclir5gw','state changed','OS::Heat::Value',NULL,251),(522,'d5bd20fc-1c07-410c-bab4-165f388684d1','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:55',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','overcloud-CephStorageServiceChain-wa27clgf4qef-UpgradeBatchTasks-jqwkxcqoc6j2','state changed','OS::Heat::Value',NULL,257),(523,'6938ab1a-7ff1-49bb-849f-96c83cf6a196','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:55',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','overcloud-NetworkerServiceChain-6b74jmawyvfk-ExternalUpdateTasks-3jguajnjtwuv','state changed','OS::Heat::Value',NULL,259),(524,'00a3dffc-32c8-46fb-9763-b22253bff059','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:55',NULL,'CREATE','COMPLETE','PuppetConfig','overcloud-BlockStorageServiceChain-42trwkc5c77f-PuppetConfig-3rq22ktbpi6b','state changed','OS::Heat::Value',NULL,211),(525,'552feb87-5a35-4504-b040-409314470040','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:55',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','overcloud-NetworkerServiceChain-6b74jmawyvfk-ExternalUpdateTasks-3jguajnjtwuv','state changed','OS::Heat::Value',NULL,259),(526,'89dc0d44-3d18-45b0-b0cb-91a16b4b8642','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:55',NULL,'CREATE','COMPLETE','DockerConfig','overcloud-NetworkerServiceChain-6b74jmawyvfk-DockerConfig-2qqzavrf6ikn','state changed','OS::Heat::Value',NULL,256),(527,'c48f4ce6-dc49-4672-b431-a0fdaa6bc039','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:55',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','overcloud-NetworkerServiceChain-6b74jmawyvfk-PostUpdateTasks-ymhm3h7ctmn5','state changed','OS::Heat::Value',NULL,260),(528,'b42758a9-5000-446c-ba48-998166b2e815','6c6a2aae-c170-4679-9397-c8b4e1ba65e7','2026-06-09 08:01:55',NULL,'CREATE','IN_PROGRESS','IncomingMetadataSettings','overcloud-NetworkerServiceChain-6b74jmawyvfk-ServiceServerMetadataHook-erem4lyu4kqi-IncomingMetadataSettings-6asamcqimzeb','state changed','OS::Heat::Value',NULL,261),(529,'583b8503-5c90-4606-9a72-2c41fe0a6cf8','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:55',NULL,'CREATE','COMPLETE','PostUpdateTasks','overcloud-NetworkerServiceChain-6b74jmawyvfk-PostUpdateTasks-ymhm3h7ctmn5','state changed','OS::Heat::Value',NULL,260),(530,'f021c48d-4143-4a89-bf6e-d77b9e5822a7','6c6a2aae-c170-4679-9397-c8b4e1ba65e7','2026-06-09 08:01:55',NULL,'CREATE','COMPLETE','IncomingMetadataSettings','overcloud-NetworkerServiceChain-6b74jmawyvfk-ServiceServerMetadataHook-erem4lyu4kqi-IncomingMetadataSettings-6asamcqimzeb','state changed','OS::Heat::Value',NULL,261),(531,'1b844f58-903b-4c7a-a758-827c6389a7a2','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:55',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','overcloud-NetworkerServiceChain-6b74jmawyvfk-FirewallFrontendRules-27sck75kqccw','state changed','OS::Heat::Value',NULL,262),(532,'3e505a2b-5e4f-4ad7-a88f-d08c427cc322','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:55',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','overcloud-NetworkerServiceChain-6b74jmawyvfk-DockerPuppetTasks-kl5s3f4ot73y','state changed','OS::Heat::Value',NULL,263),(533,'0481d1a2-ff33-4125-966c-5a32aac5f9c4','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:55',NULL,'CREATE','COMPLETE','DockerPuppetTasks','overcloud-NetworkerServiceChain-6b74jmawyvfk-DockerPuppetTasks-kl5s3f4ot73y','state changed','OS::Heat::Value',NULL,263),(534,'7f7e5bbf-50aa-4044-9587-4a96260604fe','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:55',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','overcloud-BlockStorageServiceChain-42trwkc5c77f-MonitoringSubscriptionsConfig-prc3nzy6q7jp','state changed','OS::Heat::Value',NULL,225),(535,'1acec58b-5869-43bf-b652-e2ad2de33590','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:55',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','overcloud-NetworkerServiceChain-6b74jmawyvfk-KeystoneResourcesConfigs-rwrffziact6e','state changed','OS::Heat::Value',NULL,264),(536,'6e08777d-0bd3-4e84-9654-1fc0d133afd0','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:55',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','overcloud-NetworkerServiceChain-6b74jmawyvfk-ServiceConfigSettings-qqqgwvj6oogb','state changed','OS::Heat::Value',NULL,266),(537,'e29186c2-8214-4efe-83a2-2a22d125931d','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:55',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','overcloud-NetworkerServiceChain-6b74jmawyvfk-HostFirewallTasks-nb5bksnjef7a','state changed','OS::Heat::Value',NULL,265),(538,'102cd65d-4216-425b-ae91-c6c8dec82bc7','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:55',NULL,'CREATE','COMPLETE','FirewallFrontendRules','overcloud-NetworkerServiceChain-6b74jmawyvfk-FirewallFrontendRules-27sck75kqccw','state changed','OS::Heat::Value',NULL,262),(539,'a76a6411-7496-4932-90b3-74b2dbb963f7','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:55',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','overcloud-NetworkerServiceChain-6b74jmawyvfk-DeployStepsTasks-kry3wno6nuuv','state changed','OS::Heat::Value',NULL,253),(540,'a54220ef-8155-424b-a0fe-03dc1041228d','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:55',NULL,'CREATE','COMPLETE','ServiceConfigSettings','overcloud-NetworkerServiceChain-6b74jmawyvfk-ServiceConfigSettings-qqqgwvj6oogb','state changed','OS::Heat::Value',NULL,266),(541,'04a84219-2b6f-4308-89dc-4256a11a14f3','6c6a2aae-c170-4679-9397-c8b4e1ba65e7','2026-06-09 08:01:55',NULL,'CREATE','IN_PROGRESS','IndividualServices','overcloud-NetworkerServiceChain-6b74jmawyvfk-ServiceServerMetadataHook-erem4lyu4kqi-IndividualServices-kcfivcufhau7','state changed','OS::Heat::Value',NULL,269),(542,'05e4485f-20b0-4986-9e61-2a8d10dcb895','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:55',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','overcloud-NetworkerServiceChain-6b74jmawyvfk-HostPrepTasks-kkbilugnoi6b','state changed','OS::Heat::Value',NULL,270),(543,'adab58e2-9ec3-45d0-b0d8-501ff4857f5c','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:55',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','overcloud-NetworkerServiceChain-6b74jmawyvfk-KeystoneResourcesConfigs-rwrffziact6e','state changed','OS::Heat::Value',NULL,264),(544,'184b277c-2828-415d-b34d-21e681c68b41','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:55',NULL,'CREATE','COMPLETE','HostFirewallTasks','overcloud-NetworkerServiceChain-6b74jmawyvfk-HostFirewallTasks-nb5bksnjef7a','state changed','OS::Heat::Value',NULL,265),(545,'1254da04-bf08-465e-81d3-e0f198e1499b','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:55',NULL,'CREATE','COMPLETE','HostPrepTasks','overcloud-NetworkerServiceChain-6b74jmawyvfk-HostPrepTasks-kkbilugnoi6b','state changed','OS::Heat::Value',NULL,270),(546,'b1f3cb69-0dae-4cfc-97ee-3ab29602c229','6c6a2aae-c170-4679-9397-c8b4e1ba65e7','2026-06-09 08:01:55',NULL,'CREATE','COMPLETE','IndividualServices','overcloud-NetworkerServiceChain-6b74jmawyvfk-ServiceServerMetadataHook-erem4lyu4kqi-IndividualServices-kcfivcufhau7','state changed','OS::Heat::Value',NULL,269),(547,'52b0fffb-ba71-4049-b3ae-36982feb753c','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:56',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','overcloud-NetworkerServiceChain-6b74jmawyvfk-PostUpgradeTasks-4r34eb2hc5qx','state changed','OS::Heat::Value',NULL,258),(548,'b9bd1f4d-99a9-492b-b8a2-707e4f5b9d2a','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:56',NULL,'CREATE','COMPLETE','HostPrepTasks','overcloud-BlockStorageServiceChain-42trwkc5c77f-HostPrepTasks-3edrtvmgh2db','state changed','OS::Heat::Value',NULL,231),(549,'cee6c861-a339-4966-9cdd-ae73b6ebc3b5','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:56',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','1f3875d6-1b70-4384-b85a-f9a242de6c1c','state changed','OS::TripleO::CellControllerComputeServiceServerMetadataHook',NULL,140),(550,'d66583e8-4490-49d7-a220-46ead29ce1ed','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:56',NULL,'CREATE','COMPLETE','DeployStepsTasks','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-DeployStepsTasks-774kgsyfxoz7','state changed','OS::Heat::Value',NULL,236),(551,'2101873b-1f1b-4326-a8fc-d621bcbd081f','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:56',NULL,'CREATE','COMPLETE','PostUpgradeTasks','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf-PostUpgradeTasks-ykmoeyknxra7','state changed','OS::Heat::Value',NULL,235),(552,'b824bda3-3301-44c4-92fb-6390fad7fe2e','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:56',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-ExternalUpdateTasks-kjozdh3lmhfw','state changed','OS::Heat::Value',NULL,242),(553,'b86cc14e-1aa8-4bcb-8b28-f619a95c20c7','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:56',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-ExternalPostDeployTasks-uhimbak5gb2o','state changed','OS::Heat::Value',NULL,243),(554,'d86487c2-e0d4-4ed1-b09c-cd80f6673b20','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:56',NULL,'CREATE','COMPLETE','ExternalDeployTasks','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-ExternalDeployTasks-j32gtrglclex','state changed','OS::Heat::Value',NULL,241),(555,'483e46db-9a01-45e8-94e4-2b4d5ecaa831','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:56',NULL,'CREATE','COMPLETE','UpdateTasks','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-UpdateTasks-nqlnzj45bcrh','state changed','OS::Heat::Value',NULL,245),(556,'abe88519-ae9d-48da-b72c-62a8c683e845','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:56',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','overcloud-NetworkerServiceChain-6b74jmawyvfk-AnsibleGroupVars-4xlabfiasl7g','state changed','OS::Heat::Value',NULL,271),(557,'25a12fbe-a3e2-40c4-a8de-9bbdbc376bd2','75396b04-8aa7-4164-b8c1-0bb29e9f2525','2026-06-09 08:01:56',NULL,'CREATE','IN_PROGRESS','overcloud-BlockStorageServiceChain-42trwkc5c77f-ServiceServerMetadataHook-ad6srcttp6hf','75396b04-8aa7-4164-b8c1-0bb29e9f2525','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(558,'395c8897-b511-486f-a8c5-2d21da138ef6','952ec8fb-746e-4a07-ba18-6c3668ae84f9','2026-06-09 08:01:56',NULL,'CREATE','COMPLETE','overcloud-CellControllerServiceChain-7ualui2rffsh-ServiceServerMetadataHook-wigmkl5pe2cd','952ec8fb-746e-4a07-ba18-6c3668ae84f9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(559,'92b033a5-5199-4b60-bd9e-1e570eceb4dd','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:56',NULL,'CREATE','COMPLETE','HostPrepTasks','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-HostPrepTasks-ikjyagp7v37j','state changed','OS::Heat::Value',NULL,247),(560,'25349c92-aed8-4ae5-a2d1-e7f9abf47407','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:56',NULL,'CREATE','COMPLETE','PuppetStepConfig','overcloud-NetworkerServiceChain-6b74jmawyvfk-PuppetStepConfig-jrleqclir5gw','state changed','OS::Heat::Value',NULL,251),(561,'e90d569d-eaa2-4303-b2e8-834013156b38','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:56',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','overcloud-NetworkerServiceChain-6b74jmawyvfk-MonitoringSubscriptionsConfig-y4qdgm5n73tn','state changed','OS::Heat::Value',NULL,248),(562,'e871859c-38da-483a-82e6-f362332a77e3','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:56',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','overcloud-NetworkerServiceChain-6b74jmawyvfk-UpgradeBatchTasks-2poufhaceajs','state changed','OS::Heat::Value',NULL,272),(563,'470ba2e6-f0b3-4ac0-ab5f-0967c0043e45','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:56',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','overcloud-NetworkerServiceChain-6b74jmawyvfk-UpgradeTasks-nzxzxfpyjbqe','state changed','OS::Heat::Value',NULL,273),(564,'359fe3ec-b804-44bf-a224-d06dd32be683','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:56',NULL,'CREATE','IN_PROGRESS','PuppetConfig','overcloud-CephStorageServiceChain-wa27clgf4qef-PuppetConfig-d4u34hlyrlxc','state changed','OS::Heat::Value',NULL,275),(565,'e87e252c-6161-49d9-b8b3-576beb1778f0','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:56',NULL,'CREATE','COMPLETE','PuppetConfig','overcloud-CephStorageServiceChain-wa27clgf4qef-PuppetConfig-d4u34hlyrlxc','state changed','OS::Heat::Value',NULL,275),(566,'78eb03a7-b76e-4c22-a378-364da8ec46e8','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:56',NULL,'CREATE','COMPLETE','DeployStepsTasks','overcloud-NetworkerServiceChain-6b74jmawyvfk-DeployStepsTasks-kry3wno6nuuv','state changed','OS::Heat::Value',NULL,253),(567,'884382f2-d892-4b79-a7ee-a9f284595343','6c6a2aae-c170-4679-9397-c8b4e1ba65e7','2026-06-09 08:01:56',NULL,'CREATE','IN_PROGRESS','CompactServices','overcloud-NetworkerServiceChain-6b74jmawyvfk-ServiceServerMetadataHook-erem4lyu4kqi-CompactServices-dwb2wlotxfkv','state changed','OS::Heat::Value',NULL,274),(568,'4ef7769f-9731-4b0f-80e9-76db80410c7b','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:56',NULL,'CREATE','COMPLETE','PostUpgradeTasks','overcloud-NetworkerServiceChain-6b74jmawyvfk-PostUpgradeTasks-4r34eb2hc5qx','state changed','OS::Heat::Value',NULL,258),(569,'a93e7825-9978-4d04-b4cc-c1e6a8afb3cb','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:56',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','overcloud-CephStorageServiceChain-wa27clgf4qef-ServiceConfigSettings-ci573jcbmxno','state changed','OS::Heat::Value',NULL,277),(570,'7fe3f279-5a2a-4677-9183-408727e21fbd','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:56',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','952ec8fb-746e-4a07-ba18-6c3668ae84f9','state changed','OS::TripleO::CellControllerServiceServerMetadataHook',NULL,106),(571,'e23e0e09-8aee-4629-98b2-e4e9233469cb','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:56',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','overcloud-CephStorageServiceChain-wa27clgf4qef-KeystoneResourcesConfigs-4yf6dzvkecwe','state changed','OS::Heat::Value',NULL,276),(572,'42eb1004-09c4-44d0-97e3-369c280f9032','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:56',NULL,'CREATE','COMPLETE','ServiceConfigSettings','overcloud-CephStorageServiceChain-wa27clgf4qef-ServiceConfigSettings-ci573jcbmxno','state changed','OS::Heat::Value',NULL,277),(573,'7fea0305-25bb-4973-9ed9-de001b4b0292','bd6ed836-8c74-4942-b7b0-47ad18762295','2026-06-09 08:01:56',NULL,'CREATE','COMPLETE','overcloud-CellControllerServiceChain-7ualui2rffsh','bd6ed836-8c74-4942-b7b0-47ad18762295','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(574,'494d3a9d-f7f0-4ded-bca4-de81fe384cde','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:56',NULL,'CREATE','COMPLETE','AnsibleGroupVars','overcloud-NetworkerServiceChain-6b74jmawyvfk-AnsibleGroupVars-4xlabfiasl7g','state changed','OS::Heat::Value',NULL,271),(575,'e5271e23-e28e-4a2c-8474-dc306bf80170','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:56',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','overcloud-NetworkerServiceChain-6b74jmawyvfk-UpgradeBatchTasks-2poufhaceajs','state changed','OS::Heat::Value',NULL,272),(576,'69a3e6e9-9246-4a0b-9e70-37657e607cc9','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:56',NULL,'CREATE','COMPLETE','UpgradeTasks','overcloud-NetworkerServiceChain-6b74jmawyvfk-UpgradeTasks-nzxzxfpyjbqe','state changed','OS::Heat::Value',NULL,273),(577,'3546b8d9-120f-4668-9806-d97d0d324315','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:56',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','overcloud-CephStorageServiceChain-wa27clgf4qef-DockerPuppetTasks-67t7givkvhqg','state changed','OS::Heat::Value',NULL,278),(578,'6e48063a-7dbf-4fbe-b9a2-b8c898cc85d7','6c6a2aae-c170-4679-9397-c8b4e1ba65e7','2026-06-09 08:01:56',NULL,'CREATE','COMPLETE','CompactServices','overcloud-NetworkerServiceChain-6b74jmawyvfk-ServiceServerMetadataHook-erem4lyu4kqi-CompactServices-dwb2wlotxfkv','state changed','OS::Heat::Value',NULL,274),(579,'a2afd99e-4ca4-49be-8591-75bd0207fff9','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:56',NULL,'CREATE','COMPLETE','DockerPuppetTasks','overcloud-CephStorageServiceChain-wa27clgf4qef-DockerPuppetTasks-67t7givkvhqg','state changed','OS::Heat::Value',NULL,278),(580,'fc616e78-263a-4b8e-9b68-984528f2c7d7','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:56',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','overcloud-CephStorageServiceChain-wa27clgf4qef-KeystoneResourcesConfigs-4yf6dzvkecwe','state changed','OS::Heat::Value',NULL,276),(581,'b811d206-af83-4589-9851-b88ac03c01e9','6c6a2aae-c170-4679-9397-c8b4e1ba65e7','2026-06-09 08:01:56',NULL,'CREATE','COMPLETE','overcloud-NetworkerServiceChain-6b74jmawyvfk-ServiceServerMetadataHook-erem4lyu4kqi','6c6a2aae-c170-4679-9397-c8b4e1ba65e7','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(582,'70a9fb03-1ec7-42a1-a182-bcb7d7acbe74','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:56',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','overcloud-CephStorageServiceChain-wa27clgf4qef-HostFirewallTasks-raz3nth2b5wg','state changed','OS::Heat::Value',NULL,280),(583,'83fc101c-2370-40b1-8c1f-e52a757f376a','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:56',NULL,'CREATE','IN_PROGRESS','ServiceNames','overcloud-CephStorageServiceChain-wa27clgf4qef-ServiceNames-osboqbxrlfso','state changed','OS::Heat::Value',NULL,279),(584,'cd1323c5-ed94-4a5e-8af8-017b808103e4','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:56',NULL,'CREATE','COMPLETE','HostFirewallTasks','overcloud-CephStorageServiceChain-wa27clgf4qef-HostFirewallTasks-raz3nth2b5wg','state changed','OS::Heat::Value',NULL,280),(585,'acb5d13f-1f6b-41bd-8c42-1d820800d706','655485fd-051a-46e8-88c4-6a7f45ec9e83','2026-06-09 08:01:56',NULL,'CREATE','COMPLETE','overcloud-CellControllerComputeServiceChain-mavq6fx4qrrf','655485fd-051a-46e8-88c4-6a7f45ec9e83','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(586,'d262cf83-2c88-422c-9f4c-9caa9d3db77c','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:56',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','overcloud-CephStorageServiceChain-wa27clgf4qef-ExternalUpdateTasks-fgbw25qjzgf6','state changed','OS::Heat::Value',NULL,281),(587,'aae4e046-0948-4a17-886d-4eaf8046786d','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:56',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','overcloud-CephStorageServiceChain-wa27clgf4qef-ExternalUpdateTasks-fgbw25qjzgf6','state changed','OS::Heat::Value',NULL,281),(588,'526f2640-ddb1-4503-8460-99d82974a770','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:56',NULL,'CREATE','IN_PROGRESS','KollaConfig','overcloud-CephStorageServiceChain-wa27clgf4qef-KollaConfig-mjz4dpxqqkdq','state changed','OS::Heat::Value',NULL,282),(589,'57797db7-cb4e-4742-b83e-778ef3adb9d9','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:56',NULL,'CREATE','COMPLETE','ServiceNames','overcloud-CephStorageServiceChain-wa27clgf4qef-ServiceNames-osboqbxrlfso','state changed','OS::Heat::Value',NULL,279),(590,'a72978ab-10f2-41ff-8a72-32e62c9c82ec','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:56',NULL,'CREATE','COMPLETE','KollaConfig','overcloud-CephStorageServiceChain-wa27clgf4qef-KollaConfig-mjz4dpxqqkdq','state changed','OS::Heat::Value',NULL,282),(591,'76f74684-8564-45da-8868-47dae4b023a1','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:56',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','overcloud-CephStorageServiceChain-wa27clgf4qef-ServiceServerMetadataHook-5cck6kqok5uw','state changed','OS::TripleO::CephStorageServiceServerMetadataHook',NULL,283),(592,'cffbe9d5-62c2-4efd-8a0b-6c6b16e63b81','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:56',NULL,'CREATE','IN_PROGRESS','FirewallRules','overcloud-CephStorageServiceChain-wa27clgf4qef-FirewallRules-cq2zwd7lontm','state changed','OS::Heat::Value',NULL,284),(593,'8cd11b88-4878-446d-9d6e-ec213fcc326e','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:56',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','overcloud-CephStorageServiceChain-wa27clgf4qef-ExternalDeployTasks-st6suzr4lvqp','state changed','OS::Heat::Value',NULL,285),(594,'18e155cb-bbfb-45a5-a258-1d4d77e951e4','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:56',NULL,'CREATE','COMPLETE','FirewallRules','overcloud-CephStorageServiceChain-wa27clgf4qef-FirewallRules-cq2zwd7lontm','state changed','OS::Heat::Value',NULL,284),(595,'99819a92-4a11-4c41-9196-4f2426b7cb9a','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:56',NULL,'CREATE','COMPLETE','ExternalDeployTasks','overcloud-CephStorageServiceChain-wa27clgf4qef-ExternalDeployTasks-st6suzr4lvqp','state changed','OS::Heat::Value',NULL,285),(596,'8a010d14-3d39-4cf4-86d0-f602194db529','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:56',NULL,'CREATE','COMPLETE','CellControllerServiceChain','bd6ed836-8c74-4942-b7b0-47ad18762295','state changed','OS::TripleO::CellControllerServices',NULL,79),(597,'2c6e72f0-3327-4942-9138-d879166f9bc0','b926babc-6e5b-4a21-a090-8d3084454abe','2026-06-09 08:01:56',NULL,'CREATE','IN_PROGRESS','IncomingMetadataSettings','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-ServiceServerMetadataHook-oosig2olyexo-IncomingMetadataSettings-rf4jejvo3vud','state changed','OS::Heat::Value',NULL,286),(598,'3a8cb84d-ee1d-467d-afcf-e48839ff40da','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:57',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','overcloud-CephStorageServiceChain-wa27clgf4qef-ContainerPuppetTasks-nhukc4lamrl7','state changed','OS::Heat::Value',NULL,287),(599,'f6f229a4-a955-4e0f-bb09-b498ba47efc3','b926babc-6e5b-4a21-a090-8d3084454abe','2026-06-09 08:01:57',NULL,'CREATE','COMPLETE','IncomingMetadataSettings','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-ServiceServerMetadataHook-oosig2olyexo-IncomingMetadataSettings-rf4jejvo3vud','state changed','OS::Heat::Value',NULL,286),(600,'7b1aa09f-97b5-438c-a699-7434f3c0267c','75396b04-8aa7-4164-b8c1-0bb29e9f2525','2026-06-09 08:01:57',NULL,'CREATE','IN_PROGRESS','IncomingMetadataSettings','overcloud-BlockStorageServiceChain-42trwkc5c77f-ServiceServerMetadataHook-ad6srcttp6hf-IncomingMetadataSettings-myta3yzilgqm','state changed','OS::Heat::Value',NULL,288),(601,'e8a81ffb-bf16-46fd-83cf-b4e845b36e35','cab3f512-1aa3-4a18-9fbc-7edff85dd04b','2026-06-09 08:01:57',NULL,'CREATE','IN_PROGRESS','overcloud-CephStorageServiceChain-wa27clgf4qef-ServiceServerMetadataHook-5cck6kqok5uw','cab3f512-1aa3-4a18-9fbc-7edff85dd04b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(602,'fb467a84-1b85-498a-9a4d-cae4d5750765','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:57',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','overcloud-CephStorageServiceChain-wa27clgf4qef-PreDeployStepTasks-ue5m3p6ihm5k','state changed','OS::Heat::Value',NULL,290),(603,'5077e102-0082-4b2c-8ece-5e35c8755e2a','75396b04-8aa7-4164-b8c1-0bb29e9f2525','2026-06-09 08:01:57',NULL,'CREATE','COMPLETE','IncomingMetadataSettings','overcloud-BlockStorageServiceChain-42trwkc5c77f-ServiceServerMetadataHook-ad6srcttp6hf-IncomingMetadataSettings-myta3yzilgqm','state changed','OS::Heat::Value',NULL,288),(604,'8dba4036-4b2b-45cd-9200-eae86fcdc70f','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:57',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','overcloud-CephStorageServiceChain-wa27clgf4qef-FirewallFrontendRules-vzzepyqwsr4q','state changed','OS::Heat::Value',NULL,293),(605,'81b6cc82-6c79-436f-8acc-44e866ea98d0','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:57',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','overcloud-CephStorageServiceChain-wa27clgf4qef-ContainerPuppetTasks-nhukc4lamrl7','state changed','OS::Heat::Value',NULL,287),(606,'7b719a64-ddb1-4830-a055-21d1f3caf5ce','b926babc-6e5b-4a21-a090-8d3084454abe','2026-06-09 08:01:57',NULL,'CREATE','IN_PROGRESS','IndividualServices','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-ServiceServerMetadataHook-oosig2olyexo-IndividualServices-2xdmgwqrkjxd','state changed','OS::Heat::Value',NULL,295),(607,'54176caa-9614-4fd3-9116-c6ecfe30fe15','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:57',NULL,'CREATE','COMPLETE','PreDeployStepTasks','overcloud-CephStorageServiceChain-wa27clgf4qef-PreDeployStepTasks-ue5m3p6ihm5k','state changed','OS::Heat::Value',NULL,290),(608,'98fe8923-db17-41b6-82f5-0223c8898fa1','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:57',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','overcloud-CephStorageServiceChain-wa27clgf4qef-PreUpgradeRollingTasks-422iisatfspx','state changed','OS::Heat::Value',NULL,297),(609,'b184f584-703c-424a-b26e-417adda37cea','b926babc-6e5b-4a21-a090-8d3084454abe','2026-06-09 08:01:57',NULL,'CREATE','IN_PROGRESS','CompactServices','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-ServiceServerMetadataHook-oosig2olyexo-CompactServices-6axd35rzmagk','state changed','OS::Heat::Value',NULL,294),(610,'b9161613-8bfb-4539-9b0f-9a373f6449d9','b926babc-6e5b-4a21-a090-8d3084454abe','2026-06-09 08:01:57',NULL,'CREATE','COMPLETE','IndividualServices','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-ServiceServerMetadataHook-oosig2olyexo-IndividualServices-2xdmgwqrkjxd','state changed','OS::Heat::Value',NULL,295),(611,'a3be4c94-088a-4870-9f91-5c924a4c7a3e','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:57',NULL,'CREATE','COMPLETE','FirewallFrontendRules','overcloud-CephStorageServiceChain-wa27clgf4qef-FirewallFrontendRules-vzzepyqwsr4q','state changed','OS::Heat::Value',NULL,293),(612,'a0cdb987-1c48-486b-9404-e1176b1c0ebc','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:57',NULL,'CREATE','COMPLETE','CellControllerComputeServiceChain','655485fd-051a-46e8-88c4-6a7f45ec9e83','state changed','OS::TripleO::CellControllerComputeServices',NULL,77),(613,'c37c8bdc-8fc5-45b5-97db-e7edb746b7ac','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:57',NULL,'CREATE','IN_PROGRESS','DockerConfig','overcloud-CephStorageServiceChain-wa27clgf4qef-DockerConfig-rag5yvak66bg','state changed','OS::Heat::Value',NULL,300),(614,'4d3d6506-23b5-4002-a325-3c472808d269','75396b04-8aa7-4164-b8c1-0bb29e9f2525','2026-06-09 08:01:57',NULL,'CREATE','IN_PROGRESS','IndividualServices','overcloud-BlockStorageServiceChain-42trwkc5c77f-ServiceServerMetadataHook-ad6srcttp6hf-IndividualServices-zhm7ogylh5e6','state changed','OS::Heat::Value',NULL,302),(615,'b4a85e2b-17b2-4efa-9bf7-183d9da83bae','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:57',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','overcloud-CephStorageServiceChain-wa27clgf4qef-PreUpgradeRollingTasks-422iisatfspx','state changed','OS::Heat::Value',NULL,297),(616,'33da685a-1d8d-4e8b-87c3-b169713010f1','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:57',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','overcloud-CephStorageServiceChain-wa27clgf4qef-GlobalConfigSettings-brmkd27krgrl','state changed','OS::Heat::Value',NULL,303),(617,'371c4565-ea11-4f42-8dde-0fa30eb35cf8','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:57',NULL,'CREATE','COMPLETE','DockerConfig','overcloud-CephStorageServiceChain-wa27clgf4qef-DockerConfig-rag5yvak66bg','state changed','OS::Heat::Value',NULL,300),(618,'eb2193cf-a129-4d8d-8f1a-20d77a7d3d00','75396b04-8aa7-4164-b8c1-0bb29e9f2525','2026-06-09 08:01:57',NULL,'CREATE','COMPLETE','IndividualServices','overcloud-BlockStorageServiceChain-42trwkc5c77f-ServiceServerMetadataHook-ad6srcttp6hf-IndividualServices-zhm7ogylh5e6','state changed','OS::Heat::Value',NULL,302),(619,'1d76de82-c4be-4b01-ba1d-7adf38ce6b37','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:57',NULL,'CREATE','COMPLETE','GlobalConfigSettings','overcloud-CephStorageServiceChain-wa27clgf4qef-GlobalConfigSettings-brmkd27krgrl','state changed','OS::Heat::Value',NULL,303),(620,'6f563f49-355b-4402-bf1c-987cdabe8962','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:57',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','overcloud-CephStorageServiceChain-wa27clgf4qef-DeployStepsTasks-6aygf6kmq5yg','state changed','OS::Heat::Value',NULL,307),(621,'01a524a2-128b-430e-bf2d-15317da0baa8','75396b04-8aa7-4164-b8c1-0bb29e9f2525','2026-06-09 08:01:57',NULL,'CREATE','IN_PROGRESS','CompactServices','overcloud-BlockStorageServiceChain-42trwkc5c77f-ServiceServerMetadataHook-ad6srcttp6hf-CompactServices-xr24557h7t3v','state changed','OS::Heat::Value',NULL,305),(622,'49283bd5-cd9e-40b1-9c6b-09029ab4480d','b926babc-6e5b-4a21-a090-8d3084454abe','2026-06-09 08:01:57',NULL,'CREATE','COMPLETE','CompactServices','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-ServiceServerMetadataHook-oosig2olyexo-CompactServices-6axd35rzmagk','state changed','OS::Heat::Value',NULL,294),(623,'47d87c76-d4dd-4911-bac9-7762a54a8a57','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:57',NULL,'CREATE','COMPLETE','DeployStepsTasks','overcloud-CephStorageServiceChain-wa27clgf4qef-DeployStepsTasks-6aygf6kmq5yg','state changed','OS::Heat::Value',NULL,307),(624,'11343609-19c3-4ca3-b755-b94bce1f9b42','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:57',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','overcloud-CephStorageServiceChain-wa27clgf4qef-IpaRegistrationTasks-6edwmxtonx5n','state changed','OS::Heat::Value',NULL,314),(625,'c48d82ea-2346-4e35-94d7-20aa0e20ff08','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:57',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','overcloud-CephStorageServiceChain-wa27clgf4qef-IpaRegistrationTasks-6edwmxtonx5n','state changed','OS::Heat::Value',NULL,314),(626,'8882fda4-25be-4257-a453-a90453b2c531','cab3f512-1aa3-4a18-9fbc-7edff85dd04b','2026-06-09 08:01:57',NULL,'CREATE','IN_PROGRESS','IncomingMetadataSettings','overcloud-CephStorageServiceChain-wa27clgf4qef-ServiceServerMetadataHook-5cck6kqok5uw-IncomingMetadataSettings-vrfs5y7rpgru','state changed','OS::Heat::Value',NULL,316),(627,'5294e749-77f5-4158-9e7e-a102359d1752','b926babc-6e5b-4a21-a090-8d3084454abe','2026-06-09 08:01:57',NULL,'CREATE','COMPLETE','overcloud-ObjectStorageServiceChain-ratn4mpywxcl-ServiceServerMetadataHook-oosig2olyexo','b926babc-6e5b-4a21-a090-8d3084454abe','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(628,'1010c761-0027-4b91-b2fc-9f0e40496b5e','75396b04-8aa7-4164-b8c1-0bb29e9f2525','2026-06-09 08:01:57',NULL,'CREATE','COMPLETE','CompactServices','overcloud-BlockStorageServiceChain-42trwkc5c77f-ServiceServerMetadataHook-ad6srcttp6hf-CompactServices-xr24557h7t3v','state changed','OS::Heat::Value',NULL,305),(629,'b38338f5-6967-42ab-b263-d2237260f9df','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:57',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','overcloud-CephStorageServiceChain-wa27clgf4qef-PostUpgradeTasks-jtnqutyyzs7d','state changed','OS::Heat::Value',NULL,320),(630,'61972737-4136-4fd8-b409-0ba375bf448a','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:57',NULL,'CREATE','COMPLETE','PostUpgradeTasks','overcloud-CephStorageServiceChain-wa27clgf4qef-PostUpgradeTasks-jtnqutyyzs7d','state changed','OS::Heat::Value',NULL,320),(631,'9c6534f7-9ad1-46a4-90c9-3789c51de963','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:57',NULL,'CREATE','IN_PROGRESS','UpdateTasks','overcloud-CephStorageServiceChain-wa27clgf4qef-UpdateTasks-7hwif5nmecw2','state changed','OS::Heat::Value',NULL,325),(632,'9fb0fd8f-a81e-4270-9e71-6b4e6122cf33','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:57',NULL,'CREATE','COMPLETE','UpdateTasks','overcloud-CephStorageServiceChain-wa27clgf4qef-UpdateTasks-7hwif5nmecw2','state changed','OS::Heat::Value',NULL,325),(633,'61328e86-b215-4b28-bcea-2b19863456b8','cab3f512-1aa3-4a18-9fbc-7edff85dd04b','2026-06-09 08:01:57',NULL,'CREATE','COMPLETE','IncomingMetadataSettings','overcloud-CephStorageServiceChain-wa27clgf4qef-ServiceServerMetadataHook-5cck6kqok5uw-IncomingMetadataSettings-vrfs5y7rpgru','state changed','OS::Heat::Value',NULL,316),(634,'0fc3eadb-242e-492c-ba1f-5244c90b0510','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:57',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','6c6a2aae-c170-4679-9397-c8b4e1ba65e7','state changed','OS::TripleO::NetworkerServiceServerMetadataHook',NULL,223),(635,'efe722d1-1a03-4307-8715-6192cefa80a8','75396b04-8aa7-4164-b8c1-0bb29e9f2525','2026-06-09 08:01:57',NULL,'CREATE','COMPLETE','overcloud-BlockStorageServiceChain-42trwkc5c77f-ServiceServerMetadataHook-ad6srcttp6hf','75396b04-8aa7-4164-b8c1-0bb29e9f2525','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(636,'11ba1693-0d5a-4721-a0e0-a93517d6e88b','64cedc04-99c8-452c-b61e-4a8873d9e5f7','2026-06-09 08:01:57',NULL,'CREATE','COMPLETE','overcloud-NetworkerServiceChain-6b74jmawyvfk','64cedc04-99c8-452c-b61e-4a8873d9e5f7','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(637,'8aced8f1-247f-4b31-b7e6-ee5fc18edb29','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:57',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','overcloud-CephStorageServiceChain-wa27clgf4qef-DockerConfigScripts-o6avj5bwabr6','state changed','OS::Heat::Value',NULL,346),(638,'b3227ff3-90f9-4abf-9026-0d001e7a45ed','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:57',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','overcloud-CephStorageServiceChain-wa27clgf4qef-UpgradeTasks-zv34hcwtgox3','state changed','OS::Heat::Value',NULL,343),(639,'ddcd0efb-bf29-4059-be2a-279f20bb7db9','cab3f512-1aa3-4a18-9fbc-7edff85dd04b','2026-06-09 08:01:57',NULL,'CREATE','IN_PROGRESS','IndividualServices','overcloud-CephStorageServiceChain-wa27clgf4qef-ServiceServerMetadataHook-5cck6kqok5uw-IndividualServices-2pnb52l5dj5i','state changed','OS::Heat::Value',NULL,347),(640,'9b551f48-216e-4d7a-a9bc-c49a8cd178dc','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:57',NULL,'CREATE','IN_PROGRESS','CellControllerServiceChainRoleData','overcloud-CellControllerServiceChainRoleData-yg63wolo73t3','state changed','OS::Heat::Value',NULL,348),(641,'4955d3e3-a769-48bb-b915-849de53b1de1','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:57',NULL,'CREATE','COMPLETE','DockerConfigScripts','overcloud-CephStorageServiceChain-wa27clgf4qef-DockerConfigScripts-o6avj5bwabr6','state changed','OS::Heat::Value',NULL,346),(642,'b581b0b5-6302-48d5-8c19-f9900beeeb79','cab3f512-1aa3-4a18-9fbc-7edff85dd04b','2026-06-09 08:01:57',NULL,'CREATE','COMPLETE','IndividualServices','overcloud-CephStorageServiceChain-wa27clgf4qef-ServiceServerMetadataHook-5cck6kqok5uw-IndividualServices-2pnb52l5dj5i','state changed','OS::Heat::Value',NULL,347),(643,'23de9fb0-149f-464c-8f03-7ad49f6ac601','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:57',NULL,'CREATE','COMPLETE','CellControllerServiceChainRoleData','overcloud-CellControllerServiceChainRoleData-yg63wolo73t3','state changed','OS::Heat::Value',NULL,348),(644,'8e01dc32-05e7-4679-aa19-9083eb8d437b','cab3f512-1aa3-4a18-9fbc-7edff85dd04b','2026-06-09 08:01:57',NULL,'CREATE','IN_PROGRESS','CompactServices','overcloud-CephStorageServiceChain-wa27clgf4qef-ServiceServerMetadataHook-5cck6kqok5uw-CompactServices-hbij7j2nskob','state changed','OS::Heat::Value',NULL,352),(645,'f44e40bf-5ac6-4482-bc2b-843d2da4c3f1','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:57',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','overcloud-CephStorageServiceChain-wa27clgf4qef-MonitoringSubscriptionsConfig-fx4debtprasa','state changed','OS::Heat::Value',NULL,351),(646,'9423478e-28f2-48f6-b473-1b7f064e9a28','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:57',NULL,'CREATE','COMPLETE','UpgradeTasks','overcloud-CephStorageServiceChain-wa27clgf4qef-UpgradeTasks-zv34hcwtgox3','state changed','OS::Heat::Value',NULL,343),(647,'4167a4c8-3b2c-412e-ab09-ddc30f6c6237','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:57',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','b926babc-6e5b-4a21-a090-8d3084454abe','state changed','OS::TripleO::ObjectStorageServiceServerMetadataHook',NULL,181),(648,'8d18bea7-2e33-453d-8813-bae531828280','cab3f512-1aa3-4a18-9fbc-7edff85dd04b','2026-06-09 08:01:57',NULL,'CREATE','COMPLETE','CompactServices','overcloud-CephStorageServiceChain-wa27clgf4qef-ServiceServerMetadataHook-5cck6kqok5uw-CompactServices-hbij7j2nskob','state changed','OS::Heat::Value',NULL,352),(649,'12c4c16b-1676-4b21-a09a-41e5eacc4047','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:57',NULL,'CREATE','IN_PROGRESS','ScaleTasks','overcloud-CephStorageServiceChain-wa27clgf4qef-ScaleTasks-lbwl4ullipdp','state changed','OS::Heat::Value',NULL,356),(650,'cc06aa62-8829-4b4a-bc05-6dad895c12c8','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:57',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','overcloud-CephStorageServiceChain-wa27clgf4qef-ExternalUpgradeTasks-jl3zt2w7l4ip','state changed','OS::Heat::Value',NULL,355),(651,'105042cb-aa8e-4231-8cf4-d084d5f689e1','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','2026-06-09 08:01:57',NULL,'CREATE','COMPLETE','overcloud-ObjectStorageServiceChain-ratn4mpywxcl','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(652,'c5be7f2c-63a8-491f-8380-a72f63b2f168','cab3f512-1aa3-4a18-9fbc-7edff85dd04b','2026-06-09 08:01:57',NULL,'CREATE','COMPLETE','overcloud-CephStorageServiceChain-wa27clgf4qef-ServiceServerMetadataHook-5cck6kqok5uw','cab3f512-1aa3-4a18-9fbc-7edff85dd04b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(653,'22a81888-7c12-4eae-9713-cec685cfa03e','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:57',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','overcloud-CephStorageServiceChain-wa27clgf4qef-MonitoringSubscriptionsConfig-fx4debtprasa','state changed','OS::Heat::Value',NULL,351),(654,'de5f079a-e455-48b4-849b-c0a2af613b65','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:57',NULL,'CREATE','COMPLETE','ScaleTasks','overcloud-CephStorageServiceChain-wa27clgf4qef-ScaleTasks-lbwl4ullipdp','state changed','OS::Heat::Value',NULL,356),(655,'fe7442e9-a526-4e06-b342-b2cb366d001e','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:57',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','overcloud-CephStorageServiceChain-wa27clgf4qef-ExternalPostDeployTasks-4jkkfb26o52q','state changed','OS::Heat::Value',NULL,358),(656,'0ded6740-bd8c-4e4f-b31a-5f724b2138f5','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:57',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','overcloud-CephStorageServiceChain-wa27clgf4qef-ExternalUpgradeTasks-jl3zt2w7l4ip','state changed','OS::Heat::Value',NULL,355),(657,'e21760e8-145f-431d-ad32-585ba5bdb47a','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:57',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','overcloud-CephStorageServiceChain-wa27clgf4qef-PostUpdateTasks-fs7wbkziq5hm','state changed','OS::Heat::Value',NULL,360),(658,'a831262d-1847-4900-b492-ed587b8ac47a','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:57',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','overcloud-CephStorageServiceChain-wa27clgf4qef-HostPrepTasks-xq4c7pyh5wa4','state changed','OS::Heat::Value',NULL,361),(659,'b41633e1-abb0-4402-b968-6ae293d260fb','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:57',NULL,'CREATE','COMPLETE','PostUpdateTasks','overcloud-CephStorageServiceChain-wa27clgf4qef-PostUpdateTasks-fs7wbkziq5hm','state changed','OS::Heat::Value',NULL,360),(660,'187387bc-a4bb-462b-a3e0-171b0428f5e4','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:57',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','overcloud-CephStorageServiceChain-wa27clgf4qef-ExternalPostDeployTasks-4jkkfb26o52q','state changed','OS::Heat::Value',NULL,358),(661,'b1a4a3c1-d7b0-4bb7-86b4-cc1798eec294','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:57',NULL,'CREATE','COMPLETE','HostPrepTasks','overcloud-CephStorageServiceChain-wa27clgf4qef-HostPrepTasks-xq4c7pyh5wa4','state changed','OS::Heat::Value',NULL,361),(662,'b8e66b0e-d166-4e56-988d-6bc00c2f44f1','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:57',NULL,'CREATE','IN_PROGRESS','CellControllerServiceNames','overcloud-CellControllerServiceNames-owv53lhfdrqo','state changed','OS::Heat::Value',NULL,365),(663,'945f8e4c-ece9-4a98-b8cc-9a8e537acde4','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:57',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','overcloud-CephStorageServiceChain-wa27clgf4qef-PuppetStepConfig-xbreujdjuhcq','state changed','OS::Heat::Value',NULL,364),(664,'a1adb54d-1f76-48e0-9ef5-da6f0b78ceff','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:57',NULL,'CREATE','COMPLETE','CellControllerServiceNames','overcloud-CellControllerServiceNames-owv53lhfdrqo','state changed','OS::Heat::Value',NULL,365),(665,'9f0c4f7d-d45e-4eff-b75c-95f315c333eb','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:57',NULL,'CREATE','COMPLETE','PuppetStepConfig','overcloud-CephStorageServiceChain-wa27clgf4qef-PuppetStepConfig-xbreujdjuhcq','state changed','OS::Heat::Value',NULL,364),(666,'012d2983-7a18-4a39-9a49-17f59c862b83','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:58',NULL,'CREATE','IN_PROGRESS','CellController','overcloud-CellController-pu35bwiwj6i7','state changed','OS::Heat::ResourceGroup',NULL,383),(667,'ea6cdf21-1486-443f-b8b0-177dcdc5941b','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:58',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','cab3f512-1aa3-4a18-9fbc-7edff85dd04b','state changed','OS::TripleO::CephStorageServiceServerMetadataHook',NULL,283),(668,'5980cc50-aa72-4006-adcd-2310832cbd2f','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:58',NULL,'CREATE','COMPLETE','ObjectStorageServiceChain','785c58e2-9af1-4107-bcd0-f88c3ca6d3f1','state changed','OS::TripleO::ObjectStorageServices',NULL,78),(669,'c76b85de-8091-4e2c-99c1-cd57b4c6d610','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','2026-06-09 08:01:58',NULL,'CREATE','COMPLETE','overcloud-CephStorageServiceChain-wa27clgf4qef','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(670,'f9c1a86f-1d4d-44ca-a9db-922243a923c5','c562d84a-2b8e-4b11-9a98-8a218f775a15','2026-06-09 08:01:58',NULL,'CREATE','IN_PROGRESS','overcloud-CellController-pu35bwiwj6i7','c562d84a-2b8e-4b11-9a98-8a218f775a15','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(671,'18a99d71-9aa2-4c27-a5c9-fd85cf827aa5','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:58',NULL,'CREATE','IN_PROGRESS','CellControllerComputeServiceChainRoleData','overcloud-CellControllerComputeServiceChainRoleData-kazdwu4digtx','state changed','OS::Heat::Value',NULL,400),(672,'47f34a04-fec3-48be-b3a3-966c5bc301f8','c562d84a-2b8e-4b11-9a98-8a218f775a15','2026-06-09 08:01:58',NULL,'CREATE','COMPLETE','overcloud-CellController-pu35bwiwj6i7','c562d84a-2b8e-4b11-9a98-8a218f775a15','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(673,'6c99f108-2e53-4f51-b4bc-57a323f8a1d9','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:58',NULL,'CREATE','COMPLETE','CellControllerComputeServiceChainRoleData','overcloud-CellControllerComputeServiceChainRoleData-kazdwu4digtx','state changed','OS::Heat::Value',NULL,400),(674,'5ac56e3e-7afd-4b7c-b06e-59c6c4d02621','76704e88-86e6-482c-bf6c-6e25173f798c','2026-06-09 08:01:58',NULL,'CREATE','IN_PROGRESS','2','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-2-w6w3yjlor44g','state changed','OS::TripleO::Services::Collectd',NULL,402),(675,'ae82471b-d221-4b75-a5b2-6504646e40e8','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:58',NULL,'CREATE','COMPLETE','CephStorageServiceChain','aa391ec1-d9a9-45e6-bb38-799ebea54dd2','state changed','OS::TripleO::CephStorageServices',NULL,85),(676,'00d4f601-79dc-4c46-a9a7-f1e72b13bfbb','f84178df-d6ca-4883-ae6e-e32614932fc6','2026-06-09 08:01:58',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-2-w6w3yjlor44g','f84178df-d6ca-4883-ae6e-e32614932fc6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(677,'0adf3618-ae5a-475b-960c-e286399ab32e','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:58',NULL,'CREATE','IN_PROGRESS','CellControllerComputeServiceNames','overcloud-CellControllerComputeServiceNames-65jazfms5bd3','state changed','OS::Heat::Value',NULL,418),(678,'53561ebc-8024-4910-9bc8-cfeb24ae217d','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:58',NULL,'CREATE','COMPLETE','NetworkerServiceChain','64cedc04-99c8-452c-b61e-4a8873d9e5f7','state changed','OS::TripleO::NetworkerServices',NULL,86),(679,'ef22c2cf-2f0c-4bf7-8202-2b3d39d995df','f84178df-d6ca-4883-ae6e-e32614932fc6','2026-06-09 08:01:58',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-2-w6w3yjlor44g-RoleParametersValue-t5g5vsilmcji','state changed','OS::Heat::Value',NULL,426),(680,'f2131b55-97b7-46cc-9b2b-5003eee26a3c','f84178df-d6ca-4883-ae6e-e32614932fc6','2026-06-09 08:01:58',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-2-w6w3yjlor44g-RoleParametersValue-t5g5vsilmcji','state changed','OS::Heat::Value',NULL,426),(681,'366600b5-e30e-436b-8d99-e6e11f9f0b8c','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:58',NULL,'CREATE','COMPLETE','CellControllerComputeServiceNames','overcloud-CellControllerComputeServiceNames-65jazfms5bd3','state changed','OS::Heat::Value',NULL,418),(682,'8c90d8a1-ab26-45fc-98dd-2cd17e0db968','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:58',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','75396b04-8aa7-4164-b8c1-0bb29e9f2525','state changed','OS::TripleO::BlockStorageServiceServerMetadataHook',NULL,206),(683,'63a26468-ec92-4e3a-8144-a9d51e513f14','2470f591-2ecb-487b-872e-f3141cbae41e','2026-06-09 08:01:58',NULL,'CREATE','COMPLETE','overcloud-BlockStorageServiceChain-42trwkc5c77f','2470f591-2ecb-487b-872e-f3141cbae41e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(684,'79bf6f78-5d53-48d6-9760-dbfe18254488','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:58',NULL,'CREATE','IN_PROGRESS','CellControllerCompute','overcloud-CellControllerCompute-ncjqzqwkjh2s','state changed','OS::Heat::ResourceGroup',NULL,455),(685,'5bf5c87c-9ad8-4986-bb89-412dd0cdcdc3','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:58',NULL,'CREATE','IN_PROGRESS','ObjectStorageServiceChainRoleData','overcloud-ObjectStorageServiceChainRoleData-vk32twpswwr6','state changed','OS::Heat::Value',NULL,459),(686,'ef0869c2-6962-4b46-b7b0-ad9b31a7cee2','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:58',NULL,'CREATE','COMPLETE','ObjectStorageServiceChainRoleData','overcloud-ObjectStorageServiceChainRoleData-vk32twpswwr6','state changed','OS::Heat::Value',NULL,459),(687,'eb9be785-0aca-43bc-b139-515c015c77c2','136fc0d0-50f7-4a5a-9280-05b6628e1296','2026-06-09 08:01:58',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerCompute-ncjqzqwkjh2s','136fc0d0-50f7-4a5a-9280-05b6628e1296','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(688,'87147b92-2ad8-4665-85ad-235a7f830836','136fc0d0-50f7-4a5a-9280-05b6628e1296','2026-06-09 08:01:58',NULL,'CREATE','COMPLETE','overcloud-CellControllerCompute-ncjqzqwkjh2s','136fc0d0-50f7-4a5a-9280-05b6628e1296','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(689,'b2d9d284-e0c6-4047-bc4b-217c251f5b29','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:59',NULL,'CREATE','IN_PROGRESS','ObjectStorageServiceNames','overcloud-ObjectStorageServiceNames-ycuqfcuvf7vk','state changed','OS::Heat::Value',NULL,499),(690,'6b46e7db-c367-4b28-9749-b4a0199fe720','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:59',NULL,'CREATE','COMPLETE','ObjectStorageServiceNames','overcloud-ObjectStorageServiceNames-ycuqfcuvf7vk','state changed','OS::Heat::Value',NULL,499),(691,'9aae3964-4664-401c-8d2f-4a0ce8a3d2ce','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:59',NULL,'CREATE','IN_PROGRESS','CephStorageServiceChainRoleData','overcloud-CephStorageServiceChainRoleData-nfk6hx6vemd3','state changed','OS::Heat::Value',NULL,503),(692,'876f4d35-2b4c-4feb-a552-29de973cdcf4','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:59',NULL,'CREATE','COMPLETE','CellController','c562d84a-2b8e-4b11-9a98-8a218f775a15','state changed','OS::Heat::ResourceGroup',NULL,383),(693,'6c1b6ead-42f9-4202-a4ff-212e290a7571','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:59',NULL,'CREATE','COMPLETE','CephStorageServiceChainRoleData','overcloud-CephStorageServiceChainRoleData-nfk6hx6vemd3','state changed','OS::Heat::Value',NULL,503),(694,'f81f9c1f-e2d3-4d39-8755-781e4be93abd','76704e88-86e6-482c-bf6c-6e25173f798c','2026-06-09 08:01:59',NULL,'CREATE','IN_PROGRESS','1','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-1-cryzfwilmjuo','state changed','OS::TripleO::Services::CACerts',NULL,507),(695,'051dbae5-1291-4e49-99cc-ef94d2e2d90d','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:59',NULL,'CREATE','IN_PROGRESS','ObjectStorage','overcloud-ObjectStorage-lsh6swcsa2zj','state changed','OS::Heat::ResourceGroup',NULL,508),(696,'f199701c-93c2-460a-9c00-a16757548cad','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:59',NULL,'CREATE','IN_PROGRESS','CephStorageServiceNames','overcloud-CephStorageServiceNames-sdoquf2w65y2','state changed','OS::Heat::Value',NULL,509),(697,'6b51dec8-4dfe-4cbd-b514-6de64080e922','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:59',NULL,'CREATE','IN_PROGRESS','CellControllerNetworkHostnameMap','overcloud-CellControllerNetworkHostnameMap-u3lhkjqbh4mb','state changed','OS::Heat::Value',NULL,511),(698,'70502778-ed49-4589-896b-ebd49ca85442','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:59',NULL,'CREATE','COMPLETE','CellControllerNetworkHostnameMap','overcloud-CellControllerNetworkHostnameMap-u3lhkjqbh4mb','state changed','OS::Heat::Value',NULL,511),(699,'340ec27e-0154-483a-ae6a-fb58d5537a6d','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:59',NULL,'CREATE','COMPLETE','CephStorageServiceNames','overcloud-CephStorageServiceNames-sdoquf2w65y2','state changed','OS::Heat::Value',NULL,509),(700,'a8e12afa-c828-404e-a518-7e374653ec71','9441dfff-ca07-477d-948c-60c4e42adb31','2026-06-09 08:01:59',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-1-cryzfwilmjuo','9441dfff-ca07-477d-948c-60c4e42adb31','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(701,'b01ebc92-df5a-4b42-b80b-52a98b7cfbd1','fea68de3-f0d7-4ada-adcc-50c0644e64f0','2026-06-09 08:01:59',NULL,'CREATE','IN_PROGRESS','overcloud-ObjectStorage-lsh6swcsa2zj','fea68de3-f0d7-4ada-adcc-50c0644e64f0','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(702,'88803a39-9898-402b-a135-0f9a443fbd40','f84178df-d6ca-4883-ae6e-e32614932fc6','2026-06-09 08:01:59',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-2-w6w3yjlor44g-ContainersCommon-trhjkdird3ty','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(703,'e52bde27-a2d0-4d38-a3af-e5582067a124','fea68de3-f0d7-4ada-adcc-50c0644e64f0','2026-06-09 08:01:59',NULL,'CREATE','COMPLETE','overcloud-ObjectStorage-lsh6swcsa2zj','fea68de3-f0d7-4ada-adcc-50c0644e64f0','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(704,'ace3b8e9-1cd3-452b-a97d-9487a377af84','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:59',NULL,'CREATE','IN_PROGRESS','NetworkerServiceChainRoleData','overcloud-NetworkerServiceChainRoleData-o3mwnqdyh2ps','state changed','OS::Heat::Value',NULL,516),(705,'4bbf3751-9bb2-4367-9d4a-846dd9ddcbc6','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:59',NULL,'CREATE','IN_PROGRESS','CellControllerServers','overcloud-CellControllerServers-iesoy5ywpvqj','state changed','OS::Heat::Value',NULL,517),(706,'290ac6cb-3b4f-4178-a072-b6ef34da955e','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:59',NULL,'CREATE','COMPLETE','CellControllerServers','overcloud-CellControllerServers-iesoy5ywpvqj','state changed','OS::Heat::Value',NULL,517),(707,'f542a8a7-a29a-43fd-8ddd-10b10d9055e8','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:59',NULL,'CREATE','IN_PROGRESS','CellControllerIpListMap','overcloud-CellControllerIpListMap-lquckvw2gbgq','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,518),(708,'ba891c50-6615-4527-b720-e2390c090305','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:59',NULL,'CREATE','COMPLETE','BlockStorageServiceChain','2470f591-2ecb-487b-872e-f3141cbae41e','state changed','OS::TripleO::BlockStorageServices',NULL,81),(709,'aada6a64-6963-4fed-9784-994ad1cff0c3','9441dfff-ca07-477d-948c-60c4e42adb31','2026-06-09 08:01:59',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-1-cryzfwilmjuo','9441dfff-ca07-477d-948c-60c4e42adb31','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(710,'0a91cf1e-3fd9-48db-94c1-14ad168d9807','fd2d036e-b75c-416b-a195-2db41352bc26','2026-06-09 08:01:59',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerIpListMap-lquckvw2gbgq','fd2d036e-b75c-416b-a195-2db41352bc26','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(711,'8ec08a86-167f-46de-b83a-9614835e3793','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:59',NULL,'CREATE','COMPLETE','NetworkerServiceChainRoleData','overcloud-NetworkerServiceChainRoleData-o3mwnqdyh2ps','state changed','OS::Heat::Value',NULL,516),(712,'4849d877-c82b-4c9b-b168-4fd33e1830ac','90cfed5a-2503-4511-9a3a-8bdaddd05bb5','2026-06-09 08:01:59',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-2-w6w3yjlor44g-ContainersCommon-trhjkdird3ty','90cfed5a-2503-4511-9a3a-8bdaddd05bb5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(713,'b4f6b3a1-e9fa-4e7b-abbb-65c2ca891525','76704e88-86e6-482c-bf6c-6e25173f798c','2026-06-09 08:01:59',NULL,'CREATE','COMPLETE','1','9441dfff-ca07-477d-948c-60c4e42adb31','state changed','OS::TripleO::Services::CACerts',NULL,507),(714,'90b00d69-bb2b-4a21-be67-1238c5a890c0','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:59',NULL,'CREATE','IN_PROGRESS','CephStorage','overcloud-CephStorage-imhbeeigxli4','state changed','OS::Heat::ResourceGroup',NULL,527),(715,'32aaea06-c754-42e1-9f9f-ffea615050a2','fd2d036e-b75c-416b-a195-2db41352bc26','2026-06-09 08:01:59',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-CellControllerIpListMap-lquckvw2gbgq-NetIpMapValue-irlmtesw7i5d','state changed','OS::Heat::Value',NULL,530),(716,'f677c55b-4070-47e5-8fc1-b7dba1024579','fd2d036e-b75c-416b-a195-2db41352bc26','2026-06-09 08:01:59',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-CellControllerIpListMap-lquckvw2gbgq-NetIpMapValue-irlmtesw7i5d','state changed','OS::Heat::Value',NULL,530),(717,'1566514c-8fa0-4a3f-bc05-84ed2908faec','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:01:59',NULL,'CREATE','COMPLETE','CellControllerCompute','136fc0d0-50f7-4a5a-9280-05b6628e1296','state changed','OS::Heat::ResourceGroup',NULL,455),(718,'1436a4c0-642f-4cc6-8e3e-a91101fc49f6','90cfed5a-2503-4511-9a3a-8bdaddd05bb5','2026-06-09 08:01:59',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-2-w6w3yjlor44g-ContainersCommon-trhjkdird3ty','90cfed5a-2503-4511-9a3a-8bdaddd05bb5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(719,'67471371-b8f5-43cf-8e20-3e941b1a97f4','76704e88-86e6-482c-bf6c-6e25173f798c','2026-06-09 08:02:00',NULL,'CREATE','IN_PROGRESS','5','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-5-wl3qdtegf5x3','state changed','OS::TripleO::Services::IpaClient',NULL,532),(720,'b03d4a21-5c3b-4d3e-9a89-33b31a708ec7','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:00',NULL,'CREATE','IN_PROGRESS','0','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-0-jjbizjv44ngo','state changed','OS::TripleO::Services::BootParams',NULL,534),(721,'6ec797da-5eb9-45c7-a6d5-df6f326a3413','75ab2310-d6b1-422a-a81e-5dee318f7e88','2026-06-09 08:02:00',NULL,'CREATE','IN_PROGRESS','overcloud-CephStorage-imhbeeigxli4','75ab2310-d6b1-422a-a81e-5dee318f7e88','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(722,'bbf0864d-1549-458d-a228-7bb8a4a27370','53e7ffde-6174-454a-86c7-c0ef643f7517','2026-06-09 08:02:00',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-5-wl3qdtegf5x3','53e7ffde-6174-454a-86c7-c0ef643f7517','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(723,'09ef5b9a-f5b5-4ba7-87ac-f9e8c4e994ed','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:02:00',NULL,'CREATE','IN_PROGRESS','CellControllerComputeNetworkHostnameMap','overcloud-CellControllerComputeNetworkHostnameMap-h5i4k4d34ggk','state changed','OS::Heat::Value',NULL,537),(724,'7b437dec-f3c4-4d2b-9465-1f0ad5a7d5d5','75ab2310-d6b1-422a-a81e-5dee318f7e88','2026-06-09 08:02:00',NULL,'CREATE','COMPLETE','overcloud-CephStorage-imhbeeigxli4','75ab2310-d6b1-422a-a81e-5dee318f7e88','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(725,'e8cbe3d4-b417-4300-93c2-a162eedf6c8a','53e7ffde-6174-454a-86c7-c0ef643f7517','2026-06-09 08:02:00',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-5-wl3qdtegf5x3','53e7ffde-6174-454a-86c7-c0ef643f7517','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(726,'c117a489-bb84-4fe2-952d-3892a68f05ae','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:02:00',NULL,'CREATE','COMPLETE','CellControllerComputeNetworkHostnameMap','overcloud-CellControllerComputeNetworkHostnameMap-h5i4k4d34ggk','state changed','OS::Heat::Value',NULL,537),(727,'6f44707b-2ad2-4b29-9d06-a6bdabba6240','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:02:00',NULL,'CREATE','COMPLETE','CephStorage','75ab2310-d6b1-422a-a81e-5dee318f7e88','state changed','OS::Heat::ResourceGroup',NULL,527),(728,'aebcae3a-a197-4a82-8b03-c4c88fb23d74','24c82031-43eb-4676-8698-94651f100b02','2026-06-09 08:02:00',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-0-jjbizjv44ngo','24c82031-43eb-4676-8698-94651f100b02','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(729,'036bda66-cbec-43b1-9688-5f335886f28f','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:02:00',NULL,'CREATE','IN_PROGRESS','CellControllerComputeServers','overcloud-CellControllerComputeServers-k4cb46kccsrj','state changed','OS::Heat::Value',NULL,547),(730,'4de009d8-5fef-4732-8397-fef259665610','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:02:00',NULL,'CREATE','COMPLETE','CellControllerComputeServers','overcloud-CellControllerComputeServers-k4cb46kccsrj','state changed','OS::Heat::Value',NULL,547),(731,'179776e5-8593-411d-bfc2-ea2fe07478d8','24c82031-43eb-4676-8698-94651f100b02','2026-06-09 08:02:00',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-0-jjbizjv44ngo-RoleParametersValue-ap6vlmtltf52','state changed','OS::Heat::Value',NULL,557),(732,'81037af5-c19b-4673-8ca3-d1a193a36f53','24c82031-43eb-4676-8698-94651f100b02','2026-06-09 08:02:00',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-0-jjbizjv44ngo-RoleParametersValue-ap6vlmtltf52','state changed','OS::Heat::Value',NULL,557),(733,'aadf303b-12db-4fbb-9d9a-5df50e5faa0b','24c82031-43eb-4676-8698-94651f100b02','2026-06-09 08:02:00',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-0-jjbizjv44ngo','24c82031-43eb-4676-8698-94651f100b02','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(734,'4fc9ebbe-f1f6-47bd-abcf-cd76ed14ea3c','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:02:00',NULL,'CREATE','IN_PROGRESS','NetworkerServiceNames','overcloud-NetworkerServiceNames-2mv2a4rdxsun','state changed','OS::Heat::Value',NULL,567),(735,'804e173b-0312-4775-b608-8c84c5e3fbc6','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:02:00',NULL,'CREATE','IN_PROGRESS','CephStorageNetworkHostnameMap','overcloud-CephStorageNetworkHostnameMap-f3jslfgvw7t3','state changed','OS::Heat::Value',NULL,569),(736,'5e8138c4-a184-45d9-af79-61ddad7f1747','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:02:00',NULL,'CREATE','COMPLETE','NetworkerServiceNames','overcloud-NetworkerServiceNames-2mv2a4rdxsun','state changed','OS::Heat::Value',NULL,567),(737,'9e9cdd39-69ac-46d4-8a7c-72b5ac6587ba','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:02:00',NULL,'CREATE','IN_PROGRESS','CellControllerComputeIpListMap','overcloud-CellControllerComputeIpListMap-uzfby6icnehk','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,560),(738,'ec848bcf-eac8-452f-96f1-9f28e906f96b','76704e88-86e6-482c-bf6c-6e25173f798c','2026-06-09 08:02:00',NULL,'CREATE','IN_PROGRESS','0','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-0-x6rvvrllzvl4','state changed','OS::TripleO::Services::BootParams',NULL,571),(739,'759db7da-dfb3-4ba1-b028-dd8f5f5ea7af','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:02:00',NULL,'CREATE','COMPLETE','CephStorageNetworkHostnameMap','overcloud-CephStorageNetworkHostnameMap-f3jslfgvw7t3','state changed','OS::Heat::Value',NULL,569),(740,'2f8c7068-758a-41a5-ad20-f0de6ba9c406','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:02:00',NULL,'CREATE','IN_PROGRESS','CephStorageServers','overcloud-CephStorageServers-bt6m77qgyhsz','state changed','OS::Heat::Value',NULL,574),(741,'a9fe2fe8-2e71-4af1-ba28-47affdf6bc4d','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:02:00',NULL,'CREATE','COMPLETE','ObjectStorage','fea68de3-f0d7-4ada-adcc-50c0644e64f0','state changed','OS::Heat::ResourceGroup',NULL,508),(742,'4ca1021d-c80d-486d-8fde-178641b73968','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:02:00',NULL,'CREATE','IN_PROGRESS','BlockStorageServiceChainRoleData','overcloud-BlockStorageServiceChainRoleData-eb2krec6srr2','state changed','OS::Heat::Value',NULL,575),(743,'2d4fbace-e07c-4c7d-bbc6-d753719b7231','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:02:00',NULL,'CREATE','COMPLETE','CephStorageServers','overcloud-CephStorageServers-bt6m77qgyhsz','state changed','OS::Heat::Value',NULL,574),(744,'11990dba-c856-473a-bc7a-ea8cda0fdf70','d2f79ac1-365a-47c3-a2dd-b4d7ec7f969c','2026-06-09 08:02:00',NULL,'CREATE','IN_PROGRESS','overcloud-CellControllerComputeIpListMap-uzfby6icnehk','d2f79ac1-365a-47c3-a2dd-b4d7ec7f969c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(745,'15765d75-9983-4439-8a05-812f266e67b8','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:02:00',NULL,'CREATE','IN_PROGRESS','Networker','overcloud-Networker-vyeiv5dhnqot','state changed','OS::Heat::ResourceGroup',NULL,576),(746,'34290c59-039d-4b76-937d-5e8b76ae2858','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:02:00',NULL,'CREATE','COMPLETE','BlockStorageServiceChainRoleData','overcloud-BlockStorageServiceChainRoleData-eb2krec6srr2','state changed','OS::Heat::Value',NULL,575),(747,'42f9c893-4862-45fc-92e2-6c1f5b75bc20','dfc1ce87-f889-48e0-8f50-ccf7106dd763','2026-06-09 08:02:00',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-0-x6rvvrllzvl4','dfc1ce87-f889-48e0-8f50-ccf7106dd763','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(748,'39e3c770-e4a5-4ba4-affa-ee2379c12674','dfc1ce87-f889-48e0-8f50-ccf7106dd763','2026-06-09 08:02:00',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-0-x6rvvrllzvl4-RoleParametersValue-qwyr7yqlcq25','state changed','OS::Heat::Value',NULL,579),(749,'a6b3b15a-446e-4e55-a997-eb6d1bbad80e','fd2d036e-b75c-416b-a195-2db41352bc26','2026-06-09 08:02:00',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','overcloud-CellControllerIpListMap-lquckvw2gbgq-EnabledServicesValue-bkj3naduuj3e','state changed','OS::Heat::Value',NULL,581),(750,'7125bf78-a09c-4c87-a6f3-049047ca308b','dfc1ce87-f889-48e0-8f50-ccf7106dd763','2026-06-09 08:02:00',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-0-x6rvvrllzvl4-RoleParametersValue-qwyr7yqlcq25','state changed','OS::Heat::Value',NULL,579),(751,'8fbc5799-f28b-4960-8fe9-040486442bc7','fd2d036e-b75c-416b-a195-2db41352bc26','2026-06-09 08:02:01',NULL,'CREATE','COMPLETE','EnabledServicesValue','overcloud-CellControllerIpListMap-lquckvw2gbgq-EnabledServicesValue-bkj3naduuj3e','state changed','OS::Heat::Value',NULL,581),(752,'bd26b7d5-cad8-43d1-9540-947fd0ca3d54','dfc1ce87-f889-48e0-8f50-ccf7106dd763','2026-06-09 08:02:01',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-0-x6rvvrllzvl4','dfc1ce87-f889-48e0-8f50-ccf7106dd763','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(753,'0c5401d4-e6f0-4e54-8102-e71ad2aba635','fd2d036e-b75c-416b-a195-2db41352bc26','2026-06-09 08:02:01',NULL,'CREATE','COMPLETE','overcloud-CellControllerIpListMap-lquckvw2gbgq','fd2d036e-b75c-416b-a195-2db41352bc26','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(754,'ec846057-1441-421e-9f31-c75c4e4f4a0e','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:02:01',NULL,'CREATE','IN_PROGRESS','BlockStorageServiceNames','overcloud-BlockStorageServiceNames-fbjrm6lyl46r','state changed','OS::Heat::Value',NULL,584),(755,'be460c06-d7b3-454f-98e1-2e0f2e38ab9c','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:02:01',NULL,'CREATE','IN_PROGRESS','CephStorageIpListMap','overcloud-CephStorageIpListMap-fwfob2q33opm','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,580),(756,'774350f5-1a73-41f2-a540-a0a3669b4185','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:02:01',NULL,'CREATE','COMPLETE','BlockStorageServiceNames','overcloud-BlockStorageServiceNames-fbjrm6lyl46r','state changed','OS::Heat::Value',NULL,584),(757,'e0eeda49-fc5d-4648-9c9c-04d40db2531d','76704e88-86e6-482c-bf6c-6e25173f798c','2026-06-09 08:02:01',NULL,'CREATE','COMPLETE','0','dfc1ce87-f889-48e0-8f50-ccf7106dd763','state changed','OS::TripleO::Services::BootParams',NULL,571),(758,'d58b9657-af0c-4d8f-9674-88c2672f1799','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:02:01',NULL,'CREATE','IN_PROGRESS','ObjectStorageServers','overcloud-ObjectStorageServers-lqug2h2v7xhj','state changed','OS::Heat::Value',NULL,585),(759,'a0cd5fe2-c8ca-4cec-9baf-4aa4a676eac6','79264242-b832-4ddd-a2fd-a5652fbcc1be','2026-06-09 08:02:01',NULL,'CREATE','IN_PROGRESS','overcloud-Networker-vyeiv5dhnqot','79264242-b832-4ddd-a2fd-a5652fbcc1be','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(760,'9b063abb-c520-4eb1-8ccf-47be462e96fc','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:02:01',NULL,'CREATE','COMPLETE','ObjectStorageServers','overcloud-ObjectStorageServers-lqug2h2v7xhj','state changed','OS::Heat::Value',NULL,585),(761,'151ab633-7327-4fde-8578-00d0832e3487','79264242-b832-4ddd-a2fd-a5652fbcc1be','2026-06-09 08:02:01',NULL,'CREATE','COMPLETE','overcloud-Networker-vyeiv5dhnqot','79264242-b832-4ddd-a2fd-a5652fbcc1be','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(762,'c8136daf-de04-49fe-9874-a3671c165e8d','f84178df-d6ca-4883-ae6e-e32614932fc6','2026-06-09 08:02:01',NULL,'CREATE','COMPLETE','ContainersCommon','90cfed5a-2503-4511-9a3a-8bdaddd05bb5','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(763,'83f44cfa-889a-4b9a-80e7-996cdac290f2','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:02:01',NULL,'CREATE','IN_PROGRESS','ObjectStorageNetworkHostnameMap','overcloud-ObjectStorageNetworkHostnameMap-4m6mzuya5i3q','state changed','OS::Heat::Value',NULL,583),(764,'461a960f-cee3-48b9-bee2-c4028141068f','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:01',NULL,'CREATE','IN_PROGRESS','3','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-3-guevzcguma35','state changed','OS::TripleO::Services::CeilometerAgentNotification',NULL,588),(765,'d6e0b0f7-1fc9-41b4-8d61-a3e01e05963b','76704e88-86e6-482c-bf6c-6e25173f798c','2026-06-09 08:02:01',NULL,'CREATE','COMPLETE','5','53e7ffde-6174-454a-86c7-c0ef643f7517','state changed','OS::TripleO::Services::IpaClient',NULL,532),(766,'bb67bdf8-a656-4ba0-812e-72af0c2a73ab','f84178df-d6ca-4883-ae6e-e32614932fc6','2026-06-09 08:02:01',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-2-w6w3yjlor44g','f84178df-d6ca-4883-ae6e-e32614932fc6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(767,'c26f2435-5ba9-41eb-b22f-4b1a012d0a51','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:02:01',NULL,'CREATE','COMPLETE','ObjectStorageNetworkHostnameMap','overcloud-ObjectStorageNetworkHostnameMap-4m6mzuya5i3q','state changed','OS::Heat::Value',NULL,583),(768,'270f2697-2255-4596-8a44-6de858e56211','76704e88-86e6-482c-bf6c-6e25173f798c','2026-06-09 08:02:01',NULL,'CREATE','IN_PROGRESS','4','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-4-5lbhfnwewe4q','state changed','OS::TripleO::Services::CeilometerAgentIpmi',NULL,591),(769,'28a75ab5-2422-4172-a692-3a5393df7ce0','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:01',NULL,'CREATE','COMPLETE','0','24c82031-43eb-4676-8698-94651f100b02','state changed','OS::TripleO::Services::BootParams',NULL,534),(770,'a674d957-146c-47c3-a041-9c632b2900ba','a83fea06-a306-4b77-b438-e640f473f6cb','2026-06-09 08:02:01',NULL,'CREATE','IN_PROGRESS','overcloud-CephStorageIpListMap-fwfob2q33opm','a83fea06-a306-4b77-b438-e640f473f6cb','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(771,'f707f024-bb10-4139-98d2-77d6140696ff','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:02:01',NULL,'CREATE','IN_PROGRESS','BlockStorage','overcloud-BlockStorage-45h2aa5qwptw','state changed','OS::Heat::ResourceGroup',NULL,592),(772,'161ce9a9-79c5-49e8-a4b8-5ed7f662c932','d2f79ac1-365a-47c3-a2dd-b4d7ec7f969c','2026-06-09 08:02:01',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','overcloud-CellControllerComputeIpListMap-uzfby6icnehk-EnabledServicesValue-scyq3va3orrt','state changed','OS::Heat::Value',NULL,595),(773,'dabf8e6f-0b45-40a8-a223-3bdacb6dafdd','d2f79ac1-365a-47c3-a2dd-b4d7ec7f969c','2026-06-09 08:02:01',NULL,'CREATE','COMPLETE','EnabledServicesValue','overcloud-CellControllerComputeIpListMap-uzfby6icnehk-EnabledServicesValue-scyq3va3orrt','state changed','OS::Heat::Value',NULL,595),(774,'854da132-14c5-45c8-8d2a-120ba71ed034','63e123b2-9369-4208-a7e4-49f7810e90f8','2026-06-09 08:02:01',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-3-guevzcguma35','63e123b2-9369-4208-a7e4-49f7810e90f8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(775,'5a6b8307-9881-443e-a887-344d4f9da60d','e866ce7f-f22d-491d-831c-74479a112ae0','2026-06-09 08:02:01',NULL,'CREATE','IN_PROGRESS','overcloud-BlockStorage-45h2aa5qwptw','e866ce7f-f22d-491d-831c-74479a112ae0','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(776,'5e76347d-945e-42d0-b994-2c0fd741fc5b','e866ce7f-f22d-491d-831c-74479a112ae0','2026-06-09 08:02:01',NULL,'CREATE','COMPLETE','overcloud-BlockStorage-45h2aa5qwptw','e866ce7f-f22d-491d-831c-74479a112ae0','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(777,'9535d319-8923-45ce-aa17-cf9889be7dd7','76704e88-86e6-482c-bf6c-6e25173f798c','2026-06-09 08:02:01',NULL,'CREATE','IN_PROGRESS','9','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-9-lidwb7tvgb6d','state changed','OS::TripleO::Services::MySQLClient',NULL,596),(778,'57e38d81-324e-4b4f-a942-7ae69e8cddcd','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:02:01',NULL,'CREATE','IN_PROGRESS','ObjectStorageIpListMap','overcloud-ObjectStorageIpListMap-wpkukvh3o4ne','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,598),(779,'4f2d9d95-eed0-486b-a471-00277a108e78','76704e88-86e6-482c-bf6c-6e25173f798c','2026-06-09 08:02:01',NULL,'CREATE','COMPLETE','2','f84178df-d6ca-4883-ae6e-e32614932fc6','state changed','OS::TripleO::Services::Collectd',NULL,402),(780,'5399c524-5838-4c1d-ad58-9d580ca3a80a','76704e88-86e6-482c-bf6c-6e25173f798c','2026-06-09 08:02:01',NULL,'CREATE','IN_PROGRESS','3','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-3-gugs6uoae5pf','state changed','OS::TripleO::Services::ComputeCeilometerAgent',NULL,600),(781,'77f0401b-32b5-4f64-b599-17867d42268d','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:02:01',NULL,'CREATE','COMPLETE','BlockStorage','e866ce7f-f22d-491d-831c-74479a112ae0','state changed','OS::Heat::ResourceGroup',NULL,592),(782,'a18c6bf1-e273-401f-9a78-3ec9268f0066','531597ef-dcfc-4735-9fdc-bf6cd4abe565','2026-06-09 08:02:01',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-9-lidwb7tvgb6d','531597ef-dcfc-4735-9fdc-bf6cd4abe565','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(783,'253ef4c3-c1a7-4e97-b90c-b84af0eb784f','cc15bf64-f471-4ad1-8da2-1e94ab0058e3','2026-06-09 08:02:01',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-4-5lbhfnwewe4q','cc15bf64-f471-4ad1-8da2-1e94ab0058e3','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(784,'203ee436-9f85-43da-850d-7c2421d04518','f0cbd9dd-c8cb-4aba-a6a5-6c673f7f5cf5','2026-06-09 08:02:01',NULL,'CREATE','IN_PROGRESS','overcloud-ObjectStorageIpListMap-wpkukvh3o4ne','f0cbd9dd-c8cb-4aba-a6a5-6c673f7f5cf5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(785,'f0ab1c66-83b6-4fcf-bc75-c47edec3f8a2','531597ef-dcfc-4735-9fdc-bf6cd4abe565','2026-06-09 08:02:01',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-9-lidwb7tvgb6d','531597ef-dcfc-4735-9fdc-bf6cd4abe565','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(786,'50ae441e-f048-4f55-9914-b1c600e6f752','a83fea06-a306-4b77-b438-e640f473f6cb','2026-06-09 08:02:01',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','overcloud-CephStorageIpListMap-fwfob2q33opm-EnabledServicesValue-edddet7ozjdb','state changed','OS::Heat::Value',NULL,601),(787,'e61f68a6-305d-406e-bb50-81d2b67febdb','a83fea06-a306-4b77-b438-e640f473f6cb','2026-06-09 08:02:01',NULL,'CREATE','COMPLETE','EnabledServicesValue','overcloud-CephStorageIpListMap-fwfob2q33opm-EnabledServicesValue-edddet7ozjdb','state changed','OS::Heat::Value',NULL,601),(788,'8b9671d7-3128-4a16-a238-f2f9c7ad1405','63e123b2-9369-4208-a7e4-49f7810e90f8','2026-06-09 08:02:01',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-3-guevzcguma35-ContainersCommon-4rgdilkk6m4u','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(789,'1e8d1c2c-62b6-47c2-8f13-e2f857070613','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:02:01',NULL,'CREATE','IN_PROGRESS','BlockStorageServers','overcloud-BlockStorageServers-pz7nqldmtbqk','state changed','OS::Heat::Value',NULL,609),(790,'f9a57f90-4b67-44da-a8b4-a519e83ae789','fdd7c9ba-cc15-4881-b568-e1517e1d493e','2026-06-09 08:02:01',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-3-gugs6uoae5pf','fdd7c9ba-cc15-4881-b568-e1517e1d493e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(791,'e2fd7594-c08d-4a84-b7a2-a3a3c6eccf8a','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:01',NULL,'CREATE','IN_PROGRESS','4','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-4-n3552roca63l','state changed','OS::TripleO::Services::CinderApi',NULL,607),(792,'8cf90488-6797-4e6b-856f-3f279442c2be','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:02:01',NULL,'CREATE','COMPLETE','BlockStorageServers','overcloud-BlockStorageServers-pz7nqldmtbqk','state changed','OS::Heat::Value',NULL,609),(793,'d44063df-c72d-4a64-aeb7-56b941bedf97','f0cbd9dd-c8cb-4aba-a6a5-6c673f7f5cf5','2026-06-09 08:02:01',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-ObjectStorageIpListMap-wpkukvh3o4ne-NetIpMapValue-3qhsq7hznaay','state changed','OS::Heat::Value',NULL,608),(794,'5155ee7d-6177-4622-90b0-3dd9b86f3e9b','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:02:01',NULL,'CREATE','IN_PROGRESS','BlockStorageNetworkHostnameMap','overcloud-BlockStorageNetworkHostnameMap-q46cy7ujlvoq','state changed','OS::Heat::Value',NULL,610),(795,'7f752822-835c-4ab5-82f5-016c741b612e','357ee373-7f56-4c38-9e81-130a2bad8824','2026-06-09 08:02:02',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-3-guevzcguma35-ContainersCommon-4rgdilkk6m4u','357ee373-7f56-4c38-9e81-130a2bad8824','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(796,'006e3a7a-58de-4bf0-b548-6925f62a3062','f0cbd9dd-c8cb-4aba-a6a5-6c673f7f5cf5','2026-06-09 08:02:02',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-ObjectStorageIpListMap-wpkukvh3o4ne-NetIpMapValue-3qhsq7hznaay','state changed','OS::Heat::Value',NULL,608),(797,'19134955-68f1-4d51-b415-cdb4413dd55f','357ee373-7f56-4c38-9e81-130a2bad8824','2026-06-09 08:02:02',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-3-guevzcguma35-ContainersCommon-4rgdilkk6m4u','357ee373-7f56-4c38-9e81-130a2bad8824','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(798,'53e6b5ee-0f3c-481b-8709-d0a4a9544525','76704e88-86e6-482c-bf6c-6e25173f798c','2026-06-09 08:02:02',NULL,'CREATE','IN_PROGRESS','6','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-6-wie4d6fzz7ve','state changed','OS::TripleO::Services::Iscsid',NULL,613),(799,'1cdbec31-c4af-458c-a8cc-7606f3012331','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:02:02',NULL,'CREATE','COMPLETE','CellControllerIpListMap','fd2d036e-b75c-416b-a195-2db41352bc26','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,518),(800,'e4ee61fb-8f32-43fd-a998-f7987921b779','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:02',NULL,'CREATE','IN_PROGRESS','2','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-2-j5qrqbqoixxr','state changed','OS::TripleO::Services::CeilometerAgentCentral',NULL,614),(801,'0df63de5-8ab3-4805-a9bc-5570900898ca','63e123b2-9369-4208-a7e4-49f7810e90f8','2026-06-09 08:02:02',NULL,'CREATE','COMPLETE','ContainersCommon','357ee373-7f56-4c38-9e81-130a2bad8824','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(802,'b593401e-ae31-451a-88d3-34c798d882e6','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:02:02',NULL,'CREATE','COMPLETE','Networker','79264242-b832-4ddd-a2fd-a5652fbcc1be','state changed','OS::Heat::ResourceGroup',NULL,576),(803,'ac73328e-44a5-41e2-9661-06df45ad5d0f','fdd7c9ba-cc15-4881-b568-e1517e1d493e','2026-06-09 08:02:02',NULL,'CREATE','IN_PROGRESS','CeilometerServiceBase','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-3-gugs6uoae5pf-CeilometerServiceBase-uzcqirlw3q6d','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,615),(804,'0bb60e86-8cb6-48a8-8112-5be9dbee7a41','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:02:02',NULL,'CREATE','COMPLETE','BlockStorageNetworkHostnameMap','overcloud-BlockStorageNetworkHostnameMap-q46cy7ujlvoq','state changed','OS::Heat::Value',NULL,610),(805,'fbf6cea2-4134-485d-9321-d8a0fc8804d9','e1fe4582-3252-4b51-8c24-a618b087c9f5','2026-06-09 08:02:02',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-2-j5qrqbqoixxr','e1fe4582-3252-4b51-8c24-a618b087c9f5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(806,'e94d35cc-70ff-485e-8070-66d46baf183c','e29a6867-5a44-47d0-9a1e-a8f52241bf44','2026-06-09 08:02:02',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-3-gugs6uoae5pf-CeilometerServiceBase-uzcqirlw3q6d','e29a6867-5a44-47d0-9a1e-a8f52241bf44','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(807,'b32732cb-2880-4c57-9194-bb59eb5924bb','e29a6867-5a44-47d0-9a1e-a8f52241bf44','2026-06-09 08:02:02',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-3-gugs6uoae5pf-CeilometerServiceBase-uzcqirlw3q6d','e29a6867-5a44-47d0-9a1e-a8f52241bf44','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(808,'4637365d-780a-4b9f-821d-c16d6c9a93ea','ba9e235d-ae13-45bd-87af-cd3e5bc86814','2026-06-09 08:02:02',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-4-n3552roca63l','ba9e235d-ae13-45bd-87af-cd3e5bc86814','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(809,'b0cf5f4f-9d84-4463-b7f9-47550d22ed02','5b6f6146-e0b6-49b7-a9c5-fbacd4e0ffba','2026-06-09 08:02:02',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-6-wie4d6fzz7ve','5b6f6146-e0b6-49b7-a9c5-fbacd4e0ffba','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(810,'3b1b7189-d4e0-45a2-9f23-4bb2171ef303','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:02:02',NULL,'CREATE','IN_PROGRESS','BlockStorageIpListMap','overcloud-BlockStorageIpListMap-bgfsekwnegvu','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,617),(811,'d118100a-33eb-4862-b1fe-826df68af773','e1fe4582-3252-4b51-8c24-a618b087c9f5','2026-06-09 08:02:02',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-2-j5qrqbqoixxr-RoleParametersValue-3ssfllcevutm','state changed','OS::Heat::Value',NULL,620),(812,'4f381701-fdbc-4bb8-90d9-469e5f06304e','e1fe4582-3252-4b51-8c24-a618b087c9f5','2026-06-09 08:02:02',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-2-j5qrqbqoixxr-RoleParametersValue-3ssfllcevutm','state changed','OS::Heat::Value',NULL,620),(813,'e6d3a803-4bb5-4d2d-9d50-4aa76a6b5a37','d2f79ac1-365a-47c3-a2dd-b4d7ec7f969c','2026-06-09 08:02:02',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-CellControllerComputeIpListMap-uzfby6icnehk-NetIpMapValue-gpuyvrmkbl2x','state changed','OS::Heat::Value',NULL,619),(814,'9912bba7-edb9-4981-a98b-f9091602d5e0','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:02:02',NULL,'CREATE','IN_PROGRESS','NetworkerServers','overcloud-NetworkerServers-p34pblgqf6tu','state changed','OS::Heat::Value',NULL,621),(815,'a7da50d2-0882-4cff-811b-0332821ab16b','5e0cace8-0b97-4e55-908e-6d41c653ee6e','2026-06-09 08:02:02',NULL,'CREATE','IN_PROGRESS','overcloud-BlockStorageIpListMap-bgfsekwnegvu','5e0cace8-0b97-4e55-908e-6d41c653ee6e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(816,'a084cecb-3287-48ff-8b62-c582c647d2f8','d2f79ac1-365a-47c3-a2dd-b4d7ec7f969c','2026-06-09 08:02:02',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-CellControllerComputeIpListMap-uzfby6icnehk-NetIpMapValue-gpuyvrmkbl2x','state changed','OS::Heat::Value',NULL,619),(817,'9101341c-6510-45e4-966d-afe9a4d728cd','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:02:02',NULL,'CREATE','COMPLETE','NetworkerServers','overcloud-NetworkerServers-p34pblgqf6tu','state changed','OS::Heat::Value',NULL,621),(818,'b2cffa6c-2c0b-4eb9-8934-c597cd0f094b','d2f79ac1-365a-47c3-a2dd-b4d7ec7f969c','2026-06-09 08:02:02',NULL,'CREATE','COMPLETE','overcloud-CellControllerComputeIpListMap-uzfby6icnehk','d2f79ac1-365a-47c3-a2dd-b4d7ec7f969c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(819,'a0b1230c-0e01-4b21-89ea-ccedfdf54f12','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:02:02',NULL,'CREATE','IN_PROGRESS','NetworkerNetworkHostnameMap','overcloud-NetworkerNetworkHostnameMap-73y77rmiz5zw','state changed','OS::Heat::Value',NULL,622),(820,'3a969c61-916b-4678-b904-1e0afab47229','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:02:02',NULL,'CREATE','COMPLETE','NetworkerNetworkHostnameMap','overcloud-NetworkerNetworkHostnameMap-73y77rmiz5zw','state changed','OS::Heat::Value',NULL,622),(821,'8f495bbb-033a-4907-bdd2-4e343c3695d1','a83fea06-a306-4b77-b438-e640f473f6cb','2026-06-09 08:02:02',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-CephStorageIpListMap-fwfob2q33opm-NetIpMapValue-higpmxrchek7','state changed','OS::Heat::Value',NULL,623),(822,'ad900b11-b0b1-4d53-a931-716729fef0d3','a83fea06-a306-4b77-b438-e640f473f6cb','2026-06-09 08:02:02',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-CephStorageIpListMap-fwfob2q33opm-NetIpMapValue-higpmxrchek7','state changed','OS::Heat::Value',NULL,623),(823,'9fc9f562-6f12-4a15-94bd-d5eb06e01abf','cc15bf64-f471-4ad1-8da2-1e94ab0058e3','2026-06-09 08:02:02',NULL,'CREATE','IN_PROGRESS','CeilometerServiceBase','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-4-5lbhfnwewe4q-CeilometerServiceBase-fqmq7dqx5cmn','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,624),(824,'f688d3b8-d683-4739-bdbc-e5bc43a37605','5e0cace8-0b97-4e55-908e-6d41c653ee6e','2026-06-09 08:02:02',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-BlockStorageIpListMap-bgfsekwnegvu-NetIpMapValue-quxny3nlzrsy','state changed','OS::Heat::Value',NULL,625),(825,'4c286ff6-a2b7-458f-a68e-a567e5a15251','a83fea06-a306-4b77-b438-e640f473f6cb','2026-06-09 08:02:02',NULL,'CREATE','COMPLETE','overcloud-CephStorageIpListMap-fwfob2q33opm','a83fea06-a306-4b77-b438-e640f473f6cb','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(826,'ef6b5b2d-ae13-493a-a97c-93fc12d6551f','5e0cace8-0b97-4e55-908e-6d41c653ee6e','2026-06-09 08:02:02',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-BlockStorageIpListMap-bgfsekwnegvu-NetIpMapValue-quxny3nlzrsy','state changed','OS::Heat::Value',NULL,625),(827,'7f233584-7b2d-4a7a-8286-1e792704f874','76704e88-86e6-482c-bf6c-6e25173f798c','2026-06-09 08:02:02',NULL,'CREATE','COMPLETE','9','531597ef-dcfc-4735-9fdc-bf6cd4abe565','state changed','OS::TripleO::Services::MySQLClient',NULL,596),(828,'e2ef8923-2aee-4c54-8f4d-3a615b77b78b','5b6f6146-e0b6-49b7-a9c5-fbacd4e0ffba','2026-06-09 08:02:02',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-6-wie4d6fzz7ve-RoleParametersValue-b7yi7lpeyomz','state changed','OS::Heat::Value',NULL,628),(829,'a470a160-46c5-4d34-9036-55a45fd23d93','db158eb8-49d6-4143-a31a-549f08a34851','2026-06-09 08:02:02',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-4-5lbhfnwewe4q-CeilometerServiceBase-fqmq7dqx5cmn','db158eb8-49d6-4143-a31a-549f08a34851','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(830,'c991ff0e-2985-46c0-8f8e-21b9f39955a9','5b6f6146-e0b6-49b7-a9c5-fbacd4e0ffba','2026-06-09 08:02:02',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-6-wie4d6fzz7ve-RoleParametersValue-b7yi7lpeyomz','state changed','OS::Heat::Value',NULL,628),(831,'c85eba75-b83f-4d59-af02-700cec37b417','63e123b2-9369-4208-a7e4-49f7810e90f8','2026-06-09 08:02:02',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-3-guevzcguma35-RoleParametersValue-q4bl77qdslis','state changed','OS::Heat::Value',NULL,630),(832,'41aaeac4-6c7f-4847-aa72-b6ffb88922ba','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:02:02',NULL,'CREATE','IN_PROGRESS','NetworkerIpListMap','overcloud-NetworkerIpListMap-4m2zzj2cdmtw','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,629),(833,'8a7efd9e-0348-4e82-8f56-5fbc04822f7b','db158eb8-49d6-4143-a31a-549f08a34851','2026-06-09 08:02:02',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-4-5lbhfnwewe4q-CeilometerServiceBase-fqmq7dqx5cmn','db158eb8-49d6-4143-a31a-549f08a34851','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(834,'c7ac73b9-c095-4f68-bd19-9a97e94a6454','63e123b2-9369-4208-a7e4-49f7810e90f8','2026-06-09 08:02:02',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-3-guevzcguma35-RoleParametersValue-q4bl77qdslis','state changed','OS::Heat::Value',NULL,630),(835,'b296b8f8-6ed5-4e30-ae51-56f849d0de79','f0cbd9dd-c8cb-4aba-a6a5-6c673f7f5cf5','2026-06-09 08:02:02',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','overcloud-ObjectStorageIpListMap-wpkukvh3o4ne-EnabledServicesValue-tt2g6cjwyb5c','state changed','OS::Heat::Value',NULL,632),(836,'ea22a550-87c6-40f4-ba03-1164052514b3','f0cbd9dd-c8cb-4aba-a6a5-6c673f7f5cf5','2026-06-09 08:02:02',NULL,'CREATE','COMPLETE','EnabledServicesValue','overcloud-ObjectStorageIpListMap-wpkukvh3o4ne-EnabledServicesValue-tt2g6cjwyb5c','state changed','OS::Heat::Value',NULL,632),(837,'2714fbf0-5243-45d7-8aef-ebc884f9f194','ba9e235d-ae13-45bd-87af-cd3e5bc86814','2026-06-09 08:02:02',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-4-n3552roca63l-MySQLClient-2s3e6bqdtdkb','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(838,'3b4dad14-a9f9-4af7-9acb-d5cf260a9efd','352b0322-2a5b-4df4-9d6c-92968ce1c910','2026-06-09 08:02:03',NULL,'CREATE','IN_PROGRESS','overcloud-NetworkerIpListMap-4m2zzj2cdmtw','352b0322-2a5b-4df4-9d6c-92968ce1c910','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(839,'7750a98f-c4fb-486e-96fd-b80a2aa24939','76704e88-86e6-482c-bf6c-6e25173f798c','2026-06-09 08:02:03',NULL,'CREATE','IN_PROGRESS','13','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-13-5blxgktwo2sf','state changed','OS::TripleO::Services::NovaMigrationTarget',NULL,633),(840,'66e6207b-2661-4858-b9b3-e03ba805cfef','f0cbd9dd-c8cb-4aba-a6a5-6c673f7f5cf5','2026-06-09 08:02:03',NULL,'CREATE','COMPLETE','overcloud-ObjectStorageIpListMap-wpkukvh3o4ne','f0cbd9dd-c8cb-4aba-a6a5-6c673f7f5cf5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(841,'5591279e-9ec0-4856-bf91-43615a7c72a7','b451c416-d26d-4e3c-b580-6233f3dd6d89','2026-06-09 08:02:03',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-13-5blxgktwo2sf','b451c416-d26d-4e3c-b580-6233f3dd6d89','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(842,'7a839ba8-9eb1-4afd-a03c-5eebf83b4d5e','352b0322-2a5b-4df4-9d6c-92968ce1c910','2026-06-09 08:02:03',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-NetworkerIpListMap-4m2zzj2cdmtw-NetIpMapValue-ox5fklhfe66w','state changed','OS::Heat::Value',NULL,634),(843,'0e32f589-e5db-49f7-8f70-7fb19b48475d','352b0322-2a5b-4df4-9d6c-92968ce1c910','2026-06-09 08:02:03',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-NetworkerIpListMap-4m2zzj2cdmtw-NetIpMapValue-ox5fklhfe66w','state changed','OS::Heat::Value',NULL,634),(844,'0d892adb-c1b1-4994-99b3-7b0441900329','fdd7c9ba-cc15-4881-b568-e1517e1d493e','2026-06-09 08:02:03',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-3-gugs6uoae5pf-RoleParametersValue-pmzhedzi7pkk','state changed','OS::Heat::Value',NULL,636),(845,'3618fdca-4247-4bb0-b1a1-41175b957217','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:03',NULL,'CREATE','IN_PROGRESS','1','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-1-6ip77xhd4ohn','state changed','OS::TripleO::Services::CACerts',NULL,635),(846,'1fb72427-c6e6-4143-9f78-4e4583e4ff7c','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:02:03',NULL,'CREATE','COMPLETE','CellControllerComputeIpListMap','d2f79ac1-365a-47c3-a2dd-b4d7ec7f969c','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,560),(847,'95f2a32e-55a0-467d-a6cb-a11646b4517d','fdd7c9ba-cc15-4881-b568-e1517e1d493e','2026-06-09 08:02:03',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-3-gugs6uoae5pf-RoleParametersValue-pmzhedzi7pkk','state changed','OS::Heat::Value',NULL,636),(848,'2a7e6fd8-26cd-452f-9120-21cd371fa8d3','4b6ff10c-6bed-4a2d-97d7-a09159218c93','2026-06-09 08:02:03',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-4-n3552roca63l-MySQLClient-2s3e6bqdtdkb','4b6ff10c-6bed-4a2d-97d7-a09159218c93','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(849,'e472fd2a-dc4c-4466-8f62-f39862fa8ff3','4b6ff10c-6bed-4a2d-97d7-a09159218c93','2026-06-09 08:02:03',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-4-n3552roca63l-MySQLClient-2s3e6bqdtdkb','4b6ff10c-6bed-4a2d-97d7-a09159218c93','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(850,'12561162-7d83-46ed-ac63-ccc72cc48e02','eb2ac9c7-f91d-4451-a01b-3a36f804bf55','2026-06-09 08:02:03',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-1-6ip77xhd4ohn','eb2ac9c7-f91d-4451-a01b-3a36f804bf55','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(851,'43278d4a-1fe8-46d8-ace0-5f0b5f5c1099','eb2ac9c7-f91d-4451-a01b-3a36f804bf55','2026-06-09 08:02:03',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-1-6ip77xhd4ohn','eb2ac9c7-f91d-4451-a01b-3a36f804bf55','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(852,'d047f249-fc71-4482-8e9d-0b2257aaf6ed','b451c416-d26d-4e3c-b580-6233f3dd6d89','2026-06-09 08:02:03',NULL,'CREATE','IN_PROGRESS','SshdBase','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-13-5blxgktwo2sf-SshdBase-4y44adtixska','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-puppet.yaml',NULL,637),(853,'3a3d7418-4df0-4771-9c36-dab9423831ed','fdd7c9ba-cc15-4881-b568-e1517e1d493e','2026-06-09 08:02:03',NULL,'CREATE','COMPLETE','CeilometerServiceBase','e29a6867-5a44-47d0-9a1e-a8f52241bf44','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,615),(854,'00bfd3ac-2a1e-4421-bc7e-03d83cdb5be8','4ae841cc-db8c-4f0c-95fc-df172cc92d64','2026-06-09 08:02:03',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-13-5blxgktwo2sf-SshdBase-4y44adtixska','4ae841cc-db8c-4f0c-95fc-df172cc92d64','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(855,'1071adff-2b9d-4fc3-945e-e0a83cb243cf','4ae841cc-db8c-4f0c-95fc-df172cc92d64','2026-06-09 08:02:03',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-13-5blxgktwo2sf-SshdBase-4y44adtixska','4ae841cc-db8c-4f0c-95fc-df172cc92d64','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(856,'1cc0b4cf-4b46-4c68-ad1d-6252695643dc','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:02:03',NULL,'CREATE','COMPLETE','CephStorageIpListMap','a83fea06-a306-4b77-b438-e640f473f6cb','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,580),(857,'8ed33a1e-e3ac-4376-b95e-9c90254fba14','e1fe4582-3252-4b51-8c24-a618b087c9f5','2026-06-09 08:02:03',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-2-j5qrqbqoixxr-ContainersCommon-4thlsbn6xlg5','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(858,'a8932828-e87a-4c27-9b77-1dab124e176f','cc15bf64-f471-4ad1-8da2-1e94ab0058e3','2026-06-09 08:02:03',NULL,'CREATE','IN_PROGRESS','CeilometerAgentCentralBase','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-4-5lbhfnwewe4q-CeilometerAgentCentralBase-tpi4jzs52mtu','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml',NULL,638),(859,'b53d714b-f8a8-46a5-a2c4-542516d934f6','51b59720-42dd-44b9-8478-63cb2dbec3a4','2026-06-09 08:02:03',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-2-j5qrqbqoixxr-ContainersCommon-4thlsbn6xlg5','51b59720-42dd-44b9-8478-63cb2dbec3a4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(860,'735bc268-b7e4-4b00-ac7c-bc3665026bbb','5e0cace8-0b97-4e55-908e-6d41c653ee6e','2026-06-09 08:02:03',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','overcloud-BlockStorageIpListMap-bgfsekwnegvu-EnabledServicesValue-3riu73kc2u2m','state changed','OS::Heat::Value',NULL,639),(861,'db608a99-043d-4e6b-a58f-b0856b038938','51b59720-42dd-44b9-8478-63cb2dbec3a4','2026-06-09 08:02:03',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-2-j5qrqbqoixxr-ContainersCommon-4thlsbn6xlg5','51b59720-42dd-44b9-8478-63cb2dbec3a4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(862,'c5161faf-db4e-4eb3-b16e-afbd5a701a3b','5e0cace8-0b97-4e55-908e-6d41c653ee6e','2026-06-09 08:02:03',NULL,'CREATE','COMPLETE','EnabledServicesValue','overcloud-BlockStorageIpListMap-bgfsekwnegvu-EnabledServicesValue-3riu73kc2u2m','state changed','OS::Heat::Value',NULL,639),(863,'e7889951-b2e4-420f-8160-780c0105da66','5e0cace8-0b97-4e55-908e-6d41c653ee6e','2026-06-09 08:02:03',NULL,'CREATE','COMPLETE','overcloud-BlockStorageIpListMap-bgfsekwnegvu','5e0cace8-0b97-4e55-908e-6d41c653ee6e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(864,'2cb7bb89-426f-4657-9a97-e31a0e5b768c','4ac547da-6fb9-4680-b6db-353a5cca7ef9','2026-06-09 08:02:03',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-4-5lbhfnwewe4q-CeilometerAgentCentralBase-tpi4jzs52mtu','4ac547da-6fb9-4680-b6db-353a5cca7ef9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(865,'2ba38351-e59d-4420-8eab-d0f68dc3d682','5b6f6146-e0b6-49b7-a9c5-fbacd4e0ffba','2026-06-09 08:02:03',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-6-wie4d6fzz7ve-ContainersCommon-jcdei4kkmujr','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(866,'117605f9-6faf-40de-950c-c13f2dbe33a7','63e123b2-9369-4208-a7e4-49f7810e90f8','2026-06-09 08:02:03',NULL,'CREATE','IN_PROGRESS','CeilometerServiceBase','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-3-guevzcguma35-CeilometerServiceBase-5gsuhj4xm73u','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,640),(867,'c6b188fa-17c3-498d-ac35-24c1a5d6c900','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:02:03',NULL,'CREATE','COMPLETE','ObjectStorageIpListMap','f0cbd9dd-c8cb-4aba-a6a5-6c673f7f5cf5','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,598),(868,'65022bf9-d735-4bea-a3a9-7cc302016038','cc15bf64-f471-4ad1-8da2-1e94ab0058e3','2026-06-09 08:02:03',NULL,'CREATE','COMPLETE','CeilometerServiceBase','db158eb8-49d6-4143-a31a-549f08a34851','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,624),(869,'cf4e2f92-3642-4c84-bd04-cd66aa69869d','29d665b0-87ae-44c0-bd1f-957b0fafe244','2026-06-09 08:02:03',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-6-wie4d6fzz7ve-ContainersCommon-jcdei4kkmujr','29d665b0-87ae-44c0-bd1f-957b0fafe244','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(870,'cab5663a-55e5-4f38-9b27-4f0fd9f11971','9bf02761-3848-4cba-945b-1e13a69320c4','2026-06-09 08:02:03',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-3-guevzcguma35-CeilometerServiceBase-5gsuhj4xm73u','9bf02761-3848-4cba-945b-1e13a69320c4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(871,'9025d0bf-13f9-40e4-989c-87242a5f40b4','29d665b0-87ae-44c0-bd1f-957b0fafe244','2026-06-09 08:02:03',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-6-wie4d6fzz7ve-ContainersCommon-jcdei4kkmujr','29d665b0-87ae-44c0-bd1f-957b0fafe244','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(872,'d43dc5ec-527d-4bfa-971b-ce514a2d75c5','9bf02761-3848-4cba-945b-1e13a69320c4','2026-06-09 08:02:03',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-3-guevzcguma35-CeilometerServiceBase-5gsuhj4xm73u','9bf02761-3848-4cba-945b-1e13a69320c4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(873,'d2df891c-7b16-4735-b3b8-a906ad1e7570','4ac547da-6fb9-4680-b6db-353a5cca7ef9','2026-06-09 08:02:04',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-4-5lbhfnwewe4q-CeilometerAgentCentralBase-tpi4jzs52mtu-ContainersCommon-3qrlcdnsittw','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(874,'6882c71a-b804-4f1e-97b0-936c72e72c90','63e123b2-9369-4208-a7e4-49f7810e90f8','2026-06-09 08:02:04',NULL,'CREATE','COMPLETE','CeilometerServiceBase','9bf02761-3848-4cba-945b-1e13a69320c4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,640),(875,'0d47c2ab-ebfe-450f-ae39-8a9bf1fcf744','ba9e235d-ae13-45bd-87af-cd3e5bc86814','2026-06-09 08:02:04',NULL,'CREATE','IN_PROGRESS','ApacheServiceBase','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-4-n3552roca63l-ApacheServiceBase-6ootxjbtys2b','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,641),(876,'4e377079-bc24-41e5-bae4-21b715173c75','63e123b2-9369-4208-a7e4-49f7810e90f8','2026-06-09 08:02:04',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-3-guevzcguma35','63e123b2-9369-4208-a7e4-49f7810e90f8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(877,'9873d639-e91b-409e-8ea8-9663d8be7a82','6e36d777-9a80-435c-a923-58d13a889549','2026-06-09 08:02:04',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-4-n3552roca63l-ApacheServiceBase-6ootxjbtys2b','6e36d777-9a80-435c-a923-58d13a889549','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(878,'7c44d8ec-1645-4eed-b1c3-01ddc9359aea','caf47a6d-90c2-4182-aa81-b473324b15a2','2026-06-09 08:02:04',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-4-5lbhfnwewe4q-CeilometerAgentCentralBase-tpi4jzs52mtu-ContainersCommon-3qrlcdnsittw','caf47a6d-90c2-4182-aa81-b473324b15a2','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(879,'f4783667-d5b9-4fa2-8a0f-ebd1511de53d','caf47a6d-90c2-4182-aa81-b473324b15a2','2026-06-09 08:02:04',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-4-5lbhfnwewe4q-CeilometerAgentCentralBase-tpi4jzs52mtu-ContainersCommon-3qrlcdnsittw','caf47a6d-90c2-4182-aa81-b473324b15a2','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(880,'0fa30b30-7d20-4734-b832-5c73d9b8843c','352b0322-2a5b-4df4-9d6c-92968ce1c910','2026-06-09 08:02:04',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','overcloud-NetworkerIpListMap-4m2zzj2cdmtw-EnabledServicesValue-w4gfjzpheroc','state changed','OS::Heat::Value',NULL,642),(881,'ebcbf071-43fb-48f2-a8fc-cc65b0f891e6','352b0322-2a5b-4df4-9d6c-92968ce1c910','2026-06-09 08:02:04',NULL,'CREATE','COMPLETE','EnabledServicesValue','overcloud-NetworkerIpListMap-4m2zzj2cdmtw-EnabledServicesValue-w4gfjzpheroc','state changed','OS::Heat::Value',NULL,642),(882,'4c2d36c9-31d8-4d53-aa5b-aa1931bd4bdc','4ac547da-6fb9-4680-b6db-353a5cca7ef9','2026-06-09 08:02:04',NULL,'CREATE','COMPLETE','ContainersCommon','caf47a6d-90c2-4182-aa81-b473324b15a2','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(883,'b07f8491-4b1c-44e5-807d-7244ead239c8','352b0322-2a5b-4df4-9d6c-92968ce1c910','2026-06-09 08:02:04',NULL,'CREATE','COMPLETE','overcloud-NetworkerIpListMap-4m2zzj2cdmtw','352b0322-2a5b-4df4-9d6c-92968ce1c910','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(884,'cc4c1d1b-fb61-4737-96a3-252b6e48f3d2','fdd7c9ba-cc15-4881-b568-e1517e1d493e','2026-06-09 08:02:04',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-3-gugs6uoae5pf-ContainersCommon-cx6z7gikdkl4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(885,'7da5fe06-7587-4ff4-88e5-3b1bd16f95a4','6e36d777-9a80-435c-a923-58d13a889549','2026-06-09 08:02:04',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-4-n3552roca63l-ApacheServiceBase-6ootxjbtys2b-ApacheNetworks-32jfb52xr2fr','state changed','OS::Heat::Value',NULL,643),(886,'beb4a94f-2c86-47e3-8052-3f804d34c182','6e36d777-9a80-435c-a923-58d13a889549','2026-06-09 08:02:04',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-4-n3552roca63l-ApacheServiceBase-6ootxjbtys2b-ApacheNetworks-32jfb52xr2fr','state changed','OS::Heat::Value',NULL,643),(887,'0e287f56-64b4-4619-95f7-c52018ca6e3c','e1df3c3f-afed-4b94-9573-79349221a0ce','2026-06-09 08:02:04',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-3-gugs6uoae5pf-ContainersCommon-cx6z7gikdkl4','e1df3c3f-afed-4b94-9573-79349221a0ce','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(888,'158014cf-451e-4cce-8cf4-b521bdaf7735','6e36d777-9a80-435c-a923-58d13a889549','2026-06-09 08:02:04',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-4-n3552roca63l-ApacheServiceBase-6ootxjbtys2b','6e36d777-9a80-435c-a923-58d13a889549','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(889,'4661ee1f-ca8e-44bc-a4b0-910bf9afe240','e1df3c3f-afed-4b94-9573-79349221a0ce','2026-06-09 08:02:04',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-3-gugs6uoae5pf-ContainersCommon-cx6z7gikdkl4','e1df3c3f-afed-4b94-9573-79349221a0ce','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(890,'fff25bbb-dee8-4156-a950-8518951a79a5','ba9e235d-ae13-45bd-87af-cd3e5bc86814','2026-06-09 08:02:04',NULL,'CREATE','COMPLETE','MySQLClient','4b6ff10c-6bed-4a2d-97d7-a09159218c93','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(891,'aa607dae-b8d3-4f72-8c4e-266080efd649','b451c416-d26d-4e3c-b580-6233f3dd6d89','2026-06-09 08:02:04',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-13-5blxgktwo2sf-RoleParametersValue-qaeqbzpuprks','state changed','OS::Heat::Value',NULL,644),(892,'8449cc32-5e11-4a02-9040-3ae72ad02444','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:04',NULL,'CREATE','COMPLETE','1','eb2ac9c7-f91d-4451-a01b-3a36f804bf55','state changed','OS::TripleO::Services::CACerts',NULL,635),(893,'0c2e1630-a6c7-4af5-89a6-50cbc5e83f9c','b451c416-d26d-4e3c-b580-6233f3dd6d89','2026-06-09 08:02:04',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-13-5blxgktwo2sf-RoleParametersValue-qaeqbzpuprks','state changed','OS::Heat::Value',NULL,644),(894,'34de4098-0589-44b6-9e8b-90a29655baa4','e1fe4582-3252-4b51-8c24-a618b087c9f5','2026-06-09 08:02:04',NULL,'CREATE','IN_PROGRESS','CeilometerServiceBase','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-2-j5qrqbqoixxr-CeilometerServiceBase-7j753onvqe6o','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,646),(895,'14bf5926-1a74-43ac-aa2e-da22555001b5','b451c416-d26d-4e3c-b580-6233f3dd6d89','2026-06-09 08:02:04',NULL,'CREATE','COMPLETE','SshdBase','4ae841cc-db8c-4f0c-95fc-df172cc92d64','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-puppet.yaml',NULL,637),(896,'249c10dc-fd1b-4cc9-9449-31c476d8061b','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:04',NULL,'CREATE','IN_PROGRESS','5','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-5-hw6kebp2vdws','state changed','OS::TripleO::Services::CinderBackup',NULL,647),(897,'3cfc4d59-91c3-49d9-b5da-1302e3238e60','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:02:04',NULL,'CREATE','COMPLETE','BlockStorageIpListMap','5e0cace8-0b97-4e55-908e-6d41c653ee6e','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,617),(898,'555bdfaa-8e7c-4c01-a262-f83f53feaad9','95a75728-0b1a-43b8-96db-673fd2f781d1','2026-06-09 08:02:04',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-2-j5qrqbqoixxr-CeilometerServiceBase-7j753onvqe6o','95a75728-0b1a-43b8-96db-673fd2f781d1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(899,'cbc00c0e-7049-4382-bd6b-22216ff6f589','95a75728-0b1a-43b8-96db-673fd2f781d1','2026-06-09 08:02:04',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-2-j5qrqbqoixxr-CeilometerServiceBase-7j753onvqe6o','95a75728-0b1a-43b8-96db-673fd2f781d1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(900,'36b5127e-1843-4c2d-abe6-0c8d7faf5fff','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:04',NULL,'CREATE','COMPLETE','3','63e123b2-9369-4208-a7e4-49f7810e90f8','state changed','OS::TripleO::Services::CeilometerAgentNotification',NULL,588),(901,'d51e7538-ff6f-4107-bab0-1d8708dd523e','cc15bf64-f471-4ad1-8da2-1e94ab0058e3','2026-06-09 08:02:04',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-4-5lbhfnwewe4q-ContainersCommon-6fgj45dc32cq','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(902,'d1f6c8cf-ff5f-4da6-b61d-7a77339b7367','e1fe4582-3252-4b51-8c24-a618b087c9f5','2026-06-09 08:02:04',NULL,'CREATE','COMPLETE','ContainersCommon','51b59720-42dd-44b9-8478-63cb2dbec3a4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(903,'f1aa7902-28ee-4cbf-978e-81c3c321e359','c3291729-da89-4359-adab-fecfd2c003ce','2026-06-09 08:02:04',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-5-hw6kebp2vdws','c3291729-da89-4359-adab-fecfd2c003ce','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(904,'d0f24b24-6d3d-43b0-bd63-d3c6311f29bf','a904f9f4-c016-468d-a33b-0cb2c0e852f6','2026-06-09 08:02:04',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-4-5lbhfnwewe4q-ContainersCommon-6fgj45dc32cq','a904f9f4-c016-468d-a33b-0cb2c0e852f6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(905,'7bea02aa-59a4-431a-9b49-bcc6e399b030','a904f9f4-c016-468d-a33b-0cb2c0e852f6','2026-06-09 08:02:04',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-4-5lbhfnwewe4q-ContainersCommon-6fgj45dc32cq','a904f9f4-c016-468d-a33b-0cb2c0e852f6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(906,'5bdbc4f4-14b7-45f9-aac7-628a875b18a9','ba9e235d-ae13-45bd-87af-cd3e5bc86814','2026-06-09 08:02:04',NULL,'CREATE','IN_PROGRESS','CinderCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-4-n3552roca63l-CinderCommon-lpjuuq55ssfe','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(907,'76d33fbb-d8db-461b-b383-2a9b58243cbb','c3291729-da89-4359-adab-fecfd2c003ce','2026-06-09 08:02:04',NULL,'CREATE','IN_PROGRESS','CinderCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-5-hw6kebp2vdws-CinderCommon-f5cpxzoms2ak','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(908,'82525a8e-39e2-420c-b98a-3ea25e6d5956','5b6f6146-e0b6-49b7-a9c5-fbacd4e0ffba','2026-06-09 08:02:04',NULL,'CREATE','COMPLETE','ContainersCommon','29d665b0-87ae-44c0-bd1f-957b0fafe244','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(909,'e38ec566-8507-459b-8843-7d9e3ddb35d4','4ac547da-6fb9-4680-b6db-353a5cca7ef9','2026-06-09 08:02:05',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-4-5lbhfnwewe4q-CeilometerAgentCentralBase-tpi4jzs52mtu-RoleParametersValue-uajxiudgmhk7','state changed','OS::Heat::Value',NULL,652),(910,'c35bb7fe-1237-4b2a-af91-79b7d7aa5199','4ac547da-6fb9-4680-b6db-353a5cca7ef9','2026-06-09 08:02:05',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-4-5lbhfnwewe4q-CeilometerAgentCentralBase-tpi4jzs52mtu-RoleParametersValue-uajxiudgmhk7','state changed','OS::Heat::Value',NULL,652),(911,'c8075fb2-0909-4d0b-ad88-133f59961f99','5b6f6146-e0b6-49b7-a9c5-fbacd4e0ffba','2026-06-09 08:02:05',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-6-wie4d6fzz7ve','5b6f6146-e0b6-49b7-a9c5-fbacd4e0ffba','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(912,'6db5967d-6a58-49dc-9dc3-3af041d2cdb7','fa22d66f-736c-44e4-b007-6e5aa2711e19','2026-06-09 08:02:05',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-5-hw6kebp2vdws-CinderCommon-f5cpxzoms2ak','fa22d66f-736c-44e4-b007-6e5aa2711e19','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(913,'0ffffb74-337f-45a6-b6f1-3bdc5def1014','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:02:05',NULL,'CREATE','COMPLETE','NetworkerIpListMap','352b0322-2a5b-4df4-9d6c-92968ce1c910','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,629),(914,'8d86b805-7363-473b-85e2-a255f06eb848','ba9e235d-ae13-45bd-87af-cd3e5bc86814','2026-06-09 08:02:05',NULL,'CREATE','COMPLETE','ApacheServiceBase','6e36d777-9a80-435c-a923-58d13a889549','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,641),(915,'595310f1-e098-44f8-8d8d-8537b65f079d','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:05',NULL,'CREATE','IN_PROGRESS','7','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-7-qnon7sfryude','state changed','OS::TripleO::Services::CinderVolume',NULL,653),(916,'c527c769-d8e2-4929-b741-54ee81f820f2','fa22d66f-736c-44e4-b007-6e5aa2711e19','2026-06-09 08:02:05',NULL,'CREATE','IN_PROGRESS','CinderNVMeOF','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-5-hw6kebp2vdws-CinderCommon-f5cpxzoms2ak-CinderNVMeOF-3qmduukvwmio','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(917,'6d59ee65-147b-4c98-881b-97be6e69e116','23045847-3239-44d1-8947-c8fcbf2e250a','2026-06-09 08:02:05',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-4-n3552roca63l-CinderCommon-lpjuuq55ssfe','23045847-3239-44d1-8947-c8fcbf2e250a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(918,'79ba6c6b-5c5c-4f2c-9c5d-cb328f0f90a8','fdd7c9ba-cc15-4881-b568-e1517e1d493e','2026-06-09 08:02:05',NULL,'CREATE','COMPLETE','ContainersCommon','e1df3c3f-afed-4b94-9573-79349221a0ce','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(919,'17915ec3-98a3-4a8b-b58a-df92b0861a9a','b451c416-d26d-4e3c-b580-6233f3dd6d89','2026-06-09 08:02:05',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-13-5blxgktwo2sf-ContainersCommon-r4zatvosfxwi','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(920,'0542a765-90f8-42d6-82ef-26d8fb32144d','b2adb083-2b80-428d-836f-25469fffef83','2026-06-09 08:02:05',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-7-qnon7sfryude','b2adb083-2b80-428d-836f-25469fffef83','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(921,'eeb909c8-e747-4133-9dc7-c5066add9bcd','fdd7c9ba-cc15-4881-b568-e1517e1d493e','2026-06-09 08:02:05',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-3-gugs6uoae5pf','fdd7c9ba-cc15-4881-b568-e1517e1d493e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(922,'b91d265e-48a7-4106-9476-895bbf1475bc','c4f67f62-0553-4c8e-b889-04d63137af9c','2026-06-09 08:02:05',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-5-hw6kebp2vdws-CinderCommon-f5cpxzoms2ak-CinderNVMeOF-3qmduukvwmio','c4f67f62-0553-4c8e-b889-04d63137af9c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(923,'d55589c1-462b-4c3f-be6d-57d96365e3de','c4f67f62-0553-4c8e-b889-04d63137af9c','2026-06-09 08:02:05',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-5-hw6kebp2vdws-CinderCommon-f5cpxzoms2ak-CinderNVMeOF-3qmduukvwmio','c4f67f62-0553-4c8e-b889-04d63137af9c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(924,'44fa7d4b-593b-4cf5-97fa-f3646302d1e5','0c922d32-b004-4083-a7a5-d55f28b5ca07','2026-06-09 08:02:05',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-13-5blxgktwo2sf-ContainersCommon-r4zatvosfxwi','0c922d32-b004-4083-a7a5-d55f28b5ca07','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(925,'3b234d4f-d05d-45a2-bcdd-e80497c5a94d','0c922d32-b004-4083-a7a5-d55f28b5ca07','2026-06-09 08:02:05',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-13-5blxgktwo2sf-ContainersCommon-r4zatvosfxwi','0c922d32-b004-4083-a7a5-d55f28b5ca07','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(926,'8b2dc936-2da9-4a2d-9342-0cfde98f8dfc','23045847-3239-44d1-8947-c8fcbf2e250a','2026-06-09 08:02:05',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-4-n3552roca63l-CinderCommon-lpjuuq55ssfe-ContainersCommon-uwoc46l6qbhd','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(927,'974dab4d-0b5b-4f31-bedd-1eccedf7257a','b2adb083-2b80-428d-836f-25469fffef83','2026-06-09 08:02:05',NULL,'CREATE','IN_PROGRESS','CinderBase','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-7-qnon7sfryude-CinderBase-i5faqm5y7hzk','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml',NULL,654),(928,'1d6f9c5d-cdf9-491a-9b24-a39cd72f01e5','bbd925f2-9df8-42d2-ab76-db99f539483f','2026-06-09 08:02:05',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-4-n3552roca63l-CinderCommon-lpjuuq55ssfe-ContainersCommon-uwoc46l6qbhd','bbd925f2-9df8-42d2-ab76-db99f539483f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(929,'05004f7b-5800-42ff-86f5-4af4c61af7d5','bbd925f2-9df8-42d2-ab76-db99f539483f','2026-06-09 08:02:05',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-4-n3552roca63l-CinderCommon-lpjuuq55ssfe-ContainersCommon-uwoc46l6qbhd','bbd925f2-9df8-42d2-ab76-db99f539483f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(930,'0c4b5883-6cfc-4037-8d3a-e5b7f49b7814','f8d3c480-4047-414a-9056-8986fbc8b84b','2026-06-09 08:02:05',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-7-qnon7sfryude-CinderBase-i5faqm5y7hzk','f8d3c480-4047-414a-9056-8986fbc8b84b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(931,'d669f1e1-f37a-4b03-b3dd-615e59764769','76704e88-86e6-482c-bf6c-6e25173f798c','2026-06-09 08:02:05',NULL,'CREATE','COMPLETE','6','5b6f6146-e0b6-49b7-a9c5-fbacd4e0ffba','state changed','OS::TripleO::Services::Iscsid',NULL,613),(932,'82822707-5d8d-4f7c-973f-28704e8cab4a','e1fe4582-3252-4b51-8c24-a618b087c9f5','2026-06-09 08:02:05',NULL,'CREATE','COMPLETE','CeilometerServiceBase','95a75728-0b1a-43b8-96db-673fd2f781d1','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,646),(933,'26cf179e-78fa-4c01-aee0-883532fcd5af','e1fe4582-3252-4b51-8c24-a618b087c9f5','2026-06-09 08:02:05',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-2-j5qrqbqoixxr','e1fe4582-3252-4b51-8c24-a618b087c9f5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(934,'3d21e242-71e4-436d-99a4-74d099a41cb7','cc15bf64-f471-4ad1-8da2-1e94ab0058e3','2026-06-09 08:02:05',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-4-5lbhfnwewe4q-RoleParametersValue-a6jgv6lhsmxv','state changed','OS::Heat::Value',NULL,655),(935,'fb7761b0-d6c5-45fd-aca6-fd6e5d3eebb5','cc15bf64-f471-4ad1-8da2-1e94ab0058e3','2026-06-09 08:02:05',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-4-5lbhfnwewe4q-RoleParametersValue-a6jgv6lhsmxv','state changed','OS::Heat::Value',NULL,655),(936,'e4e3af48-125e-4f5f-b941-345fb6b72401','f8d3c480-4047-414a-9056-8986fbc8b84b','2026-06-09 08:02:05',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-7-qnon7sfryude-CinderBase-i5faqm5y7hzk-ContainersCommon-3ni4uvhs7r5j','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(937,'a23f46f1-6332-4d1d-a48e-dcf3115be2ee','c1e2f44b-d61f-4074-8d7a-44f70ffb7bd1','2026-06-09 08:02:05',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-7-qnon7sfryude-CinderBase-i5faqm5y7hzk-ContainersCommon-3ni4uvhs7r5j','c1e2f44b-d61f-4074-8d7a-44f70ffb7bd1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(938,'a1c75d93-af34-4332-a1f3-63a2a5129ac1','cc15bf64-f471-4ad1-8da2-1e94ab0058e3','2026-06-09 08:02:05',NULL,'CREATE','COMPLETE','ContainersCommon','a904f9f4-c016-468d-a33b-0cb2c0e852f6','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(939,'374ad3b8-a2c7-40f6-be8a-a2e27bebda28','c1e2f44b-d61f-4074-8d7a-44f70ffb7bd1','2026-06-09 08:02:05',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-7-qnon7sfryude-CinderBase-i5faqm5y7hzk-ContainersCommon-3ni4uvhs7r5j','c1e2f44b-d61f-4074-8d7a-44f70ffb7bd1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(940,'0dc5ddd5-3a89-4b85-abfe-8b37b4c89b4b','76704e88-86e6-482c-bf6c-6e25173f798c','2026-06-09 08:02:05',NULL,'CREATE','IN_PROGRESS','10','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-10-5gijgpys77an','state changed','OS::TripleO::Services::NovaCompute',NULL,659),(941,'904f7aa1-55dd-4fb3-9643-b03aa015ee9c','4ac547da-6fb9-4680-b6db-353a5cca7ef9','2026-06-09 08:02:06',NULL,'CREATE','IN_PROGRESS','CeilometerServiceBase','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-4-5lbhfnwewe4q-CeilometerAgentCentralBase-tpi4jzs52mtu-CeilometerServiceBase-tp3hqftydgyr','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,660),(942,'16618d67-5433-484a-a678-3ef77a1f751f','ba9e235d-ae13-45bd-87af-cd3e5bc86814','2026-06-09 08:02:06',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-4-n3552roca63l-RoleParametersValue-arfhqovleaas','state changed','OS::Heat::Value',NULL,661),(943,'f1473f08-6b2d-459c-af9e-23aaa44229e1','c3291729-da89-4359-adab-fecfd2c003ce','2026-06-09 08:02:06',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-5-hw6kebp2vdws-RoleParametersValue-j5hdsiwz2k66','state changed','OS::Heat::Value',NULL,662),(944,'eea0f378-162e-4e47-bd97-19ca635a3fd6','ba9e235d-ae13-45bd-87af-cd3e5bc86814','2026-06-09 08:02:06',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-4-n3552roca63l-RoleParametersValue-arfhqovleaas','state changed','OS::Heat::Value',NULL,661),(945,'b4bc9b5a-40dc-4ed8-bd50-035f0bb4dd37','bc22e677-2cc2-45d1-9862-a9131bbb1e10','2026-06-09 08:02:06',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-10-5gijgpys77an','bc22e677-2cc2-45d1-9862-a9131bbb1e10','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(946,'fc00b36c-ec31-4715-9270-f614fd02c7b4','c3291729-da89-4359-adab-fecfd2c003ce','2026-06-09 08:02:06',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-5-hw6kebp2vdws-RoleParametersValue-j5hdsiwz2k66','state changed','OS::Heat::Value',NULL,662),(947,'d6dd153a-4c22-4884-b51d-950fee2735a4','011024dc-6d49-4490-b819-a7d91302da52','2026-06-09 08:02:06',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-4-5lbhfnwewe4q-CeilometerAgentCentralBase-tpi4jzs52mtu-CeilometerServiceBase-tp3hqftydgyr','011024dc-6d49-4490-b819-a7d91302da52','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(948,'4fdc725a-a497-4b32-a0f6-3f32e3c8afc1','011024dc-6d49-4490-b819-a7d91302da52','2026-06-09 08:02:06',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-4-5lbhfnwewe4q-CeilometerAgentCentralBase-tpi4jzs52mtu-CeilometerServiceBase-tp3hqftydgyr','011024dc-6d49-4490-b819-a7d91302da52','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(949,'5bd8fed4-7f1d-4a5c-8936-664ac6a51a4e','fa22d66f-736c-44e4-b007-6e5aa2711e19','2026-06-09 08:02:06',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-5-hw6kebp2vdws-CinderCommon-f5cpxzoms2ak-ContainersCommon-w3c3j2n2lkwl','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(950,'eb048a84-1652-42fc-b63e-9a3421b6a0df','76704e88-86e6-482c-bf6c-6e25173f798c','2026-06-09 08:02:06',NULL,'CREATE','COMPLETE','3','fdd7c9ba-cc15-4881-b568-e1517e1d493e','state changed','OS::TripleO::Services::ComputeCeilometerAgent',NULL,600),(951,'e5774dd0-04c9-4638-82e4-66f043e18c52','c3fc9371-1fa7-4a7b-a9b5-057a6626e0e1','2026-06-09 08:02:06',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-5-hw6kebp2vdws-CinderCommon-f5cpxzoms2ak-ContainersCommon-w3c3j2n2lkwl','c3fc9371-1fa7-4a7b-a9b5-057a6626e0e1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(952,'00543447-a3ea-4ae1-94bd-12d0f9418b54','bc22e677-2cc2-45d1-9862-a9131bbb1e10','2026-06-09 08:02:06',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-10-5gijgpys77an-ContainersCommon-uuhxesuqgubr','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(953,'89c37c83-b8e2-41dd-8531-25d37dd36d90','c3fc9371-1fa7-4a7b-a9b5-057a6626e0e1','2026-06-09 08:02:06',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-5-hw6kebp2vdws-CinderCommon-f5cpxzoms2ak-ContainersCommon-w3c3j2n2lkwl','c3fc9371-1fa7-4a7b-a9b5-057a6626e0e1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(954,'78f17d67-e13b-4583-8bb5-01b15fcedbde','fa22d66f-736c-44e4-b007-6e5aa2711e19','2026-06-09 08:02:06',NULL,'CREATE','COMPLETE','CinderNVMeOF','c4f67f62-0553-4c8e-b889-04d63137af9c','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(955,'df14582c-fa20-4f9a-8eaa-b6fd6535c71f','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:06',NULL,'CREATE','COMPLETE','2','e1fe4582-3252-4b51-8c24-a618b087c9f5','state changed','OS::TripleO::Services::CeilometerAgentCentral',NULL,614),(956,'0cefefe4-4b44-401d-8415-4d7e452b65b7','b451c416-d26d-4e3c-b580-6233f3dd6d89','2026-06-09 08:02:06',NULL,'CREATE','COMPLETE','ContainersCommon','0c922d32-b004-4083-a7a5-d55f28b5ca07','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(957,'1e94dee4-5fb8-4560-a994-7510351968af','23045847-3239-44d1-8947-c8fcbf2e250a','2026-06-09 08:02:06',NULL,'CREATE','IN_PROGRESS','CinderNVMeOF','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-4-n3552roca63l-CinderCommon-lpjuuq55ssfe-CinderNVMeOF-wf7ibbux47ol','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(958,'0eb624fb-db92-444a-b827-e185b0d275ce','0112597b-9e4d-4e6e-a9f2-93e924f5974b','2026-06-09 08:02:06',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-10-5gijgpys77an-ContainersCommon-uuhxesuqgubr','0112597b-9e4d-4e6e-a9f2-93e924f5974b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(959,'5e873332-741d-41cf-a485-bd4a80e06db9','b451c416-d26d-4e3c-b580-6233f3dd6d89','2026-06-09 08:02:06',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-13-5blxgktwo2sf','b451c416-d26d-4e3c-b580-6233f3dd6d89','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(960,'56a37a4d-62a8-429d-9ec0-a9c03fd1bdba','0112597b-9e4d-4e6e-a9f2-93e924f5974b','2026-06-09 08:02:06',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-10-5gijgpys77an-ContainersCommon-uuhxesuqgubr','0112597b-9e4d-4e6e-a9f2-93e924f5974b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(961,'f03852a2-7403-4854-8def-3743a8bdc3fc','b2adb083-2b80-428d-836f-25469fffef83','2026-06-09 08:02:06',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-7-qnon7sfryude-ContainersCommon-wqlhcd4mj463','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(962,'1c99e314-00e1-4b9c-9f64-a3a4141ba94e','bc22e677-2cc2-45d1-9862-a9131bbb1e10','2026-06-09 08:02:06',NULL,'CREATE','COMPLETE','ContainersCommon','0112597b-9e4d-4e6e-a9f2-93e924f5974b','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(963,'12673729-ceb4-4eac-9cf8-4bad231b192f','f85b6c0a-bbc9-4a53-a38d-40f6dc34c22b','2026-06-09 08:02:06',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-7-qnon7sfryude-ContainersCommon-wqlhcd4mj463','f85b6c0a-bbc9-4a53-a38d-40f6dc34c22b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(964,'d3f529d0-9b60-4e27-b2b9-08183c8c6243','45090728-00be-45bd-bd94-6d1ca998383e','2026-06-09 08:02:06',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-4-n3552roca63l-CinderCommon-lpjuuq55ssfe-CinderNVMeOF-wf7ibbux47ol','45090728-00be-45bd-bd94-6d1ca998383e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(965,'a9ea8a45-5db6-4b52-bdf8-65378de4d116','23045847-3239-44d1-8947-c8fcbf2e250a','2026-06-09 08:02:06',NULL,'CREATE','COMPLETE','ContainersCommon','bbd925f2-9df8-42d2-ab76-db99f539483f','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(966,'e289c5a8-fe84-472f-ba71-d043e23be56c','f85b6c0a-bbc9-4a53-a38d-40f6dc34c22b','2026-06-09 08:02:06',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-7-qnon7sfryude-ContainersCommon-wqlhcd4mj463','f85b6c0a-bbc9-4a53-a38d-40f6dc34c22b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(967,'25ebd31f-e61a-4ff5-a3ff-06e0f0a2e5ec','76704e88-86e6-482c-bf6c-6e25173f798c','2026-06-09 08:02:06',NULL,'CREATE','IN_PROGRESS','7','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-7-dwgkrw4ya3uv','state changed','OS::TripleO::Services::Kernel',NULL,669),(968,'28a88322-5f00-4257-8381-e559593b14d9','45090728-00be-45bd-bd94-6d1ca998383e','2026-06-09 08:02:06',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-4-n3552roca63l-CinderCommon-lpjuuq55ssfe-CinderNVMeOF-wf7ibbux47ol','45090728-00be-45bd-bd94-6d1ca998383e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(969,'5151fcf7-1e44-4a5a-8f78-028b9fc421c8','f8d3c480-4047-414a-9056-8986fbc8b84b','2026-06-09 08:02:06',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-7-qnon7sfryude-CinderBase-i5faqm5y7hzk-MySQLClient-ek472bvz47vw','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(970,'d6b05bea-7ef7-40dc-bbbc-a87e1cc6ca81','18e89465-acbe-4038-b7d5-cdff6f7aa97f','2026-06-09 08:02:06',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-7-qnon7sfryude-CinderBase-i5faqm5y7hzk-MySQLClient-ek472bvz47vw','18e89465-acbe-4038-b7d5-cdff6f7aa97f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(971,'51bfb48d-ca32-4a99-965f-c7f8ecce54b4','18e89465-acbe-4038-b7d5-cdff6f7aa97f','2026-06-09 08:02:06',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-7-qnon7sfryude-CinderBase-i5faqm5y7hzk-MySQLClient-ek472bvz47vw','18e89465-acbe-4038-b7d5-cdff6f7aa97f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(972,'8780f65c-3324-4588-ad0f-9063f9d6bd39','f8d3c480-4047-414a-9056-8986fbc8b84b','2026-06-09 08:02:06',NULL,'CREATE','COMPLETE','ContainersCommon','c1e2f44b-d61f-4074-8d7a-44f70ffb7bd1','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(973,'52abc18a-8f29-4f5f-900c-5271d1863386','657cbf9f-94cd-449e-9af7-032f3c220f23','2026-06-09 08:02:06',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-7-dwgkrw4ya3uv','657cbf9f-94cd-449e-9af7-032f3c220f23','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(974,'f1d435ce-5032-427a-9943-950c36fe4fd6','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:06',NULL,'CREATE','IN_PROGRESS','6','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-6-irfnfs2tsiai','state changed','OS::TripleO::Services::CinderScheduler',NULL,672),(975,'60564d6c-bfac-4d7c-a32c-3e07f2cd40ae','ba9e235d-ae13-45bd-87af-cd3e5bc86814','2026-06-09 08:02:07',NULL,'CREATE','IN_PROGRESS','CinderBase','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-4-n3552roca63l-CinderBase-rkdy5inehweb','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml',NULL,673),(976,'cfb86875-b406-46b6-b507-ad4ada96fe98','c3291729-da89-4359-adab-fecfd2c003ce','2026-06-09 08:02:07',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-5-hw6kebp2vdws-ContainersCommon-fichmiawajeq','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(977,'5f395646-7869-41b7-b053-ccfb32413094','657cbf9f-94cd-449e-9af7-032f3c220f23','2026-06-09 08:02:07',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-7-dwgkrw4ya3uv-RoleParametersValue-ahcxnu7yyzu3','state changed','OS::Heat::Value',NULL,674),(978,'827a8476-fcd9-4488-9099-2edb781b24a8','b61e61f0-ba2f-4f84-b9d0-d9482aba3e6a','2026-06-09 08:02:07',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-4-n3552roca63l-CinderBase-rkdy5inehweb','b61e61f0-ba2f-4f84-b9d0-d9482aba3e6a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(979,'aa9bf877-f854-45f6-972a-31701f4baf54','82838a6f-7e6a-4340-8f0f-97df186bf3d4','2026-06-09 08:02:07',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-6-irfnfs2tsiai','82838a6f-7e6a-4340-8f0f-97df186bf3d4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(980,'cf212a7d-c429-4831-9a10-aa20c87401cb','b61e61f0-ba2f-4f84-b9d0-d9482aba3e6a','2026-06-09 08:02:07',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-4-n3552roca63l-CinderBase-rkdy5inehweb','b61e61f0-ba2f-4f84-b9d0-d9482aba3e6a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(981,'19a0a70e-373c-4380-b26d-5fffc0486765','657cbf9f-94cd-449e-9af7-032f3c220f23','2026-06-09 08:02:07',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-7-dwgkrw4ya3uv-RoleParametersValue-ahcxnu7yyzu3','state changed','OS::Heat::Value',NULL,674),(982,'9e34987a-b4d5-4a02-b1ba-923eb14fdbab','5821f849-5cee-40ac-8d3e-15416242f51f','2026-06-09 08:02:07',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-5-hw6kebp2vdws-ContainersCommon-fichmiawajeq','5821f849-5cee-40ac-8d3e-15416242f51f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(983,'31e9a515-41da-481d-908a-377169f99b25','657cbf9f-94cd-449e-9af7-032f3c220f23','2026-06-09 08:02:07',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-7-dwgkrw4ya3uv','657cbf9f-94cd-449e-9af7-032f3c220f23','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(984,'2be27970-f6ff-4aad-9e23-ae9b52c69e6a','4ac547da-6fb9-4680-b6db-353a5cca7ef9','2026-06-09 08:02:07',NULL,'CREATE','COMPLETE','CeilometerServiceBase','011024dc-6d49-4490-b819-a7d91302da52','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml',NULL,660),(985,'7033fbf2-e6ff-406b-9316-7f42b71bd79b','5821f849-5cee-40ac-8d3e-15416242f51f','2026-06-09 08:02:07',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-5-hw6kebp2vdws-ContainersCommon-fichmiawajeq','5821f849-5cee-40ac-8d3e-15416242f51f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(986,'32022a9c-fe18-4113-b21e-3354593dd535','4ac547da-6fb9-4680-b6db-353a5cca7ef9','2026-06-09 08:02:07',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-4-5lbhfnwewe4q-CeilometerAgentCentralBase-tpi4jzs52mtu','4ac547da-6fb9-4680-b6db-353a5cca7ef9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(987,'7596d6c1-2a55-478c-ad21-ef0646bd5e30','76704e88-86e6-482c-bf6c-6e25173f798c','2026-06-09 08:02:07',NULL,'CREATE','COMPLETE','13','b451c416-d26d-4e3c-b580-6233f3dd6d89','state changed','OS::TripleO::Services::NovaMigrationTarget',NULL,633),(988,'43f2b4d8-a39c-437f-a2b6-78c72d747f35','bc22e677-2cc2-45d1-9862-a9131bbb1e10','2026-06-09 08:02:07',NULL,'CREATE','IN_PROGRESS','NovaBase','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-10-5gijgpys77an-NovaBase-nkcpy53hlaap','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,675),(989,'d1e65f9c-14f0-48b1-b920-823fe8e688ca','82838a6f-7e6a-4340-8f0f-97df186bf3d4','2026-06-09 08:02:07',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-6-irfnfs2tsiai-ContainersCommon-knv4catdbllx','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(990,'31f4ad8e-b35f-4ea7-a93e-e7e4f9c132b9','fa22d66f-736c-44e4-b007-6e5aa2711e19','2026-06-09 08:02:07',NULL,'CREATE','COMPLETE','ContainersCommon','c3fc9371-1fa7-4a7b-a9b5-057a6626e0e1','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(991,'866ae3c3-91a0-4e3d-9cf3-62c249b57265','2c9acf04-586c-4329-9678-61aa2eeb6c16','2026-06-09 08:02:07',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-10-5gijgpys77an-NovaBase-nkcpy53hlaap','2c9acf04-586c-4329-9678-61aa2eeb6c16','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(992,'f3678796-0ab6-464c-b12f-31a394a8616a','fa22d66f-736c-44e4-b007-6e5aa2711e19','2026-06-09 08:02:07',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-5-hw6kebp2vdws-CinderCommon-f5cpxzoms2ak','fa22d66f-736c-44e4-b007-6e5aa2711e19','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(993,'15f1926e-4d83-4532-babf-7d6da73bdbdf','97d0fee8-b7b6-4775-9405-16892aa288a7','2026-06-09 08:02:07',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-6-irfnfs2tsiai-ContainersCommon-knv4catdbllx','97d0fee8-b7b6-4775-9405-16892aa288a7','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(994,'87c1fd34-be2b-48bf-b989-011e5fba99ea','2c9acf04-586c-4329-9678-61aa2eeb6c16','2026-06-09 08:02:07',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-10-5gijgpys77an-NovaBase-nkcpy53hlaap-RoleParametersValue-kjzhpszrg6k7','state changed','OS::Heat::Value',NULL,680),(995,'edf5b0f4-4569-4e02-abd2-c49335849b81','b2adb083-2b80-428d-836f-25469fffef83','2026-06-09 08:02:07',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-7-qnon7sfryude-MySQLClient-tv2lm7ey2pah','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(996,'67f38bfa-98bc-48cf-b156-a1f05beece3c','2c9acf04-586c-4329-9678-61aa2eeb6c16','2026-06-09 08:02:07',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-10-5gijgpys77an-NovaBase-nkcpy53hlaap-RoleParametersValue-kjzhpszrg6k7','state changed','OS::Heat::Value',NULL,680),(997,'34e43d3b-42dc-4984-a236-186f7300da6d','2c9acf04-586c-4329-9678-61aa2eeb6c16','2026-06-09 08:02:07',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-10-5gijgpys77an-NovaBase-nkcpy53hlaap','2c9acf04-586c-4329-9678-61aa2eeb6c16','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(998,'fe5b311e-4a93-4743-b373-3bb37a496796','ccda3c01-201c-460b-b6d9-622ab7853925','2026-06-09 08:02:07',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-7-qnon7sfryude-MySQLClient-tv2lm7ey2pah','ccda3c01-201c-460b-b6d9-622ab7853925','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(999,'2e23e132-e4c3-4379-905d-d9a5eeb95abc','76704e88-86e6-482c-bf6c-6e25173f798c','2026-06-09 08:02:07',NULL,'CREATE','IN_PROGRESS','17','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-17-tl6pnu7y4cqb','state changed','OS::TripleO::Services::Snmp',NULL,681),(1000,'36b7c766-56f8-4ab7-b3aa-b86783db7f6c','97d0fee8-b7b6-4775-9405-16892aa288a7','2026-06-09 08:02:07',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-6-irfnfs2tsiai-ContainersCommon-knv4catdbllx','97d0fee8-b7b6-4775-9405-16892aa288a7','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1001,'0cc7e583-89a1-4018-a141-d37ba733308c','ccda3c01-201c-460b-b6d9-622ab7853925','2026-06-09 08:02:07',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-7-qnon7sfryude-MySQLClient-tv2lm7ey2pah','ccda3c01-201c-460b-b6d9-622ab7853925','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1002,'bd8aaa44-3ae4-4172-9d22-c8ca8c063729','46d16372-bf79-4356-ae2a-af78603a1761','2026-06-09 08:02:07',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-17-tl6pnu7y4cqb','46d16372-bf79-4356-ae2a-af78603a1761','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1003,'3951c2de-843e-4e6e-9445-6ab67efa4dfc','b2adb083-2b80-428d-836f-25469fffef83','2026-06-09 08:02:07',NULL,'CREATE','COMPLETE','ContainersCommon','f85b6c0a-bbc9-4a53-a38d-40f6dc34c22b','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1004,'fa37ba97-aeb6-4e7f-9610-864fc6bf58d5','46d16372-bf79-4356-ae2a-af78603a1761','2026-06-09 08:02:07',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-17-tl6pnu7y4cqb','46d16372-bf79-4356-ae2a-af78603a1761','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1005,'3610eeaa-638e-4c23-903a-50263cf9d4dd','23045847-3239-44d1-8947-c8fcbf2e250a','2026-06-09 08:02:07',NULL,'CREATE','COMPLETE','CinderNVMeOF','45090728-00be-45bd-bd94-6d1ca998383e','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1006,'aca4899b-c5f0-4fbf-9f98-dfb6d75dbe7a','23045847-3239-44d1-8947-c8fcbf2e250a','2026-06-09 08:02:07',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-4-n3552roca63l-CinderCommon-lpjuuq55ssfe','23045847-3239-44d1-8947-c8fcbf2e250a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1007,'8a35ac7e-d4eb-4c04-834e-759a6911b6f5','f8d3c480-4047-414a-9056-8986fbc8b84b','2026-06-09 08:02:07',NULL,'CREATE','IN_PROGRESS','CinderBase','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-7-qnon7sfryude-CinderBase-i5faqm5y7hzk-CinderBase-djbbevktvjvq','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml',NULL,682),(1008,'b08f1365-9830-47bf-9156-14b20470cc4f','89a51534-3909-4ad2-b180-cb6ab63aed9b','2026-06-09 08:02:07',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-7-qnon7sfryude-CinderBase-i5faqm5y7hzk-CinderBase-djbbevktvjvq','89a51534-3909-4ad2-b180-cb6ab63aed9b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1009,'e81fff02-3d36-473d-94a0-fc2e2f2d3e5c','89a51534-3909-4ad2-b180-cb6ab63aed9b','2026-06-09 08:02:07',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-7-qnon7sfryude-CinderBase-i5faqm5y7hzk-CinderBase-djbbevktvjvq','89a51534-3909-4ad2-b180-cb6ab63aed9b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1010,'9c299f1c-945f-4dcb-b16c-69f130906af8','f8d3c480-4047-414a-9056-8986fbc8b84b','2026-06-09 08:02:07',NULL,'CREATE','COMPLETE','MySQLClient','18e89465-acbe-4038-b7d5-cdff6f7aa97f','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1011,'3424e115-4753-4c4e-905e-3d3d0e46a901','cc15bf64-f471-4ad1-8da2-1e94ab0058e3','2026-06-09 08:02:07',NULL,'CREATE','COMPLETE','CeilometerAgentCentralBase','4ac547da-6fb9-4680-b6db-353a5cca7ef9','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml',NULL,638),(1012,'0cf6862c-e7a9-4c29-ba1c-3d15dc766542','cc15bf64-f471-4ad1-8da2-1e94ab0058e3','2026-06-09 08:02:07',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-4-5lbhfnwewe4q','cc15bf64-f471-4ad1-8da2-1e94ab0058e3','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1013,'49412647-fe6d-4b66-832a-4211d10af44c','c3291729-da89-4359-adab-fecfd2c003ce','2026-06-09 08:02:08',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-5-hw6kebp2vdws-MySQLClient-dsr2eyzqr4np','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1014,'0ae962f5-977d-442f-a750-ce94cbf4df17','ba9e235d-ae13-45bd-87af-cd3e5bc86814','2026-06-09 08:02:08',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-4-n3552roca63l-ContainersCommon-nozq2i5qq77z','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1015,'daa2284c-90d1-4291-a199-9b2f8607f37f','76704e88-86e6-482c-bf6c-6e25173f798c','2026-06-09 08:02:08',NULL,'CREATE','COMPLETE','7','657cbf9f-94cd-449e-9af7-032f3c220f23','state changed','OS::TripleO::Services::Kernel',NULL,669),(1016,'14a34ba8-f0d9-4678-9f33-f16a1659a01a','2f309682-81f1-42b2-b6bc-68895f0faae5','2026-06-09 08:02:08',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-5-hw6kebp2vdws-MySQLClient-dsr2eyzqr4np','2f309682-81f1-42b2-b6bc-68895f0faae5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1017,'e9863afd-fa97-4f0d-a189-e64e9f94ef2d','0f07b9b4-14f0-43f1-bb06-2ea4abbdd06c','2026-06-09 08:02:08',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-4-n3552roca63l-ContainersCommon-nozq2i5qq77z','0f07b9b4-14f0-43f1-bb06-2ea4abbdd06c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1018,'d4bc62d4-50f5-47c9-add5-675919602056','c3291729-da89-4359-adab-fecfd2c003ce','2026-06-09 08:02:08',NULL,'CREATE','COMPLETE','CinderCommon','fa22d66f-736c-44e4-b007-6e5aa2711e19','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(1019,'a2bb8bcb-17c6-434c-8aba-85798f335ded','ba9e235d-ae13-45bd-87af-cd3e5bc86814','2026-06-09 08:02:08',NULL,'CREATE','COMPLETE','CinderBase','b61e61f0-ba2f-4f84-b9d0-d9482aba3e6a','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml',NULL,673),(1020,'af82a6d2-7570-4a76-b32c-5aaaf9efc80e','0f07b9b4-14f0-43f1-bb06-2ea4abbdd06c','2026-06-09 08:02:08',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-4-n3552roca63l-ContainersCommon-nozq2i5qq77z','0f07b9b4-14f0-43f1-bb06-2ea4abbdd06c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1021,'ca5f5c28-6445-42e8-9df0-cc281e9f563c','2f309682-81f1-42b2-b6bc-68895f0faae5','2026-06-09 08:02:08',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-5-hw6kebp2vdws-MySQLClient-dsr2eyzqr4np','2f309682-81f1-42b2-b6bc-68895f0faae5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1022,'7f82dfd6-4023-40ed-a9cd-773a24a18173','c3291729-da89-4359-adab-fecfd2c003ce','2026-06-09 08:02:08',NULL,'CREATE','COMPLETE','ContainersCommon','5821f849-5cee-40ac-8d3e-15416242f51f','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1023,'8e1f70ad-a3fe-49e9-8c46-393d93bdfa88','76704e88-86e6-482c-bf6c-6e25173f798c','2026-06-09 08:02:08',NULL,'CREATE','IN_PROGRESS','11','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-11-dnapxadt6qy4','state changed','OS::TripleO::Services::NovaLibvirt',NULL,685),(1024,'e85000c6-c182-46bd-8aa5-2836278fbef3','82838a6f-7e6a-4340-8f0f-97df186bf3d4','2026-06-09 08:02:08',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-6-irfnfs2tsiai-MySQLClient-hkopv22bri4i','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1025,'761b1e8e-cf86-4bb0-a9dd-acdc2a5ed12d','bc22e677-2cc2-45d1-9862-a9131bbb1e10','2026-06-09 08:02:08',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-10-5gijgpys77an-RoleParametersValue-qfpwtpqsxlfr','state changed','OS::Heat::Value',NULL,686),(1026,'510be16e-55e4-4112-94bd-9d5ddcec4d7d','bc22e677-2cc2-45d1-9862-a9131bbb1e10','2026-06-09 08:02:08',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-10-5gijgpys77an-RoleParametersValue-qfpwtpqsxlfr','state changed','OS::Heat::Value',NULL,686),(1027,'97e35914-de97-4990-9731-12ddf3552f8e','f252ed30-28f6-422b-ac36-26f7cdfe0f06','2026-06-09 08:02:08',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-6-irfnfs2tsiai-MySQLClient-hkopv22bri4i','f252ed30-28f6-422b-ac36-26f7cdfe0f06','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1028,'25a0513d-bf05-46bf-b5be-a7586019207e','f252ed30-28f6-422b-ac36-26f7cdfe0f06','2026-06-09 08:02:08',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-6-irfnfs2tsiai-MySQLClient-hkopv22bri4i','f252ed30-28f6-422b-ac36-26f7cdfe0f06','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1029,'cc949e04-94f4-4b88-b43d-7cc53098e1dc','ba9e235d-ae13-45bd-87af-cd3e5bc86814','2026-06-09 08:02:08',NULL,'CREATE','COMPLETE','CinderCommon','23045847-3239-44d1-8947-c8fcbf2e250a','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(1030,'14f65563-180c-43f9-bf2e-74a315f48dc7','bc22e677-2cc2-45d1-9862-a9131bbb1e10','2026-06-09 08:02:08',NULL,'CREATE','COMPLETE','NovaBase','2c9acf04-586c-4329-9678-61aa2eeb6c16','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,675),(1031,'0994940a-49c7-45f7-a160-c57d09c621fc','82838a6f-7e6a-4340-8f0f-97df186bf3d4','2026-06-09 08:02:08',NULL,'CREATE','COMPLETE','ContainersCommon','97d0fee8-b7b6-4775-9405-16892aa288a7','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1032,'f694c933-5f39-4e4c-b8c2-20d5bf341484','e69533cb-53d1-4e45-a6a3-f8da3ed879d9','2026-06-09 08:02:08',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-11-dnapxadt6qy4','e69533cb-53d1-4e45-a6a3-f8da3ed879d9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1033,'ec185ea0-55e3-40dd-97f5-11ec4580ca15','bc22e677-2cc2-45d1-9862-a9131bbb1e10','2026-06-09 08:02:08',NULL,'CREATE','IN_PROGRESS','NovaLogging','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-10-5gijgpys77an-NovaLogging-wglga6vtfhei','state changed','OS::TripleO::Services::Logging::NovaCommon',NULL,688),(1034,'da15656e-727b-4647-9c24-8e94c81ca4bb','4703a4ef-d1f3-4b36-b11d-ced569ddbae5','2026-06-09 08:02:08',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-10-5gijgpys77an-NovaLogging-wglga6vtfhei','4703a4ef-d1f3-4b36-b11d-ced569ddbae5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1035,'cca7da2f-f1f9-4d5e-8cab-b0e859eebfc8','b2adb083-2b80-428d-836f-25469fffef83','2026-06-09 08:02:08',NULL,'CREATE','COMPLETE','MySQLClient','ccda3c01-201c-460b-b6d9-622ab7853925','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1036,'8de2ca1c-cec7-48ec-8f7e-7afc23e9c3ab','b2adb083-2b80-428d-836f-25469fffef83','2026-06-09 08:02:08',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-7-qnon7sfryude-RoleParametersValue-jdw2vuq3fe7m','state changed','OS::Heat::Value',NULL,689),(1037,'3fab566f-afb4-411d-9af4-707411e119df','b2adb083-2b80-428d-836f-25469fffef83','2026-06-09 08:02:08',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-7-qnon7sfryude-RoleParametersValue-jdw2vuq3fe7m','state changed','OS::Heat::Value',NULL,689),(1038,'ca584869-de3b-4eaa-af13-3aa001b395ba','76704e88-86e6-482c-bf6c-6e25173f798c','2026-06-09 08:02:08',NULL,'CREATE','COMPLETE','17','46d16372-bf79-4356-ae2a-af78603a1761','state changed','OS::TripleO::Services::Snmp',NULL,681),(1039,'d9d6d3bd-7246-4099-8600-2718e6d55aa9','4703a4ef-d1f3-4b36-b11d-ced569ddbae5','2026-06-09 08:02:08',NULL,'CREATE','IN_PROGRESS','InitLogContainerName','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-10-5gijgpys77an-NovaLogging-wglga6vtfhei-InitLogContainerName-64rk6oqvqc4h','state changed','OS::Heat::Value',NULL,690),(1040,'999deb2d-9ce1-408f-8364-6487178beea0','4703a4ef-d1f3-4b36-b11d-ced569ddbae5','2026-06-09 08:02:08',NULL,'CREATE','COMPLETE','InitLogContainerName','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-10-5gijgpys77an-NovaLogging-wglga6vtfhei-InitLogContainerName-64rk6oqvqc4h','state changed','OS::Heat::Value',NULL,690),(1041,'79f36012-ebcc-400b-8087-360003e9dace','e69533cb-53d1-4e45-a6a3-f8da3ed879d9','2026-06-09 08:02:08',NULL,'CREATE','IN_PROGRESS','NovaLibvirtLogging','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-11-dnapxadt6qy4-NovaLibvirtLogging-7wy32uhxcj5a','state changed','OS::TripleO::Services::Logging::NovaLibvirt',NULL,NULL),(1042,'ce69a1b9-c66d-4b83-b04e-4f82b2e0ca96','f8d3c480-4047-414a-9056-8986fbc8b84b','2026-06-09 08:02:08',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-7-qnon7sfryude-CinderBase-i5faqm5y7hzk-RoleParametersValue-htwac5drigap','state changed','OS::Heat::Value',NULL,691),(1043,'e8d666a6-33e2-4de1-9ff0-976f0a658e77','f8d3c480-4047-414a-9056-8986fbc8b84b','2026-06-09 08:02:08',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-7-qnon7sfryude-CinderBase-i5faqm5y7hzk-RoleParametersValue-htwac5drigap','state changed','OS::Heat::Value',NULL,691),(1044,'2e88bd49-2ee9-48af-81c1-fa3779699572','76704e88-86e6-482c-bf6c-6e25173f798c','2026-06-09 08:02:08',NULL,'CREATE','COMPLETE','4','cc15bf64-f471-4ad1-8da2-1e94ab0058e3','state changed','OS::TripleO::Services::CeilometerAgentIpmi',NULL,591),(1045,'365c514a-72c3-4e2f-a374-ebc87c8c611e','f8d3c480-4047-414a-9056-8986fbc8b84b','2026-06-09 08:02:08',NULL,'CREATE','COMPLETE','CinderBase','89a51534-3909-4ad2-b180-cb6ab63aed9b','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml',NULL,682),(1046,'70146be5-99cf-430f-80a4-186c44eeed3d','75ca799a-412b-4d58-9938-bf0c0a16aeef','2026-06-09 08:02:08',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-11-dnapxadt6qy4-NovaLibvirtLogging-7wy32uhxcj5a','75ca799a-412b-4d58-9938-bf0c0a16aeef','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1047,'0a1feaa7-6688-478a-8934-790ed7fb9c2f','75ca799a-412b-4d58-9938-bf0c0a16aeef','2026-06-09 08:02:08',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-11-dnapxadt6qy4-NovaLibvirtLogging-7wy32uhxcj5a','75ca799a-412b-4d58-9938-bf0c0a16aeef','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1048,'b5ddbd32-2146-47f4-9fd4-b442308b74b9','76704e88-86e6-482c-bf6c-6e25173f798c','2026-06-09 08:02:08',NULL,'CREATE','IN_PROGRESS','21','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-21-756yiqdlpxjo','state changed','OS::TripleO::Services::TripleoFirewall',NULL,693),(1049,'fa0262c6-ea8b-45fe-ae9a-59ebcb6076e3','c3291729-da89-4359-adab-fecfd2c003ce','2026-06-09 08:02:09',NULL,'CREATE','IN_PROGRESS','CinderBackupBase','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-5-hw6kebp2vdws-CinderBackupBase-zzi4ufant4zx','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-container-puppet.yaml',NULL,695),(1050,'108d1663-d737-4219-b32a-9ffd4965397f','dc3c3bd1-a347-4007-acc5-9cb81655baf8','2026-06-09 08:02:09',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-21-756yiqdlpxjo','dc3c3bd1-a347-4007-acc5-9cb81655baf8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1051,'f6155eb8-f859-40de-9bf3-0d25b33fee70','77648389-a9dd-4f63-96dc-b3676ef04074','2026-06-09 08:02:09',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-5-hw6kebp2vdws-CinderBackupBase-zzi4ufant4zx','77648389-a9dd-4f63-96dc-b3676ef04074','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1052,'36ecd884-6bdd-4951-9522-9a0c2077c6c7','dc3c3bd1-a347-4007-acc5-9cb81655baf8','2026-06-09 08:02:09',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-21-756yiqdlpxjo-RoleParametersValue-i2e4icp26ads','state changed','OS::Heat::Value',NULL,700),(1053,'381c39fb-82e6-420c-afd9-9012853c08e2','c3291729-da89-4359-adab-fecfd2c003ce','2026-06-09 08:02:09',NULL,'CREATE','COMPLETE','MySQLClient','2f309682-81f1-42b2-b6bc-68895f0faae5','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1054,'ecda1bb7-5309-43c7-803a-edf7c8eb0e9b','dc3c3bd1-a347-4007-acc5-9cb81655baf8','2026-06-09 08:02:09',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-21-756yiqdlpxjo-RoleParametersValue-i2e4icp26ads','state changed','OS::Heat::Value',NULL,700),(1055,'48f93a6a-1304-4fb0-bc5b-68b3bae88640','dc3c3bd1-a347-4007-acc5-9cb81655baf8','2026-06-09 08:02:09',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-21-756yiqdlpxjo','dc3c3bd1-a347-4007-acc5-9cb81655baf8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1056,'1b537bc1-82f6-40f3-9472-129295ddc747','ba9e235d-ae13-45bd-87af-cd3e5bc86814','2026-06-09 08:02:09',NULL,'CREATE','COMPLETE','ContainersCommon','0f07b9b4-14f0-43f1-bb06-2ea4abbdd06c','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1057,'5c12132c-89b5-4c33-b538-9d1abadc7042','77648389-a9dd-4f63-96dc-b3676ef04074','2026-06-09 08:02:09',NULL,'CREATE','IN_PROGRESS','CinderCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-5-hw6kebp2vdws-CinderBackupBase-zzi4ufant4zx-CinderCommon-7sdgbmfpiiru','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(1058,'01fecf8d-e32d-4a2e-80a6-8545123141a0','76704e88-86e6-482c-bf6c-6e25173f798c','2026-06-09 08:02:09',NULL,'CREATE','IN_PROGRESS','8','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-8-5wr4ndxmgotu','state changed','OS::TripleO::Services::MetricsQdr',NULL,701),(1059,'eb6714d9-8548-4ee7-9f7f-1f80935b00e6','82838a6f-7e6a-4340-8f0f-97df186bf3d4','2026-06-09 08:02:09',NULL,'CREATE','IN_PROGRESS','CinderBase','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-6-irfnfs2tsiai-CinderBase-pvjtn2najt73','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml',NULL,702),(1060,'77e891fe-056a-4159-ab68-adebc6b9bbe3','ba9e235d-ae13-45bd-87af-cd3e5bc86814','2026-06-09 08:02:09',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-4-n3552roca63l','ba9e235d-ae13-45bd-87af-cd3e5bc86814','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1061,'7adb6e08-e725-4eaa-b0bd-57d3da54544b','bc22e677-2cc2-45d1-9862-a9131bbb1e10','2026-06-09 08:02:09',NULL,'CREATE','IN_PROGRESS','CinderNVMeOF','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-10-5gijgpys77an-CinderNVMeOF-bxehghqoffca','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1062,'8534b5c1-29ac-4483-b8bc-17c4b5ce1da5','03a67ad4-483f-4ca0-bde1-6b0243c28e6e','2026-06-09 08:02:09',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-8-5wr4ndxmgotu','03a67ad4-483f-4ca0-bde1-6b0243c28e6e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1063,'f4af5e6a-fefe-4956-80ba-199e6310fb22','82838a6f-7e6a-4340-8f0f-97df186bf3d4','2026-06-09 08:02:09',NULL,'CREATE','COMPLETE','MySQLClient','f252ed30-28f6-422b-ac36-26f7cdfe0f06','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1064,'789eb99b-c6cf-4b80-aa12-21039cfb0a74','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:09',NULL,'CREATE','COMPLETE','4','ba9e235d-ae13-45bd-87af-cd3e5bc86814','state changed','OS::TripleO::Services::CinderApi',NULL,607),(1065,'0075309a-512e-4f58-a397-d70f51033117','02178689-b3a1-4791-a0ba-a4262bbc1b63','2026-06-09 08:02:09',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-10-5gijgpys77an-CinderNVMeOF-bxehghqoffca','02178689-b3a1-4791-a0ba-a4262bbc1b63','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1066,'10925fed-4f97-4d0c-97ac-bf50d3a58d1d','d69634b5-2603-4906-a8ee-1bbc81be7e18','2026-06-09 08:02:09',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-5-hw6kebp2vdws-CinderBackupBase-zzi4ufant4zx-CinderCommon-7sdgbmfpiiru','d69634b5-2603-4906-a8ee-1bbc81be7e18','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1067,'9902db2c-9d3b-4b83-b80d-32ee6b896f32','02178689-b3a1-4791-a0ba-a4262bbc1b63','2026-06-09 08:02:09',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-10-5gijgpys77an-CinderNVMeOF-bxehghqoffca','02178689-b3a1-4791-a0ba-a4262bbc1b63','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1068,'d621c900-a7dd-4df5-8195-d3e36b0c80a9','03a67ad4-483f-4ca0-bde1-6b0243c28e6e','2026-06-09 08:02:09',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-8-5wr4ndxmgotu-RoleParametersValue-ubtbfwzddjp2','state changed','OS::Heat::Value',NULL,703),(1069,'3c0a4c7c-c0e1-4fd3-b752-560f103f543b','03a67ad4-483f-4ca0-bde1-6b0243c28e6e','2026-06-09 08:02:09',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-8-5wr4ndxmgotu-RoleParametersValue-ubtbfwzddjp2','state changed','OS::Heat::Value',NULL,703),(1070,'680f476f-593a-4caf-899e-0ad463e2b7a6','a9605303-ab56-4fa3-8c06-de91196e71e2','2026-06-09 08:02:09',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-6-irfnfs2tsiai-CinderBase-pvjtn2najt73','a9605303-ab56-4fa3-8c06-de91196e71e2','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1071,'b6bd4887-2ac1-4735-80f4-5a6f1ffac095','b2adb083-2b80-428d-836f-25469fffef83','2026-06-09 08:02:09',NULL,'CREATE','IN_PROGRESS','CinderCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-7-qnon7sfryude-CinderCommon-l3u4pbylqfmb','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(1072,'5d9fa59d-141e-4061-8230-eb5d09ba3d55','a9605303-ab56-4fa3-8c06-de91196e71e2','2026-06-09 08:02:09',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-6-irfnfs2tsiai-CinderBase-pvjtn2najt73','a9605303-ab56-4fa3-8c06-de91196e71e2','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1073,'9c196480-6454-4450-b43f-c85bf836229e','aa8b664d-0f68-495a-88ca-a85deabfbb83','2026-06-09 08:02:09',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-7-qnon7sfryude-CinderCommon-l3u4pbylqfmb','aa8b664d-0f68-495a-88ca-a85deabfbb83','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1074,'bd2fb55e-aeac-49de-ab76-6a3f5845c318','d69634b5-2603-4906-a8ee-1bbc81be7e18','2026-06-09 08:02:09',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-5-hw6kebp2vdws-CinderBackupBase-zzi4ufant4zx-CinderCommon-7sdgbmfpiiru-ContainersCommon-w6sen3bjm4mz','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1075,'398431d1-10fb-410f-ae36-3e0a830e9da2','4703a4ef-d1f3-4b36-b11d-ced569ddbae5','2026-06-09 08:02:09',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-10-5gijgpys77an-NovaLogging-wglga6vtfhei-RoleParametersValue-a5a2r5rshujx','state changed','OS::Heat::Value',NULL,708),(1076,'23d071ad-bb13-49ed-9541-2da097dda2d0','4703a4ef-d1f3-4b36-b11d-ced569ddbae5','2026-06-09 08:02:09',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-10-5gijgpys77an-NovaLogging-wglga6vtfhei-RoleParametersValue-a5a2r5rshujx','state changed','OS::Heat::Value',NULL,708),(1077,'ced8b93c-ec7c-4032-a0f7-a363ced02667','902513e7-14ed-453f-aa8e-cf71e4373ee2','2026-06-09 08:02:09',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-5-hw6kebp2vdws-CinderBackupBase-zzi4ufant4zx-CinderCommon-7sdgbmfpiiru-ContainersCommon-w6sen3bjm4mz','902513e7-14ed-453f-aa8e-cf71e4373ee2','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1078,'be6f98f4-1e60-43b7-9ca5-62ffa479483b','4703a4ef-d1f3-4b36-b11d-ced569ddbae5','2026-06-09 08:02:09',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-10-5gijgpys77an-NovaLogging-wglga6vtfhei','4703a4ef-d1f3-4b36-b11d-ced569ddbae5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1079,'3935b71b-42fd-42b6-9e2e-813dba4fe9da','e69533cb-53d1-4e45-a6a3-f8da3ed879d9','2026-06-09 08:02:09',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-11-dnapxadt6qy4-RoleParametersValue-fn7jkgh5cfwc','state changed','OS::Heat::Value',NULL,711),(1080,'ac3a4c86-876a-4be7-8626-882185757077','e69533cb-53d1-4e45-a6a3-f8da3ed879d9','2026-06-09 08:02:09',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-11-dnapxadt6qy4-RoleParametersValue-fn7jkgh5cfwc','state changed','OS::Heat::Value',NULL,711),(1081,'6f5c014f-8e3d-4b4e-8caf-b9eb778286b3','aa8b664d-0f68-495a-88ca-a85deabfbb83','2026-06-09 08:02:09',NULL,'CREATE','IN_PROGRESS','CinderNVMeOF','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-7-qnon7sfryude-CinderCommon-l3u4pbylqfmb-CinderNVMeOF-7npmfkwmibpe','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1082,'4afb67de-b707-40b5-9ec0-180b863467e1','f8d3c480-4047-414a-9056-8986fbc8b84b','2026-06-09 08:02:09',NULL,'CREATE','IN_PROGRESS','CinderCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-7-qnon7sfryude-CinderBase-i5faqm5y7hzk-CinderCommon-4a5uhibsblm5','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(1083,'8ce3dc15-3591-455d-ba33-84c13b76a762','902513e7-14ed-453f-aa8e-cf71e4373ee2','2026-06-09 08:02:09',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-5-hw6kebp2vdws-CinderBackupBase-zzi4ufant4zx-CinderCommon-7sdgbmfpiiru-ContainersCommon-w6sen3bjm4mz','902513e7-14ed-453f-aa8e-cf71e4373ee2','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1084,'cae72847-965b-45a0-91a6-3bf482ebc95e','96b18bc8-3736-4451-80f5-1272cfd03283','2026-06-09 08:02:09',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-7-qnon7sfryude-CinderCommon-l3u4pbylqfmb-CinderNVMeOF-7npmfkwmibpe','96b18bc8-3736-4451-80f5-1272cfd03283','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1085,'705e60b1-98f2-4336-bc16-e2b6e73e2d0c','e69533cb-53d1-4e45-a6a3-f8da3ed879d9','2026-06-09 08:02:09',NULL,'CREATE','COMPLETE','NovaLibvirtLogging','75ca799a-412b-4d58-9938-bf0c0a16aeef','state changed','OS::TripleO::Services::Logging::NovaLibvirt',NULL,NULL),(1086,'911c65f9-c1a9-49c5-b743-76db10ae61e2','96b18bc8-3736-4451-80f5-1272cfd03283','2026-06-09 08:02:09',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-7-qnon7sfryude-CinderCommon-l3u4pbylqfmb-CinderNVMeOF-7npmfkwmibpe','96b18bc8-3736-4451-80f5-1272cfd03283','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1087,'57627e65-fb9c-4749-bce8-271de0cc1284','7382a26e-429d-4529-af74-f9ce31c7c884','2026-06-09 08:02:09',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-7-qnon7sfryude-CinderBase-i5faqm5y7hzk-CinderCommon-4a5uhibsblm5','7382a26e-429d-4529-af74-f9ce31c7c884','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1088,'0555e2c1-4388-40db-b01a-4ae90a86279c','7382a26e-429d-4529-af74-f9ce31c7c884','2026-06-09 08:02:10',NULL,'CREATE','IN_PROGRESS','CinderNVMeOF','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-7-qnon7sfryude-CinderBase-i5faqm5y7hzk-CinderCommon-4a5uhibsblm5-CinderNVMeOF-df5d6fzhla3d','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1089,'2a852ceb-f4be-469f-a316-8642706c88c9','76704e88-86e6-482c-bf6c-6e25173f798c','2026-06-09 08:02:10',NULL,'CREATE','COMPLETE','21','dc3c3bd1-a347-4007-acc5-9cb81655baf8','state changed','OS::TripleO::Services::TripleoFirewall',NULL,693),(1090,'2f0acf5d-8b18-48e8-ab2a-e0be2fc3a327','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:10',NULL,'CREATE','IN_PROGRESS','8','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-8-f43nst2qb4dj','state changed','OS::TripleO::Services::Clustercheck',NULL,715),(1091,'6f776ff6-7fdb-40cb-8e24-8a4af3f20107','8cc9c2c7-3a4b-4e07-b8b5-2f07d9862ec1','2026-06-09 08:02:10',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-7-qnon7sfryude-CinderBase-i5faqm5y7hzk-CinderCommon-4a5uhibsblm5-CinderNVMeOF-df5d6fzhla3d','8cc9c2c7-3a4b-4e07-b8b5-2f07d9862ec1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1092,'f6a1fbd2-ecde-4e6b-a527-8fc28ab57e01','8cc9c2c7-3a4b-4e07-b8b5-2f07d9862ec1','2026-06-09 08:02:10',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-7-qnon7sfryude-CinderBase-i5faqm5y7hzk-CinderCommon-4a5uhibsblm5-CinderNVMeOF-df5d6fzhla3d','8cc9c2c7-3a4b-4e07-b8b5-2f07d9862ec1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1093,'4b0c17c5-2b97-48b9-9cf4-1057531f67dc','82838a6f-7e6a-4340-8f0f-97df186bf3d4','2026-06-09 08:02:10',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-6-irfnfs2tsiai-RoleParametersValue-w66hiqpb6s3z','state changed','OS::Heat::Value',NULL,718),(1094,'fdb36b52-0951-4b7e-9d5d-46442af4c169','76704e88-86e6-482c-bf6c-6e25173f798c','2026-06-09 08:02:10',NULL,'CREATE','IN_PROGRESS','25','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-25-lbf73csercak','state changed','OS::TripleO::Services::OVNMetadataAgent',NULL,717),(1095,'bb5bdb85-9bde-4183-929b-cf9dffd8daa2','77648389-a9dd-4f63-96dc-b3676ef04074','2026-06-09 08:02:10',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-5-hw6kebp2vdws-CinderBackupBase-zzi4ufant4zx-MySQLClient-rpdbw3mc3yyw','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1096,'49f78dc1-40eb-4ecb-b3ac-a240c1848df4','c6c08445-cd33-4f87-9ba7-a93d588ff49f','2026-06-09 08:02:10',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-8-f43nst2qb4dj','c6c08445-cd33-4f87-9ba7-a93d588ff49f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1097,'3f34e6dc-1cff-4894-a690-2798accddd84','82838a6f-7e6a-4340-8f0f-97df186bf3d4','2026-06-09 08:02:10',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-6-irfnfs2tsiai-RoleParametersValue-w66hiqpb6s3z','state changed','OS::Heat::Value',NULL,718),(1098,'ac8b5a22-89e1-408e-8c51-1900ac91f1ee','bc22e677-2cc2-45d1-9862-a9131bbb1e10','2026-06-09 08:02:10',NULL,'CREATE','IN_PROGRESS','NovaComputeCommon','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-10-5gijgpys77an-NovaComputeCommon-7v3h7ew5m3jl','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-common-container-puppet.yaml',NULL,719),(1099,'a47bfafe-ac93-4d13-a52f-1e76218d520a','a6d13071-09fe-42ce-9ca8-c959a882024e','2026-06-09 08:02:10',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-5-hw6kebp2vdws-CinderBackupBase-zzi4ufant4zx-MySQLClient-rpdbw3mc3yyw','a6d13071-09fe-42ce-9ca8-c959a882024e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1100,'0b82b4ad-21e8-43dc-a5f9-db02642a0496','c0317e4a-e44a-4b18-95e8-44532ca9b6c7','2026-06-09 08:02:10',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-10-5gijgpys77an-NovaComputeCommon-7v3h7ew5m3jl','c0317e4a-e44a-4b18-95e8-44532ca9b6c7','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1101,'a43ceddd-ee41-4bc0-b6f8-82a11618d140','79ea311e-fcab-47b2-9985-22913ca53274','2026-06-09 08:02:10',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-25-lbf73csercak','79ea311e-fcab-47b2-9985-22913ca53274','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1102,'ccee043e-28b7-4587-85e1-cc5b24a2a8d2','a6d13071-09fe-42ce-9ca8-c959a882024e','2026-06-09 08:02:10',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-5-hw6kebp2vdws-CinderBackupBase-zzi4ufant4zx-MySQLClient-rpdbw3mc3yyw','a6d13071-09fe-42ce-9ca8-c959a882024e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1103,'312c3d19-3af1-47e6-bcfd-ab07e1e753e9','c0317e4a-e44a-4b18-95e8-44532ca9b6c7','2026-06-09 08:02:10',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-10-5gijgpys77an-NovaComputeCommon-7v3h7ew5m3jl','c0317e4a-e44a-4b18-95e8-44532ca9b6c7','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1104,'ace18819-841f-4c2f-a9ee-3ec3d3ebdb17','c6c08445-cd33-4f87-9ba7-a93d588ff49f','2026-06-09 08:02:10',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-8-f43nst2qb4dj-ContainersCommon-gaskcxi2dvmf','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1105,'616ddfda-7d0e-4c75-8fe5-dd3a951ade09','bc22e677-2cc2-45d1-9862-a9131bbb1e10','2026-06-09 08:02:10',NULL,'CREATE','COMPLETE','CinderNVMeOF','02178689-b3a1-4791-a0ba-a4262bbc1b63','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1106,'f6734a76-d969-48ae-b7ca-3a90eef8f82d','85a8b9d3-e790-454b-9bea-7bcd95459726','2026-06-09 08:02:10',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-8-f43nst2qb4dj-ContainersCommon-gaskcxi2dvmf','85a8b9d3-e790-454b-9bea-7bcd95459726','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1107,'0d856cdc-1d48-4ae0-9432-78b5d4f80ac4','03a67ad4-483f-4ca0-bde1-6b0243c28e6e','2026-06-09 08:02:10',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-8-5wr4ndxmgotu-ContainersCommon-mw4c2fxchyvo','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1108,'075ca97b-9fe7-43d2-af7a-29818aa287a8','85a8b9d3-e790-454b-9bea-7bcd95459726','2026-06-09 08:02:10',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-8-f43nst2qb4dj-ContainersCommon-gaskcxi2dvmf','85a8b9d3-e790-454b-9bea-7bcd95459726','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1109,'0411fad4-8636-4568-bc46-327d2985edf3','5dd624fd-ecf4-4e4c-ad4a-afd4c69e0935','2026-06-09 08:02:10',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-8-5wr4ndxmgotu-ContainersCommon-mw4c2fxchyvo','5dd624fd-ecf4-4e4c-ad4a-afd4c69e0935','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1110,'7c832abe-60cd-4a2d-a937-4625378cb659','82838a6f-7e6a-4340-8f0f-97df186bf3d4','2026-06-09 08:02:10',NULL,'CREATE','COMPLETE','CinderBase','a9605303-ab56-4fa3-8c06-de91196e71e2','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml',NULL,702),(1111,'5a3c7d11-31eb-4263-8cd0-4973e4f8aa8e','bc22e677-2cc2-45d1-9862-a9131bbb1e10','2026-06-09 08:02:10',NULL,'CREATE','COMPLETE','NovaLogging','4703a4ef-d1f3-4b36-b11d-ced569ddbae5','state changed','OS::TripleO::Services::Logging::NovaCommon',NULL,688),(1112,'54bbd21d-d8ff-4e82-942c-4945893e505c','5dd624fd-ecf4-4e4c-ad4a-afd4c69e0935','2026-06-09 08:02:10',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-8-5wr4ndxmgotu-ContainersCommon-mw4c2fxchyvo','5dd624fd-ecf4-4e4c-ad4a-afd4c69e0935','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1113,'64522369-3bda-4946-abc9-4981eea7da48','79ea311e-fcab-47b2-9985-22913ca53274','2026-06-09 08:02:10',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-25-lbf73csercak-ContainersCommon-vymdzvqttl3z','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1114,'6379a416-f227-4da6-96a9-e36dd2fabd70','d69634b5-2603-4906-a8ee-1bbc81be7e18','2026-06-09 08:02:10',NULL,'CREATE','IN_PROGRESS','CinderNVMeOF','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-5-hw6kebp2vdws-CinderBackupBase-zzi4ufant4zx-CinderCommon-7sdgbmfpiiru-CinderNVMeOF-ngbcut2gnm5v','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1115,'49354ea9-b3d2-443f-b2b3-bf6e7dd1b401','e8402069-db14-47bc-82f3-20374f84796c','2026-06-09 08:02:10',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-25-lbf73csercak-ContainersCommon-vymdzvqttl3z','e8402069-db14-47bc-82f3-20374f84796c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1116,'6ad31bd2-9933-41ce-91a4-7afb5315f3dc','e8402069-db14-47bc-82f3-20374f84796c','2026-06-09 08:02:10',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-25-lbf73csercak-ContainersCommon-vymdzvqttl3z','e8402069-db14-47bc-82f3-20374f84796c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1117,'58a467b8-04d0-44d9-aa3f-b9267c9342e0','652e4b28-6742-40f6-8200-51b772ae2ade','2026-06-09 08:02:10',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-5-hw6kebp2vdws-CinderBackupBase-zzi4ufant4zx-CinderCommon-7sdgbmfpiiru-CinderNVMeOF-ngbcut2gnm5v','652e4b28-6742-40f6-8200-51b772ae2ade','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1118,'9c4d9b60-7f78-42db-b922-c31bd27a0100','aa8b664d-0f68-495a-88ca-a85deabfbb83','2026-06-09 08:02:10',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-7-qnon7sfryude-CinderCommon-l3u4pbylqfmb-ContainersCommon-lac2zjcw2i7i','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1119,'98233eaf-96e2-4e09-92a0-5ce4bf3ad15d','652e4b28-6742-40f6-8200-51b772ae2ade','2026-06-09 08:02:10',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-5-hw6kebp2vdws-CinderBackupBase-zzi4ufant4zx-CinderCommon-7sdgbmfpiiru-CinderNVMeOF-ngbcut2gnm5v','652e4b28-6742-40f6-8200-51b772ae2ade','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1120,'9d4256b5-5b61-4722-b590-23ceecd33d5e','e69533cb-53d1-4e45-a6a3-f8da3ed879d9','2026-06-09 08:02:10',NULL,'CREATE','IN_PROGRESS','NovaBase','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-11-dnapxadt6qy4-NovaBase-cnfk3vu3n6ik','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,720),(1121,'505698af-e67d-4cd8-afd3-aac4931b9bba','36cdeeb3-3f17-40fc-bf3d-d91bbf79ba67','2026-06-09 08:02:10',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-7-qnon7sfryude-CinderCommon-l3u4pbylqfmb-ContainersCommon-lac2zjcw2i7i','36cdeeb3-3f17-40fc-bf3d-d91bbf79ba67','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1122,'51cd11b5-847e-45a8-8115-557f300cdf34','d69634b5-2603-4906-a8ee-1bbc81be7e18','2026-06-09 08:02:10',NULL,'CREATE','COMPLETE','ContainersCommon','902513e7-14ed-453f-aa8e-cf71e4373ee2','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1123,'c3af336d-1df5-4757-a659-f0e88e023613','36cdeeb3-3f17-40fc-bf3d-d91bbf79ba67','2026-06-09 08:02:10',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-7-qnon7sfryude-CinderCommon-l3u4pbylqfmb-ContainersCommon-lac2zjcw2i7i','36cdeeb3-3f17-40fc-bf3d-d91bbf79ba67','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1124,'c3b5504b-615f-4dac-b230-ebc5f6480ea7','aa8b664d-0f68-495a-88ca-a85deabfbb83','2026-06-09 08:02:10',NULL,'CREATE','COMPLETE','CinderNVMeOF','96b18bc8-3736-4451-80f5-1272cfd03283','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1125,'bee96e15-72f0-4177-b8d8-29ecbbf63855','c70d7fdc-e8d5-4e0a-bdbb-455072355c0c','2026-06-09 08:02:10',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-11-dnapxadt6qy4-NovaBase-cnfk3vu3n6ik','c70d7fdc-e8d5-4e0a-bdbb-455072355c0c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1126,'96951502-35ad-48cc-af7d-ed0f959e8a45','7382a26e-429d-4529-af74-f9ce31c7c884','2026-06-09 08:02:11',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-7-qnon7sfryude-CinderBase-i5faqm5y7hzk-CinderCommon-4a5uhibsblm5-ContainersCommon-6bp46hlc2ga4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1127,'3afa3410-525d-4fe0-b9f5-c87255ddc186','c70d7fdc-e8d5-4e0a-bdbb-455072355c0c','2026-06-09 08:02:11',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-11-dnapxadt6qy4-NovaBase-cnfk3vu3n6ik-RoleParametersValue-fhyb4f7tbkzy','state changed','OS::Heat::Value',NULL,721),(1128,'11e1c71c-702a-4bc1-b37a-d8bd93303177','c70d7fdc-e8d5-4e0a-bdbb-455072355c0c','2026-06-09 08:02:11',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-11-dnapxadt6qy4-NovaBase-cnfk3vu3n6ik-RoleParametersValue-fhyb4f7tbkzy','state changed','OS::Heat::Value',NULL,721),(1129,'63b6452d-d922-44b5-bea7-49682ba28f98','2fbff82c-950b-4240-8e23-d700620363cf','2026-06-09 08:02:11',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-7-qnon7sfryude-CinderBase-i5faqm5y7hzk-CinderCommon-4a5uhibsblm5-ContainersCommon-6bp46hlc2ga4','2fbff82c-950b-4240-8e23-d700620363cf','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1130,'5b11ffc2-b11f-4870-bbdb-392114f96954','c70d7fdc-e8d5-4e0a-bdbb-455072355c0c','2026-06-09 08:02:11',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-11-dnapxadt6qy4-NovaBase-cnfk3vu3n6ik','c70d7fdc-e8d5-4e0a-bdbb-455072355c0c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1131,'8ace81ca-3f31-41c3-805b-dfbe26a32c96','2fbff82c-950b-4240-8e23-d700620363cf','2026-06-09 08:02:11',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-7-qnon7sfryude-CinderBase-i5faqm5y7hzk-CinderCommon-4a5uhibsblm5-ContainersCommon-6bp46hlc2ga4','2fbff82c-950b-4240-8e23-d700620363cf','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1132,'5f036ca4-2187-4112-914e-292d1bd211d6','7382a26e-429d-4529-af74-f9ce31c7c884','2026-06-09 08:02:11',NULL,'CREATE','COMPLETE','CinderNVMeOF','8cc9c2c7-3a4b-4e07-b8b5-2f07d9862ec1','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1133,'32fed340-faf3-4660-8901-cb79ebc663af','82838a6f-7e6a-4340-8f0f-97df186bf3d4','2026-06-09 08:02:11',NULL,'CREATE','IN_PROGRESS','CinderCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-6-irfnfs2tsiai-CinderCommon-tseimvqx7zre','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(1134,'97f684ae-93b3-46c8-afab-76aee4d22192','77648389-a9dd-4f63-96dc-b3676ef04074','2026-06-09 08:02:11',NULL,'CREATE','IN_PROGRESS','CinderBase','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-5-hw6kebp2vdws-CinderBackupBase-zzi4ufant4zx-CinderBase-a4ecv2gzqcvx','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml',NULL,722),(1135,'5bc6f3dc-6147-494b-931c-56a51e25e143','bd88e0e1-00de-4750-90ee-f8f3db0e5988','2026-06-09 08:02:11',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-6-irfnfs2tsiai-CinderCommon-tseimvqx7zre','bd88e0e1-00de-4750-90ee-f8f3db0e5988','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1136,'222b564b-cb85-4cd3-971c-bbd58cca25b2','77648389-a9dd-4f63-96dc-b3676ef04074','2026-06-09 08:02:11',NULL,'CREATE','COMPLETE','MySQLClient','a6d13071-09fe-42ce-9ca8-c959a882024e','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1137,'785ca53c-691d-45b4-9a8a-041a839adeba','af2a5648-f62f-407d-9b32-755621bf5ec9','2026-06-09 08:02:11',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-5-hw6kebp2vdws-CinderBackupBase-zzi4ufant4zx-CinderBase-a4ecv2gzqcvx','af2a5648-f62f-407d-9b32-755621bf5ec9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1138,'8a9a5cbd-d050-4267-8ba0-cb76124b2a32','bc22e677-2cc2-45d1-9862-a9131bbb1e10','2026-06-09 08:02:11',NULL,'CREATE','COMPLETE','NovaComputeCommon','c0317e4a-e44a-4b18-95e8-44532ca9b6c7','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-common-container-puppet.yaml',NULL,719),(1139,'edc5428f-c64a-4d3f-80d8-605aba07de0e','af2a5648-f62f-407d-9b32-755621bf5ec9','2026-06-09 08:02:11',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-5-hw6kebp2vdws-CinderBackupBase-zzi4ufant4zx-CinderBase-a4ecv2gzqcvx','af2a5648-f62f-407d-9b32-755621bf5ec9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1140,'5977cbe4-28a0-496e-bb61-53ff6b68a4d2','c6c08445-cd33-4f87-9ba7-a93d588ff49f','2026-06-09 08:02:11',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-8-f43nst2qb4dj-RoleParametersValue-etdnnjhu7job','state changed','OS::Heat::Value',NULL,723),(1141,'01594736-9641-4fea-854a-98eaad98a7a5','bd88e0e1-00de-4750-90ee-f8f3db0e5988','2026-06-09 08:02:11',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-6-irfnfs2tsiai-CinderCommon-tseimvqx7zre-ContainersCommon-64ge24cvgjqm','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1142,'942b63f1-e840-4682-a012-b025eb162f99','bc22e677-2cc2-45d1-9862-a9131bbb1e10','2026-06-09 08:02:11',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-10-5gijgpys77an','bc22e677-2cc2-45d1-9862-a9131bbb1e10','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1143,'a993b271-9082-40d1-8254-a074a3a613f8','c6c08445-cd33-4f87-9ba7-a93d588ff49f','2026-06-09 08:02:11',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-8-f43nst2qb4dj-RoleParametersValue-etdnnjhu7job','state changed','OS::Heat::Value',NULL,723),(1144,'2d51e75e-e9e0-4755-9036-572168493e1d','c6c08445-cd33-4f87-9ba7-a93d588ff49f','2026-06-09 08:02:11',NULL,'CREATE','COMPLETE','ContainersCommon','85a8b9d3-e790-454b-9bea-7bcd95459726','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1145,'4a9d7eaa-cb5b-4730-b68a-7a9bdb55916c','bf826475-b74f-44e5-91f6-4fe3b68cd0e8','2026-06-09 08:02:11',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-6-irfnfs2tsiai-CinderCommon-tseimvqx7zre-ContainersCommon-64ge24cvgjqm','bf826475-b74f-44e5-91f6-4fe3b68cd0e8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1146,'52e9a83a-1883-4967-a88f-c759bfed77a4','bf826475-b74f-44e5-91f6-4fe3b68cd0e8','2026-06-09 08:02:11',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-6-irfnfs2tsiai-CinderCommon-tseimvqx7zre-ContainersCommon-64ge24cvgjqm','bf826475-b74f-44e5-91f6-4fe3b68cd0e8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1147,'6cc218c9-b32a-4968-a594-95c17950681c','79ea311e-fcab-47b2-9985-22913ca53274','2026-06-09 08:02:11',NULL,'CREATE','IN_PROGRESS','NeutronBase','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-25-lbf73csercak-NeutronBase-vs3iynumyaji','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-base.yaml',NULL,724),(1148,'747ec64f-6d34-4490-b145-36644dce5835','03a67ad4-483f-4ca0-bde1-6b0243c28e6e','2026-06-09 08:02:11',NULL,'CREATE','COMPLETE','ContainersCommon','5dd624fd-ecf4-4e4c-ad4a-afd4c69e0935','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1149,'541f1360-55a7-4738-8fd1-05607c557313','03a67ad4-483f-4ca0-bde1-6b0243c28e6e','2026-06-09 08:02:11',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-8-5wr4ndxmgotu','03a67ad4-483f-4ca0-bde1-6b0243c28e6e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1150,'dcc51788-97ae-4678-b7af-f77c2e579d65','19d0fb0c-37e4-4c0f-a707-b3e4b37faa86','2026-06-09 08:02:11',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-25-lbf73csercak-NeutronBase-vs3iynumyaji','19d0fb0c-37e4-4c0f-a707-b3e4b37faa86','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1151,'7f1c0ca9-841c-4334-b3c5-501c06b57c01','79ea311e-fcab-47b2-9985-22913ca53274','2026-06-09 08:02:11',NULL,'CREATE','COMPLETE','ContainersCommon','e8402069-db14-47bc-82f3-20374f84796c','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1152,'04f6dff8-053d-46b1-9c66-6bcc11489fb4','19d0fb0c-37e4-4c0f-a707-b3e4b37faa86','2026-06-09 08:02:11',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-25-lbf73csercak-NeutronBase-vs3iynumyaji','19d0fb0c-37e4-4c0f-a707-b3e4b37faa86','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1153,'dae5259b-61ee-466c-a924-282fd9c954cc','e69533cb-53d1-4e45-a6a3-f8da3ed879d9','2026-06-09 08:02:11',NULL,'CREATE','IN_PROGRESS','NovaLibvirtCommon','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-11-dnapxadt6qy4-NovaLibvirtCommon-3vc7mv2x2wr4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-common.yaml',NULL,NULL),(1154,'a1cee67e-d97c-4092-babc-76e0cf0863fb','d69634b5-2603-4906-a8ee-1bbc81be7e18','2026-06-09 08:02:11',NULL,'CREATE','COMPLETE','CinderNVMeOF','652e4b28-6742-40f6-8200-51b772ae2ade','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1155,'097aaffa-f0db-4f64-a790-d15927d4fe14','d69634b5-2603-4906-a8ee-1bbc81be7e18','2026-06-09 08:02:11',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-5-hw6kebp2vdws-CinderBackupBase-zzi4ufant4zx-CinderCommon-7sdgbmfpiiru','d69634b5-2603-4906-a8ee-1bbc81be7e18','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1156,'33cdb204-5ed3-4b37-8117-1124b0b2583f','aa8b664d-0f68-495a-88ca-a85deabfbb83','2026-06-09 08:02:11',NULL,'CREATE','COMPLETE','ContainersCommon','36cdeeb3-3f17-40fc-bf3d-d91bbf79ba67','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1157,'e34a8abc-c4fc-4b1a-bb72-baa4b8e7b11b','5fbf8bfc-1bd0-4993-a5c3-5a4f000b8b9f','2026-06-09 08:02:11',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-11-dnapxadt6qy4-NovaLibvirtCommon-3vc7mv2x2wr4','5fbf8bfc-1bd0-4993-a5c3-5a4f000b8b9f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1158,'3bdc36c5-a36e-4451-a0e6-13d225439a6a','aa8b664d-0f68-495a-88ca-a85deabfbb83','2026-06-09 08:02:12',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-7-qnon7sfryude-CinderCommon-l3u4pbylqfmb','aa8b664d-0f68-495a-88ca-a85deabfbb83','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1159,'c81393d7-3a84-443c-847a-ac435faae9e8','e69533cb-53d1-4e45-a6a3-f8da3ed879d9','2026-06-09 08:02:12',NULL,'CREATE','COMPLETE','NovaBase','c70d7fdc-e8d5-4e0a-bdbb-455072355c0c','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,720),(1160,'26024bea-25d8-4a69-bdca-df60ae9c576e','5fbf8bfc-1bd0-4993-a5c3-5a4f000b8b9f','2026-06-09 08:02:12',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-11-dnapxadt6qy4-NovaLibvirtCommon-3vc7mv2x2wr4-RoleParametersValue-3t7lkr6t7z66','state changed','OS::Heat::Value',NULL,725),(1161,'8238a0c2-e6c2-4eef-b8e9-8abbbfceb214','5fbf8bfc-1bd0-4993-a5c3-5a4f000b8b9f','2026-06-09 08:02:12',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-11-dnapxadt6qy4-NovaLibvirtCommon-3vc7mv2x2wr4-RoleParametersValue-3t7lkr6t7z66','state changed','OS::Heat::Value',NULL,725),(1162,'4b36243b-483c-4d3b-ac1d-afb84dda4262','5fbf8bfc-1bd0-4993-a5c3-5a4f000b8b9f','2026-06-09 08:02:12',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-11-dnapxadt6qy4-NovaLibvirtCommon-3vc7mv2x2wr4','5fbf8bfc-1bd0-4993-a5c3-5a4f000b8b9f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1163,'ae6715d7-c4ea-44de-bec3-e5c82232c97e','76704e88-86e6-482c-bf6c-6e25173f798c','2026-06-09 08:02:12',NULL,'CREATE','COMPLETE','10','bc22e677-2cc2-45d1-9862-a9131bbb1e10','state changed','OS::TripleO::Services::NovaCompute',NULL,659),(1164,'15fd9eaf-eefa-4a6c-906f-b8d05930ecee','7382a26e-429d-4529-af74-f9ce31c7c884','2026-06-09 08:02:12',NULL,'CREATE','COMPLETE','ContainersCommon','2fbff82c-950b-4240-8e23-d700620363cf','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1165,'50711f61-406f-4f87-b8b6-43896881e757','7382a26e-429d-4529-af74-f9ce31c7c884','2026-06-09 08:02:12',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-7-qnon7sfryude-CinderBase-i5faqm5y7hzk-CinderCommon-4a5uhibsblm5','7382a26e-429d-4529-af74-f9ce31c7c884','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1166,'1ced6129-1a78-4ee1-90c6-b4f05d99cd28','77648389-a9dd-4f63-96dc-b3676ef04074','2026-06-09 08:02:12',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-5-hw6kebp2vdws-CinderBackupBase-zzi4ufant4zx-RoleParametersValue-tq3joeasskpp','state changed','OS::Heat::Value',NULL,727),(1167,'5ea5b623-2e78-4dc0-918c-ad81a7297d6b','77648389-a9dd-4f63-96dc-b3676ef04074','2026-06-09 08:02:12',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-5-hw6kebp2vdws-CinderBackupBase-zzi4ufant4zx-RoleParametersValue-tq3joeasskpp','state changed','OS::Heat::Value',NULL,727),(1168,'1995bf78-c6a5-4b0d-9129-6af8b25b10b2','77648389-a9dd-4f63-96dc-b3676ef04074','2026-06-09 08:02:12',NULL,'CREATE','COMPLETE','CinderBase','af2a5648-f62f-407d-9b32-755621bf5ec9','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml',NULL,722),(1169,'6012248a-7070-49e5-ac3c-84b28110cf8e','c6c08445-cd33-4f87-9ba7-a93d588ff49f','2026-06-09 08:02:12',NULL,'CREATE','IN_PROGRESS','MysqlPuppetBase','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-8-f43nst2qb4dj-MysqlPuppetBase-sfg5jeb366wh','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml',NULL,731),(1170,'0cf0ecac-b19c-4ccb-8c65-80f9712ba9ff','bd88e0e1-00de-4750-90ee-f8f3db0e5988','2026-06-09 08:02:12',NULL,'CREATE','IN_PROGRESS','CinderNVMeOF','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-6-irfnfs2tsiai-CinderCommon-tseimvqx7zre-CinderNVMeOF-pj42a2lu7k72','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1171,'f05bab69-a9ac-405e-90fb-954c235b689f','76704e88-86e6-482c-bf6c-6e25173f798c','2026-06-09 08:02:12',NULL,'CREATE','COMPLETE','8','03a67ad4-483f-4ca0-bde1-6b0243c28e6e','state changed','OS::TripleO::Services::MetricsQdr',NULL,701),(1172,'36935363-a3b5-4a73-835b-9662e92e6ab3','23930dee-a9d5-4225-867d-34d50e898231','2026-06-09 08:02:12',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-8-f43nst2qb4dj-MysqlPuppetBase-sfg5jeb366wh','23930dee-a9d5-4225-867d-34d50e898231','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1173,'eb85b390-269b-444e-a778-e38063bac60b','77648389-a9dd-4f63-96dc-b3676ef04074','2026-06-09 08:02:12',NULL,'CREATE','COMPLETE','CinderCommon','d69634b5-2603-4906-a8ee-1bbc81be7e18','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(1174,'673cbb6e-5b61-42ed-a266-b2cbf36a5fec','755212b7-74b7-46c4-ad12-9af187809bf7','2026-06-09 08:02:12',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-6-irfnfs2tsiai-CinderCommon-tseimvqx7zre-CinderNVMeOF-pj42a2lu7k72','755212b7-74b7-46c4-ad12-9af187809bf7','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1175,'0fbc3ae7-453b-4bee-a2d8-537e36542aff','bd88e0e1-00de-4750-90ee-f8f3db0e5988','2026-06-09 08:02:12',NULL,'CREATE','COMPLETE','ContainersCommon','bf826475-b74f-44e5-91f6-4fe3b68cd0e8','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1176,'4ffe6763-385c-42a1-852e-229d73ffb527','755212b7-74b7-46c4-ad12-9af187809bf7','2026-06-09 08:02:12',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-6-irfnfs2tsiai-CinderCommon-tseimvqx7zre-CinderNVMeOF-pj42a2lu7k72','755212b7-74b7-46c4-ad12-9af187809bf7','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1177,'6be9d1c8-98c0-4f83-8a4b-5d849bd33b3a','bd88e0e1-00de-4750-90ee-f8f3db0e5988','2026-06-09 08:02:12',NULL,'CREATE','COMPLETE','CinderNVMeOF','755212b7-74b7-46c4-ad12-9af187809bf7','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1178,'0e777773-976b-44ac-aa84-5cfb0684a657','bd88e0e1-00de-4750-90ee-f8f3db0e5988','2026-06-09 08:02:12',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-6-irfnfs2tsiai-CinderCommon-tseimvqx7zre','bd88e0e1-00de-4750-90ee-f8f3db0e5988','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1179,'5e092eaf-ab74-4943-82ef-6c1a8d07deee','79ea311e-fcab-47b2-9985-22913ca53274','2026-06-09 08:02:12',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-25-lbf73csercak-RoleParametersValue-hmasgwf2tsfm','state changed','OS::Heat::Value',NULL,738),(1180,'a05ee635-37ee-43b8-a5ae-19fb6a627e81','b2adb083-2b80-428d-836f-25469fffef83','2026-06-09 08:02:12',NULL,'CREATE','COMPLETE','CinderCommon','aa8b664d-0f68-495a-88ca-a85deabfbb83','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(1181,'7344f325-d4be-4a60-8e9d-f5a6c1fafd67','79ea311e-fcab-47b2-9985-22913ca53274','2026-06-09 08:02:12',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-25-lbf73csercak-RoleParametersValue-hmasgwf2tsfm','state changed','OS::Heat::Value',NULL,738),(1182,'7233e247-2ec7-45f9-bdd2-ddf10f8c94b2','23930dee-a9d5-4225-867d-34d50e898231','2026-06-09 08:02:12',NULL,'CREATE','IN_PROGRESS','MysqlBase','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-8-f43nst2qb4dj-MysqlPuppetBase-sfg5jeb366wh-MysqlBase-xuyet3gpinlc','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-base.yaml',NULL,740),(1183,'b7e25129-aadb-4fd2-803a-38fd67e9a0cf','79ea311e-fcab-47b2-9985-22913ca53274','2026-06-09 08:02:12',NULL,'CREATE','COMPLETE','NeutronBase','19d0fb0c-37e4-4c0f-a707-b3e4b37faa86','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-base.yaml',NULL,724),(1184,'dc637a67-001d-497d-96bc-f21b794fe821','76704e88-86e6-482c-bf6c-6e25173f798c','2026-06-09 08:02:12',NULL,'CREATE','IN_PROGRESS','14','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-14-7wrsip3csrra','state changed','OS::TripleO::Services::ContainersLogrotateCrond',NULL,741),(1185,'771ff40b-a6ec-40fd-8129-308ad84467b8','e69533cb-53d1-4e45-a6a3-f8da3ed879d9','2026-06-09 08:02:12',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-11-dnapxadt6qy4-ContainersCommon-2jnpvnjv2noi','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1186,'751fd9d4-2873-4330-88b9-bc78b727b6c6','32bb9c8b-8e13-4d8e-ad18-4d13865a6740','2026-06-09 08:02:12',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-8-f43nst2qb4dj-MysqlPuppetBase-sfg5jeb366wh-MysqlBase-xuyet3gpinlc','32bb9c8b-8e13-4d8e-ad18-4d13865a6740','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1187,'6fef099a-7dd2-40a2-ab32-c511f50e8f74','32bb9c8b-8e13-4d8e-ad18-4d13865a6740','2026-06-09 08:02:12',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-8-f43nst2qb4dj-MysqlPuppetBase-sfg5jeb366wh-MysqlBase-xuyet3gpinlc','32bb9c8b-8e13-4d8e-ad18-4d13865a6740','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1188,'9bc3f55b-8c8a-4305-979f-21678585ea6d','63931e7b-66b7-4e57-a62c-3694385432c3','2026-06-09 08:02:12',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-11-dnapxadt6qy4-ContainersCommon-2jnpvnjv2noi','63931e7b-66b7-4e57-a62c-3694385432c3','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1189,'1012bf9f-003f-4cfe-a260-3e39e6b853c4','63931e7b-66b7-4e57-a62c-3694385432c3','2026-06-09 08:02:12',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-11-dnapxadt6qy4-ContainersCommon-2jnpvnjv2noi','63931e7b-66b7-4e57-a62c-3694385432c3','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1190,'1662b60d-974e-4c31-90d2-95bee06edb6d','76704e88-86e6-482c-bf6c-6e25173f798c','2026-06-09 08:02:12',NULL,'CREATE','IN_PROGRESS','12','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-12-elldszciuiqg','state changed','OS::TripleO::Services::NovaLibvirtGuests',NULL,743),(1191,'2669560e-6d9b-4049-b373-81b77f5e6a7b','f8d3c480-4047-414a-9056-8986fbc8b84b','2026-06-09 08:02:13',NULL,'CREATE','COMPLETE','CinderCommon','7382a26e-429d-4529-af74-f9ce31c7c884','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(1192,'f62c4957-2a55-4402-acda-6c06cebaeaee','a3c2c51c-94dd-41eb-bfd8-e85af4ac5354','2026-06-09 08:02:13',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-14-7wrsip3csrra','a3c2c51c-94dd-41eb-bfd8-e85af4ac5354','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1193,'7d972816-9191-42c8-ad8d-beec6b8d52ce','f8d3c480-4047-414a-9056-8986fbc8b84b','2026-06-09 08:02:13',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-7-qnon7sfryude-CinderBase-i5faqm5y7hzk','f8d3c480-4047-414a-9056-8986fbc8b84b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1194,'d5655582-65d2-4ad6-a914-a2a6cbcb2ac6','e69533cb-53d1-4e45-a6a3-f8da3ed879d9','2026-06-09 08:02:13',NULL,'CREATE','COMPLETE','NovaLibvirtCommon','5fbf8bfc-1bd0-4993-a5c3-5a4f000b8b9f','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-common.yaml',NULL,NULL),(1195,'adc5110e-47dc-4cc4-930d-5db4b5cc1c24','bd13d0f5-359d-45e0-be64-8a569fbf50d2','2026-06-09 08:02:13',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-12-elldszciuiqg','bd13d0f5-359d-45e0-be64-8a569fbf50d2','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1196,'bb0e7727-a349-4bda-a006-c3323bccde6d','bd13d0f5-359d-45e0-be64-8a569fbf50d2','2026-06-09 08:02:13',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-12-elldszciuiqg-RoleParametersValue-4lsl25kk56ex','state changed','OS::Heat::Value',NULL,744),(1197,'a0851043-fdd9-4057-b4fc-dca047023524','a3c2c51c-94dd-41eb-bfd8-e85af4ac5354','2026-06-09 08:02:13',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-14-7wrsip3csrra-ContainersCommon-gnxj2fziaor5','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1198,'f8796022-1c20-4b06-bc37-363c85f451f1','bd13d0f5-359d-45e0-be64-8a569fbf50d2','2026-06-09 08:02:13',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-12-elldszciuiqg-RoleParametersValue-4lsl25kk56ex','state changed','OS::Heat::Value',NULL,744),(1199,'70c4d80c-648e-4c7e-bc05-865ac428f93b','bd13d0f5-359d-45e0-be64-8a569fbf50d2','2026-06-09 08:02:13',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-12-elldszciuiqg','bd13d0f5-359d-45e0-be64-8a569fbf50d2','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1200,'141b3f49-4296-46dc-9814-33dfc69ee435','dfe6c919-4c53-43e9-9688-5699402904e5','2026-06-09 08:02:13',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-14-7wrsip3csrra-ContainersCommon-gnxj2fziaor5','dfe6c919-4c53-43e9-9688-5699402904e5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1201,'b1d093b9-f36c-4e9c-9db2-29ac44e4a8aa','dfe6c919-4c53-43e9-9688-5699402904e5','2026-06-09 08:02:13',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-14-7wrsip3csrra-ContainersCommon-gnxj2fziaor5','dfe6c919-4c53-43e9-9688-5699402904e5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1202,'f916a6cf-cc9c-43bb-9f8e-d4ddd1308ac9','77648389-a9dd-4f63-96dc-b3676ef04074','2026-06-09 08:02:13',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-5-hw6kebp2vdws-CinderBackupBase-zzi4ufant4zx-ContainersCommon-irtka4sxb463','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1203,'e2c19784-b676-4c9a-8d8d-5f627ba8792b','82838a6f-7e6a-4340-8f0f-97df186bf3d4','2026-06-09 08:02:13',NULL,'CREATE','COMPLETE','CinderCommon','bd88e0e1-00de-4750-90ee-f8f3db0e5988','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml',NULL,NULL),(1204,'af2a8da1-32e4-4bf2-9ae5-c18e82c0f260','b310a42c-68b7-4aa6-b654-f8e517b17a3e','2026-06-09 08:02:13',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-5-hw6kebp2vdws-CinderBackupBase-zzi4ufant4zx-ContainersCommon-irtka4sxb463','b310a42c-68b7-4aa6-b654-f8e517b17a3e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1205,'ce0abde3-6200-441a-96b1-451cbd22e473','82838a6f-7e6a-4340-8f0f-97df186bf3d4','2026-06-09 08:02:13',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-6-irfnfs2tsiai','82838a6f-7e6a-4340-8f0f-97df186bf3d4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1206,'a755f9ce-efb0-424c-8fb2-fa9502e6e962','b310a42c-68b7-4aa6-b654-f8e517b17a3e','2026-06-09 08:02:13',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-5-hw6kebp2vdws-CinderBackupBase-zzi4ufant4zx-ContainersCommon-irtka4sxb463','b310a42c-68b7-4aa6-b654-f8e517b17a3e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1207,'5c0b7990-f4d2-4362-9ca0-8b16dcf92962','b2adb083-2b80-428d-836f-25469fffef83','2026-06-09 08:02:13',NULL,'CREATE','COMPLETE','CinderBase','f8d3c480-4047-414a-9056-8986fbc8b84b','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml',NULL,654),(1208,'3f281f63-9b13-447b-a01f-4796a6863a09','b2adb083-2b80-428d-836f-25469fffef83','2026-06-09 08:02:13',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-7-qnon7sfryude','b2adb083-2b80-428d-836f-25469fffef83','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1209,'e5c5904b-ea9b-43c3-81cf-9b0eb5c03249','79ea311e-fcab-47b2-9985-22913ca53274','2026-06-09 08:02:13',NULL,'CREATE','IN_PROGRESS','NeutronLogging','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-25-lbf73csercak-NeutronLogging-t6oqvl7gii2d','state changed','OS::TripleO::Services::Logging::NeutronCommon',NULL,745),(1210,'cebeeadc-840a-4983-8c78-fa468ce30f37','23930dee-a9d5-4225-867d-34d50e898231','2026-06-09 08:02:13',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-8-f43nst2qb4dj-MysqlPuppetBase-sfg5jeb366wh-RoleParametersValue-ornbpipitoa4','state changed','OS::Heat::Value',NULL,746),(1211,'c9068c73-b5fe-4a66-bfb0-5727a583d6e6','b8a5fb2e-884d-48cb-96b4-189794518f0a','2026-06-09 08:02:13',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-25-lbf73csercak-NeutronLogging-t6oqvl7gii2d','b8a5fb2e-884d-48cb-96b4-189794518f0a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1212,'7b1bde54-e4a8-425b-aee3-de188b1e6d3a','23930dee-a9d5-4225-867d-34d50e898231','2026-06-09 08:02:13',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-8-f43nst2qb4dj-MysqlPuppetBase-sfg5jeb366wh-RoleParametersValue-ornbpipitoa4','state changed','OS::Heat::Value',NULL,746),(1213,'bf676f51-15f0-4b04-81f1-f91e5297ce7e','b8a5fb2e-884d-48cb-96b4-189794518f0a','2026-06-09 08:02:13',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-25-lbf73csercak-NeutronLogging-t6oqvl7gii2d','b8a5fb2e-884d-48cb-96b4-189794518f0a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1214,'f4578d7e-c55b-4773-8e0e-8d4459ce9a81','23930dee-a9d5-4225-867d-34d50e898231','2026-06-09 08:02:13',NULL,'CREATE','COMPLETE','MysqlBase','32bb9c8b-8e13-4d8e-ad18-4d13865a6740','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-base.yaml',NULL,740),(1215,'5dc15db2-5b8e-48fb-a6ab-80449724eb3c','e69533cb-53d1-4e45-a6a3-f8da3ed879d9','2026-06-09 08:02:13',NULL,'CREATE','COMPLETE','ContainersCommon','63931e7b-66b7-4e57-a62c-3694385432c3','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1216,'c268c944-03a6-4003-8d37-406e3d2b7b6b','e69533cb-53d1-4e45-a6a3-f8da3ed879d9','2026-06-09 08:02:13',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-11-dnapxadt6qy4','e69533cb-53d1-4e45-a6a3-f8da3ed879d9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1217,'4a32d989-53ab-4d1e-a343-1b6b71d6f5f1','76704e88-86e6-482c-bf6c-6e25173f798c','2026-06-09 08:02:14',NULL,'CREATE','COMPLETE','12','bd13d0f5-359d-45e0-be64-8a569fbf50d2','state changed','OS::TripleO::Services::NovaLibvirtGuests',NULL,743),(1218,'295b4bb2-9255-4be3-b42a-ad42125fa89e','a3c2c51c-94dd-41eb-bfd8-e85af4ac5354','2026-06-09 08:02:14',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-14-7wrsip3csrra-RoleParametersValue-t2fjzdczc6xj','state changed','OS::Heat::Value',NULL,747),(1219,'ee62a3be-e707-41c0-8841-4618ed758ad5','a3c2c51c-94dd-41eb-bfd8-e85af4ac5354','2026-06-09 08:02:14',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-14-7wrsip3csrra-RoleParametersValue-t2fjzdczc6xj','state changed','OS::Heat::Value',NULL,747),(1220,'95316014-126f-4501-8284-65fb1f9bd3d9','a3c2c51c-94dd-41eb-bfd8-e85af4ac5354','2026-06-09 08:02:14',NULL,'CREATE','COMPLETE','ContainersCommon','dfe6c919-4c53-43e9-9688-5699402904e5','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1221,'4f9cceee-e658-4c48-9e34-22ea5b834883','a3c2c51c-94dd-41eb-bfd8-e85af4ac5354','2026-06-09 08:02:14',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-14-7wrsip3csrra','a3c2c51c-94dd-41eb-bfd8-e85af4ac5354','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1222,'2ca623c5-71bf-4259-a1f1-cd30938a25b1','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:14',NULL,'CREATE','COMPLETE','6','82838a6f-7e6a-4340-8f0f-97df186bf3d4','state changed','OS::TripleO::Services::CinderScheduler',NULL,672),(1223,'0bcdd55d-04ee-43d7-a8e0-53ccb0a59e32','76704e88-86e6-482c-bf6c-6e25173f798c','2026-06-09 08:02:14',NULL,'CREATE','IN_PROGRESS','16','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-16-5mr4rckd62v2','state changed','OS::TripleO::Services::Rsyslog',NULL,750),(1224,'48887860-380b-4477-8b5d-6d9b087dae4c','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:14',NULL,'CREATE','COMPLETE','7','b2adb083-2b80-428d-836f-25469fffef83','state changed','OS::TripleO::Services::CinderVolume',NULL,653),(1225,'69ac640d-fc8d-4359-9dda-d37002f51ca3','77648389-a9dd-4f63-96dc-b3676ef04074','2026-06-09 08:02:14',NULL,'CREATE','COMPLETE','ContainersCommon','b310a42c-68b7-4aa6-b654-f8e517b17a3e','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1226,'ebcfc8e7-fb77-4f8d-91da-b8ee3565afce','77648389-a9dd-4f63-96dc-b3676ef04074','2026-06-09 08:02:14',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-5-hw6kebp2vdws-CinderBackupBase-zzi4ufant4zx','77648389-a9dd-4f63-96dc-b3676ef04074','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1227,'a735187c-ff17-47fc-8883-70205d66376c','908be319-d54e-4a51-9b1b-e3e9709bbe2e','2026-06-09 08:02:14',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-16-5mr4rckd62v2','908be319-d54e-4a51-9b1b-e3e9709bbe2e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1228,'9f99171c-5693-4b99-a2f8-78e4ae132c1d','908be319-d54e-4a51-9b1b-e3e9709bbe2e','2026-06-09 08:02:14',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-16-5mr4rckd62v2-ContainersCommon-qkekhtp4zmw4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1229,'f3ca6643-63b0-4b0b-a3a3-813f98c38eb7','76704e88-86e6-482c-bf6c-6e25173f798c','2026-06-09 08:02:14',NULL,'CREATE','COMPLETE','11','e69533cb-53d1-4e45-a6a3-f8da3ed879d9','state changed','OS::TripleO::Services::NovaLibvirt',NULL,685),(1230,'4b106dd8-7c45-4d8e-b74a-4e7117e5596f','c56fd853-0d79-446b-8111-0a0b75b1f560','2026-06-09 08:02:14',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-16-5mr4rckd62v2-ContainersCommon-qkekhtp4zmw4','c56fd853-0d79-446b-8111-0a0b75b1f560','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1231,'d9266e11-0464-4fc4-b78c-adf806d712e7','c56fd853-0d79-446b-8111-0a0b75b1f560','2026-06-09 08:02:14',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-16-5mr4rckd62v2-ContainersCommon-qkekhtp4zmw4','c56fd853-0d79-446b-8111-0a0b75b1f560','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1232,'8293c8f5-e8cf-44b4-8c82-4bf74e82bc83','908be319-d54e-4a51-9b1b-e3e9709bbe2e','2026-06-09 08:02:14',NULL,'CREATE','COMPLETE','ContainersCommon','c56fd853-0d79-446b-8111-0a0b75b1f560','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1233,'d745c89f-7a49-4ffe-aa01-6f586db6e6d5','23930dee-a9d5-4225-867d-34d50e898231','2026-06-09 08:02:14',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-8-f43nst2qb4dj-MysqlPuppetBase-sfg5jeb366wh-ContainersCommon-uovppx7zyoph','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1234,'0443c962-f9c8-43a0-b8b2-0fc9c999f7b2','9d2fcbbb-f56c-44ae-8ee0-ebb83e3a928c','2026-06-09 08:02:14',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-8-f43nst2qb4dj-MysqlPuppetBase-sfg5jeb366wh-ContainersCommon-uovppx7zyoph','9d2fcbbb-f56c-44ae-8ee0-ebb83e3a928c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1235,'eca1b35e-8e5c-4ede-8e9a-7c9964b3dea7','79ea311e-fcab-47b2-9985-22913ca53274','2026-06-09 08:02:14',NULL,'CREATE','COMPLETE','NeutronLogging','b8a5fb2e-884d-48cb-96b4-189794518f0a','state changed','OS::TripleO::Services::Logging::NeutronCommon',NULL,745),(1236,'33d9b68a-4147-4a5d-88b3-a15ae7e9cd27','9d2fcbbb-f56c-44ae-8ee0-ebb83e3a928c','2026-06-09 08:02:14',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-8-f43nst2qb4dj-MysqlPuppetBase-sfg5jeb366wh-ContainersCommon-uovppx7zyoph','9d2fcbbb-f56c-44ae-8ee0-ebb83e3a928c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1237,'cd5dc4d2-b2f6-4c42-af45-cb2dc428c4d5','79ea311e-fcab-47b2-9985-22913ca53274','2026-06-09 08:02:14',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-25-lbf73csercak','79ea311e-fcab-47b2-9985-22913ca53274','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1238,'3c0629cb-f679-4e41-a58b-0b69344e770f','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:15',NULL,'CREATE','IN_PROGRESS','10','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-10-b4yb7q4n3qaj','state changed','OS::TripleO::Services::ContainerImagePrepare',NULL,767),(1239,'ca8f8e4c-b2d7-463d-9d11-993cb976b1a9','76704e88-86e6-482c-bf6c-6e25173f798c','2026-06-09 08:02:15',NULL,'CREATE','COMPLETE','14','a3c2c51c-94dd-41eb-bfd8-e85af4ac5354','state changed','OS::TripleO::Services::ContainersLogrotateCrond',NULL,741),(1240,'f79503e4-36ac-4473-a50a-67add73b11b6','666c91b4-3035-4e07-8ffa-91bc4c5a8c00','2026-06-09 08:02:15',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-10-b4yb7q4n3qaj','666c91b4-3035-4e07-8ffa-91bc4c5a8c00','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1241,'acfa34e1-b959-4ef6-9366-a5f92e2260a3','c3291729-da89-4359-adab-fecfd2c003ce','2026-06-09 08:02:15',NULL,'CREATE','COMPLETE','CinderBackupBase','77648389-a9dd-4f63-96dc-b3676ef04074','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-container-puppet.yaml',NULL,695),(1242,'6ab9ef11-8d83-4233-b6fd-4f96c33339c1','666c91b4-3035-4e07-8ffa-91bc4c5a8c00','2026-06-09 08:02:15',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-10-b4yb7q4n3qaj','666c91b4-3035-4e07-8ffa-91bc4c5a8c00','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1243,'93292618-f677-4ab6-96da-c45cce4e8ec9','c3291729-da89-4359-adab-fecfd2c003ce','2026-06-09 08:02:15',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-5-hw6kebp2vdws','c3291729-da89-4359-adab-fecfd2c003ce','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1244,'52e319b6-045b-4cfb-bc5f-a11c6702d907','76704e88-86e6-482c-bf6c-6e25173f798c','2026-06-09 08:02:15',NULL,'CREATE','IN_PROGRESS','18','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-18-xakjxdnyqc4z','state changed','OS::TripleO::Services::Sshd',NULL,782),(1245,'cd603eaa-4652-4bcc-819f-1e9a820f4b23','76704e88-86e6-482c-bf6c-6e25173f798c','2026-06-09 08:02:15',NULL,'CREATE','IN_PROGRESS','15','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-15-dm7vhtrwazq7','state changed','OS::TripleO::Services::Podman',NULL,783),(1246,'5786245e-b5d2-45ef-ae6a-008ac8eef718','72028c3b-e782-4aa2-a80d-4cfa62e1c99c','2026-06-09 08:02:15',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-18-xakjxdnyqc4z','72028c3b-e782-4aa2-a80d-4cfa62e1c99c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1247,'3de2bb46-7e75-4e89-b16d-eeb9c29fe471','72028c3b-e782-4aa2-a80d-4cfa62e1c99c','2026-06-09 08:02:15',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-18-xakjxdnyqc4z','72028c3b-e782-4aa2-a80d-4cfa62e1c99c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1248,'96ca4d49-4fb3-4f3d-81d1-32caedbc366e','c8fc60d9-c067-42f9-b742-0a3ca994ab85','2026-06-09 08:02:15',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-15-dm7vhtrwazq7','c8fc60d9-c067-42f9-b742-0a3ca994ab85','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1249,'1264183f-4b8d-451f-97bd-17ae82096e3c','76704e88-86e6-482c-bf6c-6e25173f798c','2026-06-09 08:02:15',NULL,'CREATE','COMPLETE','25','79ea311e-fcab-47b2-9985-22913ca53274','state changed','OS::TripleO::Services::OVNMetadataAgent',NULL,717),(1250,'b3b22eaf-e0f3-4de3-91b8-e31d404062d5','c8fc60d9-c067-42f9-b742-0a3ca994ab85','2026-06-09 08:02:15',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-15-dm7vhtrwazq7','c8fc60d9-c067-42f9-b742-0a3ca994ab85','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1251,'6afc7ea6-178d-404b-9887-924d2e6772a9','908be319-d54e-4a51-9b1b-e3e9709bbe2e','2026-06-09 08:02:15',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-16-5mr4rckd62v2-RoleParametersValue-byofguhuz6ha','state changed','OS::Heat::Value',NULL,787),(1252,'67518f4a-a461-4503-a968-d00ef7f1894f','908be319-d54e-4a51-9b1b-e3e9709bbe2e','2026-06-09 08:02:15',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-16-5mr4rckd62v2-RoleParametersValue-byofguhuz6ha','state changed','OS::Heat::Value',NULL,787),(1253,'dfdd4781-8c49-402e-9064-c32e738d8439','908be319-d54e-4a51-9b1b-e3e9709bbe2e','2026-06-09 08:02:15',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-16-5mr4rckd62v2','908be319-d54e-4a51-9b1b-e3e9709bbe2e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1254,'b62e2833-00fd-4b4f-a091-a74f6bc5ae8d','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:15',NULL,'CREATE','IN_PROGRESS','11','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-11-ehe6cthzxnyx','state changed','OS::TripleO::Services::GlanceApi',NULL,789),(1255,'39f594b2-fd06-4488-a69c-6bf1b0d3d14f','23930dee-a9d5-4225-867d-34d50e898231','2026-06-09 08:02:15',NULL,'CREATE','COMPLETE','ContainersCommon','9d2fcbbb-f56c-44ae-8ee0-ebb83e3a928c','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1256,'8a1b9ad3-76b1-4c49-903a-c3a6d6a14945','23930dee-a9d5-4225-867d-34d50e898231','2026-06-09 08:02:15',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-8-f43nst2qb4dj-MysqlPuppetBase-sfg5jeb366wh','23930dee-a9d5-4225-867d-34d50e898231','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1257,'19144298-c31a-41fa-b6a3-cfd1c0192f5b','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:15',NULL,'CREATE','COMPLETE','5','c3291729-da89-4359-adab-fecfd2c003ce','state changed','OS::TripleO::Services::CinderBackup',NULL,647),(1258,'706cdbea-b1d6-4e4f-8159-95898e454f6d','37cd87c8-66b9-434f-9132-4eb917f43e20','2026-06-09 08:02:16',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-11-ehe6cthzxnyx','37cd87c8-66b9-434f-9132-4eb917f43e20','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1259,'f431499c-716d-47c7-b28c-07a97940e290','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:16',NULL,'CREATE','COMPLETE','10','666c91b4-3035-4e07-8ffa-91bc4c5a8c00','state changed','OS::TripleO::Services::ContainerImagePrepare',NULL,767),(1260,'800d54f7-befd-418f-a95c-43597bb5704f','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:16',NULL,'CREATE','IN_PROGRESS','14','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-14-75cab5guhuce','state changed','OS::TripleO::Services::HeatApi',NULL,799),(1261,'ba6a32c6-5f5c-4e38-a87f-1d0f1f4803c7','76704e88-86e6-482c-bf6c-6e25173f798c','2026-06-09 08:02:16',NULL,'CREATE','COMPLETE','18','72028c3b-e782-4aa2-a80d-4cfa62e1c99c','state changed','OS::TripleO::Services::Sshd',NULL,782),(1262,'b1e25fb9-8c8f-4b16-9181-c9697543ab69','76704e88-86e6-482c-bf6c-6e25173f798c','2026-06-09 08:02:16',NULL,'CREATE','COMPLETE','15','c8fc60d9-c067-42f9-b742-0a3ca994ab85','state changed','OS::TripleO::Services::Podman',NULL,783),(1263,'5d8fa132-e0dd-4e7c-855b-bb057edf8265','76704e88-86e6-482c-bf6c-6e25173f798c','2026-06-09 08:02:16',NULL,'CREATE','COMPLETE','16','908be319-d54e-4a51-9b1b-e3e9709bbe2e','state changed','OS::TripleO::Services::Rsyslog',NULL,750),(1264,'a84f44ce-4336-48c9-9c12-2117f6f4f68d','236a772a-67a2-4fd3-a893-1d7bb3049185','2026-06-09 08:02:16',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-14-75cab5guhuce','236a772a-67a2-4fd3-a893-1d7bb3049185','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1265,'40b5f9b1-2fb7-4474-b7c8-86c4cb39212c','37cd87c8-66b9-434f-9132-4eb917f43e20','2026-06-09 08:02:16',NULL,'CREATE','IN_PROGRESS','GlanceLogging','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-11-ehe6cthzxnyx-GlanceLogging-kysarwizabl7','state changed','OS::TripleO::Services::Logging::GlanceApi',NULL,NULL),(1266,'6efd690e-d9b5-4153-af30-8aaac200586d','76704e88-86e6-482c-bf6c-6e25173f798c','2026-06-09 08:02:16',NULL,'CREATE','IN_PROGRESS','22','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-22-q3umw4ebrocb','state changed','OS::TripleO::Services::TripleoPackages',NULL,804),(1267,'96e41d9c-4b32-459b-a161-786de6f3c863','6616ffa6-b71d-4aa7-8a99-4edf81ec97e9','2026-06-09 08:02:16',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-11-ehe6cthzxnyx-GlanceLogging-kysarwizabl7','6616ffa6-b71d-4aa7-8a99-4edf81ec97e9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1268,'e400f1ff-2fb6-4a6e-af51-d61332dd837b','6616ffa6-b71d-4aa7-8a99-4edf81ec97e9','2026-06-09 08:02:16',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-11-ehe6cthzxnyx-GlanceLogging-kysarwizabl7-RoleParametersValue-lmc3fqozbyng','state changed','OS::Heat::Value',NULL,813),(1269,'ca1dc8fe-ce30-46a9-ad47-852e698bd308','c6c08445-cd33-4f87-9ba7-a93d588ff49f','2026-06-09 08:02:16',NULL,'CREATE','COMPLETE','MysqlPuppetBase','23930dee-a9d5-4225-867d-34d50e898231','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml',NULL,731),(1270,'4683594b-fba9-4621-a39c-4394d667ff16','6616ffa6-b71d-4aa7-8a99-4edf81ec97e9','2026-06-09 08:02:16',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-11-ehe6cthzxnyx-GlanceLogging-kysarwizabl7-RoleParametersValue-lmc3fqozbyng','state changed','OS::Heat::Value',NULL,813),(1271,'0fb3d369-4fe0-4eca-b405-d32fb20e09c2','76704e88-86e6-482c-bf6c-6e25173f798c','2026-06-09 08:02:16',NULL,'CREATE','IN_PROGRESS','19','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-19-7ntu3yt43qrh','state changed','OS::TripleO::Services::Timesync',NULL,812),(1272,'30809951-6d81-453d-ae86-50390a421d06','76704e88-86e6-482c-bf6c-6e25173f798c','2026-06-09 08:02:16',NULL,'CREATE','IN_PROGRESS','20','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-20-6gmjbfohb2vr','state changed','OS::TripleO::Services::Timezone',NULL,814),(1273,'505c0da9-de55-46e8-9f4f-9f5a1d524f1c','6616ffa6-b71d-4aa7-8a99-4edf81ec97e9','2026-06-09 08:02:16',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-11-ehe6cthzxnyx-GlanceLogging-kysarwizabl7','6616ffa6-b71d-4aa7-8a99-4edf81ec97e9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1274,'0efaf4d0-6018-4eda-8e55-8a0843dbd56c','ee0e0921-9eba-4b91-b5e4-f4fecd309919','2026-06-09 08:02:17',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-20-6gmjbfohb2vr','ee0e0921-9eba-4b91-b5e4-f4fecd309919','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1275,'dee9288a-1cf2-44ad-9ff2-182d1ef5ccb8','e708d17c-f94d-4cc5-a268-38dac776df7c','2026-06-09 08:02:17',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-22-q3umw4ebrocb','e708d17c-f94d-4cc5-a268-38dac776df7c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1276,'02f640d4-564c-41f4-944e-0cf9ea219224','236a772a-67a2-4fd3-a893-1d7bb3049185','2026-06-09 08:02:17',NULL,'CREATE','IN_PROGRESS','HeatApiLogging','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-14-75cab5guhuce-HeatApiLogging-yajcl6bnyl2l','state changed','OS::TripleO::Services::Logging::HeatApi',NULL,NULL),(1277,'de092c5a-4629-48be-b529-660dd9504181','c6c08445-cd33-4f87-9ba7-a93d588ff49f','2026-06-09 08:02:17',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-8-f43nst2qb4dj','c6c08445-cd33-4f87-9ba7-a93d588ff49f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1278,'f62dcd79-84dd-4e16-a470-4a655636e1d3','ee0e0921-9eba-4b91-b5e4-f4fecd309919','2026-06-09 08:02:17',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-20-6gmjbfohb2vr','ee0e0921-9eba-4b91-b5e4-f4fecd309919','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1279,'f59ed3c6-7419-4ae5-a2d1-33b3effd9bd6','556239ae-cbc7-4228-8089-6504320c2edb','2026-06-09 08:02:17',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-19-7ntu3yt43qrh','556239ae-cbc7-4228-8089-6504320c2edb','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1280,'c16f4305-c1e4-4f1c-ac0b-a5ee6cb037e7','556239ae-cbc7-4228-8089-6504320c2edb','2026-06-09 08:02:17',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-19-7ntu3yt43qrh','556239ae-cbc7-4228-8089-6504320c2edb','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1281,'fc812dce-eb6e-4c46-a4ff-e2e677740a59','76704e88-86e6-482c-bf6c-6e25173f798c','2026-06-09 08:02:17',NULL,'CREATE','COMPLETE','19','556239ae-cbc7-4228-8089-6504320c2edb','state changed','OS::TripleO::Services::Timesync',NULL,812),(1282,'3b6bc975-de5c-4ea5-8a36-8dc658d1799d','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:17',NULL,'CREATE','IN_PROGRESS','9','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-9-lyoyfmrzkjn6','state changed','OS::TripleO::Services::Collectd',NULL,816),(1283,'83e2b1a1-374f-49e5-97b6-7374a675fb69','38acb8e0-17e7-4a08-8799-21714441254b','2026-06-09 08:02:17',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-14-75cab5guhuce-HeatApiLogging-yajcl6bnyl2l','38acb8e0-17e7-4a08-8799-21714441254b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1284,'d528b995-55e5-4392-b732-974c0eb80505','38acb8e0-17e7-4a08-8799-21714441254b','2026-06-09 08:02:17',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-14-75cab5guhuce-HeatApiLogging-yajcl6bnyl2l','38acb8e0-17e7-4a08-8799-21714441254b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1285,'c587b532-0029-4dad-bbc4-458a2a786811','e708d17c-f94d-4cc5-a268-38dac776df7c','2026-06-09 08:02:17',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-22-q3umw4ebrocb-RoleParametersValue-5rslnouyt44z','state changed','OS::Heat::Value',NULL,818),(1286,'bf6b6f69-9283-4827-a055-83d04555ebe2','e708d17c-f94d-4cc5-a268-38dac776df7c','2026-06-09 08:02:17',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-22-q3umw4ebrocb-RoleParametersValue-5rslnouyt44z','state changed','OS::Heat::Value',NULL,818),(1287,'6c7a169d-11eb-4a49-ba75-f761d181aeb2','76704e88-86e6-482c-bf6c-6e25173f798c','2026-06-09 08:02:17',NULL,'CREATE','IN_PROGRESS','23','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-23-bxegl2os4ugl','state changed','OS::TripleO::Services::Tuned',NULL,819),(1288,'27fc0be3-a918-407d-a466-9d12a5210d0b','244e5e95-1b49-40e0-b638-97a24a1aba8a','2026-06-09 08:02:17',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-9-lyoyfmrzkjn6','244e5e95-1b49-40e0-b638-97a24a1aba8a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1289,'c51823ca-9ff7-415d-8a9e-7050cd160653','e110c7b5-fcdf-447a-9734-c6f5e2d5f98c','2026-06-09 08:02:17',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-23-bxegl2os4ugl','e110c7b5-fcdf-447a-9734-c6f5e2d5f98c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1290,'e37c2084-088e-426c-bd85-e203a5ba9a7e','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:17',NULL,'CREATE','COMPLETE','8','c6c08445-cd33-4f87-9ba7-a93d588ff49f','state changed','OS::TripleO::Services::Clustercheck',NULL,715),(1291,'d1084ae8-5764-4cd7-bef8-57e0483ef4af','244e5e95-1b49-40e0-b638-97a24a1aba8a','2026-06-09 08:02:17',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-9-lyoyfmrzkjn6-RoleParametersValue-3pm5m3g6uh3f','state changed','OS::Heat::Value',NULL,820),(1292,'219c8278-b269-432e-9f31-b9d4dab9fd68','244e5e95-1b49-40e0-b638-97a24a1aba8a','2026-06-09 08:02:17',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-9-lyoyfmrzkjn6-RoleParametersValue-3pm5m3g6uh3f','state changed','OS::Heat::Value',NULL,820),(1293,'1537a0c6-35f2-440c-b8b0-313592824a16','e110c7b5-fcdf-447a-9734-c6f5e2d5f98c','2026-06-09 08:02:17',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-23-bxegl2os4ugl-RoleParametersValue-tha7a2p2hfza','state changed','OS::Heat::Value',NULL,822),(1294,'80556de0-7915-4a91-a960-708a6b9bd772','e110c7b5-fcdf-447a-9734-c6f5e2d5f98c','2026-06-09 08:02:17',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-23-bxegl2os4ugl-RoleParametersValue-tha7a2p2hfza','state changed','OS::Heat::Value',NULL,822),(1295,'1bdbf9d3-6bae-4d69-be2b-a6bf2e85e129','e110c7b5-fcdf-447a-9734-c6f5e2d5f98c','2026-06-09 08:02:17',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-23-bxegl2os4ugl','e110c7b5-fcdf-447a-9734-c6f5e2d5f98c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1296,'71ee5708-13ad-4ea5-9641-f648b9b6d843','37cd87c8-66b9-434f-9132-4eb917f43e20','2026-06-09 08:02:17',NULL,'CREATE','IN_PROGRESS','TLSProxyBase','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-11-ehe6cthzxnyx-TLSProxyBase-aa2gtjlvcvi7','state changed','OS::TripleO::Services::TLSProxyBase',NULL,825),(1297,'82823ec6-2c76-498a-8b8e-ea5cba82bf07','88c433cb-684b-46ac-95af-5b6b8b687b24','2026-06-09 08:02:17',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-11-ehe6cthzxnyx-TLSProxyBase-aa2gtjlvcvi7','88c433cb-684b-46ac-95af-5b6b8b687b24','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1298,'b4a52246-c574-4a44-9a9a-537da3c080f9','37cd87c8-66b9-434f-9132-4eb917f43e20','2026-06-09 08:02:17',NULL,'CREATE','COMPLETE','GlanceLogging','6616ffa6-b71d-4aa7-8a99-4edf81ec97e9','state changed','OS::TripleO::Services::Logging::GlanceApi',NULL,NULL),(1299,'a8f85b12-6d31-4b28-b84f-fcbb7a541f2a','88c433cb-684b-46ac-95af-5b6b8b687b24','2026-06-09 08:02:17',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-11-ehe6cthzxnyx-TLSProxyBase-aa2gtjlvcvi7-ApacheNetworks-5lhrtfxvl6nq','state changed','OS::Heat::Value',NULL,830),(1300,'8de9a19e-1979-447d-badc-1e9a26fdc72a','88c433cb-684b-46ac-95af-5b6b8b687b24','2026-06-09 08:02:17',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-11-ehe6cthzxnyx-TLSProxyBase-aa2gtjlvcvi7-ApacheNetworks-5lhrtfxvl6nq','state changed','OS::Heat::Value',NULL,830),(1301,'e29e261e-e78f-41dc-a88b-35418160fad1','88c433cb-684b-46ac-95af-5b6b8b687b24','2026-06-09 08:02:17',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-11-ehe6cthzxnyx-TLSProxyBase-aa2gtjlvcvi7','88c433cb-684b-46ac-95af-5b6b8b687b24','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1302,'bdfd2c61-854d-4b68-802d-f624cccee5a3','236a772a-67a2-4fd3-a893-1d7bb3049185','2026-06-09 08:02:18',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-14-75cab5guhuce-RoleParametersValue-xlnppikevv2v','state changed','OS::Heat::Value',NULL,831),(1303,'17cc9bf2-8098-43dc-bc17-a172818341bb','236a772a-67a2-4fd3-a893-1d7bb3049185','2026-06-09 08:02:18',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-14-75cab5guhuce-RoleParametersValue-xlnppikevv2v','state changed','OS::Heat::Value',NULL,831),(1304,'ef0a16a5-b4d0-4a43-8a8e-7ea0fcb45bc3','76704e88-86e6-482c-bf6c-6e25173f798c','2026-06-09 08:02:18',NULL,'CREATE','COMPLETE','20','ee0e0921-9eba-4b91-b5e4-f4fecd309919','state changed','OS::TripleO::Services::Timezone',NULL,814),(1305,'9cb18944-3dda-4b49-9915-cf5e995a6db2','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:18',NULL,'CREATE','IN_PROGRESS','12','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-12-bu6nemuhr6lm','state changed','OS::TripleO::Services::GlanceApiInternal',NULL,832),(1306,'5312bc69-55f9-43b8-bf06-42edb1d3dee5','236a772a-67a2-4fd3-a893-1d7bb3049185','2026-06-09 08:02:18',NULL,'CREATE','COMPLETE','HeatApiLogging','38acb8e0-17e7-4a08-8799-21714441254b','state changed','OS::TripleO::Services::Logging::HeatApi',NULL,NULL),(1307,'abc7aca9-6b0d-41d2-8ff2-0761ae84ff1f','76704e88-86e6-482c-bf6c-6e25173f798c','2026-06-09 08:02:18',NULL,'CREATE','IN_PROGRESS','24','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-24-3katovj34oeo','state changed','OS::TripleO::Services::OVNController',NULL,834),(1308,'141307a7-bb1d-4768-ba56-c6726e322ef7','e708d17c-f94d-4cc5-a268-38dac776df7c','2026-06-09 08:02:18',NULL,'CREATE','IN_PROGRESS','Podman','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-22-q3umw4ebrocb-Podman-dm4kopumpgth','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml',NULL,835),(1309,'d5b0e2b7-fc86-4455-869c-c23d65d1f3db','a1fc3fc0-3964-4d07-b2ff-68281cac9614','2026-06-09 08:02:18',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-12-bu6nemuhr6lm','a1fc3fc0-3964-4d07-b2ff-68281cac9614','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1310,'3b47ced6-e271-469f-afbc-c855d1e0f343','38c7cdf0-4a49-46c5-a02b-f6896208651c','2026-06-09 08:02:18',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-22-q3umw4ebrocb-Podman-dm4kopumpgth','38c7cdf0-4a49-46c5-a02b-f6896208651c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1311,'c663f30b-fdb6-42d1-a115-09ad69dc3a79','2e0142d6-d082-4b40-b2b6-666bcb3657df','2026-06-09 08:02:18',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-24-3katovj34oeo','2e0142d6-d082-4b40-b2b6-666bcb3657df','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1312,'a02239b0-81bd-4d75-bc13-72227efce23d','38c7cdf0-4a49-46c5-a02b-f6896208651c','2026-06-09 08:02:18',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-22-q3umw4ebrocb-Podman-dm4kopumpgth','38c7cdf0-4a49-46c5-a02b-f6896208651c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1313,'87027db5-bc3b-4e96-8d86-7613725148eb','76704e88-86e6-482c-bf6c-6e25173f798c','2026-06-09 08:02:18',NULL,'CREATE','COMPLETE','23','e110c7b5-fcdf-447a-9734-c6f5e2d5f98c','state changed','OS::TripleO::Services::Tuned',NULL,819),(1314,'8276ff0c-ef28-439e-b636-4b53873a483d','244e5e95-1b49-40e0-b638-97a24a1aba8a','2026-06-09 08:02:18',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-9-lyoyfmrzkjn6-ContainersCommon-lmqelmqz5x6l','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1315,'d669acf5-cc43-4ea6-be45-0ea247cb7801','a1fc3fc0-3964-4d07-b2ff-68281cac9614','2026-06-09 08:02:18',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-12-bu6nemuhr6lm-RoleParametersValue-ro5awigqpqam','state changed','OS::Heat::Value',NULL,836),(1316,'6a9fe6bd-7ae4-468d-8c4b-22271bfff95d','a1fc3fc0-3964-4d07-b2ff-68281cac9614','2026-06-09 08:02:18',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-12-bu6nemuhr6lm-RoleParametersValue-ro5awigqpqam','state changed','OS::Heat::Value',NULL,836),(1317,'0808eab2-5431-442a-abd1-bb1c015a5d1f','eb09c0f6-6de8-47cd-b2db-5930ceeaf19f','2026-06-09 08:02:18',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-9-lyoyfmrzkjn6-ContainersCommon-lmqelmqz5x6l','eb09c0f6-6de8-47cd-b2db-5930ceeaf19f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1318,'00444670-5af4-4cc2-9ce7-e2be4787baf7','2e0142d6-d082-4b40-b2b6-666bcb3657df','2026-06-09 08:02:18',NULL,'CREATE','IN_PROGRESS','OVNBridgeMappingsValue','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-24-3katovj34oeo-OVNBridgeMappingsValue-hh5y4wguk5il','state changed','OS::Heat::Value',NULL,837),(1319,'e6402986-b6c5-4d60-a521-3803481eabbd','2e0142d6-d082-4b40-b2b6-666bcb3657df','2026-06-09 08:02:18',NULL,'CREATE','COMPLETE','OVNBridgeMappingsValue','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-24-3katovj34oeo-OVNBridgeMappingsValue-hh5y4wguk5il','state changed','OS::Heat::Value',NULL,837),(1320,'6f4e65f4-188f-4a79-bb1f-2b91e6448466','eb09c0f6-6de8-47cd-b2db-5930ceeaf19f','2026-06-09 08:02:18',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-9-lyoyfmrzkjn6-ContainersCommon-lmqelmqz5x6l','eb09c0f6-6de8-47cd-b2db-5930ceeaf19f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1321,'6dc58235-a996-46f8-8d97-5717144283e4','37cd87c8-66b9-434f-9132-4eb917f43e20','2026-06-09 08:02:18',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-11-ehe6cthzxnyx-ContainersCommon-2d2iect7xkxp','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1322,'0dbd5206-13af-499f-806d-2c8975ce36d9','fc28b69d-0ea3-4417-8d19-4d3b731c7741','2026-06-09 08:02:18',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-11-ehe6cthzxnyx-ContainersCommon-2d2iect7xkxp','fc28b69d-0ea3-4417-8d19-4d3b731c7741','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1323,'02fa28f5-de03-4e0f-b0e8-6c81315c9324','fc28b69d-0ea3-4417-8d19-4d3b731c7741','2026-06-09 08:02:18',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-11-ehe6cthzxnyx-ContainersCommon-2d2iect7xkxp','fc28b69d-0ea3-4417-8d19-4d3b731c7741','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1324,'44f624f1-082d-49ea-820e-1a7fad3282e0','37cd87c8-66b9-434f-9132-4eb917f43e20','2026-06-09 08:02:18',NULL,'CREATE','COMPLETE','TLSProxyBase','88c433cb-684b-46ac-95af-5b6b8b687b24','state changed','OS::TripleO::Services::TLSProxyBase',NULL,825),(1325,'ba215637-266c-40b9-9259-ad1999ffe176','236a772a-67a2-4fd3-a893-1d7bb3049185','2026-06-09 08:02:19',NULL,'CREATE','IN_PROGRESS','HeatBase','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-14-75cab5guhuce-HeatBase-qwaw6vsttm67','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-base-puppet.yaml',NULL,838),(1326,'75ed8d71-7d98-4c74-babe-94e855a6dda7','e040ad1d-b78e-4964-9b6b-4de004c7a183','2026-06-09 08:02:19',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-14-75cab5guhuce-HeatBase-qwaw6vsttm67','e040ad1d-b78e-4964-9b6b-4de004c7a183','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1327,'c6737b46-eacd-474c-ac5b-f2c067202f7b','e040ad1d-b78e-4964-9b6b-4de004c7a183','2026-06-09 08:02:19',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-14-75cab5guhuce-HeatBase-qwaw6vsttm67','e040ad1d-b78e-4964-9b6b-4de004c7a183','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1328,'0cf202f8-7f78-4217-af60-29c75f9de2a6','e708d17c-f94d-4cc5-a268-38dac776df7c','2026-06-09 08:02:19',NULL,'CREATE','COMPLETE','Podman','38c7cdf0-4a49-46c5-a02b-f6896208651c','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml',NULL,835),(1329,'8b90eeaf-248d-4145-aa32-affed0bf6cc7','e708d17c-f94d-4cc5-a268-38dac776df7c','2026-06-09 08:02:19',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-22-q3umw4ebrocb','e708d17c-f94d-4cc5-a268-38dac776df7c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1330,'dd4a9be7-294c-4ae3-a077-0798e4a31256','a1fc3fc0-3964-4d07-b2ff-68281cac9614','2026-06-09 08:02:19',NULL,'CREATE','IN_PROGRESS','GlanceApi','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-12-bu6nemuhr6lm-GlanceApi-exkw2hlpmqsa','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml',NULL,839),(1331,'e30369e0-9e45-4df2-b019-23452b3192ba','2e0142d6-d082-4b40-b2b6-666bcb3657df','2026-06-09 08:02:19',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-24-3katovj34oeo-RoleParametersValue-nxsfdh44k5v3','state changed','OS::Heat::Value',NULL,840),(1332,'c8bfe32c-f705-4d2d-b057-fc861394feb0','2e0142d6-d082-4b40-b2b6-666bcb3657df','2026-06-09 08:02:19',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-24-3katovj34oeo-RoleParametersValue-nxsfdh44k5v3','state changed','OS::Heat::Value',NULL,840),(1333,'f7f07236-1eb8-4540-a608-39bff70ebb69','244e5e95-1b49-40e0-b638-97a24a1aba8a','2026-06-09 08:02:19',NULL,'CREATE','COMPLETE','ContainersCommon','eb09c0f6-6de8-47cd-b2db-5930ceeaf19f','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1334,'7b7a2700-f1c8-4f0f-bb9c-61e7bb3a46fb','244e5e95-1b49-40e0-b638-97a24a1aba8a','2026-06-09 08:02:19',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-9-lyoyfmrzkjn6','244e5e95-1b49-40e0-b638-97a24a1aba8a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1335,'472429d8-8901-4df1-a8bb-bac7a6c16dbf','ba74f6ef-2e1b-4ad4-8015-c2d75de2f1da','2026-06-09 08:02:19',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-12-bu6nemuhr6lm-GlanceApi-exkw2hlpmqsa','ba74f6ef-2e1b-4ad4-8015-c2d75de2f1da','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1336,'8f5ba867-d2cc-47ea-80cd-b7c3a8abd42d','37cd87c8-66b9-434f-9132-4eb917f43e20','2026-06-09 08:02:19',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-11-ehe6cthzxnyx-MySQLClient-2v5a45rs2zo4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1337,'25784231-96cb-474f-98ac-4fc5c19146ca','644a48b7-d266-4aac-975f-7935bc424c78','2026-06-09 08:02:19',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-11-ehe6cthzxnyx-MySQLClient-2v5a45rs2zo4','644a48b7-d266-4aac-975f-7935bc424c78','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1338,'559c6ac3-5786-4ecc-afd8-b4b35d0f9732','644a48b7-d266-4aac-975f-7935bc424c78','2026-06-09 08:02:19',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-11-ehe6cthzxnyx-MySQLClient-2v5a45rs2zo4','644a48b7-d266-4aac-975f-7935bc424c78','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1339,'196331cb-e4f2-42a8-8fb0-3d8524b83e91','37cd87c8-66b9-434f-9132-4eb917f43e20','2026-06-09 08:02:19',NULL,'CREATE','COMPLETE','ContainersCommon','fc28b69d-0ea3-4417-8d19-4d3b731c7741','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1340,'3259e70e-b563-405e-8f25-4d44f8562952','ba74f6ef-2e1b-4ad4-8015-c2d75de2f1da','2026-06-09 08:02:19',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-12-bu6nemuhr6lm-GlanceApi-exkw2hlpmqsa-ContainersCommon-br3fxm72joa7','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1341,'c4a94250-e0b2-46a2-855d-06e525968dc7','236a772a-67a2-4fd3-a893-1d7bb3049185','2026-06-09 08:02:20',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-14-75cab5guhuce-ContainersCommon-vtied4puhj3z','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1342,'14442344-158e-4f6a-a0e6-395a6f155f7a','8e621685-e79c-4111-ac9c-ab54e419fcdd','2026-06-09 08:02:20',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-12-bu6nemuhr6lm-GlanceApi-exkw2hlpmqsa-ContainersCommon-br3fxm72joa7','8e621685-e79c-4111-ac9c-ab54e419fcdd','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1343,'cdd6ac7b-14c5-455c-aa95-bcbc5b6d36e3','2469829d-5982-44c7-a471-900614c98eec','2026-06-09 08:02:20',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-14-75cab5guhuce-ContainersCommon-vtied4puhj3z','2469829d-5982-44c7-a471-900614c98eec','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1344,'f4822151-f1cb-432f-9923-fe1e3c02778a','8e621685-e79c-4111-ac9c-ab54e419fcdd','2026-06-09 08:02:20',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-12-bu6nemuhr6lm-GlanceApi-exkw2hlpmqsa-ContainersCommon-br3fxm72joa7','8e621685-e79c-4111-ac9c-ab54e419fcdd','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1345,'6acc256d-3a4b-47a6-876c-f4acf92c2461','2469829d-5982-44c7-a471-900614c98eec','2026-06-09 08:02:20',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-14-75cab5guhuce-ContainersCommon-vtied4puhj3z','2469829d-5982-44c7-a471-900614c98eec','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1346,'25cd7249-83a1-4356-a2b3-3991015da2d6','236a772a-67a2-4fd3-a893-1d7bb3049185','2026-06-09 08:02:20',NULL,'CREATE','COMPLETE','HeatBase','e040ad1d-b78e-4964-9b6b-4de004c7a183','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-base-puppet.yaml',NULL,838),(1347,'486c4e74-648d-4a95-98f3-98e4a81b745e','76704e88-86e6-482c-bf6c-6e25173f798c','2026-06-09 08:02:20',NULL,'CREATE','COMPLETE','22','e708d17c-f94d-4cc5-a268-38dac776df7c','state changed','OS::TripleO::Services::TripleoPackages',NULL,804),(1348,'b43d5e0f-71b8-4f1f-b40a-3fad82011ae6','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:20',NULL,'CREATE','COMPLETE','9','244e5e95-1b49-40e0-b638-97a24a1aba8a','state changed','OS::TripleO::Services::Collectd',NULL,816),(1349,'5765e55d-8e1c-4528-bc74-b5806da7ad81','a1fc3fc0-3964-4d07-b2ff-68281cac9614','2026-06-09 08:02:20',NULL,'CREATE','IN_PROGRESS','GlanceLogging','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-12-bu6nemuhr6lm-GlanceLogging-akkwh4epgq3d','state changed','OS::TripleO::Services::Logging::GlanceApi',NULL,NULL),(1350,'819ed5b1-318b-4b29-be2a-ec6fc010742b','2e0142d6-d082-4b40-b2b6-666bcb3657df','2026-06-09 08:02:20',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-24-3katovj34oeo-ContainersCommon-idp67uqh7gpn','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1351,'953d3a2d-f960-487f-85c4-035a2f6c2bbb','f34c673f-bd2c-4457-93e8-4a00d8c067f5','2026-06-09 08:02:20',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-12-bu6nemuhr6lm-GlanceLogging-akkwh4epgq3d','f34c673f-bd2c-4457-93e8-4a00d8c067f5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1352,'23cab9da-b597-4276-b0e5-87a11a41ca4f','37cd87c8-66b9-434f-9132-4eb917f43e20','2026-06-09 08:02:20',NULL,'CREATE','IN_PROGRESS','CinderNVMeOF','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-11-ehe6cthzxnyx-CinderNVMeOF-sv6ljp6w2vbi','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1353,'a38c7a6f-df8e-451a-b37c-73bb3f593a33','f34c673f-bd2c-4457-93e8-4a00d8c067f5','2026-06-09 08:02:20',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-12-bu6nemuhr6lm-GlanceLogging-akkwh4epgq3d-RoleParametersValue-kpquymu25gyl','state changed','OS::Heat::Value',NULL,844),(1354,'1fd4d410-1baf-4c2b-b206-7c387136aaa1','5ada1263-be92-44a4-bde6-1f8759c3759c','2026-06-09 08:02:20',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-11-ehe6cthzxnyx-CinderNVMeOF-sv6ljp6w2vbi','5ada1263-be92-44a4-bde6-1f8759c3759c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1355,'7bca0e60-cde9-4c5f-acc4-97779dc103e4','f34c673f-bd2c-4457-93e8-4a00d8c067f5','2026-06-09 08:02:20',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-12-bu6nemuhr6lm-GlanceLogging-akkwh4epgq3d-RoleParametersValue-kpquymu25gyl','state changed','OS::Heat::Value',NULL,844),(1356,'3c10fc7d-550e-4ce5-956f-db1d1408df52','5ada1263-be92-44a4-bde6-1f8759c3759c','2026-06-09 08:02:20',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-11-ehe6cthzxnyx-CinderNVMeOF-sv6ljp6w2vbi','5ada1263-be92-44a4-bde6-1f8759c3759c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1357,'d57b6520-f578-4349-97ec-fb94e76a4f99','f34c673f-bd2c-4457-93e8-4a00d8c067f5','2026-06-09 08:02:20',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-12-bu6nemuhr6lm-GlanceLogging-akkwh4epgq3d','f34c673f-bd2c-4457-93e8-4a00d8c067f5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1358,'5d7ac460-3940-48ec-b0a3-3e791a804604','37cd87c8-66b9-434f-9132-4eb917f43e20','2026-06-09 08:02:20',NULL,'CREATE','COMPLETE','MySQLClient','644a48b7-d266-4aac-975f-7935bc424c78','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1359,'d107f8f3-52b2-421a-9b3c-210d2232aae6','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:20',NULL,'CREATE','IN_PROGRESS','13','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-13-h3tvll3igd2n','state changed','OS::TripleO::Services::HAproxy',NULL,845),(1360,'fff0a9c0-1d93-4d81-ab1d-3b55bb2ab96d','352d3f16-3303-4c40-b107-0a3e397ee795','2026-06-09 08:02:20',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-24-3katovj34oeo-ContainersCommon-idp67uqh7gpn','352d3f16-3303-4c40-b107-0a3e397ee795','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1361,'c7bcd24c-a8f5-4fcb-8417-c18ce6108668','352d3f16-3303-4c40-b107-0a3e397ee795','2026-06-09 08:02:20',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-24-3katovj34oeo-ContainersCommon-idp67uqh7gpn','352d3f16-3303-4c40-b107-0a3e397ee795','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1362,'6ea2b1f2-ea1f-4422-b65c-b19ce55d1807','ba74f6ef-2e1b-4ad4-8015-c2d75de2f1da','2026-06-09 08:02:21',NULL,'CREATE','IN_PROGRESS','GlanceLogging','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-12-bu6nemuhr6lm-GlanceApi-exkw2hlpmqsa-GlanceLogging-4svhqvhhu7uz','state changed','OS::TripleO::Services::Logging::GlanceApi',NULL,NULL),(1363,'49d3d4da-f644-41a2-a0cc-3fa7835d7b50','bcc7a880-ac2e-4d2c-bce9-046c9687e9c1','2026-06-09 08:02:21',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-13-h3tvll3igd2n','bcc7a880-ac2e-4d2c-bce9-046c9687e9c1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1364,'db7dad51-93bf-4582-ab4f-4d3b6195c63a','236a772a-67a2-4fd3-a893-1d7bb3049185','2026-06-09 08:02:21',NULL,'CREATE','IN_PROGRESS','ApacheServiceBase','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-14-75cab5guhuce-ApacheServiceBase-huwrlzz6fbds','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,846),(1365,'d5bd864f-23bf-44d2-abc5-a34f0e678412','2e0142d6-d082-4b40-b2b6-666bcb3657df','2026-06-09 08:02:21',NULL,'CREATE','COMPLETE','ContainersCommon','352d3f16-3303-4c40-b107-0a3e397ee795','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1366,'fb92e70e-78c5-4fa5-8357-921274d5bb00','2e0142d6-d082-4b40-b2b6-666bcb3657df','2026-06-09 08:02:21',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy-24-3katovj34oeo','2e0142d6-d082-4b40-b2b6-666bcb3657df','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1367,'31a142b2-220c-4ae0-b76a-986ff9d37aee','962517a9-e714-4e9b-becb-3168442584f6','2026-06-09 08:02:21',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-12-bu6nemuhr6lm-GlanceApi-exkw2hlpmqsa-GlanceLogging-4svhqvhhu7uz','962517a9-e714-4e9b-becb-3168442584f6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1368,'71ef4d50-053c-495a-9066-91dea59ab689','c9e35342-1a3a-4377-ac60-6263fd0c7088','2026-06-09 08:02:21',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-14-75cab5guhuce-ApacheServiceBase-huwrlzz6fbds','c9e35342-1a3a-4377-ac60-6263fd0c7088','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1369,'54abea41-6672-4448-9211-bc2dfb239810','ba74f6ef-2e1b-4ad4-8015-c2d75de2f1da','2026-06-09 08:02:21',NULL,'CREATE','COMPLETE','ContainersCommon','8e621685-e79c-4111-ac9c-ab54e419fcdd','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1370,'de5edd24-a27d-4785-b57c-04ed987e4f64','236a772a-67a2-4fd3-a893-1d7bb3049185','2026-06-09 08:02:21',NULL,'CREATE','COMPLETE','ContainersCommon','2469829d-5982-44c7-a471-900614c98eec','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1371,'d789f2cd-4e07-46bd-bf97-6db74ec922a6','962517a9-e714-4e9b-becb-3168442584f6','2026-06-09 08:02:21',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-12-bu6nemuhr6lm-GlanceApi-exkw2hlpmqsa-GlanceLogging-4svhqvhhu7uz-RoleParametersValue-whxiohdha2yo','state changed','OS::Heat::Value',NULL,847),(1372,'c86a5bfc-5d6b-4df4-b8d8-ffc95a9ad2b8','c9e35342-1a3a-4377-ac60-6263fd0c7088','2026-06-09 08:02:21',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-14-75cab5guhuce-ApacheServiceBase-huwrlzz6fbds-ApacheNetworks-62lntcrfjftk','state changed','OS::Heat::Value',NULL,848),(1373,'89837c3e-27df-4b5c-a488-5244c3bdf21c','c9e35342-1a3a-4377-ac60-6263fd0c7088','2026-06-09 08:02:21',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-14-75cab5guhuce-ApacheServiceBase-huwrlzz6fbds-ApacheNetworks-62lntcrfjftk','state changed','OS::Heat::Value',NULL,848),(1374,'c2208f66-bfdf-4525-8c13-fd4c3cdada4d','962517a9-e714-4e9b-becb-3168442584f6','2026-06-09 08:02:21',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-12-bu6nemuhr6lm-GlanceApi-exkw2hlpmqsa-GlanceLogging-4svhqvhhu7uz-RoleParametersValue-whxiohdha2yo','state changed','OS::Heat::Value',NULL,847),(1375,'01ee67d4-1174-434d-958d-e9ca58ce813c','c9e35342-1a3a-4377-ac60-6263fd0c7088','2026-06-09 08:02:21',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-14-75cab5guhuce-ApacheServiceBase-huwrlzz6fbds','c9e35342-1a3a-4377-ac60-6263fd0c7088','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1376,'d6b3f584-0f19-4be2-bcc2-ac6622f30cc2','962517a9-e714-4e9b-becb-3168442584f6','2026-06-09 08:02:21',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-12-bu6nemuhr6lm-GlanceApi-exkw2hlpmqsa-GlanceLogging-4svhqvhhu7uz','962517a9-e714-4e9b-becb-3168442584f6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1377,'1d4d6b70-df31-4920-ae04-128a02bfaddd','bcc7a880-ac2e-4d2c-bce9-046c9687e9c1','2026-06-09 08:02:21',NULL,'CREATE','IN_PROGRESS','HAProxyBase','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-13-h3tvll3igd2n-HAProxyBase-csdh6ypcihqp','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-container-puppet.yaml',NULL,849),(1378,'4a6725af-de58-4158-af4b-35415a1b0ebd','9942946b-5e82-4340-afe1-2cefaba7335f','2026-06-09 08:02:21',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-13-h3tvll3igd2n-HAProxyBase-csdh6ypcihqp','9942946b-5e82-4340-afe1-2cefaba7335f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1379,'aa53ac53-0286-49cf-9d67-c60af7b25927','76704e88-86e6-482c-bf6c-6e25173f798c','2026-06-09 08:02:21',NULL,'CREATE','COMPLETE','24','2e0142d6-d082-4b40-b2b6-666bcb3657df','state changed','OS::TripleO::Services::OVNController',NULL,834),(1380,'d8df689d-8d3e-4812-a558-36675b7ba20e','a1fc3fc0-3964-4d07-b2ff-68281cac9614','2026-06-09 08:02:21',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-12-bu6nemuhr6lm-MySQLClient-e42xtjnr4zci','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1381,'2dbf08af-1f9c-45d1-86f5-55e406bcc6ab','76704e88-86e6-482c-bf6c-6e25173f798c','2026-06-09 08:02:21',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceChain-sn25t3tolrmy','76704e88-86e6-482c-bf6c-6e25173f798c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1382,'b1158d7d-8538-4666-8791-f2cbc18adb5f','0e5682ec-9c34-4794-8760-1fea11990c0f','2026-06-09 08:02:21',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-12-bu6nemuhr6lm-MySQLClient-e42xtjnr4zci','0e5682ec-9c34-4794-8760-1fea11990c0f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1383,'0fa7722b-d1b3-4ae0-a224-ecc9bcf9b823','0e5682ec-9c34-4794-8760-1fea11990c0f','2026-06-09 08:02:21',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-12-bu6nemuhr6lm-MySQLClient-e42xtjnr4zci','0e5682ec-9c34-4794-8760-1fea11990c0f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1384,'8a45975d-2e8b-473a-a3ff-5932ba91f688','9942946b-5e82-4340-afe1-2cefaba7335f','2026-06-09 08:02:21',NULL,'CREATE','IN_PROGRESS','HAProxyInternalTLS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-13-h3tvll3igd2n-HAProxyBase-csdh6ypcihqp-HAProxyInternalTLS-7orduuvemghq','state changed','OS::TripleO::Services::HAProxyInternalTLS',NULL,850),(1385,'e8bfac1b-acc9-46a2-8879-d60178801f8b','a1fc3fc0-3964-4d07-b2ff-68281cac9614','2026-06-09 08:02:21',NULL,'CREATE','COMPLETE','GlanceLogging','f34c673f-bd2c-4457-93e8-4a00d8c067f5','state changed','OS::TripleO::Services::Logging::GlanceApi',NULL,NULL),(1386,'d6aede4b-a54e-4e4a-a750-fce7d616f10b','37cd87c8-66b9-434f-9132-4eb917f43e20','2026-06-09 08:02:21',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-11-ehe6cthzxnyx-RoleParametersValue-tuuqvu27povq','state changed','OS::Heat::Value',NULL,851),(1387,'3c4c8cce-f8d0-45bb-a4ab-97331dd64e90','37cd87c8-66b9-434f-9132-4eb917f43e20','2026-06-09 08:02:21',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-11-ehe6cthzxnyx-RoleParametersValue-tuuqvu27povq','state changed','OS::Heat::Value',NULL,851),(1388,'5d0dfaea-3437-469f-8d5b-0fc6d127e07a','11df9367-768c-4e86-b92f-6281a32db7b8','2026-06-09 08:02:21',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-13-h3tvll3igd2n-HAProxyBase-csdh6ypcihqp-HAProxyInternalTLS-7orduuvemghq','11df9367-768c-4e86-b92f-6281a32db7b8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1389,'2615e2c3-9fc3-4f5d-995d-c4bd32ea24bf','37cd87c8-66b9-434f-9132-4eb917f43e20','2026-06-09 08:02:21',NULL,'CREATE','COMPLETE','CinderNVMeOF','5ada1263-be92-44a4-bde6-1f8759c3759c','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1390,'fd38c2a7-e70d-497e-93bb-458e3e31ba56','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:21',NULL,'CREATE','COMPLETE','ServiceChain','76704e88-86e6-482c-bf6c-6e25173f798c','state changed','OS::Heat::ResourceChain',NULL,94),(1391,'ff484d84-b797-4ec7-86ae-b7035dfceebc','37cd87c8-66b9-434f-9132-4eb917f43e20','2026-06-09 08:02:21',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-11-ehe6cthzxnyx','37cd87c8-66b9-434f-9132-4eb917f43e20','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1392,'7cd00996-d13c-4eb9-8e14-28cae82d886d','11df9367-768c-4e86-b92f-6281a32db7b8','2026-06-09 08:02:21',NULL,'CREATE','IN_PROGRESS','HAProxyNetworks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-13-h3tvll3igd2n-HAProxyBase-csdh6ypcihqp-HAProxyInternalTLS-7orduuvemghq-HAProxyNetworks-q3cnbd5olyyk','state changed','OS::Heat::Value',NULL,852),(1393,'86660cff-c97f-4fbb-889b-d0236961e2d5','11df9367-768c-4e86-b92f-6281a32db7b8','2026-06-09 08:02:21',NULL,'CREATE','COMPLETE','HAProxyNetworks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-13-h3tvll3igd2n-HAProxyBase-csdh6ypcihqp-HAProxyInternalTLS-7orduuvemghq-HAProxyNetworks-q3cnbd5olyyk','state changed','OS::Heat::Value',NULL,852),(1394,'3b35553c-7756-4823-8c7b-07b3c86d6fff','11df9367-768c-4e86-b92f-6281a32db7b8','2026-06-09 08:02:22',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-13-h3tvll3igd2n-HAProxyBase-csdh6ypcihqp-HAProxyInternalTLS-7orduuvemghq','11df9367-768c-4e86-b92f-6281a32db7b8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1395,'6e8a2377-6ce1-4ccf-8656-5b8f4862ee18','ba74f6ef-2e1b-4ad4-8015-c2d75de2f1da','2026-06-09 08:02:22',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-12-bu6nemuhr6lm-GlanceApi-exkw2hlpmqsa-MySQLClient-morr4giw6fvd','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1396,'ee237759-429d-4da7-bf21-0851c453b121','9ac69c0f-bae2-4e67-8a34-3b4b102affba','2026-06-09 08:02:22',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-12-bu6nemuhr6lm-GlanceApi-exkw2hlpmqsa-MySQLClient-morr4giw6fvd','9ac69c0f-bae2-4e67-8a34-3b4b102affba','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1397,'f14ba14a-e738-44f4-a9fe-1b73d60ea915','ba74f6ef-2e1b-4ad4-8015-c2d75de2f1da','2026-06-09 08:02:22',NULL,'CREATE','COMPLETE','GlanceLogging','962517a9-e714-4e9b-becb-3168442584f6','state changed','OS::TripleO::Services::Logging::GlanceApi',NULL,NULL),(1398,'01aa608a-a309-4eb9-9523-257406f44b8c','9ac69c0f-bae2-4e67-8a34-3b4b102affba','2026-06-09 08:02:22',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-12-bu6nemuhr6lm-GlanceApi-exkw2hlpmqsa-MySQLClient-morr4giw6fvd','9ac69c0f-bae2-4e67-8a34-3b4b102affba','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1399,'57b396e9-8d72-4095-81a6-cc9c3797fdcd','236a772a-67a2-4fd3-a893-1d7bb3049185','2026-06-09 08:02:22',NULL,'CREATE','COMPLETE','ApacheServiceBase','c9e35342-1a3a-4377-ac60-6263fd0c7088','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,846),(1400,'3654fe69-33f7-4c65-ae9b-65acc96f7c5a','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:22',NULL,'CREATE','COMPLETE','11','37cd87c8-66b9-434f-9132-4eb917f43e20','state changed','OS::TripleO::Services::GlanceApi',NULL,789),(1401,'bba93510-f957-457c-9abc-a79833b9a6ab','236a772a-67a2-4fd3-a893-1d7bb3049185','2026-06-09 08:02:22',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-14-75cab5guhuce','236a772a-67a2-4fd3-a893-1d7bb3049185','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1402,'163e0a17-fd89-49d9-872a-e566028bd200','bcc7a880-ac2e-4d2c-bce9-046c9687e9c1','2026-06-09 08:02:22',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-13-h3tvll3igd2n-ContainersCommon-v6iicojgdc2i','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1403,'27a4aba4-60a6-48e1-9853-ebb608d7469e','9c3d99c4-b83f-4946-80d0-7b81bdacd8c1','2026-06-09 08:02:22',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-13-h3tvll3igd2n-ContainersCommon-v6iicojgdc2i','9c3d99c4-b83f-4946-80d0-7b81bdacd8c1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1404,'80173420-fb3b-4782-98b4-1e6497f9b338','9c3d99c4-b83f-4946-80d0-7b81bdacd8c1','2026-06-09 08:02:22',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-13-h3tvll3igd2n-ContainersCommon-v6iicojgdc2i','9c3d99c4-b83f-4946-80d0-7b81bdacd8c1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1405,'18644139-0415-4a8d-8e1d-04f16bd5b8d0','a1fc3fc0-3964-4d07-b2ff-68281cac9614','2026-06-09 08:02:22',NULL,'CREATE','COMPLETE','MySQLClient','0e5682ec-9c34-4794-8760-1fea11990c0f','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1406,'af1ac6e5-e2e5-49b0-8fb2-6eee565413fb','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:22',NULL,'CREATE','COMPLETE','14','236a772a-67a2-4fd3-a893-1d7bb3049185','state changed','OS::TripleO::Services::HeatApi',NULL,799),(1407,'aacfd3e6-5e76-4e15-a2ed-052aac154a97','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:22',NULL,'CREATE','IN_PROGRESS','15','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-15-kcpzoskxh4sx','state changed','OS::TripleO::Services::HeatApiCloudwatch',NULL,874),(1408,'ec9470de-50b3-4646-b9b6-99604ebb3138','9942946b-5e82-4340-afe1-2cefaba7335f','2026-06-09 08:02:22',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-13-h3tvll3igd2n-HAProxyBase-csdh6ypcihqp-RoleParametersValue-zutisscksavt','state changed','OS::Heat::Value',NULL,876),(1409,'03d92d59-b232-4f62-bd7f-369697c52b76','9942946b-5e82-4340-afe1-2cefaba7335f','2026-06-09 08:02:22',NULL,'CREATE','COMPLETE','HAProxyInternalTLS','11df9367-768c-4e86-b92f-6281a32db7b8','state changed','OS::TripleO::Services::HAProxyInternalTLS',NULL,850),(1410,'8df227ff-a37c-46b1-9618-c6d4fb399c24','9942946b-5e82-4340-afe1-2cefaba7335f','2026-06-09 08:02:22',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-13-h3tvll3igd2n-HAProxyBase-csdh6ypcihqp-RoleParametersValue-zutisscksavt','state changed','OS::Heat::Value',NULL,876),(1411,'17330272-4735-451d-b2c7-aa935cea9cb4','0a49c948-f4f6-44d3-b8fa-fbfb0d2edca6','2026-06-09 08:02:22',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-15-kcpzoskxh4sx','0a49c948-f4f6-44d3-b8fa-fbfb0d2edca6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1412,'fae53447-7a1b-4ecc-b271-6fc5630d7622','0a49c948-f4f6-44d3-b8fa-fbfb0d2edca6','2026-06-09 08:02:22',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-15-kcpzoskxh4sx','0a49c948-f4f6-44d3-b8fa-fbfb0d2edca6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1413,'be71bba6-e3fd-461b-8416-4e33e173d72b','ba74f6ef-2e1b-4ad4-8015-c2d75de2f1da','2026-06-09 08:02:23',NULL,'CREATE','IN_PROGRESS','CinderNVMeOF','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-12-bu6nemuhr6lm-GlanceApi-exkw2hlpmqsa-CinderNVMeOF-accgpzvyihlv','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1414,'faeb3741-680b-44ad-9378-174673c20bce','ba74f6ef-2e1b-4ad4-8015-c2d75de2f1da','2026-06-09 08:02:23',NULL,'CREATE','COMPLETE','MySQLClient','9ac69c0f-bae2-4e67-8a34-3b4b102affba','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1415,'dce94dc4-ba21-4a53-97ce-2ab574cd41f2','01946424-88ae-4e0f-93b3-f6085f2bf438','2026-06-09 08:02:23',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-12-bu6nemuhr6lm-GlanceApi-exkw2hlpmqsa-CinderNVMeOF-accgpzvyihlv','01946424-88ae-4e0f-93b3-f6085f2bf438','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1416,'7cd62603-5ea3-44d1-a7fe-fa570bd4324b','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:23',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','overcloud-ComputeServiceChain-xrxe3cz66s6g-HostPrepTasks-hznq35lxxrqc','state changed','OS::Heat::Value',NULL,883),(1417,'06319a8d-db10-4aee-9e21-c9217d1bc2b9','01946424-88ae-4e0f-93b3-f6085f2bf438','2026-06-09 08:02:23',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-12-bu6nemuhr6lm-GlanceApi-exkw2hlpmqsa-CinderNVMeOF-accgpzvyihlv','01946424-88ae-4e0f-93b3-f6085f2bf438','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1418,'9106be0f-a74d-4479-8a3b-b93f085c3093','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:23',NULL,'CREATE','COMPLETE','HostPrepTasks','overcloud-ComputeServiceChain-xrxe3cz66s6g-HostPrepTasks-hznq35lxxrqc','state changed','OS::Heat::Value',NULL,883),(1419,'6419236a-aab6-4502-8c95-e0d406d69233','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:23',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','overcloud-ComputeServiceChain-xrxe3cz66s6g-MonitoringSubscriptionsConfig-so3vdbbzfluw','state changed','OS::Heat::Value',NULL,885),(1420,'07db1c9a-508b-41b8-81aa-1d5d26d51c27','bcc7a880-ac2e-4d2c-bce9-046c9687e9c1','2026-06-09 08:02:23',NULL,'CREATE','IN_PROGRESS','HAProxyInternalTLS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-13-h3tvll3igd2n-HAProxyInternalTLS-esohvlr5nksl','state changed','OS::TripleO::Services::HAProxyInternalTLS',NULL,886),(1421,'8432eeeb-0e10-432b-b043-cc36892c5e05','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:23',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','overcloud-ComputeServiceChain-xrxe3cz66s6g-DockerPuppetTasks-uqxedwerfbpo','state changed','OS::Heat::Value',NULL,888),(1422,'f21abb62-298a-4823-8bd7-6aafabd501ec','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:23',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','overcloud-ComputeServiceChain-xrxe3cz66s6g-MonitoringSubscriptionsConfig-so3vdbbzfluw','state changed','OS::Heat::Value',NULL,885),(1423,'6a9b7c34-2ce9-46ac-8c98-af0cd9a33cf4','bcc7a880-ac2e-4d2c-bce9-046c9687e9c1','2026-06-09 08:02:23',NULL,'CREATE','COMPLETE','ContainersCommon','9c3d99c4-b83f-4946-80d0-7b81bdacd8c1','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1424,'2ae0bb61-1a0d-4f72-b08c-11dfa6e1ce39','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:23',NULL,'CREATE','IN_PROGRESS','18','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-18-txn3edc7vifw','state changed','OS::TripleO::Services::Horizon',NULL,889),(1425,'bdf0ade4-5ec1-4081-a33f-2db613e370e0','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:23',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','overcloud-ComputeServiceChain-xrxe3cz66s6g-ExternalPostDeployTasks-qs4ba72lopc4','state changed','OS::Heat::Value',NULL,890),(1426,'26a69e89-a3ed-4736-a30e-306648de11af','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:23',NULL,'CREATE','COMPLETE','DockerPuppetTasks','overcloud-ComputeServiceChain-xrxe3cz66s6g-DockerPuppetTasks-uqxedwerfbpo','state changed','OS::Heat::Value',NULL,888),(1427,'1da61077-24a6-4637-a54c-dd9370ad5aeb','99d03a46-d641-431c-a6b8-907c4495cfbf','2026-06-09 08:02:23',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-13-h3tvll3igd2n-HAProxyInternalTLS-esohvlr5nksl','99d03a46-d641-431c-a6b8-907c4495cfbf','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1428,'1ee7597f-1c68-45e8-894e-933f6863515a','463d7078-8a0c-4597-9655-7b9041ac02b2','2026-06-09 08:02:23',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-18-txn3edc7vifw','463d7078-8a0c-4597-9655-7b9041ac02b2','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1429,'3dc74b8f-eeff-405e-a9ca-076438363d88','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:23',NULL,'CREATE','IN_PROGRESS','UpdateTasks','overcloud-ComputeServiceChain-xrxe3cz66s6g-UpdateTasks-3jo54lxihq3v','state changed','OS::Heat::Value',NULL,891),(1430,'9d4c50ed-a251-472d-b4e5-9cd24cf20c0c','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:23',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','overcloud-ComputeServiceChain-xrxe3cz66s6g-ExternalPostDeployTasks-qs4ba72lopc4','state changed','OS::Heat::Value',NULL,890),(1431,'585360fe-b654-41b3-8bf8-137067a8b27f','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:23',NULL,'CREATE','IN_PROGRESS','FirewallRules','overcloud-ComputeServiceChain-xrxe3cz66s6g-FirewallRules-wqdm4fhr5p6v','state changed','OS::Heat::Value',NULL,892),(1432,'d5a473b0-086c-4595-967b-660ec5264b90','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:23',NULL,'CREATE','COMPLETE','UpdateTasks','overcloud-ComputeServiceChain-xrxe3cz66s6g-UpdateTasks-3jo54lxihq3v','state changed','OS::Heat::Value',NULL,891),(1433,'bb0bedd4-fca7-4cf0-bc52-6207e7820468','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:23',NULL,'CREATE','COMPLETE','FirewallRules','overcloud-ComputeServiceChain-xrxe3cz66s6g-FirewallRules-wqdm4fhr5p6v','state changed','OS::Heat::Value',NULL,892),(1434,'b3af4e2b-408a-4163-8c6d-51ab37f25127','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:23',NULL,'CREATE','IN_PROGRESS','ScaleTasks','overcloud-ComputeServiceChain-xrxe3cz66s6g-ScaleTasks-gh3vnthhec3u','state changed','OS::Heat::Value',NULL,893),(1435,'3e5efc94-c68d-4c69-b6a9-2909cba63b47','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:23',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','overcloud-ComputeServiceChain-xrxe3cz66s6g-DeployStepsTasks-vjghhnncman5','state changed','OS::Heat::Value',NULL,895),(1436,'da5f8975-dbd8-4987-ae7f-7a1bdee05ad7','463d7078-8a0c-4597-9655-7b9041ac02b2','2026-06-09 08:02:23',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-18-txn3edc7vifw-RoleParametersValue-7cy5umkhcqo4','state changed','OS::Heat::Value',NULL,896),(1437,'b35362c3-6909-4844-9330-1cc8ab56d8c0','9942946b-5e82-4340-afe1-2cefaba7335f','2026-06-09 08:02:23',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-13-h3tvll3igd2n-HAProxyBase-csdh6ypcihqp-ContainersCommon-yxebfgv77hcj','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1438,'f723ad24-637c-4aba-a195-76b3496239ea','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:23',NULL,'CREATE','COMPLETE','ScaleTasks','overcloud-ComputeServiceChain-xrxe3cz66s6g-ScaleTasks-gh3vnthhec3u','state changed','OS::Heat::Value',NULL,893),(1439,'70660d5f-2045-40b9-8e3c-29a7365dba05','463d7078-8a0c-4597-9655-7b9041ac02b2','2026-06-09 08:02:23',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-18-txn3edc7vifw-RoleParametersValue-7cy5umkhcqo4','state changed','OS::Heat::Value',NULL,896),(1440,'161b7bbe-6b75-4eb3-bccd-801c3af959f9','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:23',NULL,'CREATE','COMPLETE','DeployStepsTasks','overcloud-ComputeServiceChain-xrxe3cz66s6g-DeployStepsTasks-vjghhnncman5','state changed','OS::Heat::Value',NULL,895),(1441,'2f932d3b-34dd-4ff7-b9c5-894441b6ed75','e5632eb6-3505-4c53-bd17-0c685fe77917','2026-06-09 08:02:23',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-13-h3tvll3igd2n-HAProxyBase-csdh6ypcihqp-ContainersCommon-yxebfgv77hcj','e5632eb6-3505-4c53-bd17-0c685fe77917','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1442,'fac8fb1b-5020-4162-a2ca-d7c755231882','99d03a46-d641-431c-a6b8-907c4495cfbf','2026-06-09 08:02:23',NULL,'CREATE','IN_PROGRESS','HAProxyNetworks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-13-h3tvll3igd2n-HAProxyInternalTLS-esohvlr5nksl-HAProxyNetworks-n5kbtw2tdswk','state changed','OS::Heat::Value',NULL,894),(1443,'ef0d3a33-c9f9-4856-9738-caf92946b27d','e5632eb6-3505-4c53-bd17-0c685fe77917','2026-06-09 08:02:23',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-13-h3tvll3igd2n-HAProxyBase-csdh6ypcihqp-ContainersCommon-yxebfgv77hcj','e5632eb6-3505-4c53-bd17-0c685fe77917','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1444,'80ebb9ed-fff2-467e-afab-5bf7097fcb50','ba74f6ef-2e1b-4ad4-8015-c2d75de2f1da','2026-06-09 08:02:24',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-12-bu6nemuhr6lm-GlanceApi-exkw2hlpmqsa-RoleParametersValue-mqrsdrulzk7z','state changed','OS::Heat::Value',NULL,898),(1445,'e0c98173-d233-407e-9aad-ca1ca2224958','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:24',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','overcloud-ComputeServiceChain-xrxe3cz66s6g-FirewallFrontendRules-sibvgvtun7kd','state changed','OS::Heat::Value',NULL,897),(1446,'31c0e6b5-42f4-48d7-95ad-62ebb1d6e8ed','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:24',NULL,'CREATE','COMPLETE','15','0a49c948-f4f6-44d3-b8fa-fbfb0d2edca6','state changed','OS::TripleO::Services::HeatApiCloudwatch',NULL,874),(1447,'437daf3c-a0b5-441f-bb59-d98d81837ad9','ba74f6ef-2e1b-4ad4-8015-c2d75de2f1da','2026-06-09 08:02:24',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-12-bu6nemuhr6lm-GlanceApi-exkw2hlpmqsa-RoleParametersValue-mqrsdrulzk7z','state changed','OS::Heat::Value',NULL,898),(1448,'20b76430-0101-4981-9803-aa0bce3d53c9','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:24',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','overcloud-ComputeServiceChain-xrxe3cz66s6g-ExternalUpdateTasks-6ypai55gy3fs','state changed','OS::Heat::Value',NULL,899),(1449,'a6d3f197-847a-4d80-9a8c-0ed8e62c41b9','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:24',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','overcloud-ComputeServiceChain-xrxe3cz66s6g-ExternalUpdateTasks-6ypai55gy3fs','state changed','OS::Heat::Value',NULL,899),(1450,'5fa881de-45b4-4281-bba1-a715e0b49760','ba74f6ef-2e1b-4ad4-8015-c2d75de2f1da','2026-06-09 08:02:24',NULL,'CREATE','COMPLETE','CinderNVMeOF','01946424-88ae-4e0f-93b3-f6085f2bf438','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml',NULL,NULL),(1451,'02038713-3713-4158-b1e9-a714c8acaca2','99d03a46-d641-431c-a6b8-907c4495cfbf','2026-06-09 08:02:24',NULL,'CREATE','COMPLETE','HAProxyNetworks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-13-h3tvll3igd2n-HAProxyInternalTLS-esohvlr5nksl-HAProxyNetworks-n5kbtw2tdswk','state changed','OS::Heat::Value',NULL,894),(1452,'3f0e0fac-9d00-4172-b523-14cfef6e4b65','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:24',NULL,'CREATE','COMPLETE','FirewallFrontendRules','overcloud-ComputeServiceChain-xrxe3cz66s6g-FirewallFrontendRules-sibvgvtun7kd','state changed','OS::Heat::Value',NULL,897),(1453,'3b2ca56a-21ce-42f9-a66f-615666bf4035','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:24',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceServerMetadataHook-7yb7lfrmf4if','state changed','OS::TripleO::ComputeServiceServerMetadataHook',NULL,902),(1454,'368e1b75-62e9-4899-9813-ada592d4ad41','bcc7a880-ac2e-4d2c-bce9-046c9687e9c1','2026-06-09 08:02:24',NULL,'CREATE','IN_PROGRESS','HAProxyPublicTLS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-13-h3tvll3igd2n-HAProxyPublicTLS-2t5ox2c7m2mp','state changed','OS::TripleO::Services::HAProxyPublicTLS',NULL,900),(1455,'ee1510a5-9974-4f1c-aa98-b7fc3d057830','99d03a46-d641-431c-a6b8-907c4495cfbf','2026-06-09 08:02:24',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-13-h3tvll3igd2n-HAProxyInternalTLS-esohvlr5nksl','99d03a46-d641-431c-a6b8-907c4495cfbf','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1456,'05c9bf08-473b-4403-bb61-71d72f28658e','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:24',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','overcloud-ComputeServiceChain-xrxe3cz66s6g-DockerConfigScripts-ppvtv3cw4l2k','state changed','OS::Heat::Value',NULL,903),(1457,'020fa02e-9440-434f-a2f3-03b64b31c2b6','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:24',NULL,'CREATE','COMPLETE','DockerConfigScripts','overcloud-ComputeServiceChain-xrxe3cz66s6g-DockerConfigScripts-ppvtv3cw4l2k','state changed','OS::Heat::Value',NULL,903),(1458,'9e7698c8-b037-4c65-8e42-e3e81da9942e','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:24',NULL,'CREATE','IN_PROGRESS','ServiceNames','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceNames-o4da3r7ai5kq','state changed','OS::Heat::Value',NULL,904),(1459,'b95c079d-baf0-43d4-9ff1-f91c58edb34c','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:24',NULL,'CREATE','COMPLETE','ServiceNames','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceNames-o4da3r7ai5kq','state changed','OS::Heat::Value',NULL,904),(1460,'8d7e696a-cc34-498d-a4de-28969775a634','db0f15dd-3098-4223-ba64-436fe1401c16','2026-06-09 08:02:24',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-13-h3tvll3igd2n-HAProxyPublicTLS-2t5ox2c7m2mp','db0f15dd-3098-4223-ba64-436fe1401c16','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1461,'70bfc425-6f0d-4dfb-b1ef-43b1d89c1774','db0f15dd-3098-4223-ba64-436fe1401c16','2026-06-09 08:02:24',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-13-h3tvll3igd2n-HAProxyPublicTLS-2t5ox2c7m2mp','db0f15dd-3098-4223-ba64-436fe1401c16','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1462,'9fa50843-b003-4571-b708-a078b64cc905','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:24',NULL,'CREATE','IN_PROGRESS','19','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-19-jwfxy3b5nlzb','state changed','OS::TripleO::Services::IpaClient',NULL,905),(1463,'115ae7df-ae20-4e3b-a145-131284a8ea99','4e3d68fc-831b-4cd4-81e8-066d9b965033','2026-06-09 08:02:24',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceServerMetadataHook-7yb7lfrmf4if','4e3d68fc-831b-4cd4-81e8-066d9b965033','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1464,'cfb35791-2e2a-4a38-b9bf-e76653581805','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:24',NULL,'CREATE','IN_PROGRESS','KollaConfig','overcloud-ComputeServiceChain-xrxe3cz66s6g-KollaConfig-mhh6lmwcgle4','state changed','OS::Heat::Value',NULL,906),(1465,'892595f2-0307-406e-a743-9a0ae58d4b66','bcc7a880-ac2e-4d2c-bce9-046c9687e9c1','2026-06-09 08:02:24',NULL,'CREATE','COMPLETE','HAProxyPublicTLS','db0f15dd-3098-4223-ba64-436fe1401c16','state changed','OS::TripleO::Services::HAProxyPublicTLS',NULL,900),(1466,'882da899-0915-42da-80f5-336c0f4e446a','d48b7137-42ea-4966-9086-ea56b9caf057','2026-06-09 08:02:24',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-19-jwfxy3b5nlzb','d48b7137-42ea-4966-9086-ea56b9caf057','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1467,'dbb6e79d-110f-4150-901e-a3f89b6b664d','bcc7a880-ac2e-4d2c-bce9-046c9687e9c1','2026-06-09 08:02:24',NULL,'CREATE','COMPLETE','HAProxyInternalTLS','99d03a46-d641-431c-a6b8-907c4495cfbf','state changed','OS::TripleO::Services::HAProxyInternalTLS',NULL,886),(1468,'f30c1848-65d1-4547-bbf1-4b46be2f2e9c','d48b7137-42ea-4966-9086-ea56b9caf057','2026-06-09 08:02:24',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-19-jwfxy3b5nlzb','d48b7137-42ea-4966-9086-ea56b9caf057','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1469,'8fa8252f-abeb-4e4c-a67a-1d92ec353600','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:24',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','overcloud-ComputeServiceChain-xrxe3cz66s6g-HostFirewallTasks-h5uvol4ffkno','state changed','OS::Heat::Value',NULL,907),(1470,'110ed1f8-70dd-4af5-b3ec-c2621c19d78d','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:24',NULL,'CREATE','COMPLETE','19','d48b7137-42ea-4966-9086-ea56b9caf057','state changed','OS::TripleO::Services::IpaClient',NULL,905),(1471,'be6ab9fe-a384-49dc-99a2-f7d071396c16','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:24',NULL,'CREATE','COMPLETE','KollaConfig','overcloud-ComputeServiceChain-xrxe3cz66s6g-KollaConfig-mhh6lmwcgle4','state changed','OS::Heat::Value',NULL,906),(1472,'a52f1bff-237d-4ff5-b755-8715e94ea67a','463d7078-8a0c-4597-9655-7b9041ac02b2','2026-06-09 08:02:24',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-18-txn3edc7vifw-ContainersCommon-m6d2auuj77kc','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1473,'b0aa02e7-6929-4591-a243-1000be767e1f','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:24',NULL,'CREATE','COMPLETE','HostFirewallTasks','overcloud-ComputeServiceChain-xrxe3cz66s6g-HostFirewallTasks-h5uvol4ffkno','state changed','OS::Heat::Value',NULL,907),(1474,'4cba964a-72a8-440e-9247-b7d6dcdfc36b','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:24',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','overcloud-ComputeServiceChain-xrxe3cz66s6g-UpgradeBatchTasks-avpjine3rnni','state changed','OS::Heat::Value',NULL,909),(1475,'a99cf72c-8777-4e94-8931-6f1969a70d52','9942946b-5e82-4340-afe1-2cefaba7335f','2026-06-09 08:02:24',NULL,'CREATE','IN_PROGRESS','HAProxyPublicTLS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-13-h3tvll3igd2n-HAProxyBase-csdh6ypcihqp-HAProxyPublicTLS-tzopw3lcz54a','state changed','OS::TripleO::Services::HAProxyPublicTLS',NULL,908),(1476,'293ab0d3-c87a-48b9-8af6-161155549622','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:24',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','overcloud-ComputeServiceChain-xrxe3cz66s6g-UpgradeBatchTasks-avpjine3rnni','state changed','OS::Heat::Value',NULL,909),(1477,'1f3ec373-adab-4b74-bc6e-d4276e4365f2','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:24',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','overcloud-ComputeServiceChain-xrxe3cz66s6g-PuppetStepConfig-lkmihjk6xnnn','state changed','OS::Heat::Value',NULL,910),(1478,'54456641-2560-426e-99de-376bb81286f2','2045e362-ac93-4c72-8c76-1841ad326743','2026-06-09 08:02:25',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-18-txn3edc7vifw-ContainersCommon-m6d2auuj77kc','2045e362-ac93-4c72-8c76-1841ad326743','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1479,'d12437dd-bc2b-400e-a7cd-d22ad8e26bd7','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:25',NULL,'CREATE','COMPLETE','PuppetStepConfig','overcloud-ComputeServiceChain-xrxe3cz66s6g-PuppetStepConfig-lkmihjk6xnnn','state changed','OS::Heat::Value',NULL,910),(1480,'93e24962-86a8-45f6-a47d-937a95be090a','2045e362-ac93-4c72-8c76-1841ad326743','2026-06-09 08:02:25',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-18-txn3edc7vifw-ContainersCommon-m6d2auuj77kc','2045e362-ac93-4c72-8c76-1841ad326743','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1481,'5d699a95-3669-4e9f-b910-e3fea2e43c21','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:25',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','overcloud-ComputeServiceChain-xrxe3cz66s6g-IpaRegistrationTasks-4rvr4i4lt3sv','state changed','OS::Heat::Value',NULL,912),(1482,'e0a9c347-aa8a-4797-b9c8-bccbaa06b359','dff068bc-c801-4994-bc2f-baf8ce3188f8','2026-06-09 08:02:25',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-13-h3tvll3igd2n-HAProxyBase-csdh6ypcihqp-HAProxyPublicTLS-tzopw3lcz54a','dff068bc-c801-4994-bc2f-baf8ce3188f8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1483,'c3f774e3-7c4c-46c1-9b0e-9ca634c63224','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:25',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','overcloud-ComputeServiceChain-xrxe3cz66s6g-IpaRegistrationTasks-4rvr4i4lt3sv','state changed','OS::Heat::Value',NULL,912),(1484,'022ff88d-0de5-40a2-883f-ff180277e546','4e3d68fc-831b-4cd4-81e8-066d9b965033','2026-06-09 08:02:25',NULL,'CREATE','IN_PROGRESS','IncomingMetadataSettings','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceServerMetadataHook-7yb7lfrmf4if-IncomingMetadataSettings-rvjzpkpkesdp','state changed','OS::Heat::Value',NULL,913),(1485,'14999fbc-7418-4911-a900-c810b38ab2e2','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:25',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','overcloud-ComputeServiceChain-xrxe3cz66s6g-ContainerPuppetTasks-f566uazqcp7f','state changed','OS::Heat::Value',NULL,914),(1486,'122bad19-6855-4efe-9565-76d1c52a9650','dff068bc-c801-4994-bc2f-baf8ce3188f8','2026-06-09 08:02:25',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-13-h3tvll3igd2n-HAProxyBase-csdh6ypcihqp-HAProxyPublicTLS-tzopw3lcz54a','dff068bc-c801-4994-bc2f-baf8ce3188f8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1487,'d7944740-4763-48e8-8796-d5ba7a2e6a56','9942946b-5e82-4340-afe1-2cefaba7335f','2026-06-09 08:02:25',NULL,'CREATE','COMPLETE','ContainersCommon','e5632eb6-3505-4c53-bd17-0c685fe77917','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1488,'300ce71b-88de-49b9-a3fb-fcf80507d8dd','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:25',NULL,'CREATE','IN_PROGRESS','23','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-23-icc4n5tw73vc','state changed','OS::TripleO::Services::ManilaApi',NULL,915),(1489,'f1bdef0c-4c05-4b46-a525-662216775a24','463d7078-8a0c-4597-9655-7b9041ac02b2','2026-06-09 08:02:25',NULL,'CREATE','COMPLETE','ContainersCommon','2045e362-ac93-4c72-8c76-1841ad326743','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1490,'d6e6f6fb-47a2-482e-912e-2312dca20d8e','ba74f6ef-2e1b-4ad4-8015-c2d75de2f1da','2026-06-09 08:02:25',NULL,'CREATE','IN_PROGRESS','TLSProxyBase','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-12-bu6nemuhr6lm-GlanceApi-exkw2hlpmqsa-TLSProxyBase-lukgmhzll7wv','state changed','OS::TripleO::Services::TLSProxyBase',NULL,916),(1491,'25ad8e56-deb0-4446-a374-572bd5dd8166','4e3d68fc-831b-4cd4-81e8-066d9b965033','2026-06-09 08:02:25',NULL,'CREATE','COMPLETE','IncomingMetadataSettings','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceServerMetadataHook-7yb7lfrmf4if-IncomingMetadataSettings-rvjzpkpkesdp','state changed','OS::Heat::Value',NULL,913),(1492,'8b72ed02-1346-4170-819d-c6b82ae3bdaf','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:25',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','overcloud-ComputeServiceChain-xrxe3cz66s6g-ContainerPuppetTasks-f566uazqcp7f','state changed','OS::Heat::Value',NULL,914),(1493,'444299ad-1f83-4092-b564-098ba3d25185','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:25',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceConfigSettings-bp2iavzea5ds','state changed','OS::Heat::Value',NULL,917),(1494,'5532f8ba-290d-4099-b605-cdf566c23712','463d7078-8a0c-4597-9655-7b9041ac02b2','2026-06-09 08:02:25',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-18-txn3edc7vifw','463d7078-8a0c-4597-9655-7b9041ac02b2','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1495,'bf358498-caff-47d7-a6ed-d8834b9cad7c','89d88cbb-b9a7-43e5-af91-b893091f6b39','2026-06-09 08:02:25',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-23-icc4n5tw73vc','89d88cbb-b9a7-43e5-af91-b893091f6b39','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1496,'afc2d21b-ec70-460f-8dc3-979a5e0e5d60','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:25',NULL,'CREATE','COMPLETE','ServiceConfigSettings','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceConfigSettings-bp2iavzea5ds','state changed','OS::Heat::Value',NULL,917),(1497,'4fdea314-600a-4cea-82dc-f484609ca276','bcc7a880-ac2e-4d2c-bce9-046c9687e9c1','2026-06-09 08:02:25',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-13-h3tvll3igd2n-RoleParametersValue-vhtfmdkeovwb','state changed','OS::Heat::Value',NULL,918),(1498,'abd53c78-a935-4d51-be26-537a31022197','bcc7a880-ac2e-4d2c-bce9-046c9687e9c1','2026-06-09 08:02:25',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-13-h3tvll3igd2n-RoleParametersValue-vhtfmdkeovwb','state changed','OS::Heat::Value',NULL,918),(1499,'0638628f-984c-4b24-a05b-017d0327cf2b','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:25',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','overcloud-ComputeServiceChain-xrxe3cz66s6g-ExternalUpgradeTasks-buj2sghyfosm','state changed','OS::Heat::Value',NULL,919),(1500,'fd64c4d8-b3dc-41e7-b351-e05b76d2b93c','4e3d68fc-831b-4cd4-81e8-066d9b965033','2026-06-09 08:02:25',NULL,'CREATE','IN_PROGRESS','IndividualServices','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceServerMetadataHook-7yb7lfrmf4if-IndividualServices-pjggexxqxbca','state changed','OS::Heat::Value',NULL,922),(1501,'bdabfcb6-8244-4ddf-b784-9a353fe5b16d','4e3d68fc-831b-4cd4-81e8-066d9b965033','2026-06-09 08:02:25',NULL,'CREATE','COMPLETE','IndividualServices','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceServerMetadataHook-7yb7lfrmf4if-IndividualServices-pjggexxqxbca','state changed','OS::Heat::Value',NULL,922),(1502,'973a5e4b-76ce-4eb5-832c-811de5a39839','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:25',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','overcloud-ComputeServiceChain-xrxe3cz66s6g-ExternalUpgradeTasks-buj2sghyfosm','state changed','OS::Heat::Value',NULL,919),(1503,'7e15fe69-f9d4-44e3-a28f-8ad6cf17f7cd','4e3d68fc-831b-4cd4-81e8-066d9b965033','2026-06-09 08:02:25',NULL,'CREATE','IN_PROGRESS','CompactServices','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceServerMetadataHook-7yb7lfrmf4if-CompactServices-jeaxchmvt6ua','state changed','OS::Heat::Value',NULL,921),(1504,'cc8d6ce2-9ae7-4927-af96-375ff3b9dd6d','f79d246f-cf84-45a6-8272-2dd23b911882','2026-06-09 08:02:25',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-12-bu6nemuhr6lm-GlanceApi-exkw2hlpmqsa-TLSProxyBase-lukgmhzll7wv','f79d246f-cf84-45a6-8272-2dd23b911882','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1505,'9db03e7e-5218-49d8-9413-a2ddad9cef41','89d88cbb-b9a7-43e5-af91-b893091f6b39','2026-06-09 08:02:25',NULL,'CREATE','IN_PROGRESS','ManilaBase','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-23-icc4n5tw73vc-ManilaBase-lgapxhcy2tbt','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-base.yaml',NULL,924),(1506,'92f20138-b2b2-4af0-9993-c41abc148c8b','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:25',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','overcloud-ComputeServiceChain-xrxe3cz66s6g-PostUpgradeTasks-g7ggiipvygz3','state changed','OS::Heat::Value',NULL,923),(1507,'fe3cb282-3c3e-43e2-9669-3f02fcd8ebe1','919e40c3-7196-45f7-9f9f-65cb6c7fa70d','2026-06-09 08:02:25',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-23-icc4n5tw73vc-ManilaBase-lgapxhcy2tbt','919e40c3-7196-45f7-9f9f-65cb6c7fa70d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1508,'ecb44828-d844-4c3e-af47-e6ddcdea407e','919e40c3-7196-45f7-9f9f-65cb6c7fa70d','2026-06-09 08:02:25',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-23-icc4n5tw73vc-ManilaBase-lgapxhcy2tbt','919e40c3-7196-45f7-9f9f-65cb6c7fa70d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1509,'df3ed6a9-470b-482b-9697-347125fa90fd','4e3d68fc-831b-4cd4-81e8-066d9b965033','2026-06-09 08:02:25',NULL,'CREATE','COMPLETE','CompactServices','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceServerMetadataHook-7yb7lfrmf4if-CompactServices-jeaxchmvt6ua','state changed','OS::Heat::Value',NULL,921),(1510,'96229e05-e215-4933-9bf0-305192adde57','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:25',NULL,'CREATE','COMPLETE','PostUpgradeTasks','overcloud-ComputeServiceChain-xrxe3cz66s6g-PostUpgradeTasks-g7ggiipvygz3','state changed','OS::Heat::Value',NULL,923),(1511,'b59a59e5-2927-428a-a9b1-105388900cd9','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:25',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','overcloud-ComputeServiceChain-xrxe3cz66s6g-PreUpgradeRollingTasks-cu3qnz2vficl','state changed','OS::Heat::Value',NULL,925),(1512,'5c0944cc-e33e-412e-a6e4-51dbc9a78b3c','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:25',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','overcloud-ComputeServiceChain-xrxe3cz66s6g-GlobalConfigSettings-gampten36t5u','state changed','OS::Heat::Value',NULL,926),(1513,'732cf384-5393-47c4-abbe-4f0880991a8f','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:25',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','overcloud-ComputeServiceChain-xrxe3cz66s6g-PreUpgradeRollingTasks-cu3qnz2vficl','state changed','OS::Heat::Value',NULL,925),(1514,'c8325b8a-ae97-459e-ab77-1c54aedc7496','4e3d68fc-831b-4cd4-81e8-066d9b965033','2026-06-09 08:02:25',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g-ServiceServerMetadataHook-7yb7lfrmf4if','4e3d68fc-831b-4cd4-81e8-066d9b965033','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1515,'53cf2a69-c192-49f5-ba36-0aab841de894','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:25',NULL,'CREATE','COMPLETE','18','463d7078-8a0c-4597-9655-7b9041ac02b2','state changed','OS::TripleO::Services::Horizon',NULL,889),(1516,'ea1b64c2-88dd-425f-85ed-124aadc39e10','9942946b-5e82-4340-afe1-2cefaba7335f','2026-06-09 08:02:25',NULL,'CREATE','IN_PROGRESS','HAProxyLogging','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-13-h3tvll3igd2n-HAProxyBase-csdh6ypcihqp-HAProxyLogging-i7wnppajzyap','state changed','OS::TripleO::Services::Logging::HAProxy',NULL,NULL),(1517,'40af6026-99df-4039-a26a-9eca5dcc9979','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:25',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','overcloud-ComputeServiceChain-xrxe3cz66s6g-ExternalDeployTasks-e7qvrrcg66ps','state changed','OS::Heat::Value',NULL,927),(1518,'f78f3cac-d064-4548-b1fe-2aa7b7e91fbf','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:25',NULL,'CREATE','COMPLETE','GlobalConfigSettings','overcloud-ComputeServiceChain-xrxe3cz66s6g-GlobalConfigSettings-gampten36t5u','state changed','OS::Heat::Value',NULL,926),(1519,'adbe5966-5f9a-4d6d-b042-62872b49d3d6','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:26',NULL,'CREATE','IN_PROGRESS','DockerConfig','overcloud-ComputeServiceChain-xrxe3cz66s6g-DockerConfig-r2plsuw55k75','state changed','OS::Heat::Value',NULL,928),(1520,'90fc1b43-28aa-4d86-80a4-e1efee2e270d','0bae58ae-8adf-4561-9872-c0c79d6c8961','2026-06-09 08:02:26',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-13-h3tvll3igd2n-HAProxyBase-csdh6ypcihqp-HAProxyLogging-i7wnppajzyap','0bae58ae-8adf-4561-9872-c0c79d6c8961','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1521,'e692d540-098c-4352-b89f-6f30508654ce','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:26',NULL,'CREATE','COMPLETE','DockerConfig','overcloud-ComputeServiceChain-xrxe3cz66s6g-DockerConfig-r2plsuw55k75','state changed','OS::Heat::Value',NULL,928),(1522,'42c23ca1-9d5f-4ff4-99f3-3a7fb17be746','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:26',NULL,'CREATE','COMPLETE','ExternalDeployTasks','overcloud-ComputeServiceChain-xrxe3cz66s6g-ExternalDeployTasks-e7qvrrcg66ps','state changed','OS::Heat::Value',NULL,927),(1523,'38d6c255-3fff-4d93-86a9-6404bf19f353','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:26',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','overcloud-ComputeServiceChain-xrxe3cz66s6g-PreDeployStepTasks-awmoesmx326d','state changed','OS::Heat::Value',NULL,931),(1524,'bbe38fd7-0c80-473a-a750-e876b80a4081','0bae58ae-8adf-4561-9872-c0c79d6c8961','2026-06-09 08:02:26',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-13-h3tvll3igd2n-HAProxyBase-csdh6ypcihqp-HAProxyLogging-i7wnppajzyap','0bae58ae-8adf-4561-9872-c0c79d6c8961','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1525,'52279702-e25a-4d35-a69f-9a2aaccc27bb','f79d246f-cf84-45a6-8272-2dd23b911882','2026-06-09 08:02:26',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-12-bu6nemuhr6lm-GlanceApi-exkw2hlpmqsa-TLSProxyBase-lukgmhzll7wv-ApacheNetworks-j6lhmqed6dph','state changed','OS::Heat::Value',NULL,930),(1526,'8747ea7d-1106-484c-af31-d273c2cd54d2','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:26',NULL,'CREATE','COMPLETE','PreDeployStepTasks','overcloud-ComputeServiceChain-xrxe3cz66s6g-PreDeployStepTasks-awmoesmx326d','state changed','OS::Heat::Value',NULL,931),(1527,'37518ef2-aae4-45bc-a046-41f54fb1a360','9942946b-5e82-4340-afe1-2cefaba7335f','2026-06-09 08:02:26',NULL,'CREATE','COMPLETE','HAProxyPublicTLS','dff068bc-c801-4994-bc2f-baf8ce3188f8','state changed','OS::TripleO::Services::HAProxyPublicTLS',NULL,908),(1528,'7e711e11-ab4a-471c-a78f-cdb363890601','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:26',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','overcloud-ComputeServiceChain-xrxe3cz66s6g-KeystoneResourcesConfigs-buem6xgh4cun','state changed','OS::Heat::Value',NULL,933),(1529,'4e9f17fd-51cd-4f0f-8937-c1ea63cf6119','9942946b-5e82-4340-afe1-2cefaba7335f','2026-06-09 08:02:26',NULL,'CREATE','COMPLETE','HAProxyLogging','0bae58ae-8adf-4561-9872-c0c79d6c8961','state changed','OS::TripleO::Services::Logging::HAProxy',NULL,NULL),(1530,'34467a39-99b4-4682-8a00-4f90495e2a4e','f79d246f-cf84-45a6-8272-2dd23b911882','2026-06-09 08:02:26',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-12-bu6nemuhr6lm-GlanceApi-exkw2hlpmqsa-TLSProxyBase-lukgmhzll7wv-ApacheNetworks-j6lhmqed6dph','state changed','OS::Heat::Value',NULL,930),(1531,'bce92375-caa5-4e38-96e3-44ac88ed9ceb','9942946b-5e82-4340-afe1-2cefaba7335f','2026-06-09 08:02:26',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-13-h3tvll3igd2n-HAProxyBase-csdh6ypcihqp','9942946b-5e82-4340-afe1-2cefaba7335f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1532,'311c85bb-d180-4f2f-a3cd-b4ce151988d0','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:26',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','overcloud-ComputeServiceChain-xrxe3cz66s6g-KeystoneResourcesConfigs-buem6xgh4cun','state changed','OS::Heat::Value',NULL,933),(1533,'30b738a0-a340-4964-9ee0-795200e0a4cf','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:26',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','overcloud-ComputeServiceChain-xrxe3cz66s6g-UpgradeTasks-oelo6o7yot6x','state changed','OS::Heat::Value',NULL,935),(1534,'91e5f779-a876-4373-86dd-8765e999d2f0','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:26',NULL,'CREATE','IN_PROGRESS','22','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-22-cvw44tnyzpz7','state changed','OS::TripleO::Services::Keystone',NULL,936),(1535,'a3307c0d-03fb-40d9-bc12-571f0b0bc2a5','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:26',NULL,'CREATE','COMPLETE','UpgradeTasks','overcloud-ComputeServiceChain-xrxe3cz66s6g-UpgradeTasks-oelo6o7yot6x','state changed','OS::Heat::Value',NULL,935),(1536,'2fb35f8a-71a7-43a7-8489-250967c4133f','f79d246f-cf84-45a6-8272-2dd23b911882','2026-06-09 08:02:26',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-12-bu6nemuhr6lm-GlanceApi-exkw2hlpmqsa-TLSProxyBase-lukgmhzll7wv','f79d246f-cf84-45a6-8272-2dd23b911882','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1537,'845ed000-5d9a-4d5d-857b-1f10aa89d609','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:26',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','overcloud-ComputeServiceChain-xrxe3cz66s6g-PostUpdateTasks-tfrsy4khdbcy','state changed','OS::Heat::Value',NULL,937),(1538,'7b0ef692-c680-4ed3-a8c2-e9701bd44be5','2b57ffef-26a4-4102-a269-d60a863b3762','2026-06-09 08:02:26',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-22-cvw44tnyzpz7','2b57ffef-26a4-4102-a269-d60a863b3762','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1539,'653184df-ad04-4a2a-99de-a71e97aedd2d','89d88cbb-b9a7-43e5-af91-b893091f6b39','2026-06-09 08:02:26',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-23-icc4n5tw73vc-RoleParametersValue-7aelu5wygzh4','state changed','OS::Heat::Value',NULL,938),(1540,'7a256ca0-1456-4578-846a-06812c6bc097','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:26',NULL,'CREATE','IN_PROGRESS','PuppetConfig','overcloud-ComputeServiceChain-xrxe3cz66s6g-PuppetConfig-zpfdlvebfbnz','state changed','OS::Heat::Value',NULL,939),(1541,'075b6196-6002-4777-b052-796b200a6817','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:26',NULL,'CREATE','COMPLETE','PostUpdateTasks','overcloud-ComputeServiceChain-xrxe3cz66s6g-PostUpdateTasks-tfrsy4khdbcy','state changed','OS::Heat::Value',NULL,937),(1542,'0a6844a5-802d-4d60-9ba0-f3e6f8d37e69','89d88cbb-b9a7-43e5-af91-b893091f6b39','2026-06-09 08:02:26',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-23-icc4n5tw73vc-RoleParametersValue-7aelu5wygzh4','state changed','OS::Heat::Value',NULL,938),(1543,'d2054f52-7771-4495-b341-8a015b059e6c','89d88cbb-b9a7-43e5-af91-b893091f6b39','2026-06-09 08:02:26',NULL,'CREATE','COMPLETE','ManilaBase','919e40c3-7196-45f7-9f9f-65cb6c7fa70d','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-base.yaml',NULL,924),(1544,'77c62c45-b63f-4b38-b1d8-7d2374553eb7','ba74f6ef-2e1b-4ad4-8015-c2d75de2f1da','2026-06-09 08:02:26',NULL,'CREATE','COMPLETE','TLSProxyBase','f79d246f-cf84-45a6-8272-2dd23b911882','state changed','OS::TripleO::Services::TLSProxyBase',NULL,916),(1545,'3dffe1cd-f376-49ea-af7a-b6ff9e113e28','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:26',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','4e3d68fc-831b-4cd4-81e8-066d9b965033','state changed','OS::TripleO::ComputeServiceServerMetadataHook',NULL,902),(1546,'ac959d05-250a-4ed4-af92-1b96f3c9caca','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:26',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','overcloud-ComputeServiceChain-xrxe3cz66s6g-AnsibleGroupVars-rumm7b7mlw3j','state changed','OS::Heat::Value',NULL,941),(1547,'62f710aa-7458-494c-8b0b-331dd2744999','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:26',NULL,'CREATE','COMPLETE','PuppetConfig','overcloud-ComputeServiceChain-xrxe3cz66s6g-PuppetConfig-zpfdlvebfbnz','state changed','OS::Heat::Value',NULL,939),(1548,'66a149eb-2641-40cb-ad2c-66fb1ca1ecaf','ba74f6ef-2e1b-4ad4-8015-c2d75de2f1da','2026-06-09 08:02:27',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-12-bu6nemuhr6lm-GlanceApi-exkw2hlpmqsa','ba74f6ef-2e1b-4ad4-8015-c2d75de2f1da','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1549,'efc0aa10-c9c6-4be9-85e8-8126ca3d66ef','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:27',NULL,'CREATE','COMPLETE','AnsibleGroupVars','overcloud-ComputeServiceChain-xrxe3cz66s6g-AnsibleGroupVars-rumm7b7mlw3j','state changed','OS::Heat::Value',NULL,941),(1550,'144f3644-a3c9-4091-b424-0aa1b61c51cb','5de0861a-4a69-4d7f-8b96-db5a25b8c838','2026-06-09 08:02:27',NULL,'CREATE','COMPLETE','overcloud-ComputeServiceChain-xrxe3cz66s6g','5de0861a-4a69-4d7f-8b96-db5a25b8c838','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1551,'25ec8436-94cd-401f-8adc-c36c6b0051c1','2b57ffef-26a4-4102-a269-d60a863b3762','2026-06-09 08:02:27',NULL,'CREATE','IN_PROGRESS','ApacheServiceBase','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-22-cvw44tnyzpz7-ApacheServiceBase-ltk3ns2gyk7s','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,942),(1552,'fe01b9e5-2c8b-4cb0-9454-4069d893fb7a','214bb8f3-2170-4be0-9b62-897ff3b340a6','2026-06-09 08:02:27',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-22-cvw44tnyzpz7-ApacheServiceBase-ltk3ns2gyk7s','214bb8f3-2170-4be0-9b62-897ff3b340a6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1553,'52a2a6bf-35cf-4d95-90e7-6204bb199562','214bb8f3-2170-4be0-9b62-897ff3b340a6','2026-06-09 08:02:27',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-22-cvw44tnyzpz7-ApacheServiceBase-ltk3ns2gyk7s-ApacheNetworks-6xvunextmcam','state changed','OS::Heat::Value',NULL,943),(1554,'b2d17aa4-6fe5-46e5-a353-da3d8c2162df','214bb8f3-2170-4be0-9b62-897ff3b340a6','2026-06-09 08:02:27',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-22-cvw44tnyzpz7-ApacheServiceBase-ltk3ns2gyk7s-ApacheNetworks-6xvunextmcam','state changed','OS::Heat::Value',NULL,943),(1555,'8ddf6875-139c-47f4-9c3e-e04ecf26b0c9','214bb8f3-2170-4be0-9b62-897ff3b340a6','2026-06-09 08:02:27',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-22-cvw44tnyzpz7-ApacheServiceBase-ltk3ns2gyk7s','214bb8f3-2170-4be0-9b62-897ff3b340a6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1556,'d7821eda-97f6-401c-ac47-8c67604be361','89d88cbb-b9a7-43e5-af91-b893091f6b39','2026-06-09 08:02:27',NULL,'CREATE','IN_PROGRESS','ApacheServiceBase','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-23-icc4n5tw73vc-ApacheServiceBase-fnvzxtas4epw','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,944),(1557,'06e850e8-54fb-4905-a7ad-f7a09974702a','bcc7a880-ac2e-4d2c-bce9-046c9687e9c1','2026-06-09 08:02:27',NULL,'CREATE','COMPLETE','HAProxyBase','9942946b-5e82-4340-afe1-2cefaba7335f','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-container-puppet.yaml',NULL,849),(1558,'b6245b95-1ee6-4851-b1c7-b499b1b67fc1','bcc7a880-ac2e-4d2c-bce9-046c9687e9c1','2026-06-09 08:02:27',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-13-h3tvll3igd2n','bcc7a880-ac2e-4d2c-bce9-046c9687e9c1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1559,'efb8ff7b-b4d7-477a-970d-16b42f7989c4','3b8116dd-796f-41d2-8682-30c173f07c07','2026-06-09 08:02:27',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-23-icc4n5tw73vc-ApacheServiceBase-fnvzxtas4epw','3b8116dd-796f-41d2-8682-30c173f07c07','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1560,'e3e7fe43-0a8b-41d3-aeb8-5673f6acb792','3b8116dd-796f-41d2-8682-30c173f07c07','2026-06-09 08:02:27',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-23-icc4n5tw73vc-ApacheServiceBase-fnvzxtas4epw-ApacheNetworks-wld4d4orisne','state changed','OS::Heat::Value',NULL,945),(1561,'ad707ed6-c7ff-4ecb-9f4e-a450752b77b0','3b8116dd-796f-41d2-8682-30c173f07c07','2026-06-09 08:02:27',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-23-icc4n5tw73vc-ApacheServiceBase-fnvzxtas4epw-ApacheNetworks-wld4d4orisne','state changed','OS::Heat::Value',NULL,945),(1562,'87511ada-86de-4336-bb81-71ccb05a6cff','3b8116dd-796f-41d2-8682-30c173f07c07','2026-06-09 08:02:27',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-23-icc4n5tw73vc-ApacheServiceBase-fnvzxtas4epw','3b8116dd-796f-41d2-8682-30c173f07c07','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1563,'450a7632-e6fb-4731-a99a-c4efd2e24c78','a1fc3fc0-3964-4d07-b2ff-68281cac9614','2026-06-09 08:02:27',NULL,'CREATE','COMPLETE','GlanceApi','ba74f6ef-2e1b-4ad4-8015-c2d75de2f1da','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml',NULL,839),(1564,'46c0f5f8-6384-4977-a5fe-ec00736f0639','a1fc3fc0-3964-4d07-b2ff-68281cac9614','2026-06-09 08:02:27',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-12-bu6nemuhr6lm','a1fc3fc0-3964-4d07-b2ff-68281cac9614','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1565,'27e361d9-7288-46c6-9ea0-0cb4f6d5fbce','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:02:28',NULL,'CREATE','COMPLETE','ComputeServiceChain','5de0861a-4a69-4d7f-8b96-db5a25b8c838','state changed','OS::TripleO::ComputeServices',NULL,83),(1566,'03ab6aa1-f735-424e-b940-c273b4e6f1dc','2b57ffef-26a4-4102-a269-d60a863b3762','2026-06-09 08:02:28',NULL,'CREATE','IN_PROGRESS','KeystoneLogging','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-22-cvw44tnyzpz7-KeystoneLogging-m6bem3rw2zhv','state changed','OS::TripleO::Services::Logging::Keystone',NULL,NULL),(1567,'b3b4eb3a-551c-4444-b2cc-703f82d64917','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:28',NULL,'CREATE','COMPLETE','13','bcc7a880-ac2e-4d2c-bce9-046c9687e9c1','state changed','OS::TripleO::Services::HAproxy',NULL,845),(1568,'5af71d14-05da-4829-a1c4-1d27fa7e3c67','e0802853-7de3-495c-a34f-aa54f67913a2','2026-06-09 08:02:28',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-22-cvw44tnyzpz7-KeystoneLogging-m6bem3rw2zhv','e0802853-7de3-495c-a34f-aa54f67913a2','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1569,'513189ce-84f6-4b4b-b06c-fe24ed98c68d','2b57ffef-26a4-4102-a269-d60a863b3762','2026-06-09 08:02:28',NULL,'CREATE','COMPLETE','ApacheServiceBase','214bb8f3-2170-4be0-9b62-897ff3b340a6','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,942),(1570,'ff474a6f-67ce-4012-bee5-3dbf8c21875f','e0802853-7de3-495c-a34f-aa54f67913a2','2026-06-09 08:02:28',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-22-cvw44tnyzpz7-KeystoneLogging-m6bem3rw2zhv-RoleParametersValue-pvjoxlaao6oe','state changed','OS::Heat::Value',NULL,957),(1571,'4d0aafe7-5801-4262-851b-e21aacad7482','e0802853-7de3-495c-a34f-aa54f67913a2','2026-06-09 08:02:28',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-22-cvw44tnyzpz7-KeystoneLogging-m6bem3rw2zhv-RoleParametersValue-pvjoxlaao6oe','state changed','OS::Heat::Value',NULL,957),(1572,'8fa527d4-c131-45a8-9b68-06c361327882','e0802853-7de3-495c-a34f-aa54f67913a2','2026-06-09 08:02:28',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-22-cvw44tnyzpz7-KeystoneLogging-m6bem3rw2zhv','e0802853-7de3-495c-a34f-aa54f67913a2','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1573,'284cac32-199b-4500-a031-7f94c95e160e','89d88cbb-b9a7-43e5-af91-b893091f6b39','2026-06-09 08:02:28',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-23-icc4n5tw73vc-ContainersCommon-tj46jvkur5go','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1574,'c2217364-ee30-41ca-9608-7d580cc8e21b','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:28',NULL,'CREATE','COMPLETE','12','a1fc3fc0-3964-4d07-b2ff-68281cac9614','state changed','OS::TripleO::Services::GlanceApiInternal',NULL,832),(1575,'cb563e32-04a4-4d96-ade6-9cca63360ebf','f4990aca-2039-4d69-a729-53edfb89d36f','2026-06-09 08:02:28',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-23-icc4n5tw73vc-ContainersCommon-tj46jvkur5go','f4990aca-2039-4d69-a729-53edfb89d36f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1576,'c0671eeb-25b2-47e3-97fe-029978bec861','f4990aca-2039-4d69-a729-53edfb89d36f','2026-06-09 08:02:28',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-23-icc4n5tw73vc-ContainersCommon-tj46jvkur5go','f4990aca-2039-4d69-a729-53edfb89d36f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1577,'37524a08-0026-444b-8139-7e57d61f6261','89d88cbb-b9a7-43e5-af91-b893091f6b39','2026-06-09 08:02:28',NULL,'CREATE','COMPLETE','ApacheServiceBase','3b8116dd-796f-41d2-8682-30c173f07c07','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,944),(1578,'fca3fd3b-7730-4091-b9fd-1f560e8bac40','2b57ffef-26a4-4102-a269-d60a863b3762','2026-06-09 08:02:29',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-22-cvw44tnyzpz7-RoleParametersValue-6ynniaced5ad','state changed','OS::Heat::Value',NULL,1002),(1579,'2f6800ef-482d-46df-a6dd-c383601b4c34','2b57ffef-26a4-4102-a269-d60a863b3762','2026-06-09 08:02:29',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-22-cvw44tnyzpz7-RoleParametersValue-6ynniaced5ad','state changed','OS::Heat::Value',NULL,1002),(1580,'0ff5de39-c1a3-487f-b96c-a3f2ece65b2a','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:02:29',NULL,'CREATE','IN_PROGRESS','ComputeServiceChainRoleData','overcloud-ComputeServiceChainRoleData-lkmyht6bef2z','state changed','OS::Heat::Value',NULL,1004),(1581,'bc1a3580-5fc2-477c-8a49-de072dc82de6','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:02:29',NULL,'CREATE','COMPLETE','ComputeServiceChainRoleData','overcloud-ComputeServiceChainRoleData-lkmyht6bef2z','state changed','OS::Heat::Value',NULL,1004),(1582,'89f979ca-1dfe-4e1d-9cb1-89e7cd4174d1','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:29',NULL,'CREATE','IN_PROGRESS','17','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-17-n65dr2g5byyw','state changed','OS::TripleO::Services::HeatEngine',NULL,1006),(1583,'5ec3bca5-6371-4f0c-8177-32b56e5ee725','2b57ffef-26a4-4102-a269-d60a863b3762','2026-06-09 08:02:29',NULL,'CREATE','COMPLETE','KeystoneLogging','e0802853-7de3-495c-a34f-aa54f67913a2','state changed','OS::TripleO::Services::Logging::Keystone',NULL,NULL),(1584,'7fa0de12-ea18-4894-8837-09eecacb3efe','3b52101a-4ece-4ae8-ad09-14f3eb8444a2','2026-06-09 08:02:29',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-17-n65dr2g5byyw','3b52101a-4ece-4ae8-ad09-14f3eb8444a2','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1585,'595086a5-d164-46c6-9aa0-71b4a147e9c5','89d88cbb-b9a7-43e5-af91-b893091f6b39','2026-06-09 08:02:29',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-23-icc4n5tw73vc-MySQLClient-gx4ju3rru5zj','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1586,'e94e5ca9-9957-4cbe-bec2-a45cd9c5ef02','4f358fc9-51ea-4a56-b341-248d24e0bca0','2026-06-09 08:02:29',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-23-icc4n5tw73vc-MySQLClient-gx4ju3rru5zj','4f358fc9-51ea-4a56-b341-248d24e0bca0','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1587,'7a254c6f-bf92-41d3-ac06-0f38eba39f91','4f358fc9-51ea-4a56-b341-248d24e0bca0','2026-06-09 08:02:29',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-23-icc4n5tw73vc-MySQLClient-gx4ju3rru5zj','4f358fc9-51ea-4a56-b341-248d24e0bca0','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1588,'f69c2485-8517-4a36-a654-547017be0181','89d88cbb-b9a7-43e5-af91-b893091f6b39','2026-06-09 08:02:29',NULL,'CREATE','COMPLETE','ContainersCommon','f4990aca-2039-4d69-a729-53edfb89d36f','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1589,'a9f60c3d-a7f8-4490-8332-1348d659a8cb','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:29',NULL,'CREATE','IN_PROGRESS','16','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-16-szbdjw6p5n6k','state changed','OS::TripleO::Services::HeatApiCfn',NULL,1012),(1590,'2e365f48-bcb2-4922-8662-db568ccba739','2b57ffef-26a4-4102-a269-d60a863b3762','2026-06-09 08:02:30',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-22-cvw44tnyzpz7-ContainersCommon-q7g2gqgtq7vf','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1591,'dbf9c258-3bb9-4673-af65-b72086133940','be1b43ae-fb1a-49ad-ae90-48555f1a946e','2026-06-09 08:02:30',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-22-cvw44tnyzpz7-ContainersCommon-q7g2gqgtq7vf','be1b43ae-fb1a-49ad-ae90-48555f1a946e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1592,'f42edd82-f715-47ab-87bb-10234868a28e','9cb4ece2-fadd-475a-9698-98a4982f2e8c','2026-06-09 08:02:30',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-16-szbdjw6p5n6k','9cb4ece2-fadd-475a-9698-98a4982f2e8c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1593,'1a540dd6-ee12-47d5-a75e-1dad878c8397','be1b43ae-fb1a-49ad-ae90-48555f1a946e','2026-06-09 08:02:30',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-22-cvw44tnyzpz7-ContainersCommon-q7g2gqgtq7vf','be1b43ae-fb1a-49ad-ae90-48555f1a946e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1594,'b419bbf0-559d-42c7-83c6-c765848b50f5','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:02:30',NULL,'CREATE','IN_PROGRESS','ComputeServiceNames','overcloud-ComputeServiceNames-l4t2fjb3itl3','state changed','OS::Heat::Value',NULL,1013),(1595,'66230f3b-b958-446b-8372-7202447c73eb','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:02:30',NULL,'CREATE','COMPLETE','ComputeServiceNames','overcloud-ComputeServiceNames-l4t2fjb3itl3','state changed','OS::Heat::Value',NULL,1013),(1596,'7b79352c-b004-42cc-b4dd-8834afc548bd','3b52101a-4ece-4ae8-ad09-14f3eb8444a2','2026-06-09 08:02:30',NULL,'CREATE','IN_PROGRESS','HeatBase','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-17-n65dr2g5byyw-HeatBase-x4u6nmph2nka','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-base-puppet.yaml',NULL,1015),(1597,'98997dbf-070e-4743-8cb6-fa1e895739b6','9cb4ece2-fadd-475a-9698-98a4982f2e8c','2026-06-09 08:02:30',NULL,'CREATE','IN_PROGRESS','HeatBase','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-16-szbdjw6p5n6k-HeatBase-gvcnuoigrtry','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-base-puppet.yaml',NULL,1016),(1598,'b32cbba2-a7cc-4cb1-9f53-39cbbced56f3','39d8abe4-989b-4e97-bd9c-73d760e5d031','2026-06-09 08:02:30',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-17-n65dr2g5byyw-HeatBase-x4u6nmph2nka','39d8abe4-989b-4e97-bd9c-73d760e5d031','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1599,'b6a07400-55d4-4bd8-b973-1ae703b82569','4e79b5ad-7492-470e-b1b6-ec198c4bbc51','2026-06-09 08:02:30',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-16-szbdjw6p5n6k-HeatBase-gvcnuoigrtry','4e79b5ad-7492-470e-b1b6-ec198c4bbc51','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1600,'8f0c5bcc-1cde-4b12-9e9a-3149614fd5ea','4e79b5ad-7492-470e-b1b6-ec198c4bbc51','2026-06-09 08:02:30',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-16-szbdjw6p5n6k-HeatBase-gvcnuoigrtry','4e79b5ad-7492-470e-b1b6-ec198c4bbc51','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1601,'0f2cd226-3855-4104-8ed0-5b961db7fb05','39d8abe4-989b-4e97-bd9c-73d760e5d031','2026-06-09 08:02:30',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-17-n65dr2g5byyw-HeatBase-x4u6nmph2nka','39d8abe4-989b-4e97-bd9c-73d760e5d031','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1602,'28aa43f7-7c05-4a3c-b090-bbb9d9978d53','89d88cbb-b9a7-43e5-af91-b893091f6b39','2026-06-09 08:02:30',NULL,'CREATE','COMPLETE','MySQLClient','4f358fc9-51ea-4a56-b341-248d24e0bca0','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1603,'618135fa-7f96-4afe-8b91-16eba12d1aed','89d88cbb-b9a7-43e5-af91-b893091f6b39','2026-06-09 08:02:30',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-23-icc4n5tw73vc','89d88cbb-b9a7-43e5-af91-b893091f6b39','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1604,'786cd1e2-445a-42e9-8ecd-6227bc5657a9','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:02:30',NULL,'CREATE','IN_PROGRESS','Compute','overcloud-Compute-cdqwojnpdfon','state changed','OS::Heat::ResourceGroup',NULL,1018),(1605,'8a3464c3-1082-47e9-b762-c279996a43fc','ccd5f3de-d0f7-46e0-81e7-5a3bb31845db','2026-06-09 08:02:30',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-cdqwojnpdfon','ccd5f3de-d0f7-46e0-81e7-5a3bb31845db','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1606,'7845d87f-8b13-4229-9adf-b8528a33ae89','ccd5f3de-d0f7-46e0-81e7-5a3bb31845db','2026-06-09 08:02:30',NULL,'CREATE','COMPLETE','overcloud-Compute-cdqwojnpdfon','ccd5f3de-d0f7-46e0-81e7-5a3bb31845db','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1607,'cad39584-7ed5-44d5-83ed-a6afd1fe19df','2b57ffef-26a4-4102-a269-d60a863b3762','2026-06-09 08:02:31',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-22-cvw44tnyzpz7-MySQLClient-6k22amoahmec','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1608,'ea700c2f-a0d3-45e3-847a-807cefb95d3b','7eb0fdb0-7221-42ff-bdb2-8e20e35cb215','2026-06-09 08:02:31',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-22-cvw44tnyzpz7-MySQLClient-6k22amoahmec','7eb0fdb0-7221-42ff-bdb2-8e20e35cb215','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1609,'40187167-6efd-4b7f-9145-8d85b7f88d7b','2b57ffef-26a4-4102-a269-d60a863b3762','2026-06-09 08:02:31',NULL,'CREATE','COMPLETE','ContainersCommon','be1b43ae-fb1a-49ad-ae90-48555f1a946e','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1610,'560654c3-4f28-4501-afaf-bd378a317b96','7eb0fdb0-7221-42ff-bdb2-8e20e35cb215','2026-06-09 08:02:31',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-22-cvw44tnyzpz7-MySQLClient-6k22amoahmec','7eb0fdb0-7221-42ff-bdb2-8e20e35cb215','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1611,'d23251ec-0d9f-4f73-97f6-887f8b9f4ee2','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:31',NULL,'CREATE','COMPLETE','23','89d88cbb-b9a7-43e5-af91-b893091f6b39','state changed','OS::TripleO::Services::ManilaApi',NULL,915),(1612,'f053b821-73bd-4ba8-b894-ee70f7402e8d','9cb4ece2-fadd-475a-9698-98a4982f2e8c','2026-06-09 08:02:31',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-16-szbdjw6p5n6k-ContainersCommon-jag62pdxnbem','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1613,'30627d90-58ea-4b89-a393-2a4b0412a625','f045dea5-f2af-4b48-801a-7cb3ce547007','2026-06-09 08:02:31',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-16-szbdjw6p5n6k-ContainersCommon-jag62pdxnbem','f045dea5-f2af-4b48-801a-7cb3ce547007','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1614,'2d6c4150-4f88-44e6-8f16-52a1b751c84a','3b52101a-4ece-4ae8-ad09-14f3eb8444a2','2026-06-09 08:02:31',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-17-n65dr2g5byyw-MySQLClient-i6lyxpmqfwao','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1615,'1f055acc-d2d5-4912-b469-c36e395f3cf4','9cb4ece2-fadd-475a-9698-98a4982f2e8c','2026-06-09 08:02:31',NULL,'CREATE','COMPLETE','HeatBase','4e79b5ad-7492-470e-b1b6-ec198c4bbc51','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-base-puppet.yaml',NULL,1016),(1616,'3e13465c-f7bd-4ebe-aad9-3b6616a5ecb5','f045dea5-f2af-4b48-801a-7cb3ce547007','2026-06-09 08:02:31',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-16-szbdjw6p5n6k-ContainersCommon-jag62pdxnbem','f045dea5-f2af-4b48-801a-7cb3ce547007','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1617,'5a45b898-7bc9-47d8-a8ee-de7f82f11efc','3b52101a-4ece-4ae8-ad09-14f3eb8444a2','2026-06-09 08:02:31',NULL,'CREATE','COMPLETE','HeatBase','39d8abe4-989b-4e97-bd9c-73d760e5d031','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-base-puppet.yaml',NULL,1015),(1618,'4c1f053b-36c1-4a50-9fda-a04748bac3df','5d50b850-22b3-4c22-b230-c2ddcf99c86c','2026-06-09 08:02:31',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-17-n65dr2g5byyw-MySQLClient-i6lyxpmqfwao','5d50b850-22b3-4c22-b230-c2ddcf99c86c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1619,'a43ddf28-62d4-4436-8305-c492799a342a','5d50b850-22b3-4c22-b230-c2ddcf99c86c','2026-06-09 08:02:31',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-17-n65dr2g5byyw-MySQLClient-i6lyxpmqfwao','5d50b850-22b3-4c22-b230-c2ddcf99c86c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1620,'d577aa6b-8e0b-4700-a2ec-d06e5d945b31','ccd5f3de-d0f7-46e0-81e7-5a3bb31845db','2026-06-09 08:02:32',NULL,'UPDATE','IN_PROGRESS','overcloud-Compute-cdqwojnpdfon','ccd5f3de-d0f7-46e0-81e7-5a3bb31845db','Stack UPDATE started','OS::Heat::Stack',NULL,NULL),(1621,'524c6a18-21d0-4919-a6ef-3c6f69c929e8','ccd5f3de-d0f7-46e0-81e7-5a3bb31845db','2026-06-09 08:02:32',NULL,'CREATE','IN_PROGRESS','2','overcloud-Compute-cdqwojnpdfon-2-5brbweb4w63v','state changed','OS::TripleO::Compute',NULL,1026),(1622,'e54210a6-fd51-4625-93d4-6013e9699289','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:32',NULL,'CREATE','IN_PROGRESS','27','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-27-fwrfedwz6j2x','state changed','OS::TripleO::Services::Memcached',NULL,1027),(1623,'ca792d85-b9b2-482e-85b6-43a180946809','a3a4fa59-ee0c-43d2-a164-f79853cd146c','2026-06-09 08:02:32',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-27-fwrfedwz6j2x','a3a4fa59-ee0c-43d2-a164-f79853cd146c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1624,'56b6cce8-638e-4ab0-b1e4-fb50e4c826a6','ddf23a8c-5258-4b47-9ee9-3c68b6558dfb','2026-06-09 08:02:32',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-cdqwojnpdfon-2-5brbweb4w63v','ddf23a8c-5258-4b47-9ee9-3c68b6558dfb','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1625,'62800864-6b41-43a1-8281-131f5328401a','2b57ffef-26a4-4102-a269-d60a863b3762','2026-06-09 08:02:32',NULL,'CREATE','COMPLETE','MySQLClient','7eb0fdb0-7221-42ff-bdb2-8e20e35cb215','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1626,'6fd372e2-7f35-4e83-a7e0-0e4421dbfd5b','2b57ffef-26a4-4102-a269-d60a863b3762','2026-06-09 08:02:32',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-22-cvw44tnyzpz7','2b57ffef-26a4-4102-a269-d60a863b3762','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1627,'53f262dd-b43b-41b1-8c7e-3d29ddadb03f','a3a4fa59-ee0c-43d2-a164-f79853cd146c','2026-06-09 08:02:32',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-27-fwrfedwz6j2x-RoleParametersValue-b6zvg6lvu7rt','state changed','OS::Heat::Value',NULL,1028),(1628,'486529d4-686e-4f3d-b0f3-d7594454a7fd','a3a4fa59-ee0c-43d2-a164-f79853cd146c','2026-06-09 08:02:32',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-27-fwrfedwz6j2x-RoleParametersValue-b6zvg6lvu7rt','state changed','OS::Heat::Value',NULL,1028),(1629,'ad37a447-df8f-4533-bcee-40131f9fc97b','3b52101a-4ece-4ae8-ad09-14f3eb8444a2','2026-06-09 08:02:32',NULL,'CREATE','IN_PROGRESS','HeatEngineLogging','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-17-n65dr2g5byyw-HeatEngineLogging-vvxbwofzemdd','state changed','OS::TripleO::Services::Logging::HeatEngine',NULL,NULL),(1630,'74393e99-7e64-404e-aa53-b927328264c0','9cb4ece2-fadd-475a-9698-98a4982f2e8c','2026-06-09 08:02:32',NULL,'CREATE','IN_PROGRESS','HeatApiCfnLogging','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-16-szbdjw6p5n6k-HeatApiCfnLogging-ehj3lavuqihw','state changed','OS::TripleO::Services::Logging::HeatApiCfn',NULL,NULL),(1631,'7f22832c-7e10-49d3-a636-352da03f0341','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:32',NULL,'CREATE','COMPLETE','22','2b57ffef-26a4-4102-a269-d60a863b3762','state changed','OS::TripleO::Services::Keystone',NULL,936),(1632,'8fd53992-70f5-4977-8889-3abbada7c668','56bfd5eb-a13e-455c-997d-8a8e9210f7a6','2026-06-09 08:02:32',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-17-n65dr2g5byyw-HeatEngineLogging-vvxbwofzemdd','56bfd5eb-a13e-455c-997d-8a8e9210f7a6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1633,'b20ed2bc-e460-4160-a211-c4271d026056','35ab8c04-27de-4404-a2c2-fdc16189c3dc','2026-06-09 08:02:32',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-16-szbdjw6p5n6k-HeatApiCfnLogging-ehj3lavuqihw','35ab8c04-27de-4404-a2c2-fdc16189c3dc','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1634,'565a84ef-f578-4000-9ad7-0178d535adcf','ddf23a8c-5258-4b47-9ee9-3c68b6558dfb','2026-06-09 08:02:32',NULL,'CREATE','IN_PROGRESS','DeploymentActions','overcloud-Compute-cdqwojnpdfon-2-5brbweb4w63v-DeploymentActions-bciheuawentu','state changed','OS::Heat::Value',NULL,1029),(1635,'57ae2cf4-30d6-4ead-811a-8bd9849b4947','ddf23a8c-5258-4b47-9ee9-3c68b6558dfb','2026-06-09 08:02:32',NULL,'CREATE','COMPLETE','DeploymentActions','overcloud-Compute-cdqwojnpdfon-2-5brbweb4w63v-DeploymentActions-bciheuawentu','state changed','OS::Heat::Value',NULL,1029),(1636,'2740bbf1-a42c-4a52-bdd3-3450f742b643','35ab8c04-27de-4404-a2c2-fdc16189c3dc','2026-06-09 08:02:32',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-16-szbdjw6p5n6k-HeatApiCfnLogging-ehj3lavuqihw','35ab8c04-27de-4404-a2c2-fdc16189c3dc','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1637,'c4c22790-e65f-40d0-8f1d-6b3c1dffad66','9cb4ece2-fadd-475a-9698-98a4982f2e8c','2026-06-09 08:02:32',NULL,'CREATE','COMPLETE','ContainersCommon','f045dea5-f2af-4b48-801a-7cb3ce547007','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1638,'3c1507da-fb92-44e8-ac9f-3ed6cfb13296','3b52101a-4ece-4ae8-ad09-14f3eb8444a2','2026-06-09 08:02:32',NULL,'CREATE','COMPLETE','MySQLClient','5d50b850-22b3-4c22-b230-c2ddcf99c86c','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1639,'1e71ee76-8315-46bb-b81e-cb92ebe05069','56bfd5eb-a13e-455c-997d-8a8e9210f7a6','2026-06-09 08:02:32',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-17-n65dr2g5byyw-HeatEngineLogging-vvxbwofzemdd-RoleParametersValue-xnfbl34henf2','state changed','OS::Heat::Value',NULL,1031),(1640,'f8f58d93-b302-448d-8cd5-70ce5c7eaf33','56bfd5eb-a13e-455c-997d-8a8e9210f7a6','2026-06-09 08:02:32',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-17-n65dr2g5byyw-HeatEngineLogging-vvxbwofzemdd-RoleParametersValue-xnfbl34henf2','state changed','OS::Heat::Value',NULL,1031),(1641,'d1004377-24a1-4597-ac79-f566d60da544','56bfd5eb-a13e-455c-997d-8a8e9210f7a6','2026-06-09 08:02:32',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-17-n65dr2g5byyw-HeatEngineLogging-vvxbwofzemdd','56bfd5eb-a13e-455c-997d-8a8e9210f7a6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1642,'a5de0ab2-ccd5-4065-84c6-f67fe2d8b754','ccd5f3de-d0f7-46e0-81e7-5a3bb31845db','2026-06-09 08:02:33',NULL,'CREATE','IN_PROGRESS','1','overcloud-Compute-cdqwojnpdfon-1-okxrswbqfhiu','state changed','OS::TripleO::Compute',NULL,1039),(1643,'2c087755-c70b-491d-8571-d2b45f7691a4','6ced9fc4-733a-4c01-9846-70cfe49fde60','2026-06-09 08:02:33',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-cdqwojnpdfon-1-okxrswbqfhiu','6ced9fc4-733a-4c01-9846-70cfe49fde60','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1644,'0c485439-b922-4489-8fb0-33c0cb310e12','a3a4fa59-ee0c-43d2-a164-f79853cd146c','2026-06-09 08:02:33',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-27-fwrfedwz6j2x-ContainersCommon-5vsmkxrypn63','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1645,'06f79169-66ee-40d1-8c59-2165819be4b7','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:33',NULL,'CREATE','IN_PROGRESS','26','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-26-2abhkmchdo3h','state changed','OS::TripleO::Services::ManilaShare',NULL,1041),(1646,'2df5ba6a-a39e-437b-a403-961041f57915','f40a9991-dc12-47d0-b0e8-94a69feaea1a','2026-06-09 08:02:33',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-27-fwrfedwz6j2x-ContainersCommon-5vsmkxrypn63','f40a9991-dc12-47d0-b0e8-94a69feaea1a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1647,'79576adb-a2d9-4b52-bce2-66a5cfd9270e','3b52101a-4ece-4ae8-ad09-14f3eb8444a2','2026-06-09 08:02:33',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-17-n65dr2g5byyw-ContainersCommon-m2nnauqjj4cq','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1648,'75c7f6be-cf4f-45df-8ea3-7b37e95de2e0','f40a9991-dc12-47d0-b0e8-94a69feaea1a','2026-06-09 08:02:33',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-27-fwrfedwz6j2x-ContainersCommon-5vsmkxrypn63','f40a9991-dc12-47d0-b0e8-94a69feaea1a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1649,'f975648b-c286-46d2-82a6-7fd3f60aea0e','8f9ec08a-62a7-48ef-9fb2-299b4d06ca54','2026-06-09 08:02:33',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-26-2abhkmchdo3h','8f9ec08a-62a7-48ef-9fb2-299b4d06ca54','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1650,'835ecd01-e330-4604-8d51-4d032d73949d','9cb4ece2-fadd-475a-9698-98a4982f2e8c','2026-06-09 08:02:33',NULL,'CREATE','IN_PROGRESS','ApacheServiceBase','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-16-szbdjw6p5n6k-ApacheServiceBase-n4m5padtyttx','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1042),(1651,'b6eba52a-cf82-42c4-8223-b8c5d74ceeac','65ec5f60-db0a-41e3-8db2-594069454016','2026-06-09 08:02:33',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-16-szbdjw6p5n6k-ApacheServiceBase-n4m5padtyttx','65ec5f60-db0a-41e3-8db2-594069454016','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1652,'3c2f47a7-0a50-478f-b73b-9b65638fb7ab','45a717bc-21a1-4c9e-b8e0-5e91481e301f','2026-06-09 08:02:33',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-17-n65dr2g5byyw-ContainersCommon-m2nnauqjj4cq','45a717bc-21a1-4c9e-b8e0-5e91481e301f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1653,'e80a5416-4ee5-4e01-8d84-9aa76616d1af','ddf23a8c-5258-4b47-9ee9-3c68b6558dfb','2026-06-09 08:02:33',NULL,'CREATE','IN_PROGRESS','NovaCompute','overcloud-Compute-cdqwojnpdfon-2-5brbweb4w63v-NovaCompute-zszjddzr32rp','state changed','OS::TripleO::ComputeServer',NULL,1043),(1654,'6ec6134a-4820-4f6d-a912-af3785a646f2','65ec5f60-db0a-41e3-8db2-594069454016','2026-06-09 08:02:33',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-16-szbdjw6p5n6k-ApacheServiceBase-n4m5padtyttx-ApacheNetworks-kzqxbo3vbxqz','state changed','OS::Heat::Value',NULL,1044),(1655,'face625e-deba-4219-815f-d2a81b3fd476','3b52101a-4ece-4ae8-ad09-14f3eb8444a2','2026-06-09 08:02:33',NULL,'CREATE','COMPLETE','HeatEngineLogging','56bfd5eb-a13e-455c-997d-8a8e9210f7a6','state changed','OS::TripleO::Services::Logging::HeatEngine',NULL,NULL),(1656,'cb55bcb1-d947-4398-8220-f9bf7f2e14dd','9cb4ece2-fadd-475a-9698-98a4982f2e8c','2026-06-09 08:02:33',NULL,'CREATE','COMPLETE','HeatApiCfnLogging','35ab8c04-27de-4404-a2c2-fdc16189c3dc','state changed','OS::TripleO::Services::Logging::HeatApiCfn',NULL,NULL),(1657,'af2f12f2-f50f-42bc-844d-955cbb49c9ff','45a717bc-21a1-4c9e-b8e0-5e91481e301f','2026-06-09 08:02:33',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-17-n65dr2g5byyw-ContainersCommon-m2nnauqjj4cq','45a717bc-21a1-4c9e-b8e0-5e91481e301f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1658,'02225b5b-4461-43d7-91e4-e3f859dd46c5','65ec5f60-db0a-41e3-8db2-594069454016','2026-06-09 08:02:33',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-16-szbdjw6p5n6k-ApacheServiceBase-n4m5padtyttx-ApacheNetworks-kzqxbo3vbxqz','state changed','OS::Heat::Value',NULL,1044),(1659,'ecb3d8e3-55c7-4427-9107-44c90eaacb09','65ec5f60-db0a-41e3-8db2-594069454016','2026-06-09 08:02:33',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-16-szbdjw6p5n6k-ApacheServiceBase-n4m5padtyttx','65ec5f60-db0a-41e3-8db2-594069454016','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1660,'1081598a-106b-48ec-8c1b-9b545ef1525c','8f9ec08a-62a7-48ef-9fb2-299b4d06ca54','2026-06-09 08:02:33',NULL,'CREATE','IN_PROGRESS','ManilaShareContainerBase','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-26-2abhkmchdo3h-ManilaShareContainerBase-bcl5jqb2wukd','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-container-puppet.yaml',NULL,1045),(1661,'358e61a6-be3d-4d36-8643-62a64ec28e5f','6ced9fc4-733a-4c01-9846-70cfe49fde60','2026-06-09 08:02:33',NULL,'CREATE','IN_PROGRESS','DeploymentActions','overcloud-Compute-cdqwojnpdfon-1-okxrswbqfhiu-DeploymentActions-prhmlg7ca3z2','state changed','OS::Heat::Value',NULL,1046),(1662,'be1473f8-03b6-4aa3-8f69-5b7ead95e1ee','6ced9fc4-733a-4c01-9846-70cfe49fde60','2026-06-09 08:02:33',NULL,'CREATE','COMPLETE','DeploymentActions','overcloud-Compute-cdqwojnpdfon-1-okxrswbqfhiu-DeploymentActions-prhmlg7ca3z2','state changed','OS::Heat::Value',NULL,1046),(1663,'a92e3392-63a2-46d9-b1dd-28bdf4354116','6a98522a-5a2d-4c58-9ced-e84d6ee429e0','2026-06-09 08:02:33',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-cdqwojnpdfon-2-5brbweb4w63v-NovaCompute-zszjddzr32rp','6a98522a-5a2d-4c58-9ced-e84d6ee429e0','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1664,'5d3a00bf-16bb-4222-bb93-fecca442ddf4','30396c75-7af1-4669-8a3c-a070d50b9803','2026-06-09 08:02:33',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-26-2abhkmchdo3h-ManilaShareContainerBase-bcl5jqb2wukd','30396c75-7af1-4669-8a3c-a070d50b9803','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1665,'e5474e32-c18f-444c-9d53-9b45fc18fbfb','6a98522a-5a2d-4c58-9ced-e84d6ee429e0','2026-06-09 08:02:34',NULL,'CREATE','IN_PROGRESS','ControlPlanePort','overcloud-Compute-cdqwojnpdfon-2-5brbweb4w63v-NovaCompute-zszjddzr32rp-ControlPlanePort-qx6oodfzdpcp','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1048),(1666,'82c550f9-3f32-4ea2-8349-775f74718bbd','30396c75-7af1-4669-8a3c-a070d50b9803','2026-06-09 08:02:34',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-26-2abhkmchdo3h-ManilaShareContainerBase-bcl5jqb2wukd-MySQLClient-tojegptcsu2d','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1667,'d05c5ec6-0b1a-4a4b-97b4-770897a8eb6f','bd0870d7-442b-4081-b2a3-7047cd7b029c','2026-06-09 08:02:34',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-cdqwojnpdfon-2-5brbweb4w63v-NovaCompute-zszjddzr32rp-ControlPlanePort-qx6oodfzdpcp','bd0870d7-442b-4081-b2a3-7047cd7b029c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1668,'41b78101-e66c-44be-9d99-d8668d5e75df','bd0870d7-442b-4081-b2a3-7047cd7b029c','2026-06-09 08:02:34',NULL,'CREATE','COMPLETE','overcloud-Compute-cdqwojnpdfon-2-5brbweb4w63v-NovaCompute-zszjddzr32rp-ControlPlanePort-qx6oodfzdpcp','bd0870d7-442b-4081-b2a3-7047cd7b029c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1669,'d1361f03-c9a9-4fdd-96a6-000b67ca5d40','ccd5f3de-d0f7-46e0-81e7-5a3bb31845db','2026-06-09 08:02:34',NULL,'CREATE','IN_PROGRESS','0','overcloud-Compute-cdqwojnpdfon-0-ghnaey3kptkx','state changed','OS::TripleO::Compute',NULL,1049),(1670,'4c5492e0-15df-4ae1-bd2c-48e7bec3a04e','4237c4f2-bb7f-4a7a-926c-1700537fca09','2026-06-09 08:02:34',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-26-2abhkmchdo3h-ManilaShareContainerBase-bcl5jqb2wukd-MySQLClient-tojegptcsu2d','4237c4f2-bb7f-4a7a-926c-1700537fca09','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1671,'907702aa-06f6-48e9-b169-de72f99b93d2','4237c4f2-bb7f-4a7a-926c-1700537fca09','2026-06-09 08:02:34',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-26-2abhkmchdo3h-ManilaShareContainerBase-bcl5jqb2wukd-MySQLClient-tojegptcsu2d','4237c4f2-bb7f-4a7a-926c-1700537fca09','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1672,'87688123-ed2c-4350-91a3-5d7f30a58424','6aa3e4a0-1e33-4f94-94b1-14ecc987144f','2026-06-09 08:02:34',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-cdqwojnpdfon-0-ghnaey3kptkx','6aa3e4a0-1e33-4f94-94b1-14ecc987144f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1673,'416d485a-4c9a-435a-b3c5-16168e38da4c','a3a4fa59-ee0c-43d2-a164-f79853cd146c','2026-06-09 08:02:34',NULL,'CREATE','COMPLETE','ContainersCommon','f40a9991-dc12-47d0-b0e8-94a69feaea1a','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1674,'a44ac023-dc41-4103-b506-897e2bbdd5b6','3b52101a-4ece-4ae8-ad09-14f3eb8444a2','2026-06-09 08:02:34',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-17-n65dr2g5byyw-RoleParametersValue-ighu5qisxi6q','state changed','OS::Heat::Value',NULL,1050),(1675,'b79b5a2b-0f20-4655-84be-88350269c6ec','a3a4fa59-ee0c-43d2-a164-f79853cd146c','2026-06-09 08:02:34',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-27-fwrfedwz6j2x','a3a4fa59-ee0c-43d2-a164-f79853cd146c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1676,'1fe9985b-e40a-423d-9992-cf91d9591a7d','3b52101a-4ece-4ae8-ad09-14f3eb8444a2','2026-06-09 08:02:34',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-17-n65dr2g5byyw-RoleParametersValue-ighu5qisxi6q','state changed','OS::Heat::Value',NULL,1050),(1677,'4d52e041-7b5d-4c51-b9a6-8764ee5490e8','9cb4ece2-fadd-475a-9698-98a4982f2e8c','2026-06-09 08:02:34',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-16-szbdjw6p5n6k-RoleParametersValue-kfl2emv2n7jv','state changed','OS::Heat::Value',NULL,1051),(1678,'832c8c92-4e55-4133-a656-350a75f5eaea','9cb4ece2-fadd-475a-9698-98a4982f2e8c','2026-06-09 08:02:34',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-16-szbdjw6p5n6k-RoleParametersValue-kfl2emv2n7jv','state changed','OS::Heat::Value',NULL,1051),(1679,'909a5033-4a5f-4397-9387-2f25439f9f66','6aa3e4a0-1e33-4f94-94b1-14ecc987144f','2026-06-09 08:02:34',NULL,'CREATE','IN_PROGRESS','DeploymentActions','overcloud-Compute-cdqwojnpdfon-0-ghnaey3kptkx-DeploymentActions-igr25zf6dc6k','state changed','OS::Heat::Value',NULL,1052),(1680,'60ed6e69-75ab-4f1e-8fc4-77058de8276d','6aa3e4a0-1e33-4f94-94b1-14ecc987144f','2026-06-09 08:02:34',NULL,'CREATE','COMPLETE','DeploymentActions','overcloud-Compute-cdqwojnpdfon-0-ghnaey3kptkx-DeploymentActions-igr25zf6dc6k','state changed','OS::Heat::Value',NULL,1052),(1681,'ff50050b-111b-4731-884b-a58420747f7f','9cb4ece2-fadd-475a-9698-98a4982f2e8c','2026-06-09 08:02:34',NULL,'CREATE','COMPLETE','ApacheServiceBase','65ec5f60-db0a-41e3-8db2-594069454016','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1042),(1682,'04ae04ad-b329-457e-967e-c3917024a117','3b52101a-4ece-4ae8-ad09-14f3eb8444a2','2026-06-09 08:02:34',NULL,'CREATE','COMPLETE','ContainersCommon','45a717bc-21a1-4c9e-b8e0-5e91481e301f','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1683,'777d853c-4f99-4ef8-a0f0-cc4b54cb8d9c','9cb4ece2-fadd-475a-9698-98a4982f2e8c','2026-06-09 08:02:34',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-16-szbdjw6p5n6k','9cb4ece2-fadd-475a-9698-98a4982f2e8c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1684,'34c731d4-3496-45a4-b34e-4059cd5aee7e','3b52101a-4ece-4ae8-ad09-14f3eb8444a2','2026-06-09 08:02:34',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-17-n65dr2g5byyw','3b52101a-4ece-4ae8-ad09-14f3eb8444a2','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1685,'b07b4bef-a763-48cc-8894-e194f1adb75d','8f9ec08a-62a7-48ef-9fb2-299b4d06ca54','2026-06-09 08:02:34',NULL,'CREATE','IN_PROGRESS','ManilaCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-26-2abhkmchdo3h-ManilaCommon-yxrf4pvvw4h6','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-common.yaml',NULL,NULL),(1686,'ef101ef9-bda6-4ec8-8e09-63c000bfaa0b','6ced9fc4-733a-4c01-9846-70cfe49fde60','2026-06-09 08:02:34',NULL,'CREATE','IN_PROGRESS','NovaCompute','overcloud-Compute-cdqwojnpdfon-1-okxrswbqfhiu-NovaCompute-wkiloatwknau','state changed','OS::TripleO::ComputeServer',NULL,1054),(1687,'bd2de313-2c6a-4292-ab12-c997fd8e625c','3cfb5411-a5ee-4aca-bcf8-9ae1ac1d1e20','2026-06-09 08:02:34',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-26-2abhkmchdo3h-ManilaCommon-yxrf4pvvw4h6','3cfb5411-a5ee-4aca-bcf8-9ae1ac1d1e20','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1688,'f2c677a7-e77f-4600-9c1e-07b8d69f388b','c30ce022-41e5-40a2-80d5-a443e5751521','2026-06-09 08:02:34',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-cdqwojnpdfon-1-okxrswbqfhiu-NovaCompute-wkiloatwknau','c30ce022-41e5-40a2-80d5-a443e5751521','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1689,'9a3cf04d-ba1b-4cc8-a932-b453af5faa4b','3cfb5411-a5ee-4aca-bcf8-9ae1ac1d1e20','2026-06-09 08:02:35',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-26-2abhkmchdo3h-ManilaCommon-yxrf4pvvw4h6-ContainersCommon-ppan62pdfctf','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1690,'0f01fa86-4bf8-41be-98f2-aa9791368926','6a98522a-5a2d-4c58-9ced-e84d6ee429e0','2026-06-09 08:02:35',NULL,'CREATE','IN_PROGRESS','deployed-server','ov-aCompute-zszjddzr32rp-deployed-server-snmxq4ahlgkw','state changed','OS::Heat::DeployedServer',NULL,1055),(1691,'e076ef2d-0e93-4347-a425-f46925ae84cb','c30ce022-41e5-40a2-80d5-a443e5751521','2026-06-09 08:02:35',NULL,'CREATE','IN_PROGRESS','deployed-server','ov-aCompute-wkiloatwknau-deployed-server-beaiicvdyt23','state changed','OS::Heat::DeployedServer',NULL,1056),(1692,'293cdfe1-7fe5-4ae2-af46-9443e1cf51c7','75f5382f-8e2e-46a8-8633-f09185e7608d','2026-06-09 08:02:35',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-26-2abhkmchdo3h-ManilaCommon-yxrf4pvvw4h6-ContainersCommon-ppan62pdfctf','75f5382f-8e2e-46a8-8633-f09185e7608d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1693,'eff957d5-8401-4362-99f6-429596f78357','30396c75-7af1-4669-8a3c-a070d50b9803','2026-06-09 08:02:35',NULL,'CREATE','IN_PROGRESS','ManilaShareCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-26-2abhkmchdo3h-ManilaShareContainerBase-bcl5jqb2wukd-ManilaShareCommon-cnivzeo4mdys','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-common.yaml',NULL,NULL),(1694,'5cd1b429-fb72-41bb-9f1a-7da87e4d1c8c','75f5382f-8e2e-46a8-8633-f09185e7608d','2026-06-09 08:02:35',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-26-2abhkmchdo3h-ManilaCommon-yxrf4pvvw4h6-ContainersCommon-ppan62pdfctf','75f5382f-8e2e-46a8-8633-f09185e7608d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1695,'dceaff82-d431-4147-a7b9-a952117af53a','6a98522a-5a2d-4c58-9ced-e84d6ee429e0','2026-06-09 08:02:35',NULL,'CREATE','COMPLETE','deployed-server','00759956-9787-4935-915b-a425a08bd36f','state changed','OS::Heat::DeployedServer',NULL,1055),(1696,'789e8561-ce83-4c1d-9b3b-8fb61f62103b','6a98522a-5a2d-4c58-9ced-e84d6ee429e0','2026-06-09 08:02:35',NULL,'CREATE','COMPLETE','ControlPlanePort','bd0870d7-442b-4081-b2a3-7047cd7b029c','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1048),(1697,'c8ba9184-4ea2-4d72-9d2a-ce2a305f07c4','6a98522a-5a2d-4c58-9ced-e84d6ee429e0','2026-06-09 08:02:35',NULL,'CREATE','COMPLETE','overcloud-Compute-cdqwojnpdfon-2-5brbweb4w63v-NovaCompute-zszjddzr32rp','6a98522a-5a2d-4c58-9ced-e84d6ee429e0','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1698,'728b5c31-5454-4815-9bdf-a473132ca469','c30ce022-41e5-40a2-80d5-a443e5751521','2026-06-09 08:02:35',NULL,'CREATE','COMPLETE','deployed-server','aa3c4f5b-0840-4090-a179-6e967dd49732','state changed','OS::Heat::DeployedServer',NULL,1056),(1699,'457e6828-b112-4dd8-81d2-a13fa3514f53','7d49efdf-bafd-41ce-9ed0-c485556864fc','2026-06-09 08:02:35',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-26-2abhkmchdo3h-ManilaShareContainerBase-bcl5jqb2wukd-ManilaShareCommon-cnivzeo4mdys','7d49efdf-bafd-41ce-9ed0-c485556864fc','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1700,'0ce92315-6780-4aea-a01e-d93a7fa9691a','30396c75-7af1-4669-8a3c-a070d50b9803','2026-06-09 08:02:35',NULL,'CREATE','COMPLETE','MySQLClient','4237c4f2-bb7f-4a7a-926c-1700537fca09','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1701,'bca3193d-e205-4b12-9f85-1b797a22b305','7d49efdf-bafd-41ce-9ed0-c485556864fc','2026-06-09 08:02:35',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-26-2abhkmchdo3h-ManilaShareContainerBase-bcl5jqb2wukd-ManilaShareCommon-cnivzeo4mdys-ContainersCommon-lrcrpvep72gr','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1702,'dc8c852a-c2bc-4c89-968b-7bcf329af321','33c37507-f7da-4cd5-8353-9c52549932bc','2026-06-09 08:02:35',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-26-2abhkmchdo3h-ManilaShareContainerBase-bcl5jqb2wukd-ManilaShareCommon-cnivzeo4mdys-ContainersCommon-lrcrpvep72gr','33c37507-f7da-4cd5-8353-9c52549932bc','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1703,'144441c7-1ee0-4fed-a04f-c2413db0ee64','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:35',NULL,'CREATE','COMPLETE','16','9cb4ece2-fadd-475a-9698-98a4982f2e8c','state changed','OS::TripleO::Services::HeatApiCfn',NULL,1012),(1704,'b39e9fce-3cd1-4566-b7ca-a76cf2ad31c3','33c37507-f7da-4cd5-8353-9c52549932bc','2026-06-09 08:02:35',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-26-2abhkmchdo3h-ManilaShareContainerBase-bcl5jqb2wukd-ManilaShareCommon-cnivzeo4mdys-ContainersCommon-lrcrpvep72gr','33c37507-f7da-4cd5-8353-9c52549932bc','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1705,'a031c46c-4ddf-4690-b2b3-2c39634962b3','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:35',NULL,'CREATE','COMPLETE','27','a3a4fa59-ee0c-43d2-a164-f79853cd146c','state changed','OS::TripleO::Services::Memcached',NULL,1027),(1706,'404d2ee1-aa65-4b3b-8a76-e1203e575861','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:35',NULL,'CREATE','COMPLETE','17','3b52101a-4ece-4ae8-ad09-14f3eb8444a2','state changed','OS::TripleO::Services::HeatEngine',NULL,1006),(1707,'3753689c-b4c6-4ecc-979b-05910aff6bf0','6aa3e4a0-1e33-4f94-94b1-14ecc987144f','2026-06-09 08:02:35',NULL,'CREATE','IN_PROGRESS','NovaCompute','overcloud-Compute-cdqwojnpdfon-0-ghnaey3kptkx-NovaCompute-3lumriiykh3p','state changed','OS::TripleO::ComputeServer',NULL,1060),(1708,'d3404d0b-0001-4353-a189-50b9355daaa9','8f9ec08a-62a7-48ef-9fb2-299b4d06ca54','2026-06-09 08:02:35',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-26-2abhkmchdo3h-MySQLClient-o3cueoe5yhop','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1709,'dfbc7500-e81f-4260-865d-3c9da8a481fa','ddf23a8c-5258-4b47-9ee9-3c68b6558dfb','2026-06-09 08:02:35',NULL,'CREATE','COMPLETE','NovaCompute','6a98522a-5a2d-4c58-9ced-e84d6ee429e0','state changed','OS::TripleO::ComputeServer',NULL,1043),(1710,'9628fff4-3106-4c3a-8ea4-605d14bbf654','43548ac0-c54d-434b-a383-452322ef9299','2026-06-09 08:02:35',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-26-2abhkmchdo3h-MySQLClient-o3cueoe5yhop','43548ac0-c54d-434b-a383-452322ef9299','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1711,'90aed209-0c93-455d-895f-a5911533d616','43548ac0-c54d-434b-a383-452322ef9299','2026-06-09 08:02:35',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-26-2abhkmchdo3h-MySQLClient-o3cueoe5yhop','43548ac0-c54d-434b-a383-452322ef9299','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1712,'d377ceca-0028-4cc8-b2e3-8d64adaadd76','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:35',NULL,'CREATE','IN_PROGRESS','31','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-31-mssug327vajy','state changed','OS::TripleO::Services::NeutronApi',NULL,1072),(1713,'9e842842-fd53-431c-90b3-1d1201652aa9','2bfec2e3-03af-40ad-9d26-5945eb747ff1','2026-06-09 08:02:36',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-cdqwojnpdfon-0-ghnaey3kptkx-NovaCompute-3lumriiykh3p','2bfec2e3-03af-40ad-9d26-5945eb747ff1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1714,'d479adbb-28b7-4916-b03e-2fa42ed02b43','8f9ec08a-62a7-48ef-9fb2-299b4d06ca54','2026-06-09 08:02:36',NULL,'CREATE','COMPLETE','MySQLClient','43548ac0-c54d-434b-a383-452322ef9299','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1715,'4ec8d4c1-470e-4718-9266-4898ef26a6b2','30396c75-7af1-4669-8a3c-a070d50b9803','2026-06-09 08:02:36',NULL,'CREATE','IN_PROGRESS','ManilaBase','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-26-2abhkmchdo3h-ManilaShareContainerBase-bcl5jqb2wukd-ManilaBase-mtsptfssna27','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-base.yaml',NULL,1075),(1716,'5a968aaf-9107-4b34-bed8-84d6b3ecc9c2','2bfec2e3-03af-40ad-9d26-5945eb747ff1','2026-06-09 08:02:36',NULL,'CREATE','IN_PROGRESS','deployed-server','ov-aCompute-3lumriiykh3p-deployed-server-tu6djwgyosu7','state changed','OS::Heat::DeployedServer',NULL,1077),(1717,'52d91179-072a-43df-a5fb-c1c342619809','c30ce022-41e5-40a2-80d5-a443e5751521','2026-06-09 08:02:36',NULL,'CREATE','IN_PROGRESS','ControlPlanePort','overcloud-Compute-cdqwojnpdfon-1-okxrswbqfhiu-NovaCompute-wkiloatwknau-ControlPlanePort-lnar4ex3te2i','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1078),(1718,'e97d3ca7-de61-4e2e-9975-9a0b0a8ef831','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:36',NULL,'CREATE','IN_PROGRESS','21','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-21-eyp5tpzaugv6','state changed','OS::TripleO::Services::Kernel',NULL,1076),(1719,'5b015a4a-9163-419f-878e-4192f1f16d1a','acf76fe8-7f78-4e14-a300-db2aac31d9f7','2026-06-09 08:02:36',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-26-2abhkmchdo3h-ManilaShareContainerBase-bcl5jqb2wukd-ManilaBase-mtsptfssna27','acf76fe8-7f78-4e14-a300-db2aac31d9f7','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1720,'1a7b73a3-ee19-4b00-9909-dac033accfc3','2bfec2e3-03af-40ad-9d26-5945eb747ff1','2026-06-09 08:02:36',NULL,'CREATE','COMPLETE','deployed-server','8d874a9f-c34d-49d3-be94-07e60f920280','state changed','OS::Heat::DeployedServer',NULL,1077),(1721,'a297994e-1ddd-4368-a593-cec33a083dde','3cfb5411-a5ee-4aca-bcf8-9ae1ac1d1e20','2026-06-09 08:02:36',NULL,'CREATE','COMPLETE','ContainersCommon','75f5382f-8e2e-46a8-8633-f09185e7608d','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1722,'e6927e69-8952-4f14-8fd7-a593983d3e6b','acf76fe8-7f78-4e14-a300-db2aac31d9f7','2026-06-09 08:02:36',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-26-2abhkmchdo3h-ManilaShareContainerBase-bcl5jqb2wukd-ManilaBase-mtsptfssna27','acf76fe8-7f78-4e14-a300-db2aac31d9f7','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1723,'44508698-9940-4bb9-9bb4-4b6092d49263','65aeaaac-7ab2-4c3b-854a-19bcf506e08f','2026-06-09 08:02:36',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-cdqwojnpdfon-1-okxrswbqfhiu-NovaCompute-wkiloatwknau-ControlPlanePort-lnar4ex3te2i','65aeaaac-7ab2-4c3b-854a-19bcf506e08f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1724,'704b5763-86fa-40f7-9d37-083ddca2ea39','ddf23a8c-5258-4b47-9ee9-3c68b6558dfb','2026-06-09 08:02:36',NULL,'CREATE','IN_PROGRESS','NetHostMap','overcloud-Compute-cdqwojnpdfon-2-5brbweb4w63v-NetHostMap-qdo6dl4vwbo5','state changed','OS::Heat::Value',NULL,1080),(1725,'2ebd3790-6823-4a51-ba1f-61987bf81975','65aeaaac-7ab2-4c3b-854a-19bcf506e08f','2026-06-09 08:02:36',NULL,'CREATE','COMPLETE','overcloud-Compute-cdqwojnpdfon-1-okxrswbqfhiu-NovaCompute-wkiloatwknau-ControlPlanePort-lnar4ex3te2i','65aeaaac-7ab2-4c3b-854a-19bcf506e08f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1726,'d96eef8c-9c62-40bf-890f-276f07ee24c8','ddf23a8c-5258-4b47-9ee9-3c68b6558dfb','2026-06-09 08:02:36',NULL,'CREATE','IN_PROGRESS','NodeTLSCAData','overcloud-Compute-cdqwojnpdfon-2-5brbweb4w63v-NodeTLSCAData-u3pyzjfuu55m','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(1727,'addc9347-0e51-41b2-a293-79975b649c67','5efca393-e805-4157-957f-787c677298c9','2026-06-09 08:02:36',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-31-mssug327vajy','5efca393-e805-4157-957f-787c677298c9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1728,'00bcaf87-d8ec-4904-b9cb-146be5eb433e','3cfb5411-a5ee-4aca-bcf8-9ae1ac1d1e20','2026-06-09 08:02:36',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-26-2abhkmchdo3h-ManilaCommon-yxrf4pvvw4h6','3cfb5411-a5ee-4aca-bcf8-9ae1ac1d1e20','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1729,'d938085d-b389-4dff-b59d-ce7bfcba8f2f','ddf23a8c-5258-4b47-9ee9-3c68b6558dfb','2026-06-09 08:02:36',NULL,'CREATE','COMPLETE','NodeTLSCAData','0f2d5d09-8494-4c60-b162-f8a74da1c9c5','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(1730,'0762714f-b91e-4228-8cde-1d04bbe1819f','ddf23a8c-5258-4b47-9ee9-3c68b6558dfb','2026-06-09 08:02:36',NULL,'CREATE','COMPLETE','NetHostMap','overcloud-Compute-cdqwojnpdfon-2-5brbweb4w63v-NetHostMap-qdo6dl4vwbo5','state changed','OS::Heat::Value',NULL,1080),(1731,'5359c2a1-c654-4fca-a287-960f6f4842ac','ddf23a8c-5258-4b47-9ee9-3c68b6558dfb','2026-06-09 08:02:36',NULL,'CREATE','IN_PROGRESS','InternalApiPort','overcloud-Compute-cdqwojnpdfon-2-5brbweb4w63v-InternalApiPort-h43z2yo3xhhs','state changed','OS::TripleO::Compute::Ports::InternalApiPort',NULL,1082),(1732,'0730a127-fcc9-4462-83c9-e52ba01567ec','4fcc52be-977d-482a-95aa-ff2cb92d6483','2026-06-09 08:02:36',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-21-eyp5tpzaugv6','4fcc52be-977d-482a-95aa-ff2cb92d6483','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1733,'454f2446-6dd1-49a8-8e4f-89e9fa8c9cf7','7d49efdf-bafd-41ce-9ed0-c485556864fc','2026-06-09 08:02:36',NULL,'CREATE','COMPLETE','ContainersCommon','33c37507-f7da-4cd5-8353-9c52549932bc','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1734,'62f5f149-0353-44a7-90ac-fa7200ee19a0','ddf23a8c-5258-4b47-9ee9-3c68b6558dfb','2026-06-09 08:02:36',NULL,'CREATE','IN_PROGRESS','ComputeExtraConfigPre','overcloud-Compute-cdqwojnpdfon-2-5brbweb4w63v-ComputeExtraConfigPre-p2mrpfj7jjmc','state changed','OS::TripleO::ComputeExtraConfigPre',NULL,1083),(1735,'d8f93df2-b023-4248-831f-d754c1b8c3db','ddf23a8c-5258-4b47-9ee9-3c68b6558dfb','2026-06-09 08:02:36',NULL,'CREATE','IN_PROGRESS','PreNetworkConfig','overcloud-Compute-cdqwojnpdfon-2-5brbweb4w63v-PreNetworkConfig-rftwgay7xo32','state changed','OS::TripleO::Compute::PreNetworkConfig',NULL,NULL),(1736,'4733b90b-b2a7-4be4-890f-f18a3d497ecb','ddf23a8c-5258-4b47-9ee9-3c68b6558dfb','2026-06-09 08:02:36',NULL,'CREATE','IN_PROGRESS','NovaComputeAnsibleHostVars','overcloud-Compute-cdqwojnpdfon-2-5brbweb4w63v-NovaComputeAnsibleHostVars-nvssqaxrb3us','state changed','OS::Heat::Value',NULL,1085),(1737,'7eb16320-89df-464d-ae9f-db1c3f802bbc','ddf23a8c-5258-4b47-9ee9-3c68b6558dfb','2026-06-09 08:02:36',NULL,'CREATE','COMPLETE','PreNetworkConfig','8c8c7abd-821d-444f-91f5-6db3126a4d4c','state changed','OS::TripleO::Compute::PreNetworkConfig',NULL,NULL),(1738,'a51a701f-1cf3-42da-8db3-046b40ee968f','ddf23a8c-5258-4b47-9ee9-3c68b6558dfb','2026-06-09 08:02:36',NULL,'CREATE','COMPLETE','NovaComputeAnsibleHostVars','overcloud-Compute-cdqwojnpdfon-2-5brbweb4w63v-NovaComputeAnsibleHostVars-nvssqaxrb3us','state changed','OS::Heat::Value',NULL,1085),(1739,'ec7fbae9-e023-4755-bba0-ad4f1c0a003f','c1ca58a1-3188-4bce-afb9-dfb95f73ec39','2026-06-09 08:02:36',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-cdqwojnpdfon-2-5brbweb4w63v-ComputeExtraConfigPre-p2mrpfj7jjmc','c1ca58a1-3188-4bce-afb9-dfb95f73ec39','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1740,'492e8ea8-2111-4d95-ba44-c5e25e884988','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:36',NULL,'CREATE','IN_PROGRESS','20','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-20-xparsc55whav','state changed','OS::TripleO::Services::Iscsid',NULL,1086),(1741,'6c780882-fe97-43d9-a8a7-78410cc3affe','c1ca58a1-3188-4bce-afb9-dfb95f73ec39','2026-06-09 08:02:36',NULL,'CREATE','COMPLETE','overcloud-Compute-cdqwojnpdfon-2-5brbweb4w63v-ComputeExtraConfigPre-p2mrpfj7jjmc','c1ca58a1-3188-4bce-afb9-dfb95f73ec39','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1742,'35fc3403-39cd-4be2-ac66-30ad97b7e685','ddf23a8c-5258-4b47-9ee9-3c68b6558dfb','2026-06-09 08:02:36',NULL,'CREATE','IN_PROGRESS','TenantPort','overcloud-Compute-cdqwojnpdfon-2-5brbweb4w63v-TenantPort-xvxcxnyvrjcw','state changed','OS::TripleO::Compute::Ports::TenantPort',NULL,1087),(1743,'3e035fbc-5dfb-4a7e-bb24-5bcccbc4239c','4db61aff-07b8-4d73-84e5-c6d6792c6de8','2026-06-09 08:02:36',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-cdqwojnpdfon-2-5brbweb4w63v-InternalApiPort-h43z2yo3xhhs','4db61aff-07b8-4d73-84e5-c6d6792c6de8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1744,'0f2b2692-a169-4aac-8460-bf365ade6727','7d49efdf-bafd-41ce-9ed0-c485556864fc','2026-06-09 08:02:36',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-26-2abhkmchdo3h-ManilaShareContainerBase-bcl5jqb2wukd-ManilaShareCommon-cnivzeo4mdys','7d49efdf-bafd-41ce-9ed0-c485556864fc','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1745,'6c5c8060-3701-417a-8b46-b141ee6d79fc','14517033-4568-49cc-8603-cea0f6d1cac4','2026-06-09 08:02:36',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-20-xparsc55whav','14517033-4568-49cc-8603-cea0f6d1cac4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1746,'f81606fb-9674-48ee-b3fc-429fa8e7b254','ddf23a8c-5258-4b47-9ee9-3c68b6558dfb','2026-06-09 08:02:36',NULL,'CREATE','IN_PROGRESS','StoragePort','overcloud-Compute-cdqwojnpdfon-2-5brbweb4w63v-StoragePort-mttscpwjeufm','state changed','OS::TripleO::Compute::Ports::StoragePort',NULL,1088),(1747,'28078008-a2cb-4410-a46f-c624ef4611d3','ddf23a8c-5258-4b47-9ee9-3c68b6558dfb','2026-06-09 08:02:36',NULL,'CREATE','COMPLETE','ComputeExtraConfigPre','c1ca58a1-3188-4bce-afb9-dfb95f73ec39','state changed','OS::TripleO::ComputeExtraConfigPre',NULL,1083),(1748,'3ca61e9e-aace-4227-9fa1-a8a784369f8d','4db61aff-07b8-4d73-84e5-c6d6792c6de8','2026-06-09 08:02:36',NULL,'CREATE','IN_PROGRESS','InternalApiDeployedPort','overcloud-Compute-cdqwojnpdfon-2-5brbweb4w63v-InternalApiPort-h43z2yo3xhhs-InternalApiDeployedPort-457rpxxj5qpc','state changed','OS::Heat::Value',NULL,1090),(1749,'837fe9e5-458c-4456-954a-33bd4e0ad510','4db61aff-07b8-4d73-84e5-c6d6792c6de8','2026-06-09 08:02:36',NULL,'CREATE','COMPLETE','InternalApiDeployedPort','overcloud-Compute-cdqwojnpdfon-2-5brbweb4w63v-InternalApiPort-h43z2yo3xhhs-InternalApiDeployedPort-457rpxxj5qpc','state changed','OS::Heat::Value',NULL,1090),(1750,'a3225461-17c3-4e74-ad9f-3971d97e22de','ed06198b-73f3-4a70-9e85-76060cb16348','2026-06-09 08:02:36',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-cdqwojnpdfon-2-5brbweb4w63v-TenantPort-xvxcxnyvrjcw','ed06198b-73f3-4a70-9e85-76060cb16348','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1751,'9f478b46-a2f7-4efb-afa5-fca2bdbd9330','4db61aff-07b8-4d73-84e5-c6d6792c6de8','2026-06-09 08:02:36',NULL,'CREATE','COMPLETE','overcloud-Compute-cdqwojnpdfon-2-5brbweb4w63v-InternalApiPort-h43z2yo3xhhs','4db61aff-07b8-4d73-84e5-c6d6792c6de8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1752,'91a4510c-de84-4031-836b-7b54b2aebdb0','4b897dc5-07a3-41a1-b94b-f98726762c0c','2026-06-09 08:02:36',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-cdqwojnpdfon-2-5brbweb4w63v-StoragePort-mttscpwjeufm','4b897dc5-07a3-41a1-b94b-f98726762c0c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1753,'85ce2e2a-f702-4b17-8640-2baf0fe76d83','4fcc52be-977d-482a-95aa-ff2cb92d6483','2026-06-09 08:02:36',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-21-eyp5tpzaugv6-RoleParametersValue-dgz2dmnl5ne3','state changed','OS::Heat::Value',NULL,1092),(1754,'b24675b8-93d9-432f-a540-4e5f868bc77a','4fcc52be-977d-482a-95aa-ff2cb92d6483','2026-06-09 08:02:36',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-21-eyp5tpzaugv6-RoleParametersValue-dgz2dmnl5ne3','state changed','OS::Heat::Value',NULL,1092),(1755,'d694f583-3cdd-4158-ba12-1c6611f72315','ddf23a8c-5258-4b47-9ee9-3c68b6558dfb','2026-06-09 08:02:36',NULL,'CREATE','IN_PROGRESS','NodeExtraConfig','overcloud-Compute-cdqwojnpdfon-2-5brbweb4w63v-NodeExtraConfig-m6ayqusymhjq','state changed','OS::TripleO::NodeExtraConfig',NULL,1093),(1756,'fa630d37-b673-4613-9551-315a0b3fd950','14517033-4568-49cc-8603-cea0f6d1cac4','2026-06-09 08:02:36',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-20-xparsc55whav-ContainersCommon-3n6h75vzdomh','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1757,'5008115e-4b3b-4370-831b-7853f15c403a','4fcc52be-977d-482a-95aa-ff2cb92d6483','2026-06-09 08:02:36',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-21-eyp5tpzaugv6','4fcc52be-977d-482a-95aa-ff2cb92d6483','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1758,'3adda945-7bf9-47d9-9f7e-567477a259f6','ed06198b-73f3-4a70-9e85-76060cb16348','2026-06-09 08:02:36',NULL,'CREATE','IN_PROGRESS','TenantDeployedPort','overcloud-Compute-cdqwojnpdfon-2-5brbweb4w63v-TenantPort-xvxcxnyvrjcw-TenantDeployedPort-lg3srnwhjxiu','state changed','OS::Heat::Value',NULL,1094),(1759,'0df13cd5-68fd-4ca7-a13a-5c236ff3b3cb','4b897dc5-07a3-41a1-b94b-f98726762c0c','2026-06-09 08:02:36',NULL,'CREATE','IN_PROGRESS','StorageDeployedPort','overcloud-Compute-cdqwojnpdfon-2-5brbweb4w63v-StoragePort-mttscpwjeufm-StorageDeployedPort-o6hi4aebpnqw','state changed','OS::Heat::Value',NULL,1095),(1760,'fc8092cf-d2b2-4928-8b95-d76d924123b1','ed06198b-73f3-4a70-9e85-76060cb16348','2026-06-09 08:02:36',NULL,'CREATE','COMPLETE','TenantDeployedPort','overcloud-Compute-cdqwojnpdfon-2-5brbweb4w63v-TenantPort-xvxcxnyvrjcw-TenantDeployedPort-lg3srnwhjxiu','state changed','OS::Heat::Value',NULL,1094),(1761,'9cf44e88-3aaa-4381-893e-54b9319fb2ef','4b897dc5-07a3-41a1-b94b-f98726762c0c','2026-06-09 08:02:36',NULL,'CREATE','COMPLETE','StorageDeployedPort','overcloud-Compute-cdqwojnpdfon-2-5brbweb4w63v-StoragePort-mttscpwjeufm-StorageDeployedPort-o6hi4aebpnqw','state changed','OS::Heat::Value',NULL,1095),(1762,'2edfbb0f-deb0-4598-92e6-bffe9bc427b5','b8dedb3e-8dc1-4165-befa-4cb525ce379b','2026-06-09 08:02:36',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-cdqwojnpdfon-2-5brbweb4w63v-NodeExtraConfig-m6ayqusymhjq','b8dedb3e-8dc1-4165-befa-4cb525ce379b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1763,'3bbd3118-3a59-49e8-a36d-28373ee5b13d','407a3001-bddd-417e-8a3c-8816da9a583d','2026-06-09 08:02:36',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-20-xparsc55whav-ContainersCommon-3n6h75vzdomh','407a3001-bddd-417e-8a3c-8816da9a583d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1764,'6eb2584b-9d2e-427f-9dac-48c09bd93192','ed06198b-73f3-4a70-9e85-76060cb16348','2026-06-09 08:02:36',NULL,'CREATE','COMPLETE','overcloud-Compute-cdqwojnpdfon-2-5brbweb4w63v-TenantPort-xvxcxnyvrjcw','ed06198b-73f3-4a70-9e85-76060cb16348','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1765,'19a20eb5-9bed-4aa5-a82d-95845f872dec','4b897dc5-07a3-41a1-b94b-f98726762c0c','2026-06-09 08:02:36',NULL,'CREATE','COMPLETE','overcloud-Compute-cdqwojnpdfon-2-5brbweb4w63v-StoragePort-mttscpwjeufm','4b897dc5-07a3-41a1-b94b-f98726762c0c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1766,'e0ec1140-02c3-4777-8dc3-4d58cd4a1a8e','b8dedb3e-8dc1-4165-befa-4cb525ce379b','2026-06-09 08:02:36',NULL,'CREATE','COMPLETE','overcloud-Compute-cdqwojnpdfon-2-5brbweb4w63v-NodeExtraConfig-m6ayqusymhjq','b8dedb3e-8dc1-4165-befa-4cb525ce379b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1767,'59419559-592e-4527-81f1-894d16ac1a3f','5efca393-e805-4157-957f-787c677298c9','2026-06-09 08:02:36',NULL,'CREATE','IN_PROGRESS','NeutronBase','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-31-mssug327vajy-NeutronBase-s5tv7gvfufao','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-base.yaml',NULL,1097),(1768,'be162a72-65ba-4eb8-a90f-9f9c7def8441','407a3001-bddd-417e-8a3c-8816da9a583d','2026-06-09 08:02:36',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-20-xparsc55whav-ContainersCommon-3n6h75vzdomh','407a3001-bddd-417e-8a3c-8816da9a583d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1769,'ba77bd14-2d97-4326-812d-58304157f996','8f9ec08a-62a7-48ef-9fb2-299b4d06ca54','2026-06-09 08:02:36',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-26-2abhkmchdo3h-RoleParametersValue-53t7lwuhu5bm','state changed','OS::Heat::Value',NULL,1096),(1770,'6eb975be-1330-4133-a56b-3cd30a00c666','ddf23a8c-5258-4b47-9ee9-3c68b6558dfb','2026-06-09 08:02:36',NULL,'CREATE','COMPLETE','NodeExtraConfig','b8dedb3e-8dc1-4165-befa-4cb525ce379b','state changed','OS::TripleO::NodeExtraConfig',NULL,1093),(1771,'e041ab5c-ce74-4c94-bb78-f7924b6a41dc','8f9ec08a-62a7-48ef-9fb2-299b4d06ca54','2026-06-09 08:02:36',NULL,'CREATE','COMPLETE','ManilaCommon','3cfb5411-a5ee-4aca-bcf8-9ae1ac1d1e20','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-common.yaml',NULL,NULL),(1772,'30a0872c-3b19-49df-a3cf-8a68be30ca92','8f9ec08a-62a7-48ef-9fb2-299b4d06ca54','2026-06-09 08:02:36',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-26-2abhkmchdo3h-RoleParametersValue-53t7lwuhu5bm','state changed','OS::Heat::Value',NULL,1096),(1773,'8298c6aa-7468-46f7-9965-88030883740c','77707504-624a-48e7-82f7-5e15d30809d0','2026-06-09 08:02:37',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-31-mssug327vajy-NeutronBase-s5tv7gvfufao','77707504-624a-48e7-82f7-5e15d30809d0','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1774,'a990d27f-4370-465f-929c-c3e99b625540','77707504-624a-48e7-82f7-5e15d30809d0','2026-06-09 08:02:37',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-31-mssug327vajy-NeutronBase-s5tv7gvfufao','77707504-624a-48e7-82f7-5e15d30809d0','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1775,'ac650a7a-a3ac-4147-8082-89d15f981db8','2bfec2e3-03af-40ad-9d26-5945eb747ff1','2026-06-09 08:02:37',NULL,'CREATE','IN_PROGRESS','ControlPlanePort','overcloud-Compute-cdqwojnpdfon-0-ghnaey3kptkx-NovaCompute-3lumriiykh3p-ControlPlanePort-be2r23qcx4jr','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1098),(1776,'25272081-e52b-4549-be39-d362accc609c','30396c75-7af1-4669-8a3c-a070d50b9803','2026-06-09 08:02:37',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-26-2abhkmchdo3h-ManilaShareContainerBase-bcl5jqb2wukd-RoleParametersValue-ehp3lqlptz7a','state changed','OS::Heat::Value',NULL,1099),(1777,'31e2fc0e-783f-46f7-a379-06d88467cd5c','30396c75-7af1-4669-8a3c-a070d50b9803','2026-06-09 08:02:37',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-26-2abhkmchdo3h-ManilaShareContainerBase-bcl5jqb2wukd-RoleParametersValue-ehp3lqlptz7a','state changed','OS::Heat::Value',NULL,1099),(1778,'169417fc-c009-4ee6-8622-82813789cfdd','aacbe44e-1812-4c2e-8270-509d04feea0c','2026-06-09 08:02:37',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-cdqwojnpdfon-0-ghnaey3kptkx-NovaCompute-3lumriiykh3p-ControlPlanePort-be2r23qcx4jr','aacbe44e-1812-4c2e-8270-509d04feea0c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1779,'2698b591-b2f9-4feb-947a-c7e97b8e5c90','30396c75-7af1-4669-8a3c-a070d50b9803','2026-06-09 08:02:37',NULL,'CREATE','COMPLETE','ManilaBase','acf76fe8-7f78-4e14-a300-db2aac31d9f7','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-base.yaml',NULL,1075),(1780,'7ec5559f-acfd-45ef-a849-0ccb9ad5f155','aacbe44e-1812-4c2e-8270-509d04feea0c','2026-06-09 08:02:37',NULL,'CREATE','COMPLETE','overcloud-Compute-cdqwojnpdfon-0-ghnaey3kptkx-NovaCompute-3lumriiykh3p-ControlPlanePort-be2r23qcx4jr','aacbe44e-1812-4c2e-8270-509d04feea0c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1781,'aab5315d-7fa8-4e9c-a165-6e64730f7980','30396c75-7af1-4669-8a3c-a070d50b9803','2026-06-09 08:02:37',NULL,'CREATE','COMPLETE','ManilaShareCommon','7d49efdf-bafd-41ce-9ed0-c485556864fc','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-common.yaml',NULL,NULL),(1782,'defbd81a-7ef2-478d-b7d0-4232258e1cb0','c30ce022-41e5-40a2-80d5-a443e5751521','2026-06-09 08:02:37',NULL,'CREATE','COMPLETE','ControlPlanePort','65aeaaac-7ab2-4c3b-854a-19bcf506e08f','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1078),(1783,'cda9a9e9-81bd-4cc6-9a4b-57fb9427667c','c30ce022-41e5-40a2-80d5-a443e5751521','2026-06-09 08:02:37',NULL,'CREATE','COMPLETE','overcloud-Compute-cdqwojnpdfon-1-okxrswbqfhiu-NovaCompute-wkiloatwknau','c30ce022-41e5-40a2-80d5-a443e5751521','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1784,'54029c7c-2c03-4699-9bd1-dd712825d376','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:37',NULL,'CREATE','COMPLETE','21','4fcc52be-977d-482a-95aa-ff2cb92d6483','state changed','OS::TripleO::Services::Kernel',NULL,1076),(1785,'43577423-7f12-4f8d-9966-11d38f9025a7','ddf23a8c-5258-4b47-9ee9-3c68b6558dfb','2026-06-09 08:02:37',NULL,'CREATE','COMPLETE','InternalApiPort','4db61aff-07b8-4d73-84e5-c6d6792c6de8','state changed','OS::TripleO::Compute::Ports::InternalApiPort',NULL,1082),(1786,'3b617ff0-734f-4160-ad5d-96d0ea09b767','ddf23a8c-5258-4b47-9ee9-3c68b6558dfb','2026-06-09 08:02:37',NULL,'CREATE','COMPLETE','TenantPort','ed06198b-73f3-4a70-9e85-76060cb16348','state changed','OS::TripleO::Compute::Ports::TenantPort',NULL,1087),(1787,'ca9f01ba-cc00-4134-8387-fd516f5369e6','ddf23a8c-5258-4b47-9ee9-3c68b6558dfb','2026-06-09 08:02:37',NULL,'CREATE','COMPLETE','StoragePort','4b897dc5-07a3-41a1-b94b-f98726762c0c','state changed','OS::TripleO::Compute::Ports::StoragePort',NULL,1088),(1788,'c89bb532-0afd-4259-aa90-686498b3540b','14517033-4568-49cc-8603-cea0f6d1cac4','2026-06-09 08:02:37',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-20-xparsc55whav-RoleParametersValue-yfl26mxlv3pr','state changed','OS::Heat::Value',NULL,1104),(1789,'4bb1aae0-aebc-4efb-9b15-51f37eb660f8','8f9ec08a-62a7-48ef-9fb2-299b4d06ca54','2026-06-09 08:02:37',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-26-2abhkmchdo3h-ContainersCommon-c3hwuqvlyf7r','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1790,'ab14b288-b5da-409f-8bcc-bb700cac3355','14517033-4568-49cc-8603-cea0f6d1cac4','2026-06-09 08:02:37',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-20-xparsc55whav-RoleParametersValue-yfl26mxlv3pr','state changed','OS::Heat::Value',NULL,1104),(1791,'c276a522-fda9-4cff-8914-b1a9c77d1ac2','14517033-4568-49cc-8603-cea0f6d1cac4','2026-06-09 08:02:37',NULL,'CREATE','COMPLETE','ContainersCommon','407a3001-bddd-417e-8a3c-8816da9a583d','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1792,'a41df875-ff9d-46c2-bd1f-6756150d0b55','5efca393-e805-4157-957f-787c677298c9','2026-06-09 08:02:37',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-31-mssug327vajy-ContainersCommon-ajaffw3u5agu','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1793,'a8967c48-e03d-4f9c-964a-50243bcbad24','14517033-4568-49cc-8603-cea0f6d1cac4','2026-06-09 08:02:37',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-20-xparsc55whav','14517033-4568-49cc-8603-cea0f6d1cac4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1794,'3ab07c49-1e2a-4e3f-b1f1-e9c7348ff6af','762a92e5-8993-4627-a762-4f4012b910c4','2026-06-09 08:02:37',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-31-mssug327vajy-ContainersCommon-ajaffw3u5agu','762a92e5-8993-4627-a762-4f4012b910c4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1795,'578c916e-8ce9-4106-bf39-0a10941defd0','762a92e5-8993-4627-a762-4f4012b910c4','2026-06-09 08:02:38',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-31-mssug327vajy-ContainersCommon-ajaffw3u5agu','762a92e5-8993-4627-a762-4f4012b910c4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1796,'96af9cd1-31dc-40c5-8239-0c3cc7486eef','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:38',NULL,'CREATE','IN_PROGRESS','25','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-25-ef3lhrgx4ewv','state changed','OS::TripleO::Services::ManilaScheduler',NULL,1109),(1797,'16138f95-1314-4496-8a1b-e94f71c42a8b','5efca393-e805-4157-957f-787c677298c9','2026-06-09 08:02:38',NULL,'CREATE','COMPLETE','NeutronBase','77707504-624a-48e7-82f7-5e15d30809d0','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-base.yaml',NULL,1097),(1798,'3bb89926-564f-4d13-862a-47d6c542e1ed','6ced9fc4-733a-4c01-9846-70cfe49fde60','2026-06-09 08:02:38',NULL,'CREATE','COMPLETE','NovaCompute','c30ce022-41e5-40a2-80d5-a443e5751521','state changed','OS::TripleO::ComputeServer',NULL,1054),(1799,'21c12d60-3c5f-4c76-b9f1-a7b4307e8dae','ddf23a8c-5258-4b47-9ee9-3c68b6558dfb','2026-06-09 08:02:38',NULL,'CREATE','IN_PROGRESS','NetIpMap','overcloud-Compute-cdqwojnpdfon-2-5brbweb4w63v-NetIpMap-kgc5du3azf6k','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1110),(1800,'2bf33907-dea1-437d-8d4e-e6a04b7087c3','07d5a372-78cd-4846-885f-1c240bb61815','2026-06-09 08:02:38',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-26-2abhkmchdo3h-ContainersCommon-c3hwuqvlyf7r','07d5a372-78cd-4846-885f-1c240bb61815','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1801,'3d8f7742-2baa-462d-898a-bfd1684f8476','30396c75-7af1-4669-8a3c-a070d50b9803','2026-06-09 08:02:38',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-26-2abhkmchdo3h-ManilaShareContainerBase-bcl5jqb2wukd-ContainersCommon-kdjfgkftqd2j','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1802,'66d502dc-d72a-4262-970d-fbe103a3aca2','11a0ddfd-2d36-4d62-bb8b-5fc1f170e09f','2026-06-09 08:02:38',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-25-ef3lhrgx4ewv','11a0ddfd-2d36-4d62-bb8b-5fc1f170e09f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1803,'ff81fab8-0034-4056-9600-732aed614408','07d5a372-78cd-4846-885f-1c240bb61815','2026-06-09 08:02:38',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-26-2abhkmchdo3h-ContainersCommon-c3hwuqvlyf7r','07d5a372-78cd-4846-885f-1c240bb61815','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1804,'24dd9228-373b-472b-ba7b-8699b4f43990','89fd2248-7e1e-4fc9-8cc7-b7d9749ffd7f','2026-06-09 08:02:38',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-cdqwojnpdfon-2-5brbweb4w63v-NetIpMap-kgc5du3azf6k','89fd2248-7e1e-4fc9-8cc7-b7d9749ffd7f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1805,'3bfe21e2-55b4-48cb-a18e-9c1258743087','6ced9fc4-733a-4c01-9846-70cfe49fde60','2026-06-09 08:02:38',NULL,'CREATE','IN_PROGRESS','TenantPort','overcloud-Compute-cdqwojnpdfon-1-okxrswbqfhiu-TenantPort-hhtogyzvl3yo','state changed','OS::TripleO::Compute::Ports::TenantPort',NULL,1112),(1806,'ef6070fa-9b75-418b-91a8-006cde125f11','6ced9fc4-733a-4c01-9846-70cfe49fde60','2026-06-09 08:02:38',NULL,'CREATE','IN_PROGRESS','ComputeExtraConfigPre','overcloud-Compute-cdqwojnpdfon-1-okxrswbqfhiu-ComputeExtraConfigPre-46lxnmnqhk4a','state changed','OS::TripleO::ComputeExtraConfigPre',NULL,1113),(1807,'4e83b447-6919-4c9b-9f23-0d51a2cf1fc9','2bfec2e3-03af-40ad-9d26-5945eb747ff1','2026-06-09 08:02:38',NULL,'CREATE','COMPLETE','ControlPlanePort','aacbe44e-1812-4c2e-8270-509d04feea0c','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1098),(1808,'87bf2f32-ef38-4c95-91f8-f7e1715c504b','6ced9fc4-733a-4c01-9846-70cfe49fde60','2026-06-09 08:02:38',NULL,'CREATE','IN_PROGRESS','NodeTLSCAData','overcloud-Compute-cdqwojnpdfon-1-okxrswbqfhiu-NodeTLSCAData-k2dk52j4eekp','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(1809,'d121d38f-f63a-4146-8ae5-98d177472398','6ced9fc4-733a-4c01-9846-70cfe49fde60','2026-06-09 08:02:38',NULL,'CREATE','COMPLETE','NodeTLSCAData','5852caa5-3b66-41ee-93a1-57558aceff8c','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(1810,'51a9fb41-8804-48fe-a508-1bad570a1a35','04a28fbd-045b-4c1a-869e-dd6476b8d8c1','2026-06-09 08:02:38',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-26-2abhkmchdo3h-ManilaShareContainerBase-bcl5jqb2wukd-ContainersCommon-kdjfgkftqd2j','04a28fbd-045b-4c1a-869e-dd6476b8d8c1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1811,'619b98aa-c4af-4c89-becb-5fefe31066e9','6ced9fc4-733a-4c01-9846-70cfe49fde60','2026-06-09 08:02:38',NULL,'CREATE','IN_PROGRESS','StoragePort','overcloud-Compute-cdqwojnpdfon-1-okxrswbqfhiu-StoragePort-icg6f4dotc2g','state changed','OS::TripleO::Compute::Ports::StoragePort',NULL,1114),(1812,'95eab323-1f33-48f9-a77a-ccd74f4328e0','6ced9fc4-733a-4c01-9846-70cfe49fde60','2026-06-09 08:02:38',NULL,'CREATE','IN_PROGRESS','PreNetworkConfig','overcloud-Compute-cdqwojnpdfon-1-okxrswbqfhiu-PreNetworkConfig-rsk4b2qxv2a3','state changed','OS::TripleO::Compute::PreNetworkConfig',NULL,NULL),(1813,'c14170c0-5438-4a0f-8c49-f78cb7ffc425','2bfec2e3-03af-40ad-9d26-5945eb747ff1','2026-06-09 08:02:38',NULL,'CREATE','COMPLETE','overcloud-Compute-cdqwojnpdfon-0-ghnaey3kptkx-NovaCompute-3lumriiykh3p','2bfec2e3-03af-40ad-9d26-5945eb747ff1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1814,'bb61a32a-8ca6-4163-ade6-3f02bc2d80ef','bdf10cb4-906c-4a6a-bd1e-ad5302068629','2026-06-09 08:02:38',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-cdqwojnpdfon-1-okxrswbqfhiu-TenantPort-hhtogyzvl3yo','bdf10cb4-906c-4a6a-bd1e-ad5302068629','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1815,'a495fbc5-e0ff-4131-907a-d73970f9370c','6ced9fc4-733a-4c01-9846-70cfe49fde60','2026-06-09 08:02:38',NULL,'CREATE','IN_PROGRESS','NetHostMap','overcloud-Compute-cdqwojnpdfon-1-okxrswbqfhiu-NetHostMap-ce72bjgsuq4w','state changed','OS::Heat::Value',NULL,1115),(1816,'2d31ef50-3beb-43c5-b98b-de66f4eb2d53','6ced9fc4-733a-4c01-9846-70cfe49fde60','2026-06-09 08:02:38',NULL,'CREATE','IN_PROGRESS','InternalApiPort','overcloud-Compute-cdqwojnpdfon-1-okxrswbqfhiu-InternalApiPort-34redufa4u5t','state changed','OS::TripleO::Compute::Ports::InternalApiPort',NULL,1117),(1817,'19ac1190-a8ce-4abe-ac38-bb0acceb65a4','cb5d3a75-0a1f-407c-b11c-1966d8a7e39b','2026-06-09 08:02:38',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-cdqwojnpdfon-1-okxrswbqfhiu-ComputeExtraConfigPre-46lxnmnqhk4a','cb5d3a75-0a1f-407c-b11c-1966d8a7e39b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1818,'a2679296-fc23-47d7-8359-d8db7d15ee85','04a28fbd-045b-4c1a-869e-dd6476b8d8c1','2026-06-09 08:02:38',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-26-2abhkmchdo3h-ManilaShareContainerBase-bcl5jqb2wukd-ContainersCommon-kdjfgkftqd2j','04a28fbd-045b-4c1a-869e-dd6476b8d8c1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1819,'b201d673-b327-4a37-a687-84aec819cc25','6ced9fc4-733a-4c01-9846-70cfe49fde60','2026-06-09 08:02:38',NULL,'CREATE','COMPLETE','NetHostMap','overcloud-Compute-cdqwojnpdfon-1-okxrswbqfhiu-NetHostMap-ce72bjgsuq4w','state changed','OS::Heat::Value',NULL,1115),(1820,'77211266-3074-4d87-9123-a6c98c431d04','6ced9fc4-733a-4c01-9846-70cfe49fde60','2026-06-09 08:02:38',NULL,'CREATE','COMPLETE','PreNetworkConfig','d4657c59-1920-4b0d-af8f-51e173830ee8','state changed','OS::TripleO::Compute::PreNetworkConfig',NULL,NULL),(1821,'654de0b5-04cf-4a39-a8f7-470a6f4a0bfd','cb5d3a75-0a1f-407c-b11c-1966d8a7e39b','2026-06-09 08:02:38',NULL,'CREATE','COMPLETE','overcloud-Compute-cdqwojnpdfon-1-okxrswbqfhiu-ComputeExtraConfigPre-46lxnmnqhk4a','cb5d3a75-0a1f-407c-b11c-1966d8a7e39b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1822,'e9c9597f-2b82-4850-b44e-13d56e98ff95','30396c75-7af1-4669-8a3c-a070d50b9803','2026-06-09 08:02:38',NULL,'CREATE','COMPLETE','ContainersCommon','04a28fbd-045b-4c1a-869e-dd6476b8d8c1','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1823,'6c117f58-d963-4dba-91a3-02cfe14d4ad3','89fd2248-7e1e-4fc9-8cc7-b7d9749ffd7f','2026-06-09 08:02:38',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-Compute-cdqwojnpdfon-2-5brbweb4w63v-NetIpMap-kgc5du3azf6k-NetIpMapValue-3s3k4tmzfkpv','state changed','OS::Heat::Value',NULL,1118),(1824,'fe0790b4-be38-45ea-98da-34349d02bfe8','f204995f-34fe-48eb-94a6-60f49b8e354a','2026-06-09 08:02:38',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-cdqwojnpdfon-1-okxrswbqfhiu-StoragePort-icg6f4dotc2g','f204995f-34fe-48eb-94a6-60f49b8e354a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1825,'c663bb5e-b06e-4b1a-85ae-01218c932f0d','30396c75-7af1-4669-8a3c-a070d50b9803','2026-06-09 08:02:38',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-26-2abhkmchdo3h-ManilaShareContainerBase-bcl5jqb2wukd','30396c75-7af1-4669-8a3c-a070d50b9803','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1826,'7baf355b-dfaf-4e43-a392-b28779623303','89fd2248-7e1e-4fc9-8cc7-b7d9749ffd7f','2026-06-09 08:02:38',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-Compute-cdqwojnpdfon-2-5brbweb4w63v-NetIpMap-kgc5du3azf6k-NetIpMapValue-3s3k4tmzfkpv','state changed','OS::Heat::Value',NULL,1118),(1827,'4f3db308-00bb-40b9-9ba3-c780db97db9c','bdf10cb4-906c-4a6a-bd1e-ad5302068629','2026-06-09 08:02:38',NULL,'CREATE','IN_PROGRESS','TenantDeployedPort','overcloud-Compute-cdqwojnpdfon-1-okxrswbqfhiu-TenantPort-hhtogyzvl3yo-TenantDeployedPort-tvtprue3qjnw','state changed','OS::Heat::Value',NULL,1120),(1828,'08a45ad3-b4e8-4852-93f3-fa8fe1b7f1dd','6ced9fc4-733a-4c01-9846-70cfe49fde60','2026-06-09 08:02:38',NULL,'CREATE','COMPLETE','ComputeExtraConfigPre','cb5d3a75-0a1f-407c-b11c-1966d8a7e39b','state changed','OS::TripleO::ComputeExtraConfigPre',NULL,1113),(1829,'6a7b8d3c-075d-4dca-98a4-cce9b22ae19f','11a0ddfd-2d36-4d62-bb8b-5fc1f170e09f','2026-06-09 08:02:38',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-25-ef3lhrgx4ewv-MySQLClient-bn43d4tnrq6h','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1830,'6a8cbfa3-9247-4b6d-a124-20dc618899f0','6ced9fc4-733a-4c01-9846-70cfe49fde60','2026-06-09 08:02:38',NULL,'CREATE','IN_PROGRESS','NovaComputeAnsibleHostVars','overcloud-Compute-cdqwojnpdfon-1-okxrswbqfhiu-NovaComputeAnsibleHostVars-kbuw2fsqn6wc','state changed','OS::Heat::Value',NULL,1121),(1831,'cd166019-c2b3-4e6e-a94d-a26c92c671ef','bdf10cb4-906c-4a6a-bd1e-ad5302068629','2026-06-09 08:02:38',NULL,'CREATE','COMPLETE','TenantDeployedPort','overcloud-Compute-cdqwojnpdfon-1-okxrswbqfhiu-TenantPort-hhtogyzvl3yo-TenantDeployedPort-tvtprue3qjnw','state changed','OS::Heat::Value',NULL,1120),(1832,'b511e816-607e-4880-b2f9-78655cdc5552','89fd2248-7e1e-4fc9-8cc7-b7d9749ffd7f','2026-06-09 08:02:38',NULL,'CREATE','COMPLETE','overcloud-Compute-cdqwojnpdfon-2-5brbweb4w63v-NetIpMap-kgc5du3azf6k','89fd2248-7e1e-4fc9-8cc7-b7d9749ffd7f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1833,'cd9df491-08b7-4162-8f7e-dd72d96b9cd1','34c7ae54-4092-401a-b3c7-0e6e4564a5e7','2026-06-09 08:02:38',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-cdqwojnpdfon-1-okxrswbqfhiu-InternalApiPort-34redufa4u5t','34c7ae54-4092-401a-b3c7-0e6e4564a5e7','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1834,'8c367ea3-e65b-4350-92fe-21e4ad36d962','6ced9fc4-733a-4c01-9846-70cfe49fde60','2026-06-09 08:02:38',NULL,'CREATE','COMPLETE','NovaComputeAnsibleHostVars','overcloud-Compute-cdqwojnpdfon-1-okxrswbqfhiu-NovaComputeAnsibleHostVars-kbuw2fsqn6wc','state changed','OS::Heat::Value',NULL,1121),(1835,'0568db3b-7cc2-4e9f-a144-cbd7124d19c8','bdf10cb4-906c-4a6a-bd1e-ad5302068629','2026-06-09 08:02:38',NULL,'CREATE','COMPLETE','overcloud-Compute-cdqwojnpdfon-1-okxrswbqfhiu-TenantPort-hhtogyzvl3yo','bdf10cb4-906c-4a6a-bd1e-ad5302068629','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1836,'4bc1f081-fe8e-400b-8dc7-5d37c2446979','f204995f-34fe-48eb-94a6-60f49b8e354a','2026-06-09 08:02:38',NULL,'CREATE','IN_PROGRESS','StorageDeployedPort','overcloud-Compute-cdqwojnpdfon-1-okxrswbqfhiu-StoragePort-icg6f4dotc2g-StorageDeployedPort-ne4f37mpya2h','state changed','OS::Heat::Value',NULL,1123),(1837,'385401ee-ec53-449d-a2d1-b442f9dfdae4','8bdfb034-9c39-44b2-beb6-93a25a0e25cc','2026-06-09 08:02:38',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-25-ef3lhrgx4ewv-MySQLClient-bn43d4tnrq6h','8bdfb034-9c39-44b2-beb6-93a25a0e25cc','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1838,'bee67653-ae6b-43a5-8ded-c6f578f4ff3d','f204995f-34fe-48eb-94a6-60f49b8e354a','2026-06-09 08:02:38',NULL,'CREATE','COMPLETE','StorageDeployedPort','overcloud-Compute-cdqwojnpdfon-1-okxrswbqfhiu-StoragePort-icg6f4dotc2g-StorageDeployedPort-ne4f37mpya2h','state changed','OS::Heat::Value',NULL,1123),(1839,'baf81734-23f3-4cf6-a3bd-27ee82d3f3d0','f204995f-34fe-48eb-94a6-60f49b8e354a','2026-06-09 08:02:38',NULL,'CREATE','COMPLETE','overcloud-Compute-cdqwojnpdfon-1-okxrswbqfhiu-StoragePort-icg6f4dotc2g','f204995f-34fe-48eb-94a6-60f49b8e354a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1840,'193f48a8-91bb-4acd-af33-e44db45e9d32','6ced9fc4-733a-4c01-9846-70cfe49fde60','2026-06-09 08:02:38',NULL,'CREATE','IN_PROGRESS','NodeExtraConfig','overcloud-Compute-cdqwojnpdfon-1-okxrswbqfhiu-NodeExtraConfig-o4cuhtnrbftm','state changed','OS::TripleO::NodeExtraConfig',NULL,1124),(1841,'79b67fb6-6ac8-418c-afa6-da6742aa125a','8bdfb034-9c39-44b2-beb6-93a25a0e25cc','2026-06-09 08:02:38',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-25-ef3lhrgx4ewv-MySQLClient-bn43d4tnrq6h','8bdfb034-9c39-44b2-beb6-93a25a0e25cc','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1842,'196c7199-fd47-428c-b33e-372df4137324','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:38',NULL,'CREATE','COMPLETE','20','14517033-4568-49cc-8603-cea0f6d1cac4','state changed','OS::TripleO::Services::Iscsid',NULL,1086),(1843,'3060c63f-d458-4bd0-aeab-c70764a024a2','34c7ae54-4092-401a-b3c7-0e6e4564a5e7','2026-06-09 08:02:38',NULL,'CREATE','IN_PROGRESS','InternalApiDeployedPort','overcloud-Compute-cdqwojnpdfon-1-okxrswbqfhiu-InternalApiPort-34redufa4u5t-InternalApiDeployedPort-7eipft4llfk2','state changed','OS::Heat::Value',NULL,1125),(1844,'91941bb6-4e2b-4aea-a0fd-60d315cb748e','c8cad023-7a3e-4742-a0d8-6b7ec8369a51','2026-06-09 08:02:38',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-cdqwojnpdfon-1-okxrswbqfhiu-NodeExtraConfig-o4cuhtnrbftm','c8cad023-7a3e-4742-a0d8-6b7ec8369a51','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1845,'e529aecc-f9fe-4cf0-a53c-892ab23c4e11','34c7ae54-4092-401a-b3c7-0e6e4564a5e7','2026-06-09 08:02:38',NULL,'CREATE','COMPLETE','InternalApiDeployedPort','overcloud-Compute-cdqwojnpdfon-1-okxrswbqfhiu-InternalApiPort-34redufa4u5t-InternalApiDeployedPort-7eipft4llfk2','state changed','OS::Heat::Value',NULL,1125),(1846,'d6fe405f-cbff-40e7-ba86-382608cdf4b6','34c7ae54-4092-401a-b3c7-0e6e4564a5e7','2026-06-09 08:02:38',NULL,'CREATE','COMPLETE','overcloud-Compute-cdqwojnpdfon-1-okxrswbqfhiu-InternalApiPort-34redufa4u5t','34c7ae54-4092-401a-b3c7-0e6e4564a5e7','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1847,'aab8123a-81f9-455b-806d-c2d2d2d7fb89','c8cad023-7a3e-4742-a0d8-6b7ec8369a51','2026-06-09 08:02:38',NULL,'CREATE','COMPLETE','overcloud-Compute-cdqwojnpdfon-1-okxrswbqfhiu-NodeExtraConfig-o4cuhtnrbftm','c8cad023-7a3e-4742-a0d8-6b7ec8369a51','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1848,'ffc02a0d-c918-428f-9db8-98e70b0b0ced','6ced9fc4-733a-4c01-9846-70cfe49fde60','2026-06-09 08:02:38',NULL,'CREATE','COMPLETE','NodeExtraConfig','c8cad023-7a3e-4742-a0d8-6b7ec8369a51','state changed','OS::TripleO::NodeExtraConfig',NULL,1124),(1849,'9f8f5bf2-6100-41e0-ad24-0c7895aca1f7','5efca393-e805-4157-957f-787c677298c9','2026-06-09 08:02:38',NULL,'CREATE','IN_PROGRESS','TLSProxyBase','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-31-mssug327vajy-TLSProxyBase-lxbwmul2obum','state changed','OS::TripleO::Services::TLSProxyBase',NULL,1128),(1850,'35b88ba0-098c-4e6c-828d-8f520f92ec74','8f9ec08a-62a7-48ef-9fb2-299b4d06ca54','2026-06-09 08:02:39',NULL,'CREATE','COMPLETE','ManilaShareContainerBase','30396c75-7af1-4669-8a3c-a070d50b9803','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-container-puppet.yaml',NULL,1045),(1851,'73fd1d1b-316a-4fd2-9fea-af010db022fd','8c1ddfd5-2f2a-4f46-a160-e5349296ed10','2026-06-09 08:02:39',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-31-mssug327vajy-TLSProxyBase-lxbwmul2obum','8c1ddfd5-2f2a-4f46-a160-e5349296ed10','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1852,'61a5322d-b3de-4f7c-849d-1dd1e631ef2a','5efca393-e805-4157-957f-787c677298c9','2026-06-09 08:02:39',NULL,'CREATE','COMPLETE','ContainersCommon','762a92e5-8993-4627-a762-4f4012b910c4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1853,'91ac6ebc-965a-4a17-ba18-2fae94b26933','6aa3e4a0-1e33-4f94-94b1-14ecc987144f','2026-06-09 08:02:39',NULL,'CREATE','COMPLETE','NovaCompute','2bfec2e3-03af-40ad-9d26-5945eb747ff1','state changed','OS::TripleO::ComputeServer',NULL,1060),(1854,'4aec53d4-ffaf-4dc9-85df-bf0ca69d5bc6','8f9ec08a-62a7-48ef-9fb2-299b4d06ca54','2026-06-09 08:02:39',NULL,'CREATE','COMPLETE','ContainersCommon','07d5a372-78cd-4846-885f-1c240bb61815','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1855,'956a479f-feca-4647-b043-746087b7f5cd','8c1ddfd5-2f2a-4f46-a160-e5349296ed10','2026-06-09 08:02:39',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-31-mssug327vajy-TLSProxyBase-lxbwmul2obum-ApacheNetworks-jx64bwozalpd','state changed','OS::Heat::Value',NULL,1130),(1856,'60a5ac6d-9731-4a43-8a69-f089b1aad169','8f9ec08a-62a7-48ef-9fb2-299b4d06ca54','2026-06-09 08:02:39',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-26-2abhkmchdo3h','8f9ec08a-62a7-48ef-9fb2-299b4d06ca54','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1857,'2a64cb32-934e-4b71-a24c-e430a4aa32a1','8c1ddfd5-2f2a-4f46-a160-e5349296ed10','2026-06-09 08:02:39',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-31-mssug327vajy-TLSProxyBase-lxbwmul2obum-ApacheNetworks-jx64bwozalpd','state changed','OS::Heat::Value',NULL,1130),(1858,'d1f8f218-8797-4efc-b548-492a6fbb8c30','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:39',NULL,'CREATE','IN_PROGRESS','24','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-24-qg6dlnjrkrbg','state changed','OS::TripleO::Services::ManilaBackendCephFs',NULL,1131),(1859,'bc065856-58d9-4616-8c2c-653d78364768','8c1ddfd5-2f2a-4f46-a160-e5349296ed10','2026-06-09 08:02:39',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-31-mssug327vajy-TLSProxyBase-lxbwmul2obum','8c1ddfd5-2f2a-4f46-a160-e5349296ed10','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1860,'855e8a1a-54e7-4aea-9f55-715217365de8','ddf23a8c-5258-4b47-9ee9-3c68b6558dfb','2026-06-09 08:02:39',NULL,'CREATE','COMPLETE','NetIpMap','89fd2248-7e1e-4fc9-8cc7-b7d9749ffd7f','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1110),(1861,'78c15b73-c210-4810-a156-1e6ad97148ea','ddf23a8c-5258-4b47-9ee9-3c68b6558dfb','2026-06-09 08:02:39',NULL,'CREATE','COMPLETE','overcloud-Compute-cdqwojnpdfon-2-5brbweb4w63v','ddf23a8c-5258-4b47-9ee9-3c68b6558dfb','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1862,'a53146da-f617-4720-be2e-2d6bf4a39379','126a95b2-a4a0-4f45-8e7b-83c4171f1c02','2026-06-09 08:02:39',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-24-qg6dlnjrkrbg','126a95b2-a4a0-4f45-8e7b-83c4171f1c02','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1863,'d3492dab-3900-4af7-b728-86fbbb12f3e8','6aa3e4a0-1e33-4f94-94b1-14ecc987144f','2026-06-09 08:02:39',NULL,'CREATE','IN_PROGRESS','NodeTLSCAData','overcloud-Compute-cdqwojnpdfon-0-ghnaey3kptkx-NodeTLSCAData-4nlp7o5fyots','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(1864,'a67e5997-43e8-4526-ac0a-e4c33915ce46','6aa3e4a0-1e33-4f94-94b1-14ecc987144f','2026-06-09 08:02:39',NULL,'CREATE','IN_PROGRESS','NetHostMap','overcloud-Compute-cdqwojnpdfon-0-ghnaey3kptkx-NetHostMap-fsuamueg66qp','state changed','OS::Heat::Value',NULL,1133),(1865,'b4f7abf5-e44e-4ae4-a559-7be6224c54bc','126a95b2-a4a0-4f45-8e7b-83c4171f1c02','2026-06-09 08:02:39',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-24-qg6dlnjrkrbg','126a95b2-a4a0-4f45-8e7b-83c4171f1c02','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1866,'3ddbd152-8afc-4b98-97a0-d77813928da1','6ced9fc4-733a-4c01-9846-70cfe49fde60','2026-06-09 08:02:39',NULL,'CREATE','COMPLETE','StoragePort','f204995f-34fe-48eb-94a6-60f49b8e354a','state changed','OS::TripleO::Compute::Ports::StoragePort',NULL,1114),(1867,'90a5d9f1-a676-4ccf-8c49-66ce87a3b387','6ced9fc4-733a-4c01-9846-70cfe49fde60','2026-06-09 08:02:39',NULL,'CREATE','COMPLETE','TenantPort','bdf10cb4-906c-4a6a-bd1e-ad5302068629','state changed','OS::TripleO::Compute::Ports::TenantPort',NULL,1112),(1868,'5c63e949-46a4-456c-a4c4-c1b9dd09e7fa','6aa3e4a0-1e33-4f94-94b1-14ecc987144f','2026-06-09 08:02:39',NULL,'CREATE','IN_PROGRESS','TenantPort','overcloud-Compute-cdqwojnpdfon-0-ghnaey3kptkx-TenantPort-telqeoajjeoa','state changed','OS::TripleO::Compute::Ports::TenantPort',NULL,1134),(1869,'df5e0b37-2cdb-4771-a571-de673e24f50c','6aa3e4a0-1e33-4f94-94b1-14ecc987144f','2026-06-09 08:02:39',NULL,'CREATE','IN_PROGRESS','InternalApiPort','overcloud-Compute-cdqwojnpdfon-0-ghnaey3kptkx-InternalApiPort-vu5hclwylgyy','state changed','OS::TripleO::Compute::Ports::InternalApiPort',NULL,1135),(1870,'cac1e669-8cd9-4236-b56d-3e83e29016bb','11a0ddfd-2d36-4d62-bb8b-5fc1f170e09f','2026-06-09 08:02:39',NULL,'CREATE','IN_PROGRESS','ManilaBase','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-25-ef3lhrgx4ewv-ManilaBase-3u5my536sbo3','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-base.yaml',NULL,1136),(1871,'3d193500-1d80-457b-bd60-cc972f166066','ccd5f3de-d0f7-46e0-81e7-5a3bb31845db','2026-06-09 08:02:39',NULL,'CREATE','COMPLETE','2','ddf23a8c-5258-4b47-9ee9-3c68b6558dfb','state changed','OS::TripleO::Compute',NULL,1026),(1872,'b250314a-d8dd-45a5-9c34-18572f927bad','6aa3e4a0-1e33-4f94-94b1-14ecc987144f','2026-06-09 08:02:39',NULL,'CREATE','COMPLETE','NetHostMap','overcloud-Compute-cdqwojnpdfon-0-ghnaey3kptkx-NetHostMap-fsuamueg66qp','state changed','OS::Heat::Value',NULL,1133),(1873,'dfb4e317-dbd7-4c3a-af0c-423f456853e6','6aa3e4a0-1e33-4f94-94b1-14ecc987144f','2026-06-09 08:02:39',NULL,'CREATE','COMPLETE','NodeTLSCAData','8d6d64df-88c9-4a51-8ea7-7fe20d62e7f2','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(1874,'f425df63-ba59-445a-b9f4-b60904162164','6ced9fc4-733a-4c01-9846-70cfe49fde60','2026-06-09 08:02:39',NULL,'CREATE','COMPLETE','InternalApiPort','34c7ae54-4092-401a-b3c7-0e6e4564a5e7','state changed','OS::TripleO::Compute::Ports::InternalApiPort',NULL,1117),(1875,'c722d3bd-e2be-4503-bee1-bcd3fe0d7a5e','6aa3e4a0-1e33-4f94-94b1-14ecc987144f','2026-06-09 08:02:39',NULL,'CREATE','IN_PROGRESS','ComputeExtraConfigPre','overcloud-Compute-cdqwojnpdfon-0-ghnaey3kptkx-ComputeExtraConfigPre-4t4jcodbp5gy','state changed','OS::TripleO::ComputeExtraConfigPre',NULL,1137),(1876,'1ec755aa-6368-43e4-b322-7509045a00aa','6aa3e4a0-1e33-4f94-94b1-14ecc987144f','2026-06-09 08:02:39',NULL,'CREATE','IN_PROGRESS','PreNetworkConfig','overcloud-Compute-cdqwojnpdfon-0-ghnaey3kptkx-PreNetworkConfig-p7o7fljlod54','state changed','OS::TripleO::Compute::PreNetworkConfig',NULL,NULL),(1877,'c579c7f0-5741-436e-9d09-a34635a726dd','11a0ddfd-2d36-4d62-bb8b-5fc1f170e09f','2026-06-09 08:02:39',NULL,'CREATE','COMPLETE','MySQLClient','8bdfb034-9c39-44b2-beb6-93a25a0e25cc','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1878,'2c5603ed-db43-489a-bafe-5088bf1461f4','6aa3e4a0-1e33-4f94-94b1-14ecc987144f','2026-06-09 08:02:39',NULL,'CREATE','IN_PROGRESS','StoragePort','overcloud-Compute-cdqwojnpdfon-0-ghnaey3kptkx-StoragePort-xyibb4shhalq','state changed','OS::TripleO::Compute::Ports::StoragePort',NULL,1141),(1879,'4fbeb3d2-3431-489a-a83a-8cff538462bc','1d3f4e0b-988d-479e-9bfe-1e8d3ab3ff47','2026-06-09 08:02:39',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-cdqwojnpdfon-0-ghnaey3kptkx-TenantPort-telqeoajjeoa','1d3f4e0b-988d-479e-9bfe-1e8d3ab3ff47','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1880,'7e992f7e-b9bb-49bf-b457-96c257e9697c','b750e04c-5bb1-4c70-a694-b9015e5aab4e','2026-06-09 08:02:39',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-25-ef3lhrgx4ewv-ManilaBase-3u5my536sbo3','b750e04c-5bb1-4c70-a694-b9015e5aab4e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1881,'a6185b99-57ca-4b83-9379-95835e16b61a','e3899a5c-9700-4609-bae5-c9d0482598d8','2026-06-09 08:02:39',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-cdqwojnpdfon-0-ghnaey3kptkx-StoragePort-xyibb4shhalq','e3899a5c-9700-4609-bae5-c9d0482598d8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1882,'3262c249-ba39-4c8c-a0bd-57b38494172b','9cdd3bc0-04fd-46bd-bcf1-49f6dd8e2acb','2026-06-09 08:02:39',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-cdqwojnpdfon-0-ghnaey3kptkx-InternalApiPort-vu5hclwylgyy','9cdd3bc0-04fd-46bd-bcf1-49f6dd8e2acb','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1883,'dc4eab56-c901-4799-beb1-5ffe9f94ecd3','6aa3e4a0-1e33-4f94-94b1-14ecc987144f','2026-06-09 08:02:39',NULL,'CREATE','IN_PROGRESS','NovaComputeAnsibleHostVars','overcloud-Compute-cdqwojnpdfon-0-ghnaey3kptkx-NovaComputeAnsibleHostVars-sk3w5amt5tcj','state changed','OS::Heat::Value',NULL,1145),(1884,'dc38f6c2-1cc4-4dbc-a3d4-f9e8acaa66ab','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:39',NULL,'CREATE','COMPLETE','26','8f9ec08a-62a7-48ef-9fb2-299b4d06ca54','state changed','OS::TripleO::Services::ManilaShare',NULL,1041),(1885,'9e3d09d1-783b-4c8f-a492-fc11ab8c0315','ef028749-9e51-41a3-a400-e13898fd7b1e','2026-06-09 08:02:39',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-cdqwojnpdfon-0-ghnaey3kptkx-ComputeExtraConfigPre-4t4jcodbp5gy','ef028749-9e51-41a3-a400-e13898fd7b1e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1886,'c441c5bc-d9e1-4aae-8f49-7cb8b2bde243','b750e04c-5bb1-4c70-a694-b9015e5aab4e','2026-06-09 08:02:39',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-25-ef3lhrgx4ewv-ManilaBase-3u5my536sbo3','b750e04c-5bb1-4c70-a694-b9015e5aab4e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1887,'f0677797-d1e3-4f31-9f4c-be9bbcbd8ed6','6aa3e4a0-1e33-4f94-94b1-14ecc987144f','2026-06-09 08:02:39',NULL,'CREATE','COMPLETE','NovaComputeAnsibleHostVars','overcloud-Compute-cdqwojnpdfon-0-ghnaey3kptkx-NovaComputeAnsibleHostVars-sk3w5amt5tcj','state changed','OS::Heat::Value',NULL,1145),(1888,'74ca3e0c-62a6-47a5-b03c-d57611dc0ed6','6ced9fc4-733a-4c01-9846-70cfe49fde60','2026-06-09 08:02:39',NULL,'CREATE','IN_PROGRESS','NetIpMap','overcloud-Compute-cdqwojnpdfon-1-okxrswbqfhiu-NetIpMap-vzla5hgfhiiy','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1147),(1889,'f2d14ee1-b621-4f1a-8b07-5d4f29445c15','e3899a5c-9700-4609-bae5-c9d0482598d8','2026-06-09 08:02:39',NULL,'CREATE','IN_PROGRESS','StorageDeployedPort','overcloud-Compute-cdqwojnpdfon-0-ghnaey3kptkx-StoragePort-xyibb4shhalq-StorageDeployedPort-oyqeo3hx67v3','state changed','OS::Heat::Value',NULL,1148),(1890,'01b74d63-52d0-47c4-9930-f3b5fb7c6fb0','e3899a5c-9700-4609-bae5-c9d0482598d8','2026-06-09 08:02:39',NULL,'CREATE','COMPLETE','StorageDeployedPort','overcloud-Compute-cdqwojnpdfon-0-ghnaey3kptkx-StoragePort-xyibb4shhalq-StorageDeployedPort-oyqeo3hx67v3','state changed','OS::Heat::Value',NULL,1148),(1891,'710ab317-7e1c-4508-a00c-a8de0ecf334e','6aa3e4a0-1e33-4f94-94b1-14ecc987144f','2026-06-09 08:02:39',NULL,'CREATE','COMPLETE','PreNetworkConfig','303b7a4e-e9b2-416e-acc6-b2769d63feb3','state changed','OS::TripleO::Compute::PreNetworkConfig',NULL,NULL),(1892,'23ca67cb-89c3-436c-b17f-d88ebed0cdb4','e3899a5c-9700-4609-bae5-c9d0482598d8','2026-06-09 08:02:39',NULL,'CREATE','COMPLETE','overcloud-Compute-cdqwojnpdfon-0-ghnaey3kptkx-StoragePort-xyibb4shhalq','e3899a5c-9700-4609-bae5-c9d0482598d8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1893,'2146ae54-27fe-4937-a29f-62f44103bcbb','86ae3ce4-8c13-4d9d-bd2c-239b050957c9','2026-06-09 08:02:39',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-cdqwojnpdfon-1-okxrswbqfhiu-NetIpMap-vzla5hgfhiiy','86ae3ce4-8c13-4d9d-bd2c-239b050957c9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1894,'37597d8a-75a4-4cd3-9255-1f11210c9394','5efca393-e805-4157-957f-787c677298c9','2026-06-09 08:02:39',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-31-mssug327vajy-MySQLClient-la2qdtcyqavx','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1895,'4ff2862a-24df-4175-872f-d3c868f55806','4208d6d2-53b2-4687-ac50-8f201888226e','2026-06-09 08:02:39',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-31-mssug327vajy-MySQLClient-la2qdtcyqavx','4208d6d2-53b2-4687-ac50-8f201888226e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1896,'6ea82813-1934-41ee-9fc2-2e8f6794aa1b','4208d6d2-53b2-4687-ac50-8f201888226e','2026-06-09 08:02:40',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-31-mssug327vajy-MySQLClient-la2qdtcyqavx','4208d6d2-53b2-4687-ac50-8f201888226e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1897,'18ef8107-f993-430e-a245-5491848714d2','86ae3ce4-8c13-4d9d-bd2c-239b050957c9','2026-06-09 08:02:40',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-Compute-cdqwojnpdfon-1-okxrswbqfhiu-NetIpMap-vzla5hgfhiiy-NetIpMapValue-ohu6277awmm4','state changed','OS::Heat::Value',NULL,1151),(1898,'ffc753f9-f899-482d-bb43-29f865e802c4','1d3f4e0b-988d-479e-9bfe-1e8d3ab3ff47','2026-06-09 08:02:40',NULL,'CREATE','IN_PROGRESS','TenantDeployedPort','overcloud-Compute-cdqwojnpdfon-0-ghnaey3kptkx-TenantPort-telqeoajjeoa-TenantDeployedPort-mqzhzgwvcnka','state changed','OS::Heat::Value',NULL,1150),(1899,'7ac6cd10-da57-431d-9fe1-755a7aef3095','86ae3ce4-8c13-4d9d-bd2c-239b050957c9','2026-06-09 08:02:40',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-Compute-cdqwojnpdfon-1-okxrswbqfhiu-NetIpMap-vzla5hgfhiiy-NetIpMapValue-ohu6277awmm4','state changed','OS::Heat::Value',NULL,1151),(1900,'4111737e-938b-48ea-a40b-b98f932441af','ef028749-9e51-41a3-a400-e13898fd7b1e','2026-06-09 08:02:40',NULL,'CREATE','COMPLETE','overcloud-Compute-cdqwojnpdfon-0-ghnaey3kptkx-ComputeExtraConfigPre-4t4jcodbp5gy','ef028749-9e51-41a3-a400-e13898fd7b1e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1901,'89e86475-9a87-45ed-913a-2a51674f6871','86ae3ce4-8c13-4d9d-bd2c-239b050957c9','2026-06-09 08:02:40',NULL,'CREATE','COMPLETE','overcloud-Compute-cdqwojnpdfon-1-okxrswbqfhiu-NetIpMap-vzla5hgfhiiy','86ae3ce4-8c13-4d9d-bd2c-239b050957c9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1902,'01cacbca-42c8-44aa-8d09-2e222516f7a7','5efca393-e805-4157-957f-787c677298c9','2026-06-09 08:02:40',NULL,'CREATE','COMPLETE','TLSProxyBase','8c1ddfd5-2f2a-4f46-a160-e5349296ed10','state changed','OS::TripleO::Services::TLSProxyBase',NULL,1128),(1903,'18cb0dab-3be6-4d21-9ef9-a297ef60788b','1d3f4e0b-988d-479e-9bfe-1e8d3ab3ff47','2026-06-09 08:02:40',NULL,'CREATE','COMPLETE','TenantDeployedPort','overcloud-Compute-cdqwojnpdfon-0-ghnaey3kptkx-TenantPort-telqeoajjeoa-TenantDeployedPort-mqzhzgwvcnka','state changed','OS::Heat::Value',NULL,1150),(1904,'447ac0bc-150b-433d-89c4-dfae0f9c95e9','1d3f4e0b-988d-479e-9bfe-1e8d3ab3ff47','2026-06-09 08:02:40',NULL,'CREATE','COMPLETE','overcloud-Compute-cdqwojnpdfon-0-ghnaey3kptkx-TenantPort-telqeoajjeoa','1d3f4e0b-988d-479e-9bfe-1e8d3ab3ff47','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1905,'8d80a11a-401a-4cfe-86e9-9bbb5a81be9f','9cdd3bc0-04fd-46bd-bcf1-49f6dd8e2acb','2026-06-09 08:02:40',NULL,'CREATE','IN_PROGRESS','InternalApiDeployedPort','overcloud-Compute-cdqwojnpdfon-0-ghnaey3kptkx-InternalApiPort-vu5hclwylgyy-InternalApiDeployedPort-w7iaw2ojigu3','state changed','OS::Heat::Value',NULL,1155),(1906,'d2f0e44f-6248-44ca-a482-9c3c5855bc46','9cdd3bc0-04fd-46bd-bcf1-49f6dd8e2acb','2026-06-09 08:02:40',NULL,'CREATE','COMPLETE','InternalApiDeployedPort','overcloud-Compute-cdqwojnpdfon-0-ghnaey3kptkx-InternalApiPort-vu5hclwylgyy-InternalApiDeployedPort-w7iaw2ojigu3','state changed','OS::Heat::Value',NULL,1155),(1907,'46f69948-e3ce-4395-8f7b-9d35eb834e10','9cdd3bc0-04fd-46bd-bcf1-49f6dd8e2acb','2026-06-09 08:02:40',NULL,'CREATE','COMPLETE','overcloud-Compute-cdqwojnpdfon-0-ghnaey3kptkx-InternalApiPort-vu5hclwylgyy','9cdd3bc0-04fd-46bd-bcf1-49f6dd8e2acb','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1908,'1b59ecfb-e483-4975-a441-f3a8a2ea3af2','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:40',NULL,'CREATE','COMPLETE','24','126a95b2-a4a0-4f45-8e7b-83c4171f1c02','state changed','OS::TripleO::Services::ManilaBackendCephFs',NULL,1131),(1909,'9dff9b21-1a12-438d-b8e2-a9eedd8e07a8','11a0ddfd-2d36-4d62-bb8b-5fc1f170e09f','2026-06-09 08:02:40',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-25-ef3lhrgx4ewv-ContainersCommon-kovgp2tehhvf','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1910,'a82e347a-ed69-4191-847f-90983d429f68','ea4fe098-f00a-4a72-9298-f646eb5a17ad','2026-06-09 08:02:40',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-25-ef3lhrgx4ewv-ContainersCommon-kovgp2tehhvf','ea4fe098-f00a-4a72-9298-f646eb5a17ad','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1911,'1a71ca2c-4821-41ca-b7c1-9dee0efcac35','ea4fe098-f00a-4a72-9298-f646eb5a17ad','2026-06-09 08:02:40',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-25-ef3lhrgx4ewv-ContainersCommon-kovgp2tehhvf','ea4fe098-f00a-4a72-9298-f646eb5a17ad','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1912,'3080100d-1b5a-4ab3-93c8-e96831f73023','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:40',NULL,'CREATE','IN_PROGRESS','28','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-28-2tkgibe4fc6g','state changed','OS::TripleO::Services::MetricsQdr',NULL,1167),(1913,'9953899c-1673-4f6b-99e6-45c9e0d56b76','6aa3e4a0-1e33-4f94-94b1-14ecc987144f','2026-06-09 08:02:40',NULL,'CREATE','COMPLETE','TenantPort','1d3f4e0b-988d-479e-9bfe-1e8d3ab3ff47','state changed','OS::TripleO::Compute::Ports::TenantPort',NULL,1134),(1914,'56dbf077-1fbf-41d3-af7b-df2369bbd16a','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:40',NULL,'CREATE','IN_PROGRESS','30','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-30-neweezr2wsok','state changed','OS::TripleO::Services::MySQLClient',NULL,1168),(1915,'d29b23d9-c53c-4bd6-84f9-1a0279cacdea','11a0ddfd-2d36-4d62-bb8b-5fc1f170e09f','2026-06-09 08:02:40',NULL,'CREATE','COMPLETE','ManilaBase','b750e04c-5bb1-4c70-a694-b9015e5aab4e','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-base.yaml',NULL,1136),(1916,'0b9279aa-1f94-43f1-94d9-3ec16c77ae63','6aa3e4a0-1e33-4f94-94b1-14ecc987144f','2026-06-09 08:02:40',NULL,'CREATE','COMPLETE','StoragePort','e3899a5c-9700-4609-bae5-c9d0482598d8','state changed','OS::TripleO::Compute::Ports::StoragePort',NULL,1141),(1917,'6728919c-2d85-4be0-94f8-6cd39e0384b6','78418e93-b7ef-4927-96a3-d1f7c78b654e','2026-06-09 08:02:40',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-30-neweezr2wsok','78418e93-b7ef-4927-96a3-d1f7c78b654e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1918,'e2ba1ae9-24c4-4b4a-9ba6-8e1ea696860d','61b74164-174f-45f4-946f-b96d6133142b','2026-06-09 08:02:40',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-28-2tkgibe4fc6g','61b74164-174f-45f4-946f-b96d6133142b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1919,'c3420745-8253-4cd1-911e-5bcda8626a8d','78418e93-b7ef-4927-96a3-d1f7c78b654e','2026-06-09 08:02:40',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-30-neweezr2wsok','78418e93-b7ef-4927-96a3-d1f7c78b654e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1920,'63edaab9-3d55-4c2e-801e-bd3b83806788','6aa3e4a0-1e33-4f94-94b1-14ecc987144f','2026-06-09 08:02:40',NULL,'CREATE','COMPLETE','ComputeExtraConfigPre','ef028749-9e51-41a3-a400-e13898fd7b1e','state changed','OS::TripleO::ComputeExtraConfigPre',NULL,1137),(1921,'780e424a-f385-4561-97e1-99040e93edfd','6aa3e4a0-1e33-4f94-94b1-14ecc987144f','2026-06-09 08:02:40',NULL,'CREATE','COMPLETE','InternalApiPort','9cdd3bc0-04fd-46bd-bcf1-49f6dd8e2acb','state changed','OS::TripleO::Compute::Ports::InternalApiPort',NULL,1135),(1922,'9403ed1c-2057-45ee-9cae-d8a6ac6080bc','5efca393-e805-4157-957f-787c677298c9','2026-06-09 08:02:40',NULL,'CREATE','IN_PROGRESS','NeutronLogging','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-31-mssug327vajy-NeutronLogging-mbz5ghsy5atk','state changed','OS::TripleO::Services::Logging::NeutronApi',NULL,1172),(1923,'05ce50ef-e93a-48b4-b34b-4ba7ebe7b2ec','6ced9fc4-733a-4c01-9846-70cfe49fde60','2026-06-09 08:02:40',NULL,'CREATE','COMPLETE','NetIpMap','86ae3ce4-8c13-4d9d-bd2c-239b050957c9','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1147),(1924,'bf7712e6-3c14-46f4-9404-f187679adbbb','6ced9fc4-733a-4c01-9846-70cfe49fde60','2026-06-09 08:02:41',NULL,'CREATE','COMPLETE','overcloud-Compute-cdqwojnpdfon-1-okxrswbqfhiu','6ced9fc4-733a-4c01-9846-70cfe49fde60','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1925,'74dca3c6-36db-40e1-a51a-46f8cb8406ce','6aa3e4a0-1e33-4f94-94b1-14ecc987144f','2026-06-09 08:02:41',NULL,'CREATE','IN_PROGRESS','NodeExtraConfig','overcloud-Compute-cdqwojnpdfon-0-ghnaey3kptkx-NodeExtraConfig-wnvn64cmkwmt','state changed','OS::TripleO::NodeExtraConfig',NULL,1175),(1926,'03b89cdd-5933-4e6d-931e-70479d7c81ed','5efca393-e805-4157-957f-787c677298c9','2026-06-09 08:02:41',NULL,'CREATE','COMPLETE','MySQLClient','4208d6d2-53b2-4687-ac50-8f201888226e','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1927,'155f6687-cb69-4419-bfbd-4612045a5f03','e4f291de-bca9-4d98-a4c6-4bc831cbff42','2026-06-09 08:02:41',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-31-mssug327vajy-NeutronLogging-mbz5ghsy5atk','e4f291de-bca9-4d98-a4c6-4bc831cbff42','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1928,'031afa9e-d307-4e3a-8866-e5f4aa1bfb51','61b74164-174f-45f4-946f-b96d6133142b','2026-06-09 08:02:41',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-28-2tkgibe4fc6g-ContainersCommon-bmemykhzytix','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1929,'82f45b50-df03-4097-8e44-eca5d9218dd7','6aa3e4a0-1e33-4f94-94b1-14ecc987144f','2026-06-09 08:02:41',NULL,'CREATE','IN_PROGRESS','NetIpMap','overcloud-Compute-cdqwojnpdfon-0-ghnaey3kptkx-NetIpMap-qtt6xedw3xov','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1178),(1930,'cdd5bef6-c2fa-4567-9d53-29145662d719','458e209e-5118-4972-a026-3bdb8aae2c87','2026-06-09 08:02:41',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-cdqwojnpdfon-0-ghnaey3kptkx-NodeExtraConfig-wnvn64cmkwmt','458e209e-5118-4972-a026-3bdb8aae2c87','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1931,'b70530bf-002b-4458-828f-01e5f53cd58d','458e209e-5118-4972-a026-3bdb8aae2c87','2026-06-09 08:02:41',NULL,'CREATE','COMPLETE','overcloud-Compute-cdqwojnpdfon-0-ghnaey3kptkx-NodeExtraConfig-wnvn64cmkwmt','458e209e-5118-4972-a026-3bdb8aae2c87','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1932,'0daeaa0a-d93d-4ea4-a1b8-b51a117338c6','e4f291de-bca9-4d98-a4c6-4bc831cbff42','2026-06-09 08:02:41',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-31-mssug327vajy-NeutronLogging-mbz5ghsy5atk-RoleParametersValue-v6gggqg4v7dn','state changed','OS::Heat::Value',NULL,1179),(1933,'6f1bf1ba-9c3f-4646-bca7-b1d72bb3b25b','7e745e8e-aa11-46cc-ab2d-38d32d5cabb0','2026-06-09 08:02:41',NULL,'CREATE','IN_PROGRESS','overcloud-Compute-cdqwojnpdfon-0-ghnaey3kptkx-NetIpMap-qtt6xedw3xov','7e745e8e-aa11-46cc-ab2d-38d32d5cabb0','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1934,'57a7dca1-d963-45c9-ba48-087b649f494f','e4f291de-bca9-4d98-a4c6-4bc831cbff42','2026-06-09 08:02:41',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-31-mssug327vajy-NeutronLogging-mbz5ghsy5atk-RoleParametersValue-v6gggqg4v7dn','state changed','OS::Heat::Value',NULL,1179),(1935,'934234f4-9708-4fd1-856f-ba30e9a6645e','f697f8d8-217a-4a66-b4cd-985c106fbf9d','2026-06-09 08:02:41',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-28-2tkgibe4fc6g-ContainersCommon-bmemykhzytix','f697f8d8-217a-4a66-b4cd-985c106fbf9d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1936,'45a13d99-7172-4002-99d3-49a6489ba2dc','e4f291de-bca9-4d98-a4c6-4bc831cbff42','2026-06-09 08:02:41',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-31-mssug327vajy-NeutronLogging-mbz5ghsy5atk','e4f291de-bca9-4d98-a4c6-4bc831cbff42','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1937,'2c2e5641-dd31-4b9e-97c9-2dd1be10ffb6','f697f8d8-217a-4a66-b4cd-985c106fbf9d','2026-06-09 08:02:41',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-28-2tkgibe4fc6g-ContainersCommon-bmemykhzytix','f697f8d8-217a-4a66-b4cd-985c106fbf9d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1938,'a8706f4f-3024-4c29-bedb-05f6651c9650','7e745e8e-aa11-46cc-ab2d-38d32d5cabb0','2026-06-09 08:02:41',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-Compute-cdqwojnpdfon-0-ghnaey3kptkx-NetIpMap-qtt6xedw3xov-NetIpMapValue-2xqdp4afs625','state changed','OS::Heat::Value',NULL,1180),(1939,'b6c16c34-6bb4-480a-be3e-9d1f40acc1f8','7e745e8e-aa11-46cc-ab2d-38d32d5cabb0','2026-06-09 08:02:41',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-Compute-cdqwojnpdfon-0-ghnaey3kptkx-NetIpMap-qtt6xedw3xov-NetIpMapValue-2xqdp4afs625','state changed','OS::Heat::Value',NULL,1180),(1940,'54adb7c2-52aa-45ec-aae1-30c5049846fd','7e745e8e-aa11-46cc-ab2d-38d32d5cabb0','2026-06-09 08:02:41',NULL,'CREATE','COMPLETE','overcloud-Compute-cdqwojnpdfon-0-ghnaey3kptkx-NetIpMap-qtt6xedw3xov','7e745e8e-aa11-46cc-ab2d-38d32d5cabb0','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1941,'a5f3359d-dbd7-44ba-a073-352b2dc3752b','11a0ddfd-2d36-4d62-bb8b-5fc1f170e09f','2026-06-09 08:02:41',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-25-ef3lhrgx4ewv-RoleParametersValue-sluxw74z5saw','state changed','OS::Heat::Value',NULL,1181),(1942,'8fff6fc0-6933-43b1-acca-36cdaedde83d','11a0ddfd-2d36-4d62-bb8b-5fc1f170e09f','2026-06-09 08:02:41',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-25-ef3lhrgx4ewv-RoleParametersValue-sluxw74z5saw','state changed','OS::Heat::Value',NULL,1181),(1943,'89360591-0dea-406a-919d-0e3c543b335f','ccd5f3de-d0f7-46e0-81e7-5a3bb31845db','2026-06-09 08:02:41',NULL,'CREATE','COMPLETE','1','6ced9fc4-733a-4c01-9846-70cfe49fde60','state changed','OS::TripleO::Compute',NULL,1039),(1944,'450a64ea-8146-414e-a366-8304ef350e15','11a0ddfd-2d36-4d62-bb8b-5fc1f170e09f','2026-06-09 08:02:41',NULL,'CREATE','COMPLETE','ContainersCommon','ea4fe098-f00a-4a72-9298-f646eb5a17ad','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1945,'fe4b9e54-02d1-4905-ace8-7b9c5a583108','11a0ddfd-2d36-4d62-bb8b-5fc1f170e09f','2026-06-09 08:02:41',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-25-ef3lhrgx4ewv','11a0ddfd-2d36-4d62-bb8b-5fc1f170e09f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1946,'aecb95bd-d7ba-468c-8a43-508be7a61e03','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:41',NULL,'CREATE','COMPLETE','30','78418e93-b7ef-4927-96a3-d1f7c78b654e','state changed','OS::TripleO::Services::MySQLClient',NULL,1168),(1947,'ab07d103-ef01-4dc3-a1f8-84192036169a','5efca393-e805-4157-957f-787c677298c9','2026-06-09 08:02:42',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-31-mssug327vajy-RoleParametersValue-nqxiulo22pla','state changed','OS::Heat::Value',NULL,1182),(1948,'d4122a0a-d5a7-4d24-89e7-488ecaaf7eb4','5efca393-e805-4157-957f-787c677298c9','2026-06-09 08:02:42',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-31-mssug327vajy-RoleParametersValue-nqxiulo22pla','state changed','OS::Heat::Value',NULL,1182),(1949,'96e19d69-fec0-47f9-bdf8-9536f623e716','5efca393-e805-4157-957f-787c677298c9','2026-06-09 08:02:42',NULL,'CREATE','COMPLETE','NeutronLogging','e4f291de-bca9-4d98-a4c6-4bc831cbff42','state changed','OS::TripleO::Services::Logging::NeutronApi',NULL,1172),(1950,'a2e811c6-79b6-4014-b7f3-d4368e1a68fb','61b74164-174f-45f4-946f-b96d6133142b','2026-06-09 08:02:42',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-28-2tkgibe4fc6g-RoleParametersValue-qpnqb6hmtd6c','state changed','OS::Heat::Value',NULL,1184),(1951,'47e43cde-e1db-40b6-ad89-9e8755b10498','5efca393-e805-4157-957f-787c677298c9','2026-06-09 08:02:42',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-31-mssug327vajy','5efca393-e805-4157-957f-787c677298c9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1952,'2e4c910c-eb0b-45c4-89e7-a679f3a05975','61b74164-174f-45f4-946f-b96d6133142b','2026-06-09 08:02:42',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-28-2tkgibe4fc6g-RoleParametersValue-qpnqb6hmtd6c','state changed','OS::Heat::Value',NULL,1184),(1953,'e189db4c-95fe-4fde-b1b0-a9de18c655b7','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:42',NULL,'CREATE','COMPLETE','25','11a0ddfd-2d36-4d62-bb8b-5fc1f170e09f','state changed','OS::TripleO::Services::ManilaScheduler',NULL,1109),(1954,'60f20688-5bb7-47c2-b49c-944d4a81107a','6aa3e4a0-1e33-4f94-94b1-14ecc987144f','2026-06-09 08:02:42',NULL,'CREATE','COMPLETE','NetIpMap','7e745e8e-aa11-46cc-ab2d-38d32d5cabb0','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1178),(1955,'d2a6667e-fed7-45d7-aa76-d76bb33c4255','6aa3e4a0-1e33-4f94-94b1-14ecc987144f','2026-06-09 08:02:42',NULL,'CREATE','COMPLETE','NodeExtraConfig','458e209e-5118-4972-a026-3bdb8aae2c87','state changed','OS::TripleO::NodeExtraConfig',NULL,1175),(1956,'5d4063cf-8f69-4015-88a6-46d3264216b3','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:42',NULL,'CREATE','IN_PROGRESS','34','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-34-7hhwrev4q2ai','state changed','OS::TripleO::Services::NovaConductor',NULL,1185),(1957,'e4256042-19f8-41b6-98ac-8533b50032b8','6aa3e4a0-1e33-4f94-94b1-14ecc987144f','2026-06-09 08:02:42',NULL,'CREATE','COMPLETE','overcloud-Compute-cdqwojnpdfon-0-ghnaey3kptkx','6aa3e4a0-1e33-4f94-94b1-14ecc987144f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1958,'106ac867-056b-4ef1-80db-8700ebb1de88','61b74164-174f-45f4-946f-b96d6133142b','2026-06-09 08:02:42',NULL,'CREATE','COMPLETE','ContainersCommon','f697f8d8-217a-4a66-b4cd-985c106fbf9d','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1959,'5aee7048-817e-4d42-b6f0-c8716187f5a4','61b74164-174f-45f4-946f-b96d6133142b','2026-06-09 08:02:42',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-28-2tkgibe4fc6g','61b74164-174f-45f4-946f-b96d6133142b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1960,'c561c2a7-9daf-4b6a-8737-db4eb6fe9d77','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:42',NULL,'CREATE','COMPLETE','31','5efca393-e805-4157-957f-787c677298c9','state changed','OS::TripleO::Services::NeutronApi',NULL,1072),(1961,'0f40b4d2-a53d-4ef2-b150-c88da83b6634','45567243-d61c-4212-8ac9-537d13017e03','2026-06-09 08:02:42',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-34-7hhwrev4q2ai','45567243-d61c-4212-8ac9-537d13017e03','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1962,'944dd574-74a0-4ed8-92f0-23ba99e242fb','ccd5f3de-d0f7-46e0-81e7-5a3bb31845db','2026-06-09 08:02:42',NULL,'CREATE','COMPLETE','0','6aa3e4a0-1e33-4f94-94b1-14ecc987144f','state changed','OS::TripleO::Compute',NULL,1049),(1963,'5304a3d2-426a-463a-91b3-d5384b4e4876','ccd5f3de-d0f7-46e0-81e7-5a3bb31845db','2026-06-09 08:02:42',NULL,'UPDATE','COMPLETE','overcloud-Compute-cdqwojnpdfon','ccd5f3de-d0f7-46e0-81e7-5a3bb31845db','Stack UPDATE completed successfully','OS::Heat::Stack',NULL,NULL),(1964,'88cc8924-1783-436d-a3e1-0f3f2f311a6e','45567243-d61c-4212-8ac9-537d13017e03','2026-06-09 08:02:42',NULL,'CREATE','IN_PROGRESS','NovaApiDBClient','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-34-7hhwrev4q2ai-NovaApiDBClient-s7s7dxqltsf7','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml',NULL,1193),(1965,'531b3a30-9ff2-4974-8e55-edf4307c2f8f','b6e51439-2bbf-4642-912d-fd10ebf28d37','2026-06-09 08:02:42',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-34-7hhwrev4q2ai-NovaApiDBClient-s7s7dxqltsf7','b6e51439-2bbf-4642-912d-fd10ebf28d37','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1966,'ad672f4c-5745-49b0-8ac1-9746ea83245d','b6e51439-2bbf-4642-912d-fd10ebf28d37','2026-06-09 08:02:42',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-34-7hhwrev4q2ai-NovaApiDBClient-s7s7dxqltsf7','b6e51439-2bbf-4642-912d-fd10ebf28d37','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1967,'d05ad522-e24d-445b-a124-3befc7b7e338','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:42',NULL,'CREATE','IN_PROGRESS','29','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-29-xzweaopjyubb','state changed','OS::TripleO::Services::MySQL',NULL,1194),(1968,'4fd1e51a-bacf-4f2a-96f6-1044e01ec96a','4859ef51-4e76-4098-963b-ec51962038c1','2026-06-09 08:02:42',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-29-xzweaopjyubb','4859ef51-4e76-4098-963b-ec51962038c1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1969,'b747aa65-c2ff-42f4-8253-4a330950b5d5','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:42',NULL,'CREATE','COMPLETE','28','61b74164-174f-45f4-946f-b96d6133142b','state changed','OS::TripleO::Services::MetricsQdr',NULL,1167),(1970,'4e8387f7-c585-435a-82f1-68d3683feef2','4859ef51-4e76-4098-963b-ec51962038c1','2026-06-09 08:02:43',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-29-xzweaopjyubb-ContainersCommon-3homblbmdtgz','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1971,'5f3866d5-9a1b-4fb0-8391-0d66612c4c8d','be3c7a51-12b1-425f-8e98-92495dea9c0e','2026-06-09 08:02:43',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-29-xzweaopjyubb-ContainersCommon-3homblbmdtgz','be3c7a51-12b1-425f-8e98-92495dea9c0e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1972,'0c25b895-7655-4510-b4a0-e4a7cfa0e466','be3c7a51-12b1-425f-8e98-92495dea9c0e','2026-06-09 08:02:43',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-29-xzweaopjyubb-ContainersCommon-3homblbmdtgz','be3c7a51-12b1-425f-8e98-92495dea9c0e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1973,'f68cd6e1-e21a-4d3e-8517-fb6cb569fd5f','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:43',NULL,'CREATE','IN_PROGRESS','35','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-35-i6huwjv4fmzm','state changed','OS::TripleO::Services::NovaMetadata',NULL,1203),(1974,'7baa4e9c-19b6-406f-9bd0-f20063cb79b5','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:02:43',NULL,'CREATE','COMPLETE','Compute','ccd5f3de-d0f7-46e0-81e7-5a3bb31845db','state changed','OS::Heat::ResourceGroup',NULL,1018),(1975,'34538ca4-d9e7-4273-9997-7d6760242c15','946cb619-c679-4692-b834-7f2e005736b8','2026-06-09 08:02:43',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-35-i6huwjv4fmzm','946cb619-c679-4692-b834-7f2e005736b8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1976,'de044c4f-785d-4fce-91ff-1fc7c6e83a50','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:43',NULL,'CREATE','IN_PROGRESS','32','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-32-pohygagpdz4f','state changed','OS::TripleO::Services::NeutronCorePlugin',NULL,1206),(1977,'258d3476-b4f4-4530-9d29-86c8cbd3e66d','946cb619-c679-4692-b834-7f2e005736b8','2026-06-09 08:02:43',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-35-i6huwjv4fmzm-MySQLClient-5fp42njxz66p','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(1978,'8adacff4-2245-480d-a0a8-b11ee785aaf7','45567243-d61c-4212-8ac9-537d13017e03','2026-06-09 08:02:43',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-34-7hhwrev4q2ai-RoleParametersValue-73dxg2zj4mrx','state changed','OS::Heat::Value',NULL,1212),(1979,'096cbbef-6b95-4e72-9a81-b42d07ba1c95','208db2cd-8593-4ada-b9b7-7fb03a00cab4','2026-06-09 08:02:43',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-32-pohygagpdz4f','208db2cd-8593-4ada-b9b7-7fb03a00cab4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1980,'61367bb3-6abc-4b9a-8839-8a2a13392b5c','45567243-d61c-4212-8ac9-537d13017e03','2026-06-09 08:02:43',NULL,'CREATE','COMPLETE','NovaApiDBClient','b6e51439-2bbf-4642-912d-fd10ebf28d37','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml',NULL,1193),(1981,'e7a6e6f5-3149-425e-9eb0-f4613f4f3d7f','ec5c4857-74b7-41f5-8301-1b4ce6e733ce','2026-06-09 08:02:43',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-35-i6huwjv4fmzm-MySQLClient-5fp42njxz66p','ec5c4857-74b7-41f5-8301-1b4ce6e733ce','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1982,'f8ee0775-3cc3-4481-abb5-e67599c20060','45567243-d61c-4212-8ac9-537d13017e03','2026-06-09 08:02:43',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-34-7hhwrev4q2ai-RoleParametersValue-73dxg2zj4mrx','state changed','OS::Heat::Value',NULL,1212),(1983,'3eddff8e-61ed-439e-a262-45c99eb237c4','4859ef51-4e76-4098-963b-ec51962038c1','2026-06-09 08:02:44',NULL,'CREATE','IN_PROGRESS','MysqlBase','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-29-xzweaopjyubb-MysqlBase-s2u7alrgfvap','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-base.yaml',NULL,1215),(1984,'26fe96f5-bb63-47a8-9f6f-8dd3a1f9d4d6','4859ef51-4e76-4098-963b-ec51962038c1','2026-06-09 08:02:44',NULL,'CREATE','COMPLETE','ContainersCommon','be3c7a51-12b1-425f-8e98-92495dea9c0e','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(1985,'733902b3-ade0-4f0b-86ea-9da1f7ec601c','ec5c4857-74b7-41f5-8301-1b4ce6e733ce','2026-06-09 08:02:44',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-35-i6huwjv4fmzm-MySQLClient-5fp42njxz66p','ec5c4857-74b7-41f5-8301-1b4ce6e733ce','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1986,'a9007f72-5e0b-4279-800d-de7b62689a12','208db2cd-8593-4ada-b9b7-7fb03a00cab4','2026-06-09 08:02:44',NULL,'CREATE','IN_PROGRESS','NeutronBase','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-32-pohygagpdz4f-NeutronBase-uixpawor7flb','state changed','OS::TripleO::Services::NeutronMl2PluginBase',NULL,1218),(1987,'31721f01-6ff6-41ce-a2c7-13e66e0160e5','45567243-d61c-4212-8ac9-537d13017e03','2026-06-09 08:02:44',NULL,'CREATE','IN_PROGRESS','NovaLogging','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-34-7hhwrev4q2ai-NovaLogging-ria6cs2j2r6f','state changed','OS::TripleO::Services::Logging::NovaCommon',NULL,1220),(1988,'6cdd43b5-4279-4c48-a201-ea9c58891857','2a826061-c6cb-49a0-8d15-5548fea1a304','2026-06-09 08:02:44',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-29-xzweaopjyubb-MysqlBase-s2u7alrgfvap','2a826061-c6cb-49a0-8d15-5548fea1a304','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1989,'a7a17195-7b21-4a5a-8296-8ca5de4dbe57','2a826061-c6cb-49a0-8d15-5548fea1a304','2026-06-09 08:02:44',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-29-xzweaopjyubb-MysqlBase-s2u7alrgfvap','2a826061-c6cb-49a0-8d15-5548fea1a304','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(1990,'e1eb1aa9-5ba9-4251-a974-b087ed14869d','499b49b1-cba7-4d7a-9fc1-965ac90d3b7a','2026-06-09 08:02:44',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-34-7hhwrev4q2ai-NovaLogging-ria6cs2j2r6f','499b49b1-cba7-4d7a-9fc1-965ac90d3b7a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1991,'7d549fae-b5b0-4353-a32a-fc3462e93d2a','6703e131-eb52-409b-a436-5deb446a112f','2026-06-09 08:02:44',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-32-pohygagpdz4f-NeutronBase-uixpawor7flb','6703e131-eb52-409b-a436-5deb446a112f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1992,'5934151e-86bd-4972-8eae-82737fcf289b','6703e131-eb52-409b-a436-5deb446a112f','2026-06-09 08:02:44',NULL,'CREATE','IN_PROGRESS','NeutronMl2Base','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-32-pohygagpdz4f-NeutronBase-uixpawor7flb-NeutronMl2Base-t64bffq6rii5','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2.yaml',NULL,1225),(1993,'39756562-987b-41cb-a2fd-e3a2a69fff32','499b49b1-cba7-4d7a-9fc1-965ac90d3b7a','2026-06-09 08:02:44',NULL,'CREATE','IN_PROGRESS','InitLogContainerName','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-34-7hhwrev4q2ai-NovaLogging-ria6cs2j2r6f-InitLogContainerName-pu5umssnll2q','state changed','OS::Heat::Value',NULL,1226),(1994,'8a119c5b-74d5-4fed-9247-b2764d6efd3d','499b49b1-cba7-4d7a-9fc1-965ac90d3b7a','2026-06-09 08:02:44',NULL,'CREATE','COMPLETE','InitLogContainerName','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-34-7hhwrev4q2ai-NovaLogging-ria6cs2j2r6f-InitLogContainerName-pu5umssnll2q','state changed','OS::Heat::Value',NULL,1226),(1995,'b4c1547e-2a95-441f-beed-8c8c6266c0a5','719dc273-4de7-4544-8da6-a8f1a14f0ccb','2026-06-09 08:02:44',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-32-pohygagpdz4f-NeutronBase-uixpawor7flb-NeutronMl2Base-t64bffq6rii5','719dc273-4de7-4544-8da6-a8f1a14f0ccb','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(1996,'44386164-5bc1-4265-b91c-22f4712eb0f6','719dc273-4de7-4544-8da6-a8f1a14f0ccb','2026-06-09 08:02:44',NULL,'CREATE','IN_PROGRESS','NeutronBase','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-32-pohygagpdz4f-NeutronBase-uixpawor7flb-NeutronMl2Base-t64bffq6rii5-NeutronBase-tnutz4lb44qy','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-base.yaml',NULL,1229),(1997,'820f00ad-7b0f-4a0a-8564-11e5c22f910f','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:02:44',NULL,'CREATE','IN_PROGRESS','ComputeServers','overcloud-ComputeServers-hhkav22fvk3t','state changed','OS::Heat::Value',NULL,1230),(1998,'761fd220-d5e4-496b-951e-1674da769dbd','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:02:44',NULL,'CREATE','COMPLETE','ComputeServers','overcloud-ComputeServers-hhkav22fvk3t','state changed','OS::Heat::Value',NULL,1230),(1999,'24975c9d-6ac4-4d9a-a83e-41028a11c05c','b6713975-a619-4a7a-96d9-8df753ec3df8','2026-06-09 08:02:44',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-32-pohygagpdz4f-NeutronBase-uixpawor7flb-NeutronMl2Base-t64bffq6rii5-NeutronBase-tnutz4lb44qy','b6713975-a619-4a7a-96d9-8df753ec3df8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2000,'7b346afc-f881-4fb3-b646-b53bbed74968','946cb619-c679-4692-b834-7f2e005736b8','2026-06-09 08:02:44',NULL,'CREATE','IN_PROGRESS','NovaBase','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-35-i6huwjv4fmzm-NovaBase-a2azjckkxibr','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,1232),(2001,'a19645de-78c8-4fee-b5d6-a3a35a37e273','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:02:44',NULL,'CREATE','IN_PROGRESS','ComputeNetworkHostnameMap','overcloud-ComputeNetworkHostnameMap-p3dxttgykhtg','state changed','OS::Heat::Value',NULL,1231),(2002,'9b8e62be-3c3b-4316-96a5-807cab3b2b76','b6713975-a619-4a7a-96d9-8df753ec3df8','2026-06-09 08:02:44',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-32-pohygagpdz4f-NeutronBase-uixpawor7flb-NeutronMl2Base-t64bffq6rii5-NeutronBase-tnutz4lb44qy','b6713975-a619-4a7a-96d9-8df753ec3df8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2003,'da43da86-807a-4629-af18-69dae3ff4482','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:02:44',NULL,'CREATE','COMPLETE','ComputeNetworkHostnameMap','overcloud-ComputeNetworkHostnameMap-p3dxttgykhtg','state changed','OS::Heat::Value',NULL,1231),(2004,'f023abd7-a5a7-4747-8258-9fd8e26cc163','45567243-d61c-4212-8ac9-537d13017e03','2026-06-09 08:02:44',NULL,'CREATE','IN_PROGRESS','NovaBase','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-34-7hhwrev4q2ai-NovaBase-ow3o77yagrlm','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,1234),(2005,'f867a14a-3d10-486b-a9ed-8f222dadc948','9c57a73b-0fd5-4bfc-a4fa-0093fa6dc119','2026-06-09 08:02:44',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-35-i6huwjv4fmzm-NovaBase-a2azjckkxibr','9c57a73b-0fd5-4bfc-a4fa-0093fa6dc119','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2006,'b69a8d69-9776-43a8-aa7c-00269455867b','f1005309-2210-4458-90e0-633e6360410c','2026-06-09 08:02:44',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-34-7hhwrev4q2ai-NovaBase-ow3o77yagrlm','f1005309-2210-4458-90e0-633e6360410c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2007,'b95656a5-0c11-45c6-bba8-17c4002e4aad','f1005309-2210-4458-90e0-633e6360410c','2026-06-09 08:02:44',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-34-7hhwrev4q2ai-NovaBase-ow3o77yagrlm-RoleParametersValue-sk7ovddcz5hs','state changed','OS::Heat::Value',NULL,1237),(2008,'1158f46d-9518-429e-baaa-728371d28395','f1005309-2210-4458-90e0-633e6360410c','2026-06-09 08:02:44',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-34-7hhwrev4q2ai-NovaBase-ow3o77yagrlm-RoleParametersValue-sk7ovddcz5hs','state changed','OS::Heat::Value',NULL,1237),(2009,'80f6bf63-30f6-428c-be0b-ea136a563fe9','f1005309-2210-4458-90e0-633e6360410c','2026-06-09 08:02:44',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-34-7hhwrev4q2ai-NovaBase-ow3o77yagrlm','f1005309-2210-4458-90e0-633e6360410c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2010,'3ce620ca-09ca-4235-8a36-2a4a92e0921c','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:02:44',NULL,'CREATE','IN_PROGRESS','ComputeIpListMap','overcloud-ComputeIpListMap-u5plxiq774ic','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,1238),(2011,'ca168ba7-1cd1-4080-92f9-1f64fe47ad3d','9c57a73b-0fd5-4bfc-a4fa-0093fa6dc119','2026-06-09 08:02:44',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-35-i6huwjv4fmzm-NovaBase-a2azjckkxibr-RoleParametersValue-srgmje6hsyqs','state changed','OS::Heat::Value',NULL,1239),(2012,'d6d29925-f4d4-499b-a4d0-74ee6b49ec64','9c57a73b-0fd5-4bfc-a4fa-0093fa6dc119','2026-06-09 08:02:45',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-35-i6huwjv4fmzm-NovaBase-a2azjckkxibr-RoleParametersValue-srgmje6hsyqs','state changed','OS::Heat::Value',NULL,1239),(2013,'d99c3e9c-edc9-45a9-aa31-9209c024d20b','4ba94053-b11b-4b8d-8f66-f88f5ce7bbe1','2026-06-09 08:02:45',NULL,'CREATE','IN_PROGRESS','overcloud-ComputeIpListMap-u5plxiq774ic','4ba94053-b11b-4b8d-8f66-f88f5ce7bbe1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2014,'3dc72854-a45d-4da3-a215-3b8354ed7222','9c57a73b-0fd5-4bfc-a4fa-0093fa6dc119','2026-06-09 08:02:45',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-35-i6huwjv4fmzm-NovaBase-a2azjckkxibr','9c57a73b-0fd5-4bfc-a4fa-0093fa6dc119','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2015,'65136d8d-ef07-41b3-98e0-1b0a9e2f0c31','4859ef51-4e76-4098-963b-ec51962038c1','2026-06-09 08:02:45',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-29-xzweaopjyubb-RoleParametersValue-ny6mxuhpkuzr','state changed','OS::Heat::Value',NULL,1240),(2016,'a0920993-83e6-43a4-84b2-2629b532257d','4859ef51-4e76-4098-963b-ec51962038c1','2026-06-09 08:02:45',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-29-xzweaopjyubb-RoleParametersValue-ny6mxuhpkuzr','state changed','OS::Heat::Value',NULL,1240),(2017,'c462bc20-bf96-41a1-abda-24ce85fb07f1','946cb619-c679-4692-b834-7f2e005736b8','2026-06-09 08:02:45',NULL,'CREATE','COMPLETE','MySQLClient','ec5c4857-74b7-41f5-8301-1b4ce6e733ce','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2018,'70b40919-ec8c-4356-b765-036fd59ba2ea','208db2cd-8593-4ada-b9b7-7fb03a00cab4','2026-06-09 08:02:45',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-32-pohygagpdz4f-RoleParametersValue-jx6nhzmgzicf','state changed','OS::Heat::Value',NULL,1241),(2019,'b6cfb62d-b0fb-420f-bda6-5cbce8f7f973','4ba94053-b11b-4b8d-8f66-f88f5ce7bbe1','2026-06-09 08:02:45',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','overcloud-ComputeIpListMap-u5plxiq774ic-EnabledServicesValue-ravb5adhwkrl','state changed','OS::Heat::Value',NULL,1242),(2020,'fa5d2edf-1e8f-4942-a3fd-e7d60d2b4c7a','208db2cd-8593-4ada-b9b7-7fb03a00cab4','2026-06-09 08:02:45',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-32-pohygagpdz4f-RoleParametersValue-jx6nhzmgzicf','state changed','OS::Heat::Value',NULL,1241),(2021,'325560a9-b323-40a6-a847-9214caab7229','4ba94053-b11b-4b8d-8f66-f88f5ce7bbe1','2026-06-09 08:02:45',NULL,'CREATE','COMPLETE','EnabledServicesValue','overcloud-ComputeIpListMap-u5plxiq774ic-EnabledServicesValue-ravb5adhwkrl','state changed','OS::Heat::Value',NULL,1242),(2022,'9df792fb-c6cd-43b3-9fdb-6357f3c76aa9','4859ef51-4e76-4098-963b-ec51962038c1','2026-06-09 08:02:45',NULL,'CREATE','COMPLETE','MysqlBase','2a826061-c6cb-49a0-8d15-5548fea1a304','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-base.yaml',NULL,1215),(2023,'3edf0add-45ad-4b74-81cb-6aaefa50b308','4859ef51-4e76-4098-963b-ec51962038c1','2026-06-09 08:02:45',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-29-xzweaopjyubb','4859ef51-4e76-4098-963b-ec51962038c1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2024,'e558d827-6290-42a3-b722-37e9b486abb8','499b49b1-cba7-4d7a-9fc1-965ac90d3b7a','2026-06-09 08:02:45',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-34-7hhwrev4q2ai-NovaLogging-ria6cs2j2r6f-RoleParametersValue-fg6byhueb7zt','state changed','OS::Heat::Value',NULL,1243),(2025,'58d166de-4415-46b2-85b7-fb9c84042d23','499b49b1-cba7-4d7a-9fc1-965ac90d3b7a','2026-06-09 08:02:45',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-34-7hhwrev4q2ai-NovaLogging-ria6cs2j2r6f-RoleParametersValue-fg6byhueb7zt','state changed','OS::Heat::Value',NULL,1243),(2026,'84d94f6a-7f48-4091-a35a-a20ab7570746','499b49b1-cba7-4d7a-9fc1-965ac90d3b7a','2026-06-09 08:02:45',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-34-7hhwrev4q2ai-NovaLogging-ria6cs2j2r6f','499b49b1-cba7-4d7a-9fc1-965ac90d3b7a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2027,'a0047213-d5a7-4052-bb5c-03547d55372c','719dc273-4de7-4544-8da6-a8f1a14f0ccb','2026-06-09 08:02:45',NULL,'CREATE','COMPLETE','NeutronBase','b6713975-a619-4a7a-96d9-8df753ec3df8','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-base.yaml',NULL,1229),(2028,'c455dff2-5571-420d-83fc-a12091033201','946cb619-c679-4692-b834-7f2e005736b8','2026-06-09 08:02:45',NULL,'CREATE','IN_PROGRESS','NovaApiDBClient','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-35-i6huwjv4fmzm-NovaApiDBClient-5zlle6wmtccc','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml',NULL,1244),(2029,'defe2de1-4d3e-41d6-955e-767e70478763','45567243-d61c-4212-8ac9-537d13017e03','2026-06-09 08:02:45',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-34-7hhwrev4q2ai-MySQLClient-qpzscwxc3akd','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2030,'37152533-be62-46b3-9282-d98e22d82209','719dc273-4de7-4544-8da6-a8f1a14f0ccb','2026-06-09 08:02:45',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-32-pohygagpdz4f-NeutronBase-uixpawor7flb-NeutronMl2Base-t64bffq6rii5','719dc273-4de7-4544-8da6-a8f1a14f0ccb','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2031,'8b391778-2a33-4022-92ac-c9e996db0113','8c8f5daf-43a7-4685-9d68-a86fd0ed09aa','2026-06-09 08:02:45',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-35-i6huwjv4fmzm-NovaApiDBClient-5zlle6wmtccc','8c8f5daf-43a7-4685-9d68-a86fd0ed09aa','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2032,'92ed51bb-424a-4581-81a7-d6d6896a2a99','8c8f5daf-43a7-4685-9d68-a86fd0ed09aa','2026-06-09 08:02:45',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-35-i6huwjv4fmzm-NovaApiDBClient-5zlle6wmtccc','8c8f5daf-43a7-4685-9d68-a86fd0ed09aa','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2033,'d17036ec-21d5-4ed4-b21b-3f76e26b5323','e8f4328d-0185-45bf-9603-f33fa6c4d722','2026-06-09 08:02:45',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-34-7hhwrev4q2ai-MySQLClient-qpzscwxc3akd','e8f4328d-0185-45bf-9603-f33fa6c4d722','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2034,'b1498731-d31b-4f73-8940-e73cecdc9d9c','946cb619-c679-4692-b834-7f2e005736b8','2026-06-09 08:02:45',NULL,'CREATE','COMPLETE','NovaBase','9c57a73b-0fd5-4bfc-a4fa-0093fa6dc119','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,1232),(2035,'4a1759d1-e0c0-4018-a3ab-fa7d8da4ba8e','e8f4328d-0185-45bf-9603-f33fa6c4d722','2026-06-09 08:02:45',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-34-7hhwrev4q2ai-MySQLClient-qpzscwxc3akd','e8f4328d-0185-45bf-9603-f33fa6c4d722','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2036,'440a307f-eb99-46e7-aab9-11a4c3e1b169','45567243-d61c-4212-8ac9-537d13017e03','2026-06-09 08:02:45',NULL,'CREATE','COMPLETE','NovaBase','f1005309-2210-4458-90e0-633e6360410c','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,1234),(2037,'66f8c4d6-eda9-4828-b022-1490b505d4fa','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:45',NULL,'CREATE','COMPLETE','29','4859ef51-4e76-4098-963b-ec51962038c1','state changed','OS::TripleO::Services::MySQL',NULL,1194),(2038,'ae0a5148-bc3f-4816-9740-0cc6e218ad77','4ba94053-b11b-4b8d-8f66-f88f5ce7bbe1','2026-06-09 08:02:46',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-ComputeIpListMap-u5plxiq774ic-NetIpMapValue-6kwrlb3776zl','state changed','OS::Heat::Value',NULL,1246),(2039,'1265a0eb-c5f6-430e-9a0e-387ae5aa3771','4ba94053-b11b-4b8d-8f66-f88f5ce7bbe1','2026-06-09 08:02:46',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-ComputeIpListMap-u5plxiq774ic-NetIpMapValue-6kwrlb3776zl','state changed','OS::Heat::Value',NULL,1246),(2040,'779dfef5-9ca5-43cd-8758-b4050bc66f1e','4ba94053-b11b-4b8d-8f66-f88f5ce7bbe1','2026-06-09 08:02:46',NULL,'CREATE','COMPLETE','overcloud-ComputeIpListMap-u5plxiq774ic','4ba94053-b11b-4b8d-8f66-f88f5ce7bbe1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2041,'d092fb0d-49c9-450c-ab88-67ca39bf8d81','45567243-d61c-4212-8ac9-537d13017e03','2026-06-09 08:02:46',NULL,'CREATE','COMPLETE','NovaLogging','499b49b1-cba7-4d7a-9fc1-965ac90d3b7a','state changed','OS::TripleO::Services::Logging::NovaCommon',NULL,1220),(2042,'bc3cda70-51fd-4d90-af3c-ebc23914f1d4','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:46',NULL,'CREATE','IN_PROGRESS','33','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-33-yy3sktsnfc3e','state changed','OS::TripleO::Services::NovaApi',NULL,1250),(2043,'d5937eed-c3f1-4485-9551-325360e0c5cf','6703e131-eb52-409b-a436-5deb446a112f','2026-06-09 08:02:46',NULL,'CREATE','COMPLETE','NeutronMl2Base','719dc273-4de7-4544-8da6-a8f1a14f0ccb','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2.yaml',NULL,1225),(2044,'854f4b74-9c5b-42bb-8de2-438caba49d71','6703e131-eb52-409b-a436-5deb446a112f','2026-06-09 08:02:46',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-32-pohygagpdz4f-NeutronBase-uixpawor7flb','6703e131-eb52-409b-a436-5deb446a112f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2045,'be89c2f2-f081-466e-b2ed-e99ce92e58fc','40ff5841-a282-483f-b4eb-9352fceb77a9','2026-06-09 08:02:46',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-33-yy3sktsnfc3e','40ff5841-a282-483f-b4eb-9352fceb77a9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2046,'a7d87599-e519-4db1-b11b-eef6379d5f7d','946cb619-c679-4692-b834-7f2e005736b8','2026-06-09 08:02:46',NULL,'CREATE','IN_PROGRESS','NovaMetadataLogging','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-35-i6huwjv4fmzm-NovaMetadataLogging-qijzdy5rnmwd','state changed','OS::TripleO::Services::Logging::NovaMetadata',NULL,NULL),(2047,'3fd905bc-e71d-47db-9b35-9796c7a3fe45','45567243-d61c-4212-8ac9-537d13017e03','2026-06-09 08:02:46',NULL,'CREATE','IN_PROGRESS','NovaDBClient','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-34-7hhwrev4q2ai-NovaDBClient-vqw6hu6xn4jq','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,1251),(2048,'b15fe215-4f2c-4194-b414-d84e4b635cab','49e5e8ce-2eea-467a-a164-1423bbd3c2a8','2026-06-09 08:02:46',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-35-i6huwjv4fmzm-NovaMetadataLogging-qijzdy5rnmwd','49e5e8ce-2eea-467a-a164-1423bbd3c2a8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2049,'8e445bed-3655-47f1-8f90-a64aae739ae4','946cb619-c679-4692-b834-7f2e005736b8','2026-06-09 08:02:46',NULL,'CREATE','COMPLETE','NovaApiDBClient','8c8f5daf-43a7-4685-9d68-a86fd0ed09aa','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml',NULL,1244),(2050,'5c991feb-e07a-4658-831e-16468e6dc7e4','9416fc16-54d5-4f91-b6c6-f35d1b5ac2ec','2026-06-09 08:02:46',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-34-7hhwrev4q2ai-NovaDBClient-vqw6hu6xn4jq','9416fc16-54d5-4f91-b6c6-f35d1b5ac2ec','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2051,'a79e657e-520c-401c-b903-a530bca3c905','40ff5841-a282-483f-b4eb-9352fceb77a9','2026-06-09 08:02:46',NULL,'CREATE','IN_PROGRESS','NovaApiLogging','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-33-yy3sktsnfc3e-NovaApiLogging-kgkkkkpnjojl','state changed','OS::TripleO::Services::Logging::NovaApi',NULL,NULL),(2052,'d45eb366-13ff-4229-b76f-bece377bd700','45567243-d61c-4212-8ac9-537d13017e03','2026-06-09 08:02:46',NULL,'CREATE','COMPLETE','MySQLClient','e8f4328d-0185-45bf-9603-f33fa6c4d722','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2053,'0236ec28-a023-4f8d-8027-1b3a10993507','9416fc16-54d5-4f91-b6c6-f35d1b5ac2ec','2026-06-09 08:02:46',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-34-7hhwrev4q2ai-NovaDBClient-vqw6hu6xn4jq','9416fc16-54d5-4f91-b6c6-f35d1b5ac2ec','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2054,'87737150-a17b-45bb-a9b3-c9fdb02cd87d','49e5e8ce-2eea-467a-a164-1423bbd3c2a8','2026-06-09 08:02:46',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-35-i6huwjv4fmzm-NovaMetadataLogging-qijzdy5rnmwd-RoleParametersValue-anmy3f7ens4s','state changed','OS::Heat::Value',NULL,1252),(2055,'26e30a1e-f7bd-4ab5-8fc0-43d9c1fd6289','49e5e8ce-2eea-467a-a164-1423bbd3c2a8','2026-06-09 08:02:46',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-35-i6huwjv4fmzm-NovaMetadataLogging-qijzdy5rnmwd-RoleParametersValue-anmy3f7ens4s','state changed','OS::Heat::Value',NULL,1252),(2056,'f93e95f2-829b-4316-8570-d0f22dbea91f','49e5e8ce-2eea-467a-a164-1423bbd3c2a8','2026-06-09 08:02:46',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-35-i6huwjv4fmzm-NovaMetadataLogging-qijzdy5rnmwd','49e5e8ce-2eea-467a-a164-1423bbd3c2a8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2057,'d8a95b6d-de68-4d9b-8770-a98ab7af4331','494ccf6f-df62-4098-8a01-34d3e30c473b','2026-06-09 08:02:46',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-33-yy3sktsnfc3e-NovaApiLogging-kgkkkkpnjojl','494ccf6f-df62-4098-8a01-34d3e30c473b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2058,'0c67b983-4743-4f1d-bfd8-555072890113','494ccf6f-df62-4098-8a01-34d3e30c473b','2026-06-09 08:02:46',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-33-yy3sktsnfc3e-NovaApiLogging-kgkkkkpnjojl-RoleParametersValue-464btqbas2qf','state changed','OS::Heat::Value',NULL,1253),(2059,'74750863-8458-426e-81dc-63e24f345e35','494ccf6f-df62-4098-8a01-34d3e30c473b','2026-06-09 08:02:47',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-33-yy3sktsnfc3e-NovaApiLogging-kgkkkkpnjojl-RoleParametersValue-464btqbas2qf','state changed','OS::Heat::Value',NULL,1253),(2060,'3f7409d9-5420-44f0-9881-43d29518fb49','494ccf6f-df62-4098-8a01-34d3e30c473b','2026-06-09 08:02:47',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-33-yy3sktsnfc3e-NovaApiLogging-kgkkkkpnjojl','494ccf6f-df62-4098-8a01-34d3e30c473b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2061,'8b8c9a77-22a5-406b-97a0-6c88f3cefbf8','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:02:47',NULL,'CREATE','COMPLETE','ComputeIpListMap','4ba94053-b11b-4b8d-8f66-f88f5ce7bbe1','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,1238),(2062,'54f73037-d90a-4b0d-b305-4b30dc1a331b','208db2cd-8593-4ada-b9b7-7fb03a00cab4','2026-06-09 08:02:47',NULL,'CREATE','COMPLETE','NeutronBase','6703e131-eb52-409b-a436-5deb446a112f','state changed','OS::TripleO::Services::NeutronMl2PluginBase',NULL,1218),(2063,'31fb0f5e-c297-4c6f-96fa-d56823e7375c','208db2cd-8593-4ada-b9b7-7fb03a00cab4','2026-06-09 08:02:47',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-32-pohygagpdz4f','208db2cd-8593-4ada-b9b7-7fb03a00cab4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2064,'705db4a3-46d6-4b45-9494-60aa5dc6f4a7','946cb619-c679-4692-b834-7f2e005736b8','2026-06-09 08:02:47',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-35-i6huwjv4fmzm-RoleParametersValue-jz3767iu2avl','state changed','OS::Heat::Value',NULL,1254),(2065,'6730d421-f192-48a7-b13d-4f2d8b2a2f4e','946cb619-c679-4692-b834-7f2e005736b8','2026-06-09 08:02:47',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-35-i6huwjv4fmzm-RoleParametersValue-jz3767iu2avl','state changed','OS::Heat::Value',NULL,1254),(2066,'e1804120-4e0a-4ac3-a79a-197ae59056cc','45567243-d61c-4212-8ac9-537d13017e03','2026-06-09 08:02:47',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-34-7hhwrev4q2ai-ContainersCommon-4dr4spzn4yfo','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2067,'e7ae86e6-7bc1-4beb-b950-0743aea0c81e','946cb619-c679-4692-b834-7f2e005736b8','2026-06-09 08:02:47',NULL,'CREATE','COMPLETE','NovaMetadataLogging','49e5e8ce-2eea-467a-a164-1423bbd3c2a8','state changed','OS::TripleO::Services::Logging::NovaMetadata',NULL,NULL),(2068,'2c7566d7-07c1-4d71-a607-a0019a47de08','ad3cb5ec-ff43-42e6-837d-5520b1d723e8','2026-06-09 08:02:47',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-34-7hhwrev4q2ai-ContainersCommon-4dr4spzn4yfo','ad3cb5ec-ff43-42e6-837d-5520b1d723e8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2069,'b986753b-f722-4ada-9502-bb2d73933e5f','40ff5841-a282-483f-b4eb-9352fceb77a9','2026-06-09 08:02:47',NULL,'CREATE','IN_PROGRESS','ApacheServiceBase','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-33-yy3sktsnfc3e-ApacheServiceBase-2n6dpje44cj2','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1255),(2070,'48eca30e-7352-49dc-b1a0-32b70e278837','45567243-d61c-4212-8ac9-537d13017e03','2026-06-09 08:02:47',NULL,'CREATE','COMPLETE','NovaDBClient','9416fc16-54d5-4f91-b6c6-f35d1b5ac2ec','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,1251),(2071,'cb768762-1a62-4184-99a8-ef74f1aa6da9','ad3cb5ec-ff43-42e6-837d-5520b1d723e8','2026-06-09 08:02:47',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-34-7hhwrev4q2ai-ContainersCommon-4dr4spzn4yfo','ad3cb5ec-ff43-42e6-837d-5520b1d723e8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2072,'fd1c0187-c175-4399-84e5-268c8b4dabb0','40ff5841-a282-483f-b4eb-9352fceb77a9','2026-06-09 08:02:47',NULL,'CREATE','COMPLETE','NovaApiLogging','494ccf6f-df62-4098-8a01-34d3e30c473b','state changed','OS::TripleO::Services::Logging::NovaApi',NULL,NULL),(2073,'663927b9-702a-43e9-a5e5-d7347a02f209','e5beffce-90f5-4916-bfc5-88a57fbcf520','2026-06-09 08:02:47',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-33-yy3sktsnfc3e-ApacheServiceBase-2n6dpje44cj2','e5beffce-90f5-4916-bfc5-88a57fbcf520','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2074,'f3f01612-cb6b-4d98-b6b7-2f1e1123cd17','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:47',NULL,'CREATE','COMPLETE','32','208db2cd-8593-4ada-b9b7-7fb03a00cab4','state changed','OS::TripleO::Services::NeutronCorePlugin',NULL,1206),(2075,'2a8802fd-e1ba-4a92-ae5a-23f830a4666b','e5beffce-90f5-4916-bfc5-88a57fbcf520','2026-06-09 08:02:48',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-33-yy3sktsnfc3e-ApacheServiceBase-2n6dpje44cj2-ApacheNetworks-lr3zyry452wn','state changed','OS::Heat::Value',NULL,1256),(2076,'1d30e2f1-d1c7-421c-a1eb-6d4e1003aba1','e5beffce-90f5-4916-bfc5-88a57fbcf520','2026-06-09 08:02:48',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-33-yy3sktsnfc3e-ApacheServiceBase-2n6dpje44cj2-ApacheNetworks-lr3zyry452wn','state changed','OS::Heat::Value',NULL,1256),(2077,'54665d7b-0bbd-407e-b928-c5516fa96a29','e5beffce-90f5-4916-bfc5-88a57fbcf520','2026-06-09 08:02:48',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-33-yy3sktsnfc3e-ApacheServiceBase-2n6dpje44cj2','e5beffce-90f5-4916-bfc5-88a57fbcf520','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2078,'659988c9-80f4-429d-ade6-13545c57bb5d','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:48',NULL,'CREATE','IN_PROGRESS','36','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-36-k2mgipsp6nf5','state changed','OS::TripleO::Services::NovaScheduler',NULL,1262),(2079,'96d1b158-a243-48e9-970e-e1580e509b97','80d0a572-4f38-487a-aa00-501929d5d5b2','2026-06-09 08:02:48',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-36-k2mgipsp6nf5','80d0a572-4f38-487a-aa00-501929d5d5b2','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2080,'a838bb23-bdc9-498e-93ec-a9b7f43aeb9e','946cb619-c679-4692-b834-7f2e005736b8','2026-06-09 08:02:48',NULL,'CREATE','IN_PROGRESS','NovaDBClient','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-35-i6huwjv4fmzm-NovaDBClient-rnwxu5j3igjq','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,1263),(2081,'f450c011-56c8-4ef0-b520-6145c56cd2c0','5d3af0dd-939b-4814-9dc1-95789e9a0fc5','2026-06-09 08:02:48',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-35-i6huwjv4fmzm-NovaDBClient-rnwxu5j3igjq','5d3af0dd-939b-4814-9dc1-95789e9a0fc5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2082,'adbd011d-ea9d-41e5-aa3d-dd0c03bdb38a','80d0a572-4f38-487a-aa00-501929d5d5b2','2026-06-09 08:02:48',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-36-k2mgipsp6nf5-MySQLClient-keeiruz6p4uc','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2083,'1b866609-ba7b-4a6f-9a37-350cfd22d60b','5d3af0dd-939b-4814-9dc1-95789e9a0fc5','2026-06-09 08:02:48',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-35-i6huwjv4fmzm-NovaDBClient-rnwxu5j3igjq','5d3af0dd-939b-4814-9dc1-95789e9a0fc5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2084,'7cbe84a9-ac5f-41ce-8bcc-4a0a3cf4dc7c','40ff5841-a282-483f-b4eb-9352fceb77a9','2026-06-09 08:02:48',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-33-yy3sktsnfc3e-MySQLClient-zkgh7c5a7euu','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2085,'c68ec4b5-5995-40a9-b565-d4d2285b2547','20a01675-172d-4015-b321-65cc8fb9c9fb','2026-06-09 08:02:48',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-36-k2mgipsp6nf5-MySQLClient-keeiruz6p4uc','20a01675-172d-4015-b321-65cc8fb9c9fb','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2086,'1e08bb33-839e-41b3-8609-bf24a0dadefc','45567243-d61c-4212-8ac9-537d13017e03','2026-06-09 08:02:48',NULL,'CREATE','COMPLETE','ContainersCommon','ad3cb5ec-ff43-42e6-837d-5520b1d723e8','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2087,'1e6379e1-d577-49e0-a7b5-6e12466608cd','1d0c1289-904c-4113-a711-115c8f1de2f7','2026-06-09 08:02:48',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-33-yy3sktsnfc3e-MySQLClient-zkgh7c5a7euu','1d0c1289-904c-4113-a711-115c8f1de2f7','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2088,'1edf50be-8bb6-4375-9e76-a97b7e1a4179','20a01675-172d-4015-b321-65cc8fb9c9fb','2026-06-09 08:02:48',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-36-k2mgipsp6nf5-MySQLClient-keeiruz6p4uc','20a01675-172d-4015-b321-65cc8fb9c9fb','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2089,'9bc4f9c0-5a28-463a-95c2-dfbd44ba42dd','45567243-d61c-4212-8ac9-537d13017e03','2026-06-09 08:02:48',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-34-7hhwrev4q2ai','45567243-d61c-4212-8ac9-537d13017e03','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2090,'3f144da8-454b-4f43-98aa-eaac79ed9834','1d0c1289-904c-4113-a711-115c8f1de2f7','2026-06-09 08:02:48',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-33-yy3sktsnfc3e-MySQLClient-zkgh7c5a7euu','1d0c1289-904c-4113-a711-115c8f1de2f7','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2091,'0d7048f8-c091-46fa-b8de-6d47389c6f95','40ff5841-a282-483f-b4eb-9352fceb77a9','2026-06-09 08:02:49',NULL,'CREATE','COMPLETE','ApacheServiceBase','e5beffce-90f5-4916-bfc5-88a57fbcf520','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1255),(2092,'d50d0a30-e7c6-4d47-9e1c-99b2512b8f64','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:49',NULL,'CREATE','COMPLETE','34','45567243-d61c-4212-8ac9-537d13017e03','state changed','OS::TripleO::Services::NovaConductor',NULL,1185),(2093,'30e70ebb-6ebf-4170-bf02-8cae1a7279a5','946cb619-c679-4692-b834-7f2e005736b8','2026-06-09 08:02:49',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-35-i6huwjv4fmzm-ContainersCommon-7wufx472nncn','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2094,'b568e338-474b-4496-8036-aaa617729f54','946cb619-c679-4692-b834-7f2e005736b8','2026-06-09 08:02:49',NULL,'CREATE','COMPLETE','NovaDBClient','5d3af0dd-939b-4814-9dc1-95789e9a0fc5','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,1263),(2095,'f1d20721-ace0-46a9-889c-b50fd9fea880','80d0a572-4f38-487a-aa00-501929d5d5b2','2026-06-09 08:02:49',NULL,'CREATE','IN_PROGRESS','NovaApiDBClient','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-36-k2mgipsp6nf5-NovaApiDBClient-vzjdsagt7qhl','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml',NULL,1267),(2096,'6483c748-0c4a-4ad1-8c30-f7fc98f505b2','40ff5841-a282-483f-b4eb-9352fceb77a9','2026-06-09 08:02:49',NULL,'CREATE','IN_PROGRESS','NovaBase','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-33-yy3sktsnfc3e-NovaBase-qrzzegxbc4fj','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,1268),(2097,'07730ebf-d04b-4010-8100-f7dec107cc97','54994913-b310-4149-accc-e762f5e4f72e','2026-06-09 08:02:49',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-35-i6huwjv4fmzm-ContainersCommon-7wufx472nncn','54994913-b310-4149-accc-e762f5e4f72e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2098,'8083b3fd-d874-4add-b1fe-99fbd8685742','80d0a572-4f38-487a-aa00-501929d5d5b2','2026-06-09 08:02:49',NULL,'CREATE','COMPLETE','MySQLClient','20a01675-172d-4015-b321-65cc8fb9c9fb','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2099,'4fe522f6-c364-4710-970c-81cb9d16abca','40ff5841-a282-483f-b4eb-9352fceb77a9','2026-06-09 08:02:50',NULL,'CREATE','COMPLETE','MySQLClient','1d0c1289-904c-4113-a711-115c8f1de2f7','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2100,'d3d30103-2b48-4430-84df-91e56679ba17','54994913-b310-4149-accc-e762f5e4f72e','2026-06-09 08:02:50',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-35-i6huwjv4fmzm-ContainersCommon-7wufx472nncn','54994913-b310-4149-accc-e762f5e4f72e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2101,'69bb9286-87b2-4ec8-96bf-1fe841d69569','5b8a1a8e-e36a-424f-9425-8bce9c60d2fe','2026-06-09 08:02:50',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-36-k2mgipsp6nf5-NovaApiDBClient-vzjdsagt7qhl','5b8a1a8e-e36a-424f-9425-8bce9c60d2fe','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2102,'218e2a98-6feb-4745-8754-59c4123d2340','ccaae786-c9c5-4353-9cd7-9ec2214ea8e3','2026-06-09 08:02:50',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-33-yy3sktsnfc3e-NovaBase-qrzzegxbc4fj','ccaae786-c9c5-4353-9cd7-9ec2214ea8e3','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2103,'69b68fc7-4351-43b9-a16f-b6afcfd510a0','5b8a1a8e-e36a-424f-9425-8bce9c60d2fe','2026-06-09 08:02:50',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-36-k2mgipsp6nf5-NovaApiDBClient-vzjdsagt7qhl','5b8a1a8e-e36a-424f-9425-8bce9c60d2fe','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2104,'9f7fe7b4-9c7f-4c71-a5db-c4185c679fc5','ccaae786-c9c5-4353-9cd7-9ec2214ea8e3','2026-06-09 08:02:50',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-33-yy3sktsnfc3e-NovaBase-qrzzegxbc4fj-RoleParametersValue-jp4eogcb5kpm','state changed','OS::Heat::Value',NULL,1274),(2105,'0d41b554-5f35-4891-98fd-9a048fbdf7e7','ccaae786-c9c5-4353-9cd7-9ec2214ea8e3','2026-06-09 08:02:50',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-33-yy3sktsnfc3e-NovaBase-qrzzegxbc4fj-RoleParametersValue-jp4eogcb5kpm','state changed','OS::Heat::Value',NULL,1274),(2106,'80d94f7f-10a5-4885-98c7-0851afecdd94','ccaae786-c9c5-4353-9cd7-9ec2214ea8e3','2026-06-09 08:02:50',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-33-yy3sktsnfc3e-NovaBase-qrzzegxbc4fj','ccaae786-c9c5-4353-9cd7-9ec2214ea8e3','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2107,'72db9138-ab85-46e4-84ba-9b689ebe88aa','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:50',NULL,'CREATE','IN_PROGRESS','38','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-38-r65tzlkuv7jn','state changed','OS::TripleO::Services::ContainersLogrotateCrond',NULL,1277),(2108,'a73d2eb1-49f3-40d7-a2c8-e4e8cb018baf','5d6d22b5-9bdd-490f-98a1-02a76a214bb2','2026-06-09 08:02:50',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-38-r65tzlkuv7jn','5d6d22b5-9bdd-490f-98a1-02a76a214bb2','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2109,'814e9e1e-0616-4ea1-9217-b930f2b91d65','946cb619-c679-4692-b834-7f2e005736b8','2026-06-09 08:02:50',NULL,'CREATE','IN_PROGRESS','ApacheServiceBase','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-35-i6huwjv4fmzm-ApacheServiceBase-degcslcx5fnc','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1278),(2110,'a98100d3-298b-46d5-9d37-aa9bcca0813f','5d6d22b5-9bdd-490f-98a1-02a76a214bb2','2026-06-09 08:02:50',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-38-r65tzlkuv7jn-RoleParametersValue-lscmjcakzldl','state changed','OS::Heat::Value',NULL,1279),(2111,'87ee5828-fb54-466e-b6aa-ac66c77060b2','5d6d22b5-9bdd-490f-98a1-02a76a214bb2','2026-06-09 08:02:50',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-38-r65tzlkuv7jn-RoleParametersValue-lscmjcakzldl','state changed','OS::Heat::Value',NULL,1279),(2112,'aedce8dd-13af-475a-ad68-82151b1108b6','80d0a572-4f38-487a-aa00-501929d5d5b2','2026-06-09 08:02:50',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-36-k2mgipsp6nf5-ContainersCommon-bswixs3rycbr','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2113,'da80fe69-d352-426a-aacd-e19344c72498','e76b5bd5-c793-4c74-af46-bd591dea1a04','2026-06-09 08:02:50',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-35-i6huwjv4fmzm-ApacheServiceBase-degcslcx5fnc','e76b5bd5-c793-4c74-af46-bd591dea1a04','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2114,'bc5af10b-e83d-40e1-a1fc-48c0b4fe000b','40ff5841-a282-483f-b4eb-9352fceb77a9','2026-06-09 08:02:50',NULL,'CREATE','IN_PROGRESS','NovaApiDBClient','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-33-yy3sktsnfc3e-NovaApiDBClient-26kysckk3odo','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml',NULL,1280),(2115,'282b970e-fc96-469c-b9ae-5dbb9440e2cc','e76b5bd5-c793-4c74-af46-bd591dea1a04','2026-06-09 08:02:50',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-35-i6huwjv4fmzm-ApacheServiceBase-degcslcx5fnc-ApacheNetworks-higelbq5kqu7','state changed','OS::Heat::Value',NULL,1281),(2116,'127d75ff-25f8-44af-ba9b-b6982b035047','0fade375-c10a-464a-8981-e436ebdbf03f','2026-06-09 08:02:50',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-36-k2mgipsp6nf5-ContainersCommon-bswixs3rycbr','0fade375-c10a-464a-8981-e436ebdbf03f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2117,'e1ecf5d1-4cf6-4286-84f1-d3bb9f3feff6','e76b5bd5-c793-4c74-af46-bd591dea1a04','2026-06-09 08:02:50',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-35-i6huwjv4fmzm-ApacheServiceBase-degcslcx5fnc-ApacheNetworks-higelbq5kqu7','state changed','OS::Heat::Value',NULL,1281),(2118,'13892902-a434-402a-a039-d5cd17bf2226','0fade375-c10a-464a-8981-e436ebdbf03f','2026-06-09 08:02:50',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-36-k2mgipsp6nf5-ContainersCommon-bswixs3rycbr','0fade375-c10a-464a-8981-e436ebdbf03f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2119,'f0d05f81-9b04-49bb-87b5-542d291655a9','e2718d5b-7746-4c54-ab5e-716642352bbe','2026-06-09 08:02:50',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-33-yy3sktsnfc3e-NovaApiDBClient-26kysckk3odo','e2718d5b-7746-4c54-ab5e-716642352bbe','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2120,'4e8451fc-db18-45d2-bcde-1c92fb6a99b8','e76b5bd5-c793-4c74-af46-bd591dea1a04','2026-06-09 08:02:50',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-35-i6huwjv4fmzm-ApacheServiceBase-degcslcx5fnc','e76b5bd5-c793-4c74-af46-bd591dea1a04','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2121,'aee5d8f0-38fd-43da-9128-bf41ec246d09','e2718d5b-7746-4c54-ab5e-716642352bbe','2026-06-09 08:02:50',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-33-yy3sktsnfc3e-NovaApiDBClient-26kysckk3odo','e2718d5b-7746-4c54-ab5e-716642352bbe','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2122,'8d14931d-03cb-46ac-8e60-08770d8d94f2','946cb619-c679-4692-b834-7f2e005736b8','2026-06-09 08:02:51',NULL,'CREATE','COMPLETE','ContainersCommon','54994913-b310-4149-accc-e762f5e4f72e','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2123,'65e692d3-1e2b-4761-b73b-209384664793','40ff5841-a282-483f-b4eb-9352fceb77a9','2026-06-09 08:02:51',NULL,'CREATE','COMPLETE','NovaBase','ccaae786-c9c5-4353-9cd7-9ec2214ea8e3','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,1268),(2124,'4b6f2205-2e9f-442c-a3cc-5d542617abb1','80d0a572-4f38-487a-aa00-501929d5d5b2','2026-06-09 08:02:51',NULL,'CREATE','COMPLETE','NovaApiDBClient','5b8a1a8e-e36a-424f-9425-8bce9c60d2fe','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml',NULL,1267),(2125,'cc17efae-e82c-4db1-b3b4-b01931bced8d','5d6d22b5-9bdd-490f-98a1-02a76a214bb2','2026-06-09 08:02:51',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-38-r65tzlkuv7jn-ContainersCommon-lg2jruliksun','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2126,'a2455f9e-3c3a-4804-9450-331e626f4280','80d0a572-4f38-487a-aa00-501929d5d5b2','2026-06-09 08:02:51',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-36-k2mgipsp6nf5-RoleParametersValue-c52w7oz6wvnp','state changed','OS::Heat::Value',NULL,1282),(2127,'954c01ba-654d-473e-8bcb-950e5a951beb','80d0a572-4f38-487a-aa00-501929d5d5b2','2026-06-09 08:02:51',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-36-k2mgipsp6nf5-RoleParametersValue-c52w7oz6wvnp','state changed','OS::Heat::Value',NULL,1282),(2128,'fae18907-0320-4c1a-a04c-f5c4286f9887','74e37239-532f-457f-b523-c8487444da3e','2026-06-09 08:02:51',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-38-r65tzlkuv7jn-ContainersCommon-lg2jruliksun','74e37239-532f-457f-b523-c8487444da3e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2129,'5ecbf4b7-f102-48a1-ba58-246076ba98df','946cb619-c679-4692-b834-7f2e005736b8','2026-06-09 08:02:51',NULL,'CREATE','COMPLETE','ApacheServiceBase','e76b5bd5-c793-4c74-af46-bd591dea1a04','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1278),(2130,'c7639500-3427-4de6-9339-4ce4c8dcde1c','74e37239-532f-457f-b523-c8487444da3e','2026-06-09 08:02:51',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-38-r65tzlkuv7jn-ContainersCommon-lg2jruliksun','74e37239-532f-457f-b523-c8487444da3e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2131,'76bb72ae-bc7a-44c4-96d3-a5ad5e73f81c','40ff5841-a282-483f-b4eb-9352fceb77a9','2026-06-09 08:02:51',NULL,'CREATE','IN_PROGRESS','NovaDBClient','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-33-yy3sktsnfc3e-NovaDBClient-5mdve6gipait','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,1284),(2132,'307fd8ae-4679-42f2-8155-b21d7bc4c6d5','80d0a572-4f38-487a-aa00-501929d5d5b2','2026-06-09 08:02:51',NULL,'CREATE','IN_PROGRESS','NovaLogging','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-36-k2mgipsp6nf5-NovaLogging-vermekzoif6b','state changed','OS::TripleO::Services::Logging::NovaCommon',NULL,1285),(2133,'21159c11-f304-48d2-95d4-124ad141be1b','946cb619-c679-4692-b834-7f2e005736b8','2026-06-09 08:02:51',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-35-i6huwjv4fmzm','946cb619-c679-4692-b834-7f2e005736b8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2134,'b277896d-763b-41b2-b6d7-3047fff18ae4','80d0a572-4f38-487a-aa00-501929d5d5b2','2026-06-09 08:02:51',NULL,'CREATE','COMPLETE','ContainersCommon','0fade375-c10a-464a-8981-e436ebdbf03f','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2135,'20ee6d27-13e4-41a2-a4e9-fded3d6bbb4c','5ff89bc1-a3c2-4f1a-9927-ba164d74d296','2026-06-09 08:02:51',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-33-yy3sktsnfc3e-NovaDBClient-5mdve6gipait','5ff89bc1-a3c2-4f1a-9927-ba164d74d296','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2136,'20cc1adc-ee3c-4f4e-ba4c-320917e1229b','d96c44e5-c3eb-4c94-8a18-44418cb04243','2026-06-09 08:02:51',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-36-k2mgipsp6nf5-NovaLogging-vermekzoif6b','d96c44e5-c3eb-4c94-8a18-44418cb04243','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2137,'7cfb05a9-7207-41ae-8c83-3e7364a872b6','5ff89bc1-a3c2-4f1a-9927-ba164d74d296','2026-06-09 08:02:52',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-33-yy3sktsnfc3e-NovaDBClient-5mdve6gipait','5ff89bc1-a3c2-4f1a-9927-ba164d74d296','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2138,'69e49503-449a-4487-8464-7c0477dbcfd8','40ff5841-a282-483f-b4eb-9352fceb77a9','2026-06-09 08:02:52',NULL,'CREATE','COMPLETE','NovaApiDBClient','e2718d5b-7746-4c54-ab5e-716642352bbe','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-apidb-client-puppet.yaml',NULL,1280),(2139,'698cff02-c83c-4b9a-9ead-82891c6901d3','d96c44e5-c3eb-4c94-8a18-44418cb04243','2026-06-09 08:02:52',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-36-k2mgipsp6nf5-NovaLogging-vermekzoif6b-RoleParametersValue-kcydl5izqfnq','state changed','OS::Heat::Value',NULL,1286),(2140,'1f57d16e-f2a5-4ed4-929a-b639c6c9d659','d96c44e5-c3eb-4c94-8a18-44418cb04243','2026-06-09 08:02:52',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-36-k2mgipsp6nf5-NovaLogging-vermekzoif6b-RoleParametersValue-kcydl5izqfnq','state changed','OS::Heat::Value',NULL,1286),(2141,'3fccd259-ec8b-4a2f-94ec-2655922ffe4c','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:52',NULL,'CREATE','COMPLETE','35','946cb619-c679-4692-b834-7f2e005736b8','state changed','OS::TripleO::Services::NovaMetadata',NULL,1203),(2142,'4615e38e-a88b-462e-a683-71b4e19de794','80d0a572-4f38-487a-aa00-501929d5d5b2','2026-06-09 08:02:52',NULL,'CREATE','IN_PROGRESS','NovaBase','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-36-k2mgipsp6nf5-NovaBase-7bbnx24uszq4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,1293),(2143,'75275349-03f6-4ac6-b013-ed8ee54b29a0','40ff5841-a282-483f-b4eb-9352fceb77a9','2026-06-09 08:02:52',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-33-yy3sktsnfc3e-ContainersCommon-2u27nreg67dr','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2144,'bb56a6e8-5a66-4f4c-bd9b-ea5ba5ecc5f7','5d6d22b5-9bdd-490f-98a1-02a76a214bb2','2026-06-09 08:02:52',NULL,'CREATE','COMPLETE','ContainersCommon','74e37239-532f-457f-b523-c8487444da3e','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2145,'12eeb850-f35f-4b75-9709-6ec4f37b1e47','5d6d22b5-9bdd-490f-98a1-02a76a214bb2','2026-06-09 08:02:52',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-38-r65tzlkuv7jn','5d6d22b5-9bdd-490f-98a1-02a76a214bb2','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2146,'4926dc30-e55a-48a5-80f4-88d8d6d81b98','749393f6-1c75-4e6a-8a4a-662340f43d5e','2026-06-09 08:02:52',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-36-k2mgipsp6nf5-NovaBase-7bbnx24uszq4','749393f6-1c75-4e6a-8a4a-662340f43d5e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2147,'c3c7b2a8-d6eb-4519-b85c-85205f71b05a','bcd08211-edcf-4cc0-9ae9-5a3577f8aedb','2026-06-09 08:02:52',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-33-yy3sktsnfc3e-ContainersCommon-2u27nreg67dr','bcd08211-edcf-4cc0-9ae9-5a3577f8aedb','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2148,'ecad2391-b737-4858-a3a2-4d35f56e8009','bcd08211-edcf-4cc0-9ae9-5a3577f8aedb','2026-06-09 08:02:53',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-33-yy3sktsnfc3e-ContainersCommon-2u27nreg67dr','bcd08211-edcf-4cc0-9ae9-5a3577f8aedb','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2149,'fd83ec5f-98b5-4b3e-b138-e3e51e99f76a','40ff5841-a282-483f-b4eb-9352fceb77a9','2026-06-09 08:02:53',NULL,'CREATE','COMPLETE','NovaDBClient','5ff89bc1-a3c2-4f1a-9927-ba164d74d296','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,1284),(2150,'4a8f915b-025d-4fab-9731-57a06dcd2019','749393f6-1c75-4e6a-8a4a-662340f43d5e','2026-06-09 08:02:53',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-36-k2mgipsp6nf5-NovaBase-7bbnx24uszq4-RoleParametersValue-faezl6fvoc25','state changed','OS::Heat::Value',NULL,1299),(2151,'c26fb9df-412c-4d1d-b7f0-a1ba411909a3','749393f6-1c75-4e6a-8a4a-662340f43d5e','2026-06-09 08:02:53',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-36-k2mgipsp6nf5-NovaBase-7bbnx24uszq4-RoleParametersValue-faezl6fvoc25','state changed','OS::Heat::Value',NULL,1299),(2152,'35fadb30-6683-4a8d-a38d-06f74c026034','749393f6-1c75-4e6a-8a4a-662340f43d5e','2026-06-09 08:02:53',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-36-k2mgipsp6nf5-NovaBase-7bbnx24uszq4','749393f6-1c75-4e6a-8a4a-662340f43d5e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2153,'5a2ffcc0-a87c-4afd-8025-3d3a16e4e47b','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:53',NULL,'CREATE','IN_PROGRESS','39','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-39-vhzvwynk7o3u','state changed','OS::TripleO::Services::OVNDBs',NULL,1301),(2154,'8e8cb919-1cf1-46e2-9f2c-f5b117fbe4a8','d96c44e5-c3eb-4c94-8a18-44418cb04243','2026-06-09 08:02:53',NULL,'CREATE','IN_PROGRESS','InitLogContainerName','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-36-k2mgipsp6nf5-NovaLogging-vermekzoif6b-InitLogContainerName-okkuohidbqgd','state changed','OS::Heat::Value',NULL,1302),(2155,'84e83d4b-48be-410e-b16e-20b8bfc30ed1','d96c44e5-c3eb-4c94-8a18-44418cb04243','2026-06-09 08:02:53',NULL,'CREATE','COMPLETE','InitLogContainerName','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-36-k2mgipsp6nf5-NovaLogging-vermekzoif6b-InitLogContainerName-okkuohidbqgd','state changed','OS::Heat::Value',NULL,1302),(2156,'0c7b1882-fc8f-41d8-90c6-72a213680afe','d96c44e5-c3eb-4c94-8a18-44418cb04243','2026-06-09 08:02:53',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-36-k2mgipsp6nf5-NovaLogging-vermekzoif6b','d96c44e5-c3eb-4c94-8a18-44418cb04243','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2157,'2f433fa6-e0d7-4fda-941a-dfeb99003788','b1fc9cfd-9bdd-4af5-b6f5-7d60ee97bc6b','2026-06-09 08:02:53',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-39-vhzvwynk7o3u','b1fc9cfd-9bdd-4af5-b6f5-7d60ee97bc6b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2158,'b3fc1eb8-fcbf-44a5-b580-ddd0c8c49920','b1fc9cfd-9bdd-4af5-b6f5-7d60ee97bc6b','2026-06-09 08:02:53',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-39-vhzvwynk7o3u-ContainersCommon-wxmsqseonuj2','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2159,'d9d90cc4-dbe3-495e-9639-84147c063edf','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:53',NULL,'CREATE','COMPLETE','38','5d6d22b5-9bdd-490f-98a1-02a76a214bb2','state changed','OS::TripleO::Services::ContainersLogrotateCrond',NULL,1277),(2160,'6edc896b-16db-4685-b80b-d56e9a9cd379','199182f9-d5a8-4bf3-bf6e-3e4079cfe2f0','2026-06-09 08:02:53',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-39-vhzvwynk7o3u-ContainersCommon-wxmsqseonuj2','199182f9-d5a8-4bf3-bf6e-3e4079cfe2f0','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2161,'f897e511-8651-488f-960d-9b1901fec898','199182f9-d5a8-4bf3-bf6e-3e4079cfe2f0','2026-06-09 08:02:53',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-39-vhzvwynk7o3u-ContainersCommon-wxmsqseonuj2','199182f9-d5a8-4bf3-bf6e-3e4079cfe2f0','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2162,'f59e0c0d-cbd0-49f5-8bf6-07ba608a8771','b1fc9cfd-9bdd-4af5-b6f5-7d60ee97bc6b','2026-06-09 08:02:53',NULL,'CREATE','COMPLETE','ContainersCommon','199182f9-d5a8-4bf3-bf6e-3e4079cfe2f0','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2163,'cc4b481f-e956-48de-8e4c-610c7ed2f445','80d0a572-4f38-487a-aa00-501929d5d5b2','2026-06-09 08:02:53',NULL,'CREATE','IN_PROGRESS','NovaDBClient','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-36-k2mgipsp6nf5-NovaDBClient-mcxjgy3hodra','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,1304),(2164,'6af672be-6566-4b6e-8233-243567a2c712','40ff5841-a282-483f-b4eb-9352fceb77a9','2026-06-09 08:02:53',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-33-yy3sktsnfc3e-RoleParametersValue-urbx7cdqqysg','state changed','OS::Heat::Value',NULL,1306),(2165,'fdbf5980-ad3d-47b3-85cf-5778d0ff104b','2f0dd7d5-2af7-46a2-9ed3-4cabcfea24c6','2026-06-09 08:02:53',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-36-k2mgipsp6nf5-NovaDBClient-mcxjgy3hodra','2f0dd7d5-2af7-46a2-9ed3-4cabcfea24c6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2166,'71b1dde1-29da-48a4-b867-f5a00c918035','40ff5841-a282-483f-b4eb-9352fceb77a9','2026-06-09 08:02:53',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-33-yy3sktsnfc3e-RoleParametersValue-urbx7cdqqysg','state changed','OS::Heat::Value',NULL,1306),(2167,'d2596be9-df76-4975-a62a-4a082755fe5a','2f0dd7d5-2af7-46a2-9ed3-4cabcfea24c6','2026-06-09 08:02:53',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-36-k2mgipsp6nf5-NovaDBClient-mcxjgy3hodra','2f0dd7d5-2af7-46a2-9ed3-4cabcfea24c6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2168,'fd172af3-2182-4cf9-8ba7-41c39d1c71df','40ff5841-a282-483f-b4eb-9352fceb77a9','2026-06-09 08:02:54',NULL,'CREATE','COMPLETE','ContainersCommon','bcd08211-edcf-4cc0-9ae9-5a3577f8aedb','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2169,'64f24616-4315-4428-994d-3f37abbdb75b','40ff5841-a282-483f-b4eb-9352fceb77a9','2026-06-09 08:02:54',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-33-yy3sktsnfc3e','40ff5841-a282-483f-b4eb-9352fceb77a9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2170,'c93346da-cfc7-4b89-9124-d24ea009b84e','80d0a572-4f38-487a-aa00-501929d5d5b2','2026-06-09 08:02:54',NULL,'CREATE','COMPLETE','NovaLogging','d96c44e5-c3eb-4c94-8a18-44418cb04243','state changed','OS::TripleO::Services::Logging::NovaCommon',NULL,1285),(2171,'28ea79ba-4f81-4b89-a26a-c3cc0d56547a','80d0a572-4f38-487a-aa00-501929d5d5b2','2026-06-09 08:02:54',NULL,'CREATE','COMPLETE','NovaBase','749393f6-1c75-4e6a-8a4a-662340f43d5e','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,1293),(2172,'a84921ff-546f-49ce-9e68-3dae5bef23b3','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:54',NULL,'CREATE','IN_PROGRESS','42','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-42-egavomxfc4y4','state changed','OS::TripleO::Services::PlacementApi',NULL,1308),(2173,'0a331cdf-dcf8-48fb-b347-3f18048eb8e7','ab392585-82fa-475f-8b23-6c43ec036ed9','2026-06-09 08:02:54',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-42-egavomxfc4y4','ab392585-82fa-475f-8b23-6c43ec036ed9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2174,'3ea810d8-a621-412c-93cf-baa294e0525e','ab392585-82fa-475f-8b23-6c43ec036ed9','2026-06-09 08:02:54',NULL,'CREATE','IN_PROGRESS','ApacheServiceBase','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-42-egavomxfc4y4-ApacheServiceBase-fgc534p4wzns','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1309),(2175,'08094a75-cbbc-4aeb-ab5c-2f46378e08ba','ecc5b0f7-0413-42e3-9f38-addd15709e8c','2026-06-09 08:02:54',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-42-egavomxfc4y4-ApacheServiceBase-fgc534p4wzns','ecc5b0f7-0413-42e3-9f38-addd15709e8c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2176,'fec9421c-20e0-4c8b-8f3b-d97f953250fc','ecc5b0f7-0413-42e3-9f38-addd15709e8c','2026-06-09 08:02:54',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-42-egavomxfc4y4-ApacheServiceBase-fgc534p4wzns-ApacheNetworks-gziiqzqjg6y7','state changed','OS::Heat::Value',NULL,1310),(2177,'dfcf0f46-269e-4eae-9957-20ff8185c99c','b1fc9cfd-9bdd-4af5-b6f5-7d60ee97bc6b','2026-06-09 08:02:54',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-39-vhzvwynk7o3u-RoleParametersValue-q2ligegxikhh','state changed','OS::Heat::Value',NULL,1311),(2178,'4f4fce55-7b66-4373-ace1-11dec96e780c','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:54',NULL,'CREATE','COMPLETE','33','40ff5841-a282-483f-b4eb-9352fceb77a9','state changed','OS::TripleO::Services::NovaApi',NULL,1250),(2179,'207266e4-6857-410d-8471-05b632e68ffa','ecc5b0f7-0413-42e3-9f38-addd15709e8c','2026-06-09 08:02:54',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-42-egavomxfc4y4-ApacheServiceBase-fgc534p4wzns-ApacheNetworks-gziiqzqjg6y7','state changed','OS::Heat::Value',NULL,1310),(2180,'d0ecc07e-a7a3-439e-badf-302a7255b807','ecc5b0f7-0413-42e3-9f38-addd15709e8c','2026-06-09 08:02:54',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-42-egavomxfc4y4-ApacheServiceBase-fgc534p4wzns','ecc5b0f7-0413-42e3-9f38-addd15709e8c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2181,'6a6b2287-b8df-4227-9b2d-136d6ad312dd','b1fc9cfd-9bdd-4af5-b6f5-7d60ee97bc6b','2026-06-09 08:02:54',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-39-vhzvwynk7o3u-RoleParametersValue-q2ligegxikhh','state changed','OS::Heat::Value',NULL,1311),(2182,'1276e4fc-14d8-4756-90ea-b3599e240bb6','b1fc9cfd-9bdd-4af5-b6f5-7d60ee97bc6b','2026-06-09 08:02:54',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-39-vhzvwynk7o3u','b1fc9cfd-9bdd-4af5-b6f5-7d60ee97bc6b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2183,'dd05ea82-b94e-423a-b25a-a4ed6d68e233','80d0a572-4f38-487a-aa00-501929d5d5b2','2026-06-09 08:02:54',NULL,'CREATE','COMPLETE','NovaDBClient','2f0dd7d5-2af7-46a2-9ed3-4cabcfea24c6','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,1304),(2184,'9b4ca1c2-eb2b-4716-aa03-8ff24904811c','80d0a572-4f38-487a-aa00-501929d5d5b2','2026-06-09 08:02:54',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-36-k2mgipsp6nf5','80d0a572-4f38-487a-aa00-501929d5d5b2','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2185,'d677a615-5eb4-4fd8-9b3b-f7b2ed1e4f17','ab392585-82fa-475f-8b23-6c43ec036ed9','2026-06-09 08:02:55',NULL,'CREATE','IN_PROGRESS','PlacementLogging','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-42-egavomxfc4y4-PlacementLogging-tc6bhmd6khgv','state changed','OS::TripleO::Services::Logging::PlacementApi',NULL,NULL),(2186,'d346a207-998f-4105-876e-8c4cc30847ba','1f7086da-4099-4d35-a5a3-c14d0128f0ec','2026-06-09 08:02:55',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-42-egavomxfc4y4-PlacementLogging-tc6bhmd6khgv','1f7086da-4099-4d35-a5a3-c14d0128f0ec','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2187,'75f5a929-77f4-4e03-868a-7a6809301900','ab392585-82fa-475f-8b23-6c43ec036ed9','2026-06-09 08:02:55',NULL,'CREATE','COMPLETE','ApacheServiceBase','ecc5b0f7-0413-42e3-9f38-addd15709e8c','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml',NULL,1309),(2188,'6bcb1783-c8f3-437d-a620-2b2f191531d3','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:55',NULL,'CREATE','COMPLETE','36','80d0a572-4f38-487a-aa00-501929d5d5b2','state changed','OS::TripleO::Services::NovaScheduler',NULL,1262),(2189,'4347b861-6d79-4697-819d-51401bba3672','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:55',NULL,'CREATE','IN_PROGRESS','37','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-37-cxkekdd2xoy2','state changed','OS::TripleO::Services::NovaVncProxy',NULL,1324),(2190,'5e392eac-5ad8-453d-8bbc-c66c7c3c8e42','1f7086da-4099-4d35-a5a3-c14d0128f0ec','2026-06-09 08:02:55',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-42-egavomxfc4y4-PlacementLogging-tc6bhmd6khgv-RoleParametersValue-tsdztg7t5e5j','state changed','OS::Heat::Value',NULL,1325),(2191,'8f9269fe-56a1-450c-a753-c76fae4f2594','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:55',NULL,'CREATE','COMPLETE','39','b1fc9cfd-9bdd-4af5-b6f5-7d60ee97bc6b','state changed','OS::TripleO::Services::OVNDBs',NULL,1301),(2192,'e4e56d13-472c-4636-b889-7f3876e12478','1f7086da-4099-4d35-a5a3-c14d0128f0ec','2026-06-09 08:02:55',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-42-egavomxfc4y4-PlacementLogging-tc6bhmd6khgv-RoleParametersValue-tsdztg7t5e5j','state changed','OS::Heat::Value',NULL,1325),(2193,'101463c8-d9ac-426c-94bb-d6da64d4b94b','1f7086da-4099-4d35-a5a3-c14d0128f0ec','2026-06-09 08:02:55',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-42-egavomxfc4y4-PlacementLogging-tc6bhmd6khgv','1f7086da-4099-4d35-a5a3-c14d0128f0ec','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2194,'29cbe347-00b3-4eb7-87d6-b4f25cda1387','3b0b1b5d-1f24-4dcf-9878-beae0b9c5931','2026-06-09 08:02:55',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-37-cxkekdd2xoy2','3b0b1b5d-1f24-4dcf-9878-beae0b9c5931','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2195,'bba4b234-c020-4453-9530-b7da88476f1b','3b0b1b5d-1f24-4dcf-9878-beae0b9c5931','2026-06-09 08:02:55',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-37-cxkekdd2xoy2-MySQLClient-tjk25cre4dwq','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2196,'1bd93bae-d56c-4e2d-86d5-f7622a467bb6','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:56',NULL,'CREATE','IN_PROGRESS','43','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-43-uy3uto22dcmg','state changed','OS::TripleO::Services::OsloMessagingRpc',NULL,1332),(2197,'7ec0fa15-4ffe-48a3-a7cf-6bf2d0ccd318','b003e986-2c62-41df-bba0-89d2a40fd034','2026-06-09 08:02:56',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-37-cxkekdd2xoy2-MySQLClient-tjk25cre4dwq','b003e986-2c62-41df-bba0-89d2a40fd034','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2198,'ef76b994-6f9a-49ae-a1cc-18969400af06','b003e986-2c62-41df-bba0-89d2a40fd034','2026-06-09 08:02:56',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-37-cxkekdd2xoy2-MySQLClient-tjk25cre4dwq','b003e986-2c62-41df-bba0-89d2a40fd034','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2199,'bc4bc2b5-4bda-4aaa-8e1d-ccad80798c3c','d7e631e1-741b-420b-9c4f-359417b46afb','2026-06-09 08:02:56',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-43-uy3uto22dcmg','d7e631e1-741b-420b-9c4f-359417b46afb','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2200,'11370847-49e7-4c32-aef4-7985b81a4bf3','d7e631e1-741b-420b-9c4f-359417b46afb','2026-06-09 08:02:56',NULL,'CREATE','IN_PROGRESS','RabbitmqBase','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-43-uy3uto22dcmg-RabbitmqBase-5trhemakfy6k','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-container-puppet.yaml',NULL,1339),(2201,'92494435-887d-4e58-8f24-2d4f0b095ca0','7520214a-aaa5-4131-8cc1-6d46c9d24a1b','2026-06-09 08:02:56',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-43-uy3uto22dcmg-RabbitmqBase-5trhemakfy6k','7520214a-aaa5-4131-8cc1-6d46c9d24a1b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2202,'74e0c4f3-d722-44c2-8441-114f00146b24','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:02:56',NULL,'CREATE','IN_PROGRESS','40','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-40-w6zh2clxbacy','state changed','OS::TripleO::Services::OVNController',NULL,1341),(2203,'2653dcf2-4d14-4ffd-83d2-439ccaaf8691','ab392585-82fa-475f-8b23-6c43ec036ed9','2026-06-09 08:02:56',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-42-egavomxfc4y4-RoleParametersValue-nspgud2gtvrr','state changed','OS::Heat::Value',NULL,1342),(2204,'a2202441-b4af-4088-8680-c99635b21731','ab392585-82fa-475f-8b23-6c43ec036ed9','2026-06-09 08:02:56',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-42-egavomxfc4y4-RoleParametersValue-nspgud2gtvrr','state changed','OS::Heat::Value',NULL,1342),(2205,'ce294bb0-e073-4a32-8b11-c4aa68e23710','7520214a-aaa5-4131-8cc1-6d46c9d24a1b','2026-06-09 08:02:56',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-43-uy3uto22dcmg-RabbitmqBase-5trhemakfy6k-ContainersCommon-rrqqhrm7xtn6','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2206,'d98b70c3-5423-4758-aac1-c08deddcda9b','c623a287-0c65-495a-aa19-b0ac7a68263f','2026-06-09 08:02:56',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-40-w6zh2clxbacy','c623a287-0c65-495a-aa19-b0ac7a68263f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2207,'694a3e31-cb46-4865-a3c8-2aac6aee4eaf','ab392585-82fa-475f-8b23-6c43ec036ed9','2026-06-09 08:02:56',NULL,'CREATE','COMPLETE','PlacementLogging','1f7086da-4099-4d35-a5a3-c14d0128f0ec','state changed','OS::TripleO::Services::Logging::PlacementApi',NULL,NULL),(2208,'4ff1e1a9-3e29-475f-9746-feaa39c79749','aaa7fb7c-a76b-4fc2-af72-6dbc5783d273','2026-06-09 08:02:56',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-43-uy3uto22dcmg-RabbitmqBase-5trhemakfy6k-ContainersCommon-rrqqhrm7xtn6','aaa7fb7c-a76b-4fc2-af72-6dbc5783d273','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2209,'465975a7-0c83-4f86-9f0e-27f1490b44f4','aaa7fb7c-a76b-4fc2-af72-6dbc5783d273','2026-06-09 08:02:56',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-43-uy3uto22dcmg-RabbitmqBase-5trhemakfy6k-ContainersCommon-rrqqhrm7xtn6','aaa7fb7c-a76b-4fc2-af72-6dbc5783d273','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2210,'64a11477-00e7-4241-9874-f7a37ae005b8','c623a287-0c65-495a-aa19-b0ac7a68263f','2026-06-09 08:02:56',NULL,'CREATE','IN_PROGRESS','OVNBridgeMappingsValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-40-w6zh2clxbacy-OVNBridgeMappingsValue-5wbwrcnlfiph','state changed','OS::Heat::Value',NULL,1343),(2211,'835f2ebb-ac68-4006-90db-dc4693458ca1','c623a287-0c65-495a-aa19-b0ac7a68263f','2026-06-09 08:02:56',NULL,'CREATE','COMPLETE','OVNBridgeMappingsValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-40-w6zh2clxbacy-OVNBridgeMappingsValue-5wbwrcnlfiph','state changed','OS::Heat::Value',NULL,1343),(2212,'49b4b5dc-df3a-49bc-88fe-9af7c2282a42','3b0b1b5d-1f24-4dcf-9878-beae0b9c5931','2026-06-09 08:02:56',NULL,'CREATE','IN_PROGRESS','NovaDBClient','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-37-cxkekdd2xoy2-NovaDBClient-zdn5jnz6exw4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,1344),(2213,'31bf695d-b13d-4f96-a5c5-b3856e97f123','3b0b1b5d-1f24-4dcf-9878-beae0b9c5931','2026-06-09 08:02:57',NULL,'CREATE','COMPLETE','MySQLClient','b003e986-2c62-41df-bba0-89d2a40fd034','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2214,'d7b4d7d9-f97b-4121-bb31-e78cf36092c5','00e6b89a-9e07-4c03-ba76-28ae695c442e','2026-06-09 08:02:57',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-37-cxkekdd2xoy2-NovaDBClient-zdn5jnz6exw4','00e6b89a-9e07-4c03-ba76-28ae695c442e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2215,'878a8183-cb00-46b5-b279-5a63fea71c0b','00e6b89a-9e07-4c03-ba76-28ae695c442e','2026-06-09 08:02:57',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-37-cxkekdd2xoy2-NovaDBClient-zdn5jnz6exw4','00e6b89a-9e07-4c03-ba76-28ae695c442e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2216,'4a4e2110-d9dd-43eb-982e-62315f07ea8e','d7e631e1-741b-420b-9c4f-359417b46afb','2026-06-09 08:02:57',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-43-uy3uto22dcmg-RoleParametersValue-mdid2rvm57ow','state changed','OS::Heat::Value',NULL,1345),(2217,'fd9dcf24-0d90-41a6-81ba-67600507e1b9','d7e631e1-741b-420b-9c4f-359417b46afb','2026-06-09 08:02:57',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-43-uy3uto22dcmg-RoleParametersValue-mdid2rvm57ow','state changed','OS::Heat::Value',NULL,1345),(2218,'7d3abf42-50d4-4f3e-b8ae-b07e66891e0a','ab392585-82fa-475f-8b23-6c43ec036ed9','2026-06-09 08:02:57',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-42-egavomxfc4y4-ContainersCommon-wmlhgh43yx7m','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2219,'886c1923-678c-4948-8e14-b7fb91f1e9fc','7520214a-aaa5-4131-8cc1-6d46c9d24a1b','2026-06-09 08:02:57',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-43-uy3uto22dcmg-RabbitmqBase-5trhemakfy6k-RoleParametersValue-m7hr3wauml4n','state changed','OS::Heat::Value',NULL,1346),(2220,'663ce41d-0064-44fb-bab6-be569c5e4c47','5cdbbd65-c118-461e-b652-02258af0452c','2026-06-09 08:02:57',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-42-egavomxfc4y4-ContainersCommon-wmlhgh43yx7m','5cdbbd65-c118-461e-b652-02258af0452c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2221,'724b0401-3cea-453c-a9a9-be8a8f6801d6','7520214a-aaa5-4131-8cc1-6d46c9d24a1b','2026-06-09 08:02:57',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-43-uy3uto22dcmg-RabbitmqBase-5trhemakfy6k-RoleParametersValue-m7hr3wauml4n','state changed','OS::Heat::Value',NULL,1346),(2222,'3d834bb7-cb73-41ab-952a-557734e720c0','7520214a-aaa5-4131-8cc1-6d46c9d24a1b','2026-06-09 08:02:57',NULL,'CREATE','COMPLETE','ContainersCommon','aaa7fb7c-a76b-4fc2-af72-6dbc5783d273','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2223,'4ac2ab4b-aab4-4fa2-b57a-c9d692c7c9e8','5cdbbd65-c118-461e-b652-02258af0452c','2026-06-09 08:02:57',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-42-egavomxfc4y4-ContainersCommon-wmlhgh43yx7m','5cdbbd65-c118-461e-b652-02258af0452c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2224,'30254215-33f2-4262-85dc-b36d82b84372','c623a287-0c65-495a-aa19-b0ac7a68263f','2026-06-09 08:02:57',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-40-w6zh2clxbacy-RoleParametersValue-ovjhievwf4ms','state changed','OS::Heat::Value',NULL,1347),(2225,'0247dacb-841f-4262-9afd-f0d81caffb0d','c623a287-0c65-495a-aa19-b0ac7a68263f','2026-06-09 08:02:57',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-40-w6zh2clxbacy-RoleParametersValue-ovjhievwf4ms','state changed','OS::Heat::Value',NULL,1347),(2226,'fd9e6f9a-d0c5-45ab-be11-5afc7ab1bfc8','3b0b1b5d-1f24-4dcf-9878-beae0b9c5931','2026-06-09 08:02:57',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-37-cxkekdd2xoy2-RoleParametersValue-wifx5pxhdkgh','state changed','OS::Heat::Value',NULL,1348),(2227,'36604ee9-837e-47af-9b5f-5057e86fd6d4','3b0b1b5d-1f24-4dcf-9878-beae0b9c5931','2026-06-09 08:02:57',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-37-cxkekdd2xoy2-RoleParametersValue-wifx5pxhdkgh','state changed','OS::Heat::Value',NULL,1348),(2228,'3ee8a873-2819-40d9-9806-0ace8b83de7b','3b0b1b5d-1f24-4dcf-9878-beae0b9c5931','2026-06-09 08:02:58',NULL,'CREATE','IN_PROGRESS','NovaLogging','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-37-cxkekdd2xoy2-NovaLogging-zpo2xaocqwub','state changed','OS::TripleO::Services::Logging::NovaCommon',NULL,1350),(2229,'290c1cb4-28a1-4f5f-87f4-d2db7a3fbb76','3b0b1b5d-1f24-4dcf-9878-beae0b9c5931','2026-06-09 08:02:58',NULL,'CREATE','COMPLETE','NovaDBClient','00e6b89a-9e07-4c03-ba76-28ae695c442e','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-db-client-puppet.yaml',NULL,1344),(2230,'297fcf2a-746d-4d38-a6c7-ee935843e7ba','a5be0031-8bfa-48bd-b964-332390b36794','2026-06-09 08:02:58',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-37-cxkekdd2xoy2-NovaLogging-zpo2xaocqwub','a5be0031-8bfa-48bd-b964-332390b36794','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2231,'2be1ee8d-6fdf-4ba1-bfb3-577eb27677ad','d7e631e1-741b-420b-9c4f-359417b46afb','2026-06-09 08:02:58',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-43-uy3uto22dcmg-ContainersCommon-cuxajx22p4if','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2232,'1c2c366b-b6d6-47fb-aedb-e4fda1511292','a5be0031-8bfa-48bd-b964-332390b36794','2026-06-09 08:02:58',NULL,'CREATE','IN_PROGRESS','InitLogContainerName','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-37-cxkekdd2xoy2-NovaLogging-zpo2xaocqwub-InitLogContainerName-4fpgtyscisv2','state changed','OS::Heat::Value',NULL,1351),(2233,'784069b2-cfdf-4af3-9c49-a78bd5bdfa05','a5be0031-8bfa-48bd-b964-332390b36794','2026-06-09 08:02:58',NULL,'CREATE','COMPLETE','InitLogContainerName','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-37-cxkekdd2xoy2-NovaLogging-zpo2xaocqwub-InitLogContainerName-4fpgtyscisv2','state changed','OS::Heat::Value',NULL,1351),(2234,'589c20b9-1c74-4f93-98c4-f6445873ad6b','3e3bc68d-0d17-4f86-bbe7-6e4a52741223','2026-06-09 08:02:58',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-43-uy3uto22dcmg-ContainersCommon-cuxajx22p4if','3e3bc68d-0d17-4f86-bbe7-6e4a52741223','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2235,'85f61e01-f060-4fa1-860b-1c0eddbc3132','3e3bc68d-0d17-4f86-bbe7-6e4a52741223','2026-06-09 08:02:58',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-43-uy3uto22dcmg-ContainersCommon-cuxajx22p4if','3e3bc68d-0d17-4f86-bbe7-6e4a52741223','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2236,'4dbffd80-97db-4f6f-9749-3548ee817a2f','ab392585-82fa-475f-8b23-6c43ec036ed9','2026-06-09 08:02:58',NULL,'CREATE','IN_PROGRESS','MySQLClient','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-42-egavomxfc4y4-MySQLClient-uog77ymjc32r','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2237,'76371320-e90e-420a-8e44-d9504c35d230','bdcb7ebd-fa47-4a87-a212-9e7756640bb7','2026-06-09 08:02:58',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-42-egavomxfc4y4-MySQLClient-uog77ymjc32r','bdcb7ebd-fa47-4a87-a212-9e7756640bb7','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2238,'3b6e3e5b-db6a-4cf6-9df9-b4f4b691ddf8','7520214a-aaa5-4131-8cc1-6d46c9d24a1b','2026-06-09 08:02:58',NULL,'CREATE','IN_PROGRESS','RabbitMQServiceBase','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-43-uy3uto22dcmg-RabbitmqBase-5trhemakfy6k-RabbitMQServiceBase-r2hkpf4lfk3s','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-container-puppet.yaml',NULL,1352),(2239,'8095bcdc-1f48-414d-93bf-0bed3fe46791','bdcb7ebd-fa47-4a87-a212-9e7756640bb7','2026-06-09 08:02:58',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-42-egavomxfc4y4-MySQLClient-uog77ymjc32r','bdcb7ebd-fa47-4a87-a212-9e7756640bb7','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2240,'b21edd7c-dd8d-4aba-a6cd-d38a7ce66206','ab392585-82fa-475f-8b23-6c43ec036ed9','2026-06-09 08:02:58',NULL,'CREATE','COMPLETE','ContainersCommon','5cdbbd65-c118-461e-b652-02258af0452c','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2241,'0524889d-4adf-4ca2-81e0-24827c9a07dc','9e45522f-6e58-45fc-95a2-afa95719f233','2026-06-09 08:02:58',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-43-uy3uto22dcmg-RabbitmqBase-5trhemakfy6k-RabbitMQServiceBase-r2hkpf4lfk3s','9e45522f-6e58-45fc-95a2-afa95719f233','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2242,'25e95434-ee04-4521-9b30-1dbc78660296','c623a287-0c65-495a-aa19-b0ac7a68263f','2026-06-09 08:02:58',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-40-w6zh2clxbacy-ContainersCommon-qhd37iowspu7','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2243,'0ec5f3ba-4a1e-4483-b298-7e92faea0fba','e8a7af34-fc5a-4187-9b0f-4454ef4766c4','2026-06-09 08:02:58',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-40-w6zh2clxbacy-ContainersCommon-qhd37iowspu7','e8a7af34-fc5a-4187-9b0f-4454ef4766c4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2244,'9d586153-f876-4c48-b4a5-17679e218e54','9e45522f-6e58-45fc-95a2-afa95719f233','2026-06-09 08:02:58',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-43-uy3uto22dcmg-RabbitmqBase-5trhemakfy6k-RabbitMQServiceBase-r2hkpf4lfk3s-RoleParametersValue-yjbsnwmpmkpf','state changed','OS::Heat::Value',NULL,1353),(2245,'9098f8d0-5106-43be-89a4-d27cd270d43c','9e45522f-6e58-45fc-95a2-afa95719f233','2026-06-09 08:02:58',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-43-uy3uto22dcmg-RabbitmqBase-5trhemakfy6k-RabbitMQServiceBase-r2hkpf4lfk3s-RoleParametersValue-yjbsnwmpmkpf','state changed','OS::Heat::Value',NULL,1353),(2246,'a04eb050-e09a-49ca-92ff-05f16fcfa1b9','e8a7af34-fc5a-4187-9b0f-4454ef4766c4','2026-06-09 08:02:58',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-40-w6zh2clxbacy-ContainersCommon-qhd37iowspu7','e8a7af34-fc5a-4187-9b0f-4454ef4766c4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2247,'d4de63f0-7fd9-49db-a36b-9e10b9d1a49b','3b0b1b5d-1f24-4dcf-9878-beae0b9c5931','2026-06-09 08:02:58',NULL,'CREATE','IN_PROGRESS','NovaBase','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-37-cxkekdd2xoy2-NovaBase-enykttmml5fp','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,1354),(2248,'fb597382-a139-4f45-88d3-11413e8ed6da','1088c1c4-c7b7-4ff0-b9fc-7f3b6a1f3c6b','2026-06-09 08:02:59',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-37-cxkekdd2xoy2-NovaBase-enykttmml5fp','1088c1c4-c7b7-4ff0-b9fc-7f3b6a1f3c6b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2249,'1588bd78-81a9-475d-af60-c78b58621e23','1088c1c4-c7b7-4ff0-b9fc-7f3b6a1f3c6b','2026-06-09 08:02:59',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-37-cxkekdd2xoy2-NovaBase-enykttmml5fp-RoleParametersValue-uyscjjxlock3','state changed','OS::Heat::Value',NULL,1355),(2250,'a3f5e79a-e9de-4786-af60-4f6ff020b090','1088c1c4-c7b7-4ff0-b9fc-7f3b6a1f3c6b','2026-06-09 08:02:59',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-37-cxkekdd2xoy2-NovaBase-enykttmml5fp-RoleParametersValue-uyscjjxlock3','state changed','OS::Heat::Value',NULL,1355),(2251,'c5db89fd-f35f-429b-8648-7da3938e5aac','1088c1c4-c7b7-4ff0-b9fc-7f3b6a1f3c6b','2026-06-09 08:02:59',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-37-cxkekdd2xoy2-NovaBase-enykttmml5fp','1088c1c4-c7b7-4ff0-b9fc-7f3b6a1f3c6b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2252,'60677b9e-92c0-472a-928f-f79c36048048','a5be0031-8bfa-48bd-b964-332390b36794','2026-06-09 08:02:59',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-37-cxkekdd2xoy2-NovaLogging-zpo2xaocqwub-RoleParametersValue-e56hhoni2vin','state changed','OS::Heat::Value',NULL,1356),(2253,'fce75b44-3c63-442e-978d-eb9771795af2','a5be0031-8bfa-48bd-b964-332390b36794','2026-06-09 08:02:59',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-37-cxkekdd2xoy2-NovaLogging-zpo2xaocqwub-RoleParametersValue-e56hhoni2vin','state changed','OS::Heat::Value',NULL,1356),(2254,'99257e93-23fa-4446-96fa-af878ed9b8c1','a5be0031-8bfa-48bd-b964-332390b36794','2026-06-09 08:02:59',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-37-cxkekdd2xoy2-NovaLogging-zpo2xaocqwub','a5be0031-8bfa-48bd-b964-332390b36794','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2255,'a17cb025-c8f5-45a6-9c15-489e92c0bebb','d7e631e1-741b-420b-9c4f-359417b46afb','2026-06-09 08:02:59',NULL,'CREATE','COMPLETE','ContainersCommon','3e3bc68d-0d17-4f86-bbe7-6e4a52741223','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2256,'20dd1c88-39b5-4ad7-9223-dfee1f2edc9e','ab392585-82fa-475f-8b23-6c43ec036ed9','2026-06-09 08:02:59',NULL,'CREATE','COMPLETE','MySQLClient','bdcb7ebd-fa47-4a87-a212-9e7756640bb7','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml',NULL,NULL),(2257,'b86e3b91-e3bc-4b86-a386-5d36935a60eb','ab392585-82fa-475f-8b23-6c43ec036ed9','2026-06-09 08:02:59',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-42-egavomxfc4y4','ab392585-82fa-475f-8b23-6c43ec036ed9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2258,'6230c235-da64-44e0-bb1c-167368ad8142','9e45522f-6e58-45fc-95a2-afa95719f233','2026-06-09 08:02:59',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-43-uy3uto22dcmg-RabbitmqBase-5trhemakfy6k-RabbitMQServiceBase-r2hkpf4lfk3s-ContainersCommon-u7zdeuvlk3mb','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2259,'5e768efa-bb13-4794-a33c-4f26aab8f56d','c623a287-0c65-495a-aa19-b0ac7a68263f','2026-06-09 08:02:59',NULL,'CREATE','COMPLETE','ContainersCommon','e8a7af34-fc5a-4187-9b0f-4454ef4766c4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2260,'9b1236a0-dbed-4d6b-8956-9b9172d6f5a1','c623a287-0c65-495a-aa19-b0ac7a68263f','2026-06-09 08:02:59',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-40-w6zh2clxbacy','c623a287-0c65-495a-aa19-b0ac7a68263f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2261,'8841f0cf-442c-4912-a054-67b4c98b4567','7c9c73ec-2f88-431a-b7a0-7d82dc149a99','2026-06-09 08:02:59',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-43-uy3uto22dcmg-RabbitmqBase-5trhemakfy6k-RabbitMQServiceBase-r2hkpf4lfk3s-ContainersCommon-u7zdeuvlk3mb','7c9c73ec-2f88-431a-b7a0-7d82dc149a99','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2262,'9c443c21-8d49-4ff0-ae95-be2b463af55c','7c9c73ec-2f88-431a-b7a0-7d82dc149a99','2026-06-09 08:02:59',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-43-uy3uto22dcmg-RabbitmqBase-5trhemakfy6k-RabbitMQServiceBase-r2hkpf4lfk3s-ContainersCommon-u7zdeuvlk3mb','7c9c73ec-2f88-431a-b7a0-7d82dc149a99','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2263,'cb3b395e-c5a4-42a8-9261-b79c0b97f41c','3b0b1b5d-1f24-4dcf-9878-beae0b9c5931','2026-06-09 08:02:59',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-37-cxkekdd2xoy2-ContainersCommon-uuxyg5kqe374','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2264,'8801efa7-16f7-48c8-b99b-630587bf20d3','7c006de7-6983-4f98-80ed-68336be5cb39','2026-06-09 08:03:00',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-37-cxkekdd2xoy2-ContainersCommon-uuxyg5kqe374','7c006de7-6983-4f98-80ed-68336be5cb39','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2265,'794b640b-ddf8-44d5-8cf3-b8095e438bec','7c006de7-6983-4f98-80ed-68336be5cb39','2026-06-09 08:03:00',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-37-cxkekdd2xoy2-ContainersCommon-uuxyg5kqe374','7c006de7-6983-4f98-80ed-68336be5cb39','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2266,'79036df4-b31d-46b8-b4ff-b972e46f9d8e','3b0b1b5d-1f24-4dcf-9878-beae0b9c5931','2026-06-09 08:03:00',NULL,'CREATE','COMPLETE','NovaBase','1088c1c4-c7b7-4ff0-b9fc-7f3b6a1f3c6b','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml',NULL,1354),(2267,'5a3b9c1f-47dc-4c03-bf30-313a152e0f55','3b0b1b5d-1f24-4dcf-9878-beae0b9c5931','2026-06-09 08:03:00',NULL,'CREATE','COMPLETE','NovaLogging','a5be0031-8bfa-48bd-b964-332390b36794','state changed','OS::TripleO::Services::Logging::NovaCommon',NULL,1350),(2268,'ed974a4c-fb55-48f2-88ee-494828caa1ff','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:03:00',NULL,'CREATE','COMPLETE','42','ab392585-82fa-475f-8b23-6c43ec036ed9','state changed','OS::TripleO::Services::PlacementApi',NULL,1308),(2269,'d52e9d9d-b600-42b9-baa5-030b40eaae5c','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:03:00',NULL,'CREATE','COMPLETE','40','c623a287-0c65-495a-aa19-b0ac7a68263f','state changed','OS::TripleO::Services::OVNController',NULL,1341),(2270,'a82f68fa-20d8-4059-a9c5-e2813ab7a0f2','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:03:00',NULL,'CREATE','IN_PROGRESS','46','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-46-jckbg3leoonh','state changed','OS::TripleO::Services::Redis',NULL,1369),(2271,'57069db4-4dd1-4d94-bd8c-8692d5b85aae','9e45522f-6e58-45fc-95a2-afa95719f233','2026-06-09 08:03:00',NULL,'CREATE','COMPLETE','ContainersCommon','7c9c73ec-2f88-431a-b7a0-7d82dc149a99','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2272,'62579607-2259-4052-9306-2591cc457985','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:03:00',NULL,'CREATE','IN_PROGRESS','44','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-44-35q7d35avjxs','state changed','OS::TripleO::Services::OsloMessagingNotify',NULL,1370),(2273,'f4c7cc54-f28a-4c28-910c-54564c0b0a70','9e45522f-6e58-45fc-95a2-afa95719f233','2026-06-09 08:03:01',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-43-uy3uto22dcmg-RabbitmqBase-5trhemakfy6k-RabbitMQServiceBase-r2hkpf4lfk3s','9e45522f-6e58-45fc-95a2-afa95719f233','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2274,'e09af723-161c-4761-bb55-208fd955388c','fb4ab94a-63a4-4a3c-9a0a-8a0ae6eb1a2d','2026-06-09 08:03:01',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-46-jckbg3leoonh','fb4ab94a-63a4-4a3c-9a0a-8a0ae6eb1a2d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2275,'7d37f43b-509b-4872-9808-a53604842e83','3b0b1b5d-1f24-4dcf-9878-beae0b9c5931','2026-06-09 08:03:01',NULL,'CREATE','COMPLETE','ContainersCommon','7c006de7-6983-4f98-80ed-68336be5cb39','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2276,'bce90447-0cf1-4771-93c9-028e434e9482','2a8a44e8-7e8a-4ba5-865e-385220b3f189','2026-06-09 08:03:01',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-44-35q7d35avjxs','2a8a44e8-7e8a-4ba5-865e-385220b3f189','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2277,'4c5a0280-b464-4c50-a6d0-f022f5a59d5a','3b0b1b5d-1f24-4dcf-9878-beae0b9c5931','2026-06-09 08:03:01',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-37-cxkekdd2xoy2','3b0b1b5d-1f24-4dcf-9878-beae0b9c5931','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2278,'d80a89c9-3426-4bf2-9b63-d1c41ac30905','2a8a44e8-7e8a-4ba5-865e-385220b3f189','2026-06-09 08:03:01',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-44-35q7d35avjxs-ContainersCommon-rnxpjuffqb3l','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2279,'f7d90edf-3afe-44d5-b90e-bac57bfcea67','91b512d6-2ad7-4745-90ff-d4c85cdf7f2f','2026-06-09 08:03:01',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-44-35q7d35avjxs-ContainersCommon-rnxpjuffqb3l','91b512d6-2ad7-4745-90ff-d4c85cdf7f2f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2280,'8692f808-f07f-4782-8361-1178f32ed4f3','fb4ab94a-63a4-4a3c-9a0a-8a0ae6eb1a2d','2026-06-09 08:03:01',NULL,'CREATE','IN_PROGRESS','RedisBase','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-46-jckbg3leoonh-RedisBase-lbiwc75axsmh','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-container-puppet.yaml',NULL,1371),(2281,'4f917da8-03fe-4dc7-ab82-e270bf15249b','91b512d6-2ad7-4745-90ff-d4c85cdf7f2f','2026-06-09 08:03:01',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-44-35q7d35avjxs-ContainersCommon-rnxpjuffqb3l','91b512d6-2ad7-4745-90ff-d4c85cdf7f2f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2282,'a3471093-aa3a-4242-96d1-9594e2b6de7e','b1f8097a-2606-4a49-8254-c848d9505770','2026-06-09 08:03:01',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-46-jckbg3leoonh-RedisBase-lbiwc75axsmh','b1f8097a-2606-4a49-8254-c848d9505770','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2283,'92f83c65-9e18-49ec-9448-447e6aef3db3','b1f8097a-2606-4a49-8254-c848d9505770','2026-06-09 08:03:01',NULL,'CREATE','IN_PROGRESS','RedisBase','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-46-jckbg3leoonh-RedisBase-lbiwc75axsmh-RedisBase-iti5nhgf3aif','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-base-puppet.yaml',NULL,1372),(2284,'5c10de72-e5bf-4f95-ad10-9005a2255d97','9d494b72-b02e-4714-8541-8d3debb81912','2026-06-09 08:03:01',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-46-jckbg3leoonh-RedisBase-lbiwc75axsmh-RedisBase-iti5nhgf3aif','9d494b72-b02e-4714-8541-8d3debb81912','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2285,'6584f227-8930-4083-b9de-7dbcadd3ebed','9d494b72-b02e-4714-8541-8d3debb81912','2026-06-09 08:03:01',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-46-jckbg3leoonh-RedisBase-lbiwc75axsmh-RedisBase-iti5nhgf3aif','9d494b72-b02e-4714-8541-8d3debb81912','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2286,'a22e4b40-7f1b-43a8-a6f1-abec329f3fa2','7520214a-aaa5-4131-8cc1-6d46c9d24a1b','2026-06-09 08:03:01',NULL,'CREATE','COMPLETE','RabbitMQServiceBase','9e45522f-6e58-45fc-95a2-afa95719f233','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-container-puppet.yaml',NULL,1352),(2287,'68066421-2179-48d6-b9b2-53c67e0a0332','7520214a-aaa5-4131-8cc1-6d46c9d24a1b','2026-06-09 08:03:01',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-43-uy3uto22dcmg-RabbitmqBase-5trhemakfy6k','7520214a-aaa5-4131-8cc1-6d46c9d24a1b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2288,'c1555523-9c89-4372-8036-a1b5aaf51882','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:03:01',NULL,'CREATE','COMPLETE','37','3b0b1b5d-1f24-4dcf-9878-beae0b9c5931','state changed','OS::TripleO::Services::NovaVncProxy',NULL,1324),(2289,'f8a02563-aefa-40ae-ad3d-2c56905fd701','fb4ab94a-63a4-4a3c-9a0a-8a0ae6eb1a2d','2026-06-09 08:03:02',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-46-jckbg3leoonh-RoleParametersValue-cktnrwt5nzxq','state changed','OS::Heat::Value',NULL,1381),(2290,'a568faed-f136-420c-9353-29d52593555c','fb4ab94a-63a4-4a3c-9a0a-8a0ae6eb1a2d','2026-06-09 08:03:02',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-46-jckbg3leoonh-RoleParametersValue-cktnrwt5nzxq','state changed','OS::Heat::Value',NULL,1381),(2291,'62ed6016-3e48-4bd2-adf8-374acfac51e1','d7e631e1-741b-420b-9c4f-359417b46afb','2026-06-09 08:03:02',NULL,'CREATE','COMPLETE','RabbitmqBase','7520214a-aaa5-4131-8cc1-6d46c9d24a1b','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-container-puppet.yaml',NULL,1339),(2292,'3fbe9770-92e3-4447-b4a8-4f405623acd4','d7e631e1-741b-420b-9c4f-359417b46afb','2026-06-09 08:03:02',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-43-uy3uto22dcmg','d7e631e1-741b-420b-9c4f-359417b46afb','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2293,'baad230d-3efb-4c3a-a752-76c7ca2a1c37','2a8a44e8-7e8a-4ba5-865e-385220b3f189','2026-06-09 08:03:02',NULL,'CREATE','COMPLETE','ContainersCommon','91b512d6-2ad7-4745-90ff-d4c85cdf7f2f','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2294,'e4a83058-0334-4af7-b206-f64b2f99c0e5','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:03:02',NULL,'CREATE','IN_PROGRESS','41','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-41-b7hwioxyfgcv','state changed','OS::TripleO::Services::Pacemaker',NULL,1383),(2295,'cbda6446-7952-497e-b6fe-0c3abb2526f7','2a8a44e8-7e8a-4ba5-865e-385220b3f189','2026-06-09 08:03:02',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-44-35q7d35avjxs','2a8a44e8-7e8a-4ba5-865e-385220b3f189','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2296,'7b86ac31-3e3f-4392-9fc8-ff2661db83b0','b1f8097a-2606-4a49-8254-c848d9505770','2026-06-09 08:03:02',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-46-jckbg3leoonh-RedisBase-lbiwc75axsmh-ContainersCommon-z3sivjttb7lc','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2297,'36d673e5-6e3f-4135-8b6f-242c95295f46','15d6f444-2255-4978-b2f1-c4d938112576','2026-06-09 08:03:02',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-41-b7hwioxyfgcv','15d6f444-2255-4978-b2f1-c4d938112576','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2298,'666d544e-613f-4c81-aa1d-1d593037285b','15d6f444-2255-4978-b2f1-c4d938112576','2026-06-09 08:03:02',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-41-b7hwioxyfgcv','15d6f444-2255-4978-b2f1-c4d938112576','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2299,'6ed00ec3-a53e-4b4e-a2d8-a1a928d4b44a','b1f8097a-2606-4a49-8254-c848d9505770','2026-06-09 08:03:02',NULL,'CREATE','COMPLETE','RedisBase','9d494b72-b02e-4714-8541-8d3debb81912','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-base-puppet.yaml',NULL,1372),(2300,'628e78ba-6977-46d9-b363-78670b7b08b4','50bdfade-4822-4ee7-93b0-a3279ea41cba','2026-06-09 08:03:02',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-46-jckbg3leoonh-RedisBase-lbiwc75axsmh-ContainersCommon-z3sivjttb7lc','50bdfade-4822-4ee7-93b0-a3279ea41cba','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2301,'459d84c4-6e95-4f2f-a492-3977199f94f1','50bdfade-4822-4ee7-93b0-a3279ea41cba','2026-06-09 08:03:02',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-46-jckbg3leoonh-RedisBase-lbiwc75axsmh-ContainersCommon-z3sivjttb7lc','50bdfade-4822-4ee7-93b0-a3279ea41cba','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2302,'51f620c6-6f5b-4f7f-aaaa-6d6929c4de34','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:03:03',NULL,'CREATE','COMPLETE','44','2a8a44e8-7e8a-4ba5-865e-385220b3f189','state changed','OS::TripleO::Services::OsloMessagingNotify',NULL,1370),(2303,'3f6ca3b4-a283-4aa4-abe0-c7badcd20a1f','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:03:03',NULL,'CREATE','COMPLETE','43','d7e631e1-741b-420b-9c4f-359417b46afb','state changed','OS::TripleO::Services::OsloMessagingRpc',NULL,1332),(2304,'587bf44e-c79b-466f-bf4e-8ef60e40a3e2','fb4ab94a-63a4-4a3c-9a0a-8a0ae6eb1a2d','2026-06-09 08:03:03',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-46-jckbg3leoonh-ContainersCommon-kkk6xmuuhfyw','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2305,'9cbec654-62fb-45d9-b563-62b5d410c8c4','fbb7e8fd-cef5-4f76-ac07-2b23820de5d3','2026-06-09 08:03:03',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-46-jckbg3leoonh-ContainersCommon-kkk6xmuuhfyw','fbb7e8fd-cef5-4f76-ac07-2b23820de5d3','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2306,'b316f397-b057-4e1e-ab8f-05407d43ffb8','fbb7e8fd-cef5-4f76-ac07-2b23820de5d3','2026-06-09 08:03:03',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-46-jckbg3leoonh-ContainersCommon-kkk6xmuuhfyw','fbb7e8fd-cef5-4f76-ac07-2b23820de5d3','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2307,'516b9d62-0c47-438a-b393-023b00d89e94','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:03:03',NULL,'CREATE','IN_PROGRESS','48','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-48-lwczxam23viw','state changed','OS::TripleO::Services::Snmp',NULL,1388),(2308,'ea746965-32a9-488f-9da5-834e56524339','b1f8097a-2606-4a49-8254-c848d9505770','2026-06-09 08:03:03',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-46-jckbg3leoonh-RedisBase-lbiwc75axsmh-RoleParametersValue-jolrks57bdqu','state changed','OS::Heat::Value',NULL,1390),(2309,'7cf463bb-9c7c-452c-a4ab-9a9a38e527aa','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:03:03',NULL,'CREATE','COMPLETE','41','15d6f444-2255-4978-b2f1-c4d938112576','state changed','OS::TripleO::Services::Pacemaker',NULL,1383),(2310,'bc6b9b31-69b2-4a5e-a51b-f0b34bb9b0df','b1f8097a-2606-4a49-8254-c848d9505770','2026-06-09 08:03:03',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-46-jckbg3leoonh-RedisBase-lbiwc75axsmh-RoleParametersValue-jolrks57bdqu','state changed','OS::Heat::Value',NULL,1390),(2311,'57ed737a-2188-41a0-a43f-5630973cba05','6c005145-a9ca-4736-8cf6-6d1b8633304c','2026-06-09 08:03:03',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-48-lwczxam23viw','6c005145-a9ca-4736-8cf6-6d1b8633304c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2312,'4baed769-f3f8-4c90-9a40-351126afa95a','6c005145-a9ca-4736-8cf6-6d1b8633304c','2026-06-09 08:03:03',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-48-lwczxam23viw','6c005145-a9ca-4736-8cf6-6d1b8633304c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2313,'1c696bdf-8a6e-47e4-917e-10511bf5ef12','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:03:03',NULL,'CREATE','IN_PROGRESS','45','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-45-zw2uaqrw65vs','state changed','OS::TripleO::Services::Podman',NULL,1397),(2314,'c3fb134c-f8ea-4023-a3a6-7c3081557617','b1f8097a-2606-4a49-8254-c848d9505770','2026-06-09 08:03:03',NULL,'CREATE','COMPLETE','ContainersCommon','50bdfade-4822-4ee7-93b0-a3279ea41cba','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2315,'a8a48fc8-d64b-4cf1-9628-9560fe2f2eb2','b1f8097a-2606-4a49-8254-c848d9505770','2026-06-09 08:03:04',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-46-jckbg3leoonh-RedisBase-lbiwc75axsmh','b1f8097a-2606-4a49-8254-c848d9505770','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2316,'d5a56f0c-3a40-48f4-bb26-2795e3482751','6695688e-e43a-47b8-97b1-a87bb3311084','2026-06-09 08:03:04',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-45-zw2uaqrw65vs','6695688e-e43a-47b8-97b1-a87bb3311084','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2317,'1aa64194-ef18-42e3-a5a4-2ca3016e18bd','6695688e-e43a-47b8-97b1-a87bb3311084','2026-06-09 08:03:04',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-45-zw2uaqrw65vs','6695688e-e43a-47b8-97b1-a87bb3311084','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2318,'ff76ac3e-1c51-434b-97d0-13848911f1d6','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:03:04',NULL,'CREATE','IN_PROGRESS','47','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-47-6uivqnt4ojei','state changed','OS::TripleO::Services::Rsyslog',NULL,1399),(2319,'6fbfd17a-733d-4f92-ba49-2fba696b2435','0eabef1f-8876-407f-b648-c57cafa5dc53','2026-06-09 08:03:04',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-47-6uivqnt4ojei','0eabef1f-8876-407f-b648-c57cafa5dc53','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2320,'ef0808f8-1afa-4904-921c-bfe38c1c5544','fb4ab94a-63a4-4a3c-9a0a-8a0ae6eb1a2d','2026-06-09 08:03:04',NULL,'CREATE','COMPLETE','ContainersCommon','fbb7e8fd-cef5-4f76-ac07-2b23820de5d3','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2321,'bdb3d83b-bfb4-4339-b21e-fb03add916c5','fb4ab94a-63a4-4a3c-9a0a-8a0ae6eb1a2d','2026-06-09 08:03:04',NULL,'CREATE','COMPLETE','RedisBase','b1f8097a-2606-4a49-8254-c848d9505770','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-container-puppet.yaml',NULL,1371),(2322,'7b74572a-0637-4e41-b926-7fd2894055d1','0eabef1f-8876-407f-b648-c57cafa5dc53','2026-06-09 08:03:04',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-47-6uivqnt4ojei-RoleParametersValue-nuwbbl7dbks3','state changed','OS::Heat::Value',NULL,1400),(2323,'41cd2526-67f8-46f1-a619-9bcf1e316478','fb4ab94a-63a4-4a3c-9a0a-8a0ae6eb1a2d','2026-06-09 08:03:04',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-46-jckbg3leoonh','fb4ab94a-63a4-4a3c-9a0a-8a0ae6eb1a2d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2324,'4a924054-1743-4066-92af-427759557afa','0eabef1f-8876-407f-b648-c57cafa5dc53','2026-06-09 08:03:04',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-47-6uivqnt4ojei-RoleParametersValue-nuwbbl7dbks3','state changed','OS::Heat::Value',NULL,1400),(2325,'5342a7ac-f9bb-4915-aeec-99eddbd1ccd4','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:03:04',NULL,'CREATE','COMPLETE','48','6c005145-a9ca-4736-8cf6-6d1b8633304c','state changed','OS::TripleO::Services::Snmp',NULL,1388),(2326,'fc14cc5e-d457-4edf-a737-3343e57c1d01','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:03:04',NULL,'CREATE','IN_PROGRESS','52','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-52-34cku7h3toyo','state changed','OS::TripleO::Services::SwiftStorage',NULL,1402),(2327,'ecf7bfc3-9bc6-4ae5-b038-263a4e4c004a','fa66feec-3f9f-4020-a076-78f84b4593e5','2026-06-09 08:03:05',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-52-34cku7h3toyo','fa66feec-3f9f-4020-a076-78f84b4593e5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2328,'758ea86a-6d1f-4b43-9928-cd5180dfacdc','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:03:05',NULL,'CREATE','COMPLETE','45','6695688e-e43a-47b8-97b1-a87bb3311084','state changed','OS::TripleO::Services::Podman',NULL,1397),(2329,'b0c2fc3e-759a-4f86-b02d-7dd2754b7721','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:03:05',NULL,'CREATE','COMPLETE','46','fb4ab94a-63a4-4a3c-9a0a-8a0ae6eb1a2d','state changed','OS::TripleO::Services::Redis',NULL,1369),(2330,'c750afec-6302-4713-a390-395942e9e89f','fa66feec-3f9f-4020-a076-78f84b4593e5','2026-06-09 08:03:05',NULL,'CREATE','IN_PROGRESS','SwiftBase','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-52-34cku7h3toyo-SwiftBase-htai7pw52i7y','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-base.yaml',NULL,1403),(2331,'b1935016-890b-47c7-9144-47a07088dd30','0ebe93ab-28d9-4b2f-923c-ab3fdb8e59d5','2026-06-09 08:03:05',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-52-34cku7h3toyo-SwiftBase-htai7pw52i7y','0ebe93ab-28d9-4b2f-923c-ab3fdb8e59d5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2332,'9d644b97-3c46-48ff-9424-7d364fa56735','0ebe93ab-28d9-4b2f-923c-ab3fdb8e59d5','2026-06-09 08:03:05',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-52-34cku7h3toyo-SwiftBase-htai7pw52i7y','0ebe93ab-28d9-4b2f-923c-ab3fdb8e59d5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2333,'5e723e5e-a5fc-4829-91da-f962a35c42cc','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:03:05',NULL,'CREATE','IN_PROGRESS','49','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-49-rn7xghfvytxc','state changed','OS::TripleO::Services::Sshd',NULL,1406),(2334,'b997c8ee-305b-47a5-8df8-749c28f91e7b','0eabef1f-8876-407f-b648-c57cafa5dc53','2026-06-09 08:03:05',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-47-6uivqnt4ojei-ContainersCommon-fymta4w47akc','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2335,'79a6641c-2230-4596-8719-d7e1a92407f6','bb69c048-83e9-4762-88c9-71ec043a4102','2026-06-09 08:03:05',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-49-rn7xghfvytxc','bb69c048-83e9-4762-88c9-71ec043a4102','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2336,'d2aee90c-b58e-46d3-98fa-d55afbfbb2eb','28c5e9e6-0a3f-4564-955b-57afe93cfadb','2026-06-09 08:03:05',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-47-6uivqnt4ojei-ContainersCommon-fymta4w47akc','28c5e9e6-0a3f-4564-955b-57afe93cfadb','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2337,'4a8cdc62-df1b-40db-aa8a-102e0e1639da','bb69c048-83e9-4762-88c9-71ec043a4102','2026-06-09 08:03:05',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-49-rn7xghfvytxc','bb69c048-83e9-4762-88c9-71ec043a4102','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2338,'329264c7-5145-426a-bb35-a138866d5bae','28c5e9e6-0a3f-4564-955b-57afe93cfadb','2026-06-09 08:03:05',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-47-6uivqnt4ojei-ContainersCommon-fymta4w47akc','28c5e9e6-0a3f-4564-955b-57afe93cfadb','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2339,'a6d1a565-c16f-439e-9078-5d6923a91c13','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:03:05',NULL,'CREATE','IN_PROGRESS','50','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-50-7i6xjwyvws6q','state changed','OS::TripleO::Services::SwiftProxy',NULL,1413),(2340,'e4ca45ef-7e41-4fd2-a8a8-b6779e52eded','93e3de0f-8e7d-467b-b333-36546f1558f5','2026-06-09 08:03:06',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-50-7i6xjwyvws6q','93e3de0f-8e7d-467b-b333-36546f1558f5','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2341,'eec13b1c-d5e0-4216-82c9-010f69a2870f','fa66feec-3f9f-4020-a076-78f84b4593e5','2026-06-09 08:03:06',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-52-34cku7h3toyo-ContainersCommon-rdj6tp2766xy','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2342,'d2cdd7e2-8f19-4a32-b116-2852d64fb7f0','3ff5ef8e-c5f8-405c-902e-26949bde81d8','2026-06-09 08:03:06',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-52-34cku7h3toyo-ContainersCommon-rdj6tp2766xy','3ff5ef8e-c5f8-405c-902e-26949bde81d8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2343,'b363504e-8299-469f-8a77-afa130fcdc6e','93e3de0f-8e7d-467b-b333-36546f1558f5','2026-06-09 08:03:06',NULL,'CREATE','IN_PROGRESS','SwiftBase','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-50-7i6xjwyvws6q-SwiftBase-hpleuamezsaj','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-base.yaml',NULL,1414),(2344,'93b16a3f-6dbc-49a2-a191-37ef363e91be','3ff5ef8e-c5f8-405c-902e-26949bde81d8','2026-06-09 08:03:06',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-52-34cku7h3toyo-ContainersCommon-rdj6tp2766xy','3ff5ef8e-c5f8-405c-902e-26949bde81d8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2345,'3d22d1c3-9e50-47df-8bcf-c1622a647661','fa66feec-3f9f-4020-a076-78f84b4593e5','2026-06-09 08:03:06',NULL,'CREATE','COMPLETE','SwiftBase','0ebe93ab-28d9-4b2f-923c-ab3fdb8e59d5','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-base.yaml',NULL,1403),(2346,'15ff3046-be1a-4368-ae02-36ca4fd359ce','6efea8ba-afd7-4b88-b7ba-aa84cf2ccf1d','2026-06-09 08:03:06',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-50-7i6xjwyvws6q-SwiftBase-hpleuamezsaj','6efea8ba-afd7-4b88-b7ba-aa84cf2ccf1d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2347,'4c97af7f-2b21-40ab-835c-961f0f2806af','6efea8ba-afd7-4b88-b7ba-aa84cf2ccf1d','2026-06-09 08:03:06',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-50-7i6xjwyvws6q-SwiftBase-hpleuamezsaj','6efea8ba-afd7-4b88-b7ba-aa84cf2ccf1d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2348,'56feb872-0266-47ea-a853-6f5a97d61194','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:03:06',NULL,'CREATE','COMPLETE','49','bb69c048-83e9-4762-88c9-71ec043a4102','state changed','OS::TripleO::Services::Sshd',NULL,1406),(2349,'be64dd47-db6f-4dea-b0b6-fd37da229b64','0eabef1f-8876-407f-b648-c57cafa5dc53','2026-06-09 08:03:06',NULL,'CREATE','COMPLETE','ContainersCommon','28c5e9e6-0a3f-4564-955b-57afe93cfadb','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2350,'b181eee8-3ea1-4dfc-97b8-95368af7f9db','0eabef1f-8876-407f-b648-c57cafa5dc53','2026-06-09 08:03:06',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-47-6uivqnt4ojei','0eabef1f-8876-407f-b648-c57cafa5dc53','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2351,'ec8a251f-d37a-4aee-9f40-3c1c5f449075','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:03:07',NULL,'CREATE','IN_PROGRESS','53','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-53-vc6oknfycrql','state changed','OS::TripleO::Services::Timesync',NULL,1416),(2352,'de87bcd5-bec2-4482-873a-2720289db85e','14d1aae8-f828-4316-b626-da1a658c82cc','2026-06-09 08:03:07',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-53-vc6oknfycrql','14d1aae8-f828-4316-b626-da1a658c82cc','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2353,'77621c3b-e966-42d1-b830-806d26209833','14d1aae8-f828-4316-b626-da1a658c82cc','2026-06-09 08:03:07',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-53-vc6oknfycrql','14d1aae8-f828-4316-b626-da1a658c82cc','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2354,'ce103b5a-d8be-46af-8493-a5aee8c8d4ef','fa66feec-3f9f-4020-a076-78f84b4593e5','2026-06-09 08:03:07',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-52-34cku7h3toyo-RoleParametersValue-3dqy5tcy23cl','state changed','OS::Heat::Value',NULL,1417),(2355,'733fb43c-c90e-4177-a9a5-15e7906756cc','fa66feec-3f9f-4020-a076-78f84b4593e5','2026-06-09 08:03:07',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-52-34cku7h3toyo-RoleParametersValue-3dqy5tcy23cl','state changed','OS::Heat::Value',NULL,1417),(2356,'ad075c34-9010-4603-8e59-ae61c4268a21','93e3de0f-8e7d-467b-b333-36546f1558f5','2026-06-09 08:03:07',NULL,'CREATE','IN_PROGRESS','ContainersCommon','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-50-7i6xjwyvws6q-ContainersCommon-lmb5q533dz5w','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2357,'0f14e076-e753-4342-9f4a-ec4d97b45fcc','fa66feec-3f9f-4020-a076-78f84b4593e5','2026-06-09 08:03:07',NULL,'CREATE','COMPLETE','ContainersCommon','3ff5ef8e-c5f8-405c-902e-26949bde81d8','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2358,'955e804f-b928-4118-9c89-9b993eb67a9f','fa66feec-3f9f-4020-a076-78f84b4593e5','2026-06-09 08:03:07',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-52-34cku7h3toyo','fa66feec-3f9f-4020-a076-78f84b4593e5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2359,'4e60905e-e9ee-4573-96ae-d830437fb4dc','5d88e2ed-92dc-4b0d-a1a1-105bcc75b7d9','2026-06-09 08:03:07',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-50-7i6xjwyvws6q-ContainersCommon-lmb5q533dz5w','5d88e2ed-92dc-4b0d-a1a1-105bcc75b7d9','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2360,'0d868601-6982-4369-8dcb-0fcc351805f3','5d88e2ed-92dc-4b0d-a1a1-105bcc75b7d9','2026-06-09 08:03:07',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-50-7i6xjwyvws6q-ContainersCommon-lmb5q533dz5w','5d88e2ed-92dc-4b0d-a1a1-105bcc75b7d9','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2361,'9af0dd94-4162-4159-bd5f-7cf179e6cc26','93e3de0f-8e7d-467b-b333-36546f1558f5','2026-06-09 08:03:07',NULL,'CREATE','COMPLETE','SwiftBase','6efea8ba-afd7-4b88-b7ba-aa84cf2ccf1d','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-base.yaml',NULL,1414),(2362,'d6454736-5633-46a5-a346-77ca09363b73','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:03:07',NULL,'CREATE','COMPLETE','47','0eabef1f-8876-407f-b648-c57cafa5dc53','state changed','OS::TripleO::Services::Rsyslog',NULL,1399),(2363,'c73ff93d-0a3a-4f22-9325-3db85544e644','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:03:08',NULL,'CREATE','IN_PROGRESS','51','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-51-6lipnldxca6o','state changed','OS::TripleO::Services::SwiftRingBuilder',NULL,1421),(2364,'40e9dbfa-5434-4d30-a272-44b773825fb6','3354c7c4-193e-4557-a178-cf4778aa8f63','2026-06-09 08:03:08',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-51-6lipnldxca6o','3354c7c4-193e-4557-a178-cf4778aa8f63','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2365,'4af77791-9d5b-419b-8904-d5e5c30035b0','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:03:08',NULL,'CREATE','COMPLETE','53','14d1aae8-f828-4316-b626-da1a658c82cc','state changed','OS::TripleO::Services::Timesync',NULL,1416),(2366,'443f366c-9366-4612-9f3e-dedb67c6a3ce','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:03:08',NULL,'CREATE','COMPLETE','52','fa66feec-3f9f-4020-a076-78f84b4593e5','state changed','OS::TripleO::Services::SwiftStorage',NULL,1402),(2367,'b81fbf36-163d-4979-a2ec-fba77f9efbc5','3354c7c4-193e-4557-a178-cf4778aa8f63','2026-06-09 08:03:08',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-51-6lipnldxca6o-RoleParametersValue-uhju43ed6vqr','state changed','OS::Heat::Value',NULL,1424),(2368,'d9316071-b616-4770-be75-9624076f94de','3354c7c4-193e-4557-a178-cf4778aa8f63','2026-06-09 08:03:08',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-51-6lipnldxca6o-RoleParametersValue-uhju43ed6vqr','state changed','OS::Heat::Value',NULL,1424),(2369,'b920a613-1de4-483e-a268-ca3b3e2d4714','93e3de0f-8e7d-467b-b333-36546f1558f5','2026-06-09 08:03:08',NULL,'CREATE','IN_PROGRESS','TLSProxyBase','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-50-7i6xjwyvws6q-TLSProxyBase-fji7ieqrcxjd','state changed','OS::TripleO::Services::TLSProxyBase',NULL,1426),(2370,'2cf9996d-f4f3-4717-aef7-355c4ae2c6e1','3354c7c4-193e-4557-a178-cf4778aa8f63','2026-06-09 08:03:08',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-51-6lipnldxca6o','3354c7c4-193e-4557-a178-cf4778aa8f63','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2371,'f544bafb-aa16-4596-a6a0-e2f7ba4332d1','49ad8899-7dda-4d3f-8258-5ec09bf44512','2026-06-09 08:03:08',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-50-7i6xjwyvws6q-TLSProxyBase-fji7ieqrcxjd','49ad8899-7dda-4d3f-8258-5ec09bf44512','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2372,'208909ea-efb6-4cab-9c13-7563fe1de322','93e3de0f-8e7d-467b-b333-36546f1558f5','2026-06-09 08:03:08',NULL,'CREATE','COMPLETE','ContainersCommon','5d88e2ed-92dc-4b0d-a1a1-105bcc75b7d9','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml',NULL,NULL),(2373,'bb977cb3-4b38-4701-89c2-1a4306826b33','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:03:08',NULL,'CREATE','IN_PROGRESS','57','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-57-b7nsu3uukkiw','state changed','OS::TripleO::Services::Tuned',NULL,1427),(2374,'616d8905-a1c0-4301-88bd-b5efa3d0c0ee','49ad8899-7dda-4d3f-8258-5ec09bf44512','2026-06-09 08:03:08',NULL,'CREATE','IN_PROGRESS','ApacheNetworks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-50-7i6xjwyvws6q-TLSProxyBase-fji7ieqrcxjd-ApacheNetworks-jb6pq2gqhwca','state changed','OS::Heat::Value',NULL,1428),(2375,'1f063b48-4cff-4f33-b9a5-0a2825b97ad4','49ad8899-7dda-4d3f-8258-5ec09bf44512','2026-06-09 08:03:08',NULL,'CREATE','COMPLETE','ApacheNetworks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-50-7i6xjwyvws6q-TLSProxyBase-fji7ieqrcxjd-ApacheNetworks-jb6pq2gqhwca','state changed','OS::Heat::Value',NULL,1428),(2376,'1e1d02e2-a693-48b8-864a-cf45792e5771','7ea52a52-b0d4-40cc-a065-d472d963ccb8','2026-06-09 08:03:08',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-57-b7nsu3uukkiw','7ea52a52-b0d4-40cc-a065-d472d963ccb8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2377,'3613b1d7-64c4-4b02-be8c-3e4b09681196','49ad8899-7dda-4d3f-8258-5ec09bf44512','2026-06-09 08:03:08',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-50-7i6xjwyvws6q-TLSProxyBase-fji7ieqrcxjd','49ad8899-7dda-4d3f-8258-5ec09bf44512','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2378,'7e2a38cf-1211-476f-a9dc-724ff11d2fc0','7ea52a52-b0d4-40cc-a065-d472d963ccb8','2026-06-09 08:03:08',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-57-b7nsu3uukkiw-RoleParametersValue-rubluq4oktc3','state changed','OS::Heat::Value',NULL,1431),(2379,'bc5c10c9-9c58-4d66-861c-f3febc671a49','7ea52a52-b0d4-40cc-a065-d472d963ccb8','2026-06-09 08:03:08',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-57-b7nsu3uukkiw-RoleParametersValue-rubluq4oktc3','state changed','OS::Heat::Value',NULL,1431),(2380,'4cd3df58-cbc4-4f5f-9f71-9f26d56c6834','7ea52a52-b0d4-40cc-a065-d472d963ccb8','2026-06-09 08:03:08',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-57-b7nsu3uukkiw','7ea52a52-b0d4-40cc-a065-d472d963ccb8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2381,'92fc7fe8-f02f-44e6-8991-bc29a0e6f518','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:03:08',NULL,'CREATE','IN_PROGRESS','56','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-56-bgdroyqrg4z3','state changed','OS::TripleO::Services::TripleoPackages',NULL,1432),(2382,'b3a0a4bd-3bc8-47e3-9b92-a8e73d51390e','936fa845-73f0-4685-bffc-3f2fc7ceba06','2026-06-09 08:03:08',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-56-bgdroyqrg4z3','936fa845-73f0-4685-bffc-3f2fc7ceba06','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2383,'d16cdba5-1f0a-4f00-a73f-0d8c5b087143','936fa845-73f0-4685-bffc-3f2fc7ceba06','2026-06-09 08:03:09',NULL,'CREATE','IN_PROGRESS','Podman','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-56-bgdroyqrg4z3-Podman-oofzlvalkwg4','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml',NULL,1433),(2384,'5c135302-92f5-4ecc-8657-6df27d0bb892','ac45f77f-4c87-491f-b234-96c4489878f8','2026-06-09 08:03:09',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-56-bgdroyqrg4z3-Podman-oofzlvalkwg4','ac45f77f-4c87-491f-b234-96c4489878f8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2385,'bc9f9de9-2607-456c-9690-712fbdb977c9','ac45f77f-4c87-491f-b234-96c4489878f8','2026-06-09 08:03:09',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-56-bgdroyqrg4z3-Podman-oofzlvalkwg4','ac45f77f-4c87-491f-b234-96c4489878f8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2386,'d61ad0d9-bb9d-4b33-a59e-c3e93709b7dd','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:03:09',NULL,'CREATE','COMPLETE','51','3354c7c4-193e-4557-a178-cf4778aa8f63','state changed','OS::TripleO::Services::SwiftRingBuilder',NULL,1421),(2387,'d2ffd87b-6201-4376-a9cf-25d38cf0bcb4','93e3de0f-8e7d-467b-b333-36546f1558f5','2026-06-09 08:03:09',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-50-7i6xjwyvws6q-RoleParametersValue-xplaejjs5ixr','state changed','OS::Heat::Value',NULL,1434),(2388,'e1127874-f026-4d21-bc7e-99b0b5a74ef2','93e3de0f-8e7d-467b-b333-36546f1558f5','2026-06-09 08:03:09',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-50-7i6xjwyvws6q-RoleParametersValue-xplaejjs5ixr','state changed','OS::Heat::Value',NULL,1434),(2389,'c0ded272-34ae-441c-a24e-57b4b65d3861','93e3de0f-8e7d-467b-b333-36546f1558f5','2026-06-09 08:03:09',NULL,'CREATE','COMPLETE','TLSProxyBase','49ad8899-7dda-4d3f-8258-5ec09bf44512','state changed','OS::TripleO::Services::TLSProxyBase',NULL,1426),(2390,'3e311be4-9c7f-46d4-a1e1-b04f0da1fa9d','93e3de0f-8e7d-467b-b333-36546f1558f5','2026-06-09 08:03:09',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-50-7i6xjwyvws6q','93e3de0f-8e7d-467b-b333-36546f1558f5','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2391,'e68de246-bd1e-4d46-93ea-112a2f131e73','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:03:09',NULL,'CREATE','COMPLETE','57','7ea52a52-b0d4-40cc-a065-d472d963ccb8','state changed','OS::TripleO::Services::Tuned',NULL,1427),(2392,'e0a103da-43c5-4897-9269-b44ca3558eb3','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:03:09',NULL,'CREATE','IN_PROGRESS','55','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-55-qqicc6euawha','state changed','OS::TripleO::Services::TripleoFirewall',NULL,1437),(2393,'f15de589-3c9c-4617-8999-88bb8ee819a0','934f680b-7a04-4462-8062-6fd9a19465ce','2026-06-09 08:03:09',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-55-qqicc6euawha','934f680b-7a04-4462-8062-6fd9a19465ce','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2394,'d68d8182-5903-40de-bc44-9a45d85c3549','934f680b-7a04-4462-8062-6fd9a19465ce','2026-06-09 08:03:09',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-55-qqicc6euawha-RoleParametersValue-eih34gfdeokx','state changed','OS::Heat::Value',NULL,1438),(2395,'99402133-6e7e-4636-9d52-332702fcd04f','934f680b-7a04-4462-8062-6fd9a19465ce','2026-06-09 08:03:09',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-55-qqicc6euawha-RoleParametersValue-eih34gfdeokx','state changed','OS::Heat::Value',NULL,1438),(2396,'5c0657d3-7b2b-487d-8218-c33ee518cc60','934f680b-7a04-4462-8062-6fd9a19465ce','2026-06-09 08:03:09',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-55-qqicc6euawha','934f680b-7a04-4462-8062-6fd9a19465ce','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2397,'25384100-0c1d-403a-b211-16b7610fca7c','936fa845-73f0-4685-bffc-3f2fc7ceba06','2026-06-09 08:03:10',NULL,'CREATE','IN_PROGRESS','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-56-bgdroyqrg4z3-RoleParametersValue-t3q52ka6bei4','state changed','OS::Heat::Value',NULL,1439),(2398,'f54b98e5-958c-4f99-8cf5-67dfa59f093a','936fa845-73f0-4685-bffc-3f2fc7ceba06','2026-06-09 08:03:10',NULL,'CREATE','COMPLETE','RoleParametersValue','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-56-bgdroyqrg4z3-RoleParametersValue-t3q52ka6bei4','state changed','OS::Heat::Value',NULL,1439),(2399,'ecf58dba-53c2-4ebb-85ce-8e8e6240cc3e','936fa845-73f0-4685-bffc-3f2fc7ceba06','2026-06-09 08:03:10',NULL,'CREATE','COMPLETE','Podman','ac45f77f-4c87-491f-b234-96c4489878f8','state changed','file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml',NULL,1433),(2400,'d23f58b3-5aa9-4b3a-aa36-e08e0b7ec0b1','936fa845-73f0-4685-bffc-3f2fc7ceba06','2026-06-09 08:03:10',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-56-bgdroyqrg4z3','936fa845-73f0-4685-bffc-3f2fc7ceba06','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2401,'1689d0a8-5820-45ba-9945-f435789718a4','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:03:10',NULL,'CREATE','COMPLETE','50','93e3de0f-8e7d-467b-b333-36546f1558f5','state changed','OS::TripleO::Services::SwiftProxy',NULL,1413),(2402,'6825cc91-7dd0-4ff4-90ba-06fc9cb40f22','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:03:10',NULL,'CREATE','COMPLETE','55','934f680b-7a04-4462-8062-6fd9a19465ce','state changed','OS::TripleO::Services::TripleoFirewall',NULL,1437),(2403,'acd5672c-3267-47b0-a605-150bfbadbf44','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:03:10',NULL,'CREATE','IN_PROGRESS','54','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-54-isji7tqbq2bd','state changed','OS::TripleO::Services::Timezone',NULL,1446),(2404,'0ebea158-ad3b-4d6b-a5ae-be6f6af0a64d','91c911c4-4435-44a1-be1f-b3725a9410ec','2026-06-09 08:03:10',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-54-isji7tqbq2bd','91c911c4-4435-44a1-be1f-b3725a9410ec','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2405,'6aecda89-de81-4a17-82f3-18e5848c2157','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:03:10',NULL,'CREATE','COMPLETE','56','936fa845-73f0-4685-bffc-3f2fc7ceba06','state changed','OS::TripleO::Services::TripleoPackages',NULL,1432),(2406,'f7a582f9-64e9-45bf-8914-b0e740cf0a81','91c911c4-4435-44a1-be1f-b3725a9410ec','2026-06-09 08:03:10',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf-54-isji7tqbq2bd','91c911c4-4435-44a1-be1f-b3725a9410ec','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2407,'4089ccb2-bc81-4dcf-b66a-4b5e3180e1c5','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:03:11',NULL,'CREATE','COMPLETE','54','91c911c4-4435-44a1-be1f-b3725a9410ec','state changed','OS::TripleO::Services::Timezone',NULL,1446),(2408,'ed4de350-040f-4b06-9f15-f98e4c7b78dd','5268a897-7d28-46be-87ec-d35196b6744d','2026-06-09 08:03:11',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceChain-4wictqkmb6nf','5268a897-7d28-46be-87ec-d35196b6744d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2409,'51b23b6a-94f0-4c70-8024-70cb2b52ef35','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:12',NULL,'CREATE','COMPLETE','ServiceChain','5268a897-7d28-46be-87ec-d35196b6744d','state changed','OS::Heat::ResourceChain',NULL,91),(2410,'1afe857d-64a3-42c9-9d1a-0a6a697440d4','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:13',NULL,'CREATE','IN_PROGRESS','UpgradeTasks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-UpgradeTasks-ozxhdp6e6ycw','state changed','OS::Heat::Value',NULL,1455),(2411,'b859b675-5f13-4993-be63-c9a756a0e299','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:13',NULL,'CREATE','IN_PROGRESS','DockerConfigScripts','overcloud-ControllerServiceChain-rvcxrx4tyxu2-DockerConfigScripts-kasn7yhpcbi7','state changed','OS::Heat::Value',NULL,1456),(2412,'82d35c00-91da-4b6a-a968-bcc01a5c8cf6','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:14',NULL,'CREATE','COMPLETE','DockerConfigScripts','overcloud-ControllerServiceChain-rvcxrx4tyxu2-DockerConfigScripts-kasn7yhpcbi7','state changed','OS::Heat::Value',NULL,1456),(2413,'bda49d27-a7e8-49be-bd52-d2cd122db585','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:14',NULL,'CREATE','COMPLETE','UpgradeTasks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-UpgradeTasks-ozxhdp6e6ycw','state changed','OS::Heat::Value',NULL,1455),(2414,'b4806169-bfe8-4db4-8c1e-4234fc072d54','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:14',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ExternalPostDeployTasks-mwb6o2svvxbe','state changed','OS::Heat::Value',NULL,1457),(2415,'a07630f1-9e8a-4354-8254-979dce80eb3d','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:14',NULL,'CREATE','IN_PROGRESS','HostPrepTasks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-HostPrepTasks-nukbiyapztno','state changed','OS::Heat::Value',NULL,1458),(2416,'5d7cc610-74df-45c4-b2a7-b15bcef66114','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:14',NULL,'CREATE','COMPLETE','HostPrepTasks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-HostPrepTasks-nukbiyapztno','state changed','OS::Heat::Value',NULL,1458),(2417,'9e7d84ab-800b-451c-a53d-9dc76b36b3c1','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:14',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ExternalPostDeployTasks-mwb6o2svvxbe','state changed','OS::Heat::Value',NULL,1457),(2418,'a4ce3495-6b59-4c4d-ae2a-2b83c6a50749','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:14',NULL,'CREATE','IN_PROGRESS','DockerConfig','overcloud-ControllerServiceChain-rvcxrx4tyxu2-DockerConfig-nrmt3zgac4gq','state changed','OS::Heat::Value',NULL,1459),(2419,'b7a836da-c906-4b39-ae0d-8326b17b6fff','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:14',NULL,'CREATE','COMPLETE','DockerConfig','overcloud-ControllerServiceChain-rvcxrx4tyxu2-DockerConfig-nrmt3zgac4gq','state changed','OS::Heat::Value',NULL,1459),(2420,'88124612-2e4f-49d3-ac51-a97fef4c5f7b','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:15',NULL,'CREATE','IN_PROGRESS','KeystoneResourcesConfigs','overcloud-ControllerServiceChain-rvcxrx4tyxu2-KeystoneResourcesConfigs-exanko7htlmn','state changed','OS::Heat::Value',NULL,1460),(2421,'7af8dccc-748c-4305-a0f2-61c15feca335','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:15',NULL,'CREATE','COMPLETE','KeystoneResourcesConfigs','overcloud-ControllerServiceChain-rvcxrx4tyxu2-KeystoneResourcesConfigs-exanko7htlmn','state changed','OS::Heat::Value',NULL,1460),(2422,'15c8bf53-2701-48a4-ac11-e70ffc502280','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:15',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ExternalDeployTasks-3shv5zu2t2o6','state changed','OS::Heat::Value',NULL,1461),(2423,'3578b22f-4a5e-4ee9-8884-110d0afc242c','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:15',NULL,'CREATE','IN_PROGRESS','HostFirewallTasks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-HostFirewallTasks-3nalkl4mfwvq','state changed','OS::Heat::Value',NULL,1462),(2424,'7875d00b-d63d-4a45-b3e6-b914e7198528','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:15',NULL,'CREATE','COMPLETE','HostFirewallTasks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-HostFirewallTasks-3nalkl4mfwvq','state changed','OS::Heat::Value',NULL,1462),(2425,'f5538970-98c7-4ce7-8cf3-ca3a892b7791','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:15',NULL,'CREATE','COMPLETE','ExternalDeployTasks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ExternalDeployTasks-3shv5zu2t2o6','state changed','OS::Heat::Value',NULL,1461),(2426,'b6a6cef1-9330-4a91-9322-2a2f37ce1856','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:15',NULL,'CREATE','IN_PROGRESS','IpaRegistrationTasks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-IpaRegistrationTasks-tbxlt6hrsivl','state changed','OS::Heat::Value',NULL,1463),(2427,'f7766e61-3498-4a86-9769-aa098fd864a1','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:15',NULL,'CREATE','COMPLETE','IpaRegistrationTasks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-IpaRegistrationTasks-tbxlt6hrsivl','state changed','OS::Heat::Value',NULL,1463),(2428,'eda7552a-11b8-494a-9aaa-157c2279c3fd','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:15',NULL,'CREATE','IN_PROGRESS','ServiceServerMetadataHook','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceServerMetadataHook-phe6kjcon6c5','state changed','OS::TripleO::ControllerServiceServerMetadataHook',NULL,1464),(2429,'79f935c3-ee98-422d-ab5d-66a3739c03bc','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:16',NULL,'CREATE','IN_PROGRESS','ServiceNames','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceNames-l3rpl6fex62a','state changed','OS::Heat::Value',NULL,1465),(2430,'d286d579-b406-41c3-909d-e3c7ac7bb732','82182e22-febd-4b39-bb87-74d00353cdd1','2026-06-09 08:03:16',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceServerMetadataHook-phe6kjcon6c5','82182e22-febd-4b39-bb87-74d00353cdd1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2431,'a2af0ded-00af-42f0-aac6-fd2f6d564bc3','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:16',NULL,'CREATE','COMPLETE','ServiceNames','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceNames-l3rpl6fex62a','state changed','OS::Heat::Value',NULL,1465),(2432,'ede9b158-c546-49d0-b184-581cf9d4a483','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:16',NULL,'CREATE','IN_PROGRESS','UpgradeBatchTasks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-UpgradeBatchTasks-fm2gku2p4tzk','state changed','OS::Heat::Value',NULL,1466),(2433,'d40fa906-4445-406a-8544-3a7c848da2c0','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:16',NULL,'CREATE','COMPLETE','UpgradeBatchTasks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-UpgradeBatchTasks-fm2gku2p4tzk','state changed','OS::Heat::Value',NULL,1466),(2434,'d477feef-9524-420a-81b8-97c009f71d99','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:16',NULL,'CREATE','IN_PROGRESS','AnsibleGroupVars','overcloud-ControllerServiceChain-rvcxrx4tyxu2-AnsibleGroupVars-ohae3wr77ynm','state changed','OS::Heat::Value',NULL,1467),(2435,'783f6d06-b6d2-4ff4-a0fa-0a57fb536644','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:16',NULL,'CREATE','COMPLETE','AnsibleGroupVars','overcloud-ControllerServiceChain-rvcxrx4tyxu2-AnsibleGroupVars-ohae3wr77ynm','state changed','OS::Heat::Value',NULL,1467),(2436,'00a79ddd-a972-452c-bdf0-dbcdd34a26b9','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:16',NULL,'CREATE','IN_PROGRESS','FirewallRules','overcloud-ControllerServiceChain-rvcxrx4tyxu2-FirewallRules-vndiez5clywu','state changed','OS::Heat::Value',NULL,1468),(2437,'2aae0546-c753-4481-bd29-80f57b8587b3','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:17',NULL,'CREATE','COMPLETE','FirewallRules','overcloud-ControllerServiceChain-rvcxrx4tyxu2-FirewallRules-vndiez5clywu','state changed','OS::Heat::Value',NULL,1468),(2438,'c69a862b-8ad9-4a6a-9e78-89be20e87386','82182e22-febd-4b39-bb87-74d00353cdd1','2026-06-09 08:03:17',NULL,'CREATE','IN_PROGRESS','IncomingMetadataSettings','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceServerMetadataHook-phe6kjcon6c5-IncomingMetadataSettings-ahfupwtg5hz2','state changed','OS::Heat::Value',NULL,1469),(2439,'9190e94c-793c-4fbf-aebe-b8af161b4928','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:17',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ExternalUpdateTasks-lgaib2nhzfeq','state changed','OS::Heat::Value',NULL,1470),(2440,'9f8c39e6-0f26-44ea-ab0a-efaec5ddd6b0','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:17',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ExternalUpdateTasks-lgaib2nhzfeq','state changed','OS::Heat::Value',NULL,1470),(2441,'5d7dca17-6a49-4375-ad56-6e9c40cb2eb1','82182e22-febd-4b39-bb87-74d00353cdd1','2026-06-09 08:03:17',NULL,'CREATE','COMPLETE','IncomingMetadataSettings','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceServerMetadataHook-phe6kjcon6c5-IncomingMetadataSettings-ahfupwtg5hz2','state changed','OS::Heat::Value',NULL,1469),(2442,'31c4a519-f4d9-44dd-9907-976d8189b4ee','82182e22-febd-4b39-bb87-74d00353cdd1','2026-06-09 08:03:17',NULL,'CREATE','IN_PROGRESS','CompactServices','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceServerMetadataHook-phe6kjcon6c5-CompactServices-nz4ubde5eden','state changed','OS::Heat::Value',NULL,1473),(2443,'ff13d2be-7735-4615-8949-bba8496c9fab','82182e22-febd-4b39-bb87-74d00353cdd1','2026-06-09 08:03:17',NULL,'CREATE','COMPLETE','CompactServices','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceServerMetadataHook-phe6kjcon6c5-CompactServices-nz4ubde5eden','state changed','OS::Heat::Value',NULL,1473),(2444,'22a9f99a-d5a4-4633-b172-968443e721bc','82182e22-febd-4b39-bb87-74d00353cdd1','2026-06-09 08:03:17',NULL,'CREATE','IN_PROGRESS','IndividualServices','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceServerMetadataHook-phe6kjcon6c5-IndividualServices-2fqzasqfo2mx','state changed','OS::Heat::Value',NULL,1472),(2445,'6d1d1dc3-29da-44aa-ace7-1a3ca62c3adf','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:17',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','overcloud-ControllerServiceChain-rvcxrx4tyxu2-FirewallFrontendRules-ousua7zui7d2','state changed','OS::Heat::Value',NULL,1474),(2446,'c9ddbf40-0090-4fa8-93e7-60a26d904083','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:17',NULL,'CREATE','IN_PROGRESS','PuppetStepConfig','overcloud-ControllerServiceChain-rvcxrx4tyxu2-PuppetStepConfig-bipm5f225ey3','state changed','OS::Heat::Value',NULL,1475),(2447,'9b70fc51-147a-49b6-8efa-1154e2374692','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:17',NULL,'CREATE','COMPLETE','PuppetStepConfig','overcloud-ControllerServiceChain-rvcxrx4tyxu2-PuppetStepConfig-bipm5f225ey3','state changed','OS::Heat::Value',NULL,1475),(2448,'f90c9212-754c-4db6-9101-785b0920e8e5','82182e22-febd-4b39-bb87-74d00353cdd1','2026-06-09 08:03:17',NULL,'CREATE','COMPLETE','IndividualServices','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceServerMetadataHook-phe6kjcon6c5-IndividualServices-2fqzasqfo2mx','state changed','OS::Heat::Value',NULL,1472),(2449,'b9206ae0-dbaa-487d-8c59-24dedd9c3ce4','82182e22-febd-4b39-bb87-74d00353cdd1','2026-06-09 08:03:17',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceServerMetadataHook-phe6kjcon6c5','82182e22-febd-4b39-bb87-74d00353cdd1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2450,'abe903cd-7a6d-40ec-9c58-c6feac6c9f03','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:18',NULL,'CREATE','COMPLETE','FirewallFrontendRules','overcloud-ControllerServiceChain-rvcxrx4tyxu2-FirewallFrontendRules-ousua7zui7d2','state changed','OS::Heat::Value',NULL,1474),(2451,'813b7b89-f8be-45e6-accf-4f292350d104','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:18',NULL,'CREATE','IN_PROGRESS','ScaleTasks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ScaleTasks-o5tz7aljyx65','state changed','OS::Heat::Value',NULL,1476),(2452,'7a9330db-98a3-4558-893d-787155b39278','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:18',NULL,'CREATE','COMPLETE','ScaleTasks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ScaleTasks-o5tz7aljyx65','state changed','OS::Heat::Value',NULL,1476),(2453,'fec955f1-43d9-41fc-bbb6-f0b0df407fa7','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:18',NULL,'CREATE','IN_PROGRESS','DeployStepsTasks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-DeployStepsTasks-wd2o4625bh6q','state changed','OS::Heat::Value',NULL,1477),(2454,'3d9baf52-cdeb-4e73-ad0b-b51b7521b41e','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:18',NULL,'CREATE','COMPLETE','DeployStepsTasks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-DeployStepsTasks-wd2o4625bh6q','state changed','OS::Heat::Value',NULL,1477),(2455,'ec2ec718-0610-4b27-858b-2cf0841a66bc','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:18',NULL,'CREATE','COMPLETE','ServiceServerMetadataHook','82182e22-febd-4b39-bb87-74d00353cdd1','state changed','OS::TripleO::ControllerServiceServerMetadataHook',NULL,1464),(2456,'adf3b582-0640-4ec9-88a7-500260a28e65','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:18',NULL,'CREATE','IN_PROGRESS','DockerPuppetTasks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-DockerPuppetTasks-flkbeo5yimvp','state changed','OS::Heat::Value',NULL,1478),(2457,'cfb2cf30-9668-4bbe-a384-b744c47aaa94','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:18',NULL,'CREATE','IN_PROGRESS','PuppetConfig','overcloud-ControllerServiceChain-rvcxrx4tyxu2-PuppetConfig-sogrgieiofcs','state changed','OS::Heat::Value',NULL,1479),(2458,'e3785a07-13b0-44c7-811a-43f91ce01772','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:18',NULL,'CREATE','COMPLETE','PuppetConfig','overcloud-ControllerServiceChain-rvcxrx4tyxu2-PuppetConfig-sogrgieiofcs','state changed','OS::Heat::Value',NULL,1479),(2459,'b890dbd0-456a-4320-824c-211cae0fee92','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:18',NULL,'CREATE','COMPLETE','DockerPuppetTasks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-DockerPuppetTasks-flkbeo5yimvp','state changed','OS::Heat::Value',NULL,1478),(2460,'c45593e7-b3d7-4468-a87e-a0348b2ac88b','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:18',NULL,'CREATE','IN_PROGRESS','GlobalConfigSettings','overcloud-ControllerServiceChain-rvcxrx4tyxu2-GlobalConfigSettings-re6sezt2hbbc','state changed','OS::Heat::Value',NULL,1480),(2461,'68b226b3-13a6-4fcc-b03d-daebf86568cb','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:19',NULL,'CREATE','COMPLETE','GlobalConfigSettings','overcloud-ControllerServiceChain-rvcxrx4tyxu2-GlobalConfigSettings-re6sezt2hbbc','state changed','OS::Heat::Value',NULL,1480),(2462,'e38885f4-132f-450b-a622-aa2b95f6fc87','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:19',NULL,'CREATE','IN_PROGRESS','PostUpgradeTasks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-PostUpgradeTasks-364toavzkbqb','state changed','OS::Heat::Value',NULL,1481),(2463,'81731908-475b-4525-a47e-1fc4e7227a25','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:19',NULL,'CREATE','COMPLETE','PostUpgradeTasks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-PostUpgradeTasks-364toavzkbqb','state changed','OS::Heat::Value',NULL,1481),(2464,'d17df4d5-6b22-410b-b49e-fd6e0cd26efd','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:19',NULL,'CREATE','IN_PROGRESS','KollaConfig','overcloud-ControllerServiceChain-rvcxrx4tyxu2-KollaConfig-k4ufjifss6yz','state changed','OS::Heat::Value',NULL,1482),(2465,'c67faa8d-da4a-4f61-94e0-e9388941c7b9','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:19',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ExternalUpgradeTasks-alawdadoo27h','state changed','OS::Heat::Value',NULL,1483),(2466,'fe48a549-a873-41d7-822f-85b256bd9324','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:19',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ExternalUpgradeTasks-alawdadoo27h','state changed','OS::Heat::Value',NULL,1483),(2467,'b88212c2-d59c-4a86-9702-ccbf2be50e2e','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:19',NULL,'CREATE','COMPLETE','KollaConfig','overcloud-ControllerServiceChain-rvcxrx4tyxu2-KollaConfig-k4ufjifss6yz','state changed','OS::Heat::Value',NULL,1482),(2468,'bface8a6-ed8c-4fb6-aeef-7853c02f5b5b','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:19',NULL,'CREATE','IN_PROGRESS','PostUpdateTasks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-PostUpdateTasks-ndkrb52w2wjx','state changed','OS::Heat::Value',NULL,1484),(2469,'82408395-c109-40e7-8f01-48d96178a184','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:19',NULL,'CREATE','COMPLETE','PostUpdateTasks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-PostUpdateTasks-ndkrb52w2wjx','state changed','OS::Heat::Value',NULL,1484),(2470,'5d42cbeb-308e-412f-80ed-c585d4208d45','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:20',NULL,'CREATE','IN_PROGRESS','ServiceConfigSettings','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceConfigSettings-zcp5i6ncpj7b','state changed','OS::Heat::Value',NULL,1485),(2471,'1600d7f8-d67f-4499-9f11-a310f27debb2','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:20',NULL,'CREATE','COMPLETE','ServiceConfigSettings','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ServiceConfigSettings-zcp5i6ncpj7b','state changed','OS::Heat::Value',NULL,1485),(2472,'8590ad5d-9581-4835-8a82-80c1b67e4f1b','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:20',NULL,'CREATE','IN_PROGRESS','MonitoringSubscriptionsConfig','overcloud-ControllerServiceChain-rvcxrx4tyxu2-MonitoringSubscriptionsConfig-ycvuwxpmlzm4','state changed','OS::Heat::Value',NULL,1486),(2473,'8ca0d1c6-6d1f-4b2c-8e4d-73552f1d2837','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:20',NULL,'CREATE','IN_PROGRESS','UpdateTasks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-UpdateTasks-h5z2tdefblp4','state changed','OS::Heat::Value',NULL,1487),(2474,'d9260d00-b2ae-450c-bb98-e2c86f86659a','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:20',NULL,'CREATE','COMPLETE','MonitoringSubscriptionsConfig','overcloud-ControllerServiceChain-rvcxrx4tyxu2-MonitoringSubscriptionsConfig-ycvuwxpmlzm4','state changed','OS::Heat::Value',NULL,1486),(2475,'264d03fe-da8e-407a-b93f-04cebad86046','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:20',NULL,'CREATE','COMPLETE','UpdateTasks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-UpdateTasks-h5z2tdefblp4','state changed','OS::Heat::Value',NULL,1487),(2476,'bd3379ca-fee7-44f6-8ed5-dbabfcc93359','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:20',NULL,'CREATE','IN_PROGRESS','PreUpgradeRollingTasks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-PreUpgradeRollingTasks-mr32stjblnze','state changed','OS::Heat::Value',NULL,1488),(2477,'fcb1934a-59cf-4fef-9287-60b9d0d0cd2f','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:20',NULL,'CREATE','COMPLETE','PreUpgradeRollingTasks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-PreUpgradeRollingTasks-mr32stjblnze','state changed','OS::Heat::Value',NULL,1488),(2478,'59ba2c74-529f-4026-9974-0fa5ecde582f','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:20',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-PreDeployStepTasks-jm4jiiheaywx','state changed','OS::Heat::Value',NULL,1489),(2479,'f52cac9a-e287-4be2-94ba-5f3d877fd873','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:21',NULL,'CREATE','COMPLETE','PreDeployStepTasks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-PreDeployStepTasks-jm4jiiheaywx','state changed','OS::Heat::Value',NULL,1489),(2480,'d5f404b5-c14d-4516-aadf-a0550f8163ef','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:21',NULL,'CREATE','IN_PROGRESS','ContainerPuppetTasks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ContainerPuppetTasks-nekxbd2nbtfr','state changed','OS::Heat::Value',NULL,1491),(2481,'d7908f6f-0500-448c-92c3-6a5ee014a44a','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:21',NULL,'CREATE','COMPLETE','ContainerPuppetTasks','overcloud-ControllerServiceChain-rvcxrx4tyxu2-ContainerPuppetTasks-nekxbd2nbtfr','state changed','OS::Heat::Value',NULL,1491),(2482,'4b7567d1-65cf-4b95-bf05-46db1d664304','14758e60-8013-4d42-8d8b-6640437712eb','2026-06-09 08:03:21',NULL,'CREATE','COMPLETE','overcloud-ControllerServiceChain-rvcxrx4tyxu2','14758e60-8013-4d42-8d8b-6640437712eb','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2483,'b513a849-1790-40ee-baf2-a1fdbef20c8e','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:22',NULL,'CREATE','COMPLETE','ControllerServiceChain','14758e60-8013-4d42-8d8b-6640437712eb','state changed','OS::TripleO::ControllerServices',NULL,80),(2484,'4d048397-d2ef-438f-a1b3-7d813ff77baf','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:23',NULL,'CREATE','IN_PROGRESS','ControllerServiceChainRoleData','overcloud-ControllerServiceChainRoleData-njajfgtyupwo','state changed','OS::Heat::Value',NULL,1527),(2485,'32420ee8-b90b-4ca5-bef7-82613a4469c0','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:23',NULL,'CREATE','COMPLETE','ControllerServiceChainRoleData','overcloud-ControllerServiceChainRoleData-njajfgtyupwo','state changed','OS::Heat::Value',NULL,1527),(2486,'fa35fb2d-c361-472e-aa28-e20c0bbd27b6','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:24',NULL,'CREATE','IN_PROGRESS','BlockStorageServiceConfigSettings','overcloud-BlockStorageServiceConfigSettings-6tuvlmzwsqi6','state changed','OS::Heat::Value',NULL,1528),(2487,'33c6bc9d-5f0b-4ebf-8fc9-9e27c66ca07c','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:24',NULL,'CREATE','COMPLETE','BlockStorageServiceConfigSettings','overcloud-BlockStorageServiceConfigSettings-6tuvlmzwsqi6','state changed','OS::Heat::Value',NULL,1528),(2488,'d982dcc5-01cc-49db-a100-8304a14205cf','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:24',NULL,'CREATE','IN_PROGRESS','CellControllerServiceConfigSettings','overcloud-CellControllerServiceConfigSettings-t3gjcookytdk','state changed','OS::Heat::Value',NULL,1530),(2489,'75efd193-7461-4abc-bffc-804b1e2209d4','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:24',NULL,'CREATE','COMPLETE','CellControllerServiceConfigSettings','overcloud-CellControllerServiceConfigSettings-t3gjcookytdk','state changed','OS::Heat::Value',NULL,1530),(2490,'f5658ecd-2606-4e56-ab34-097caf69fa95','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:24',NULL,'CREATE','IN_PROGRESS','BlockStorageConfigData','overcloud-BlockStorageConfigData-xeliku2m3oaz','state changed','OS::Heat::Value',NULL,1531),(2491,'bee0dc35-0e6e-4cea-9392-03e4f5aaf0df','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:24',NULL,'CREATE','COMPLETE','BlockStorageConfigData','overcloud-BlockStorageConfigData-xeliku2m3oaz','state changed','OS::Heat::Value',NULL,1531),(2492,'a367900b-5ffd-458e-bdd4-96a747c84a07','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:24',NULL,'CREATE','IN_PROGRESS','CellControllerConfigData','overcloud-CellControllerConfigData-pvqugnkum36c','state changed','OS::Heat::Value',NULL,1533),(2493,'4bdbecb6-96f2-4075-9c52-a485d26fe5d7','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:24',NULL,'CREATE','COMPLETE','CellControllerConfigData','overcloud-CellControllerConfigData-pvqugnkum36c','state changed','OS::Heat::Value',NULL,1533),(2494,'804fdf5f-4dc0-4319-b88c-7e3d333db221','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:24',NULL,'CREATE','IN_PROGRESS','ComputeServiceConfigSettings','overcloud-ComputeServiceConfigSettings-deujwj7txhnl','state changed','OS::Heat::Value',NULL,1534),(2495,'5c909b17-addf-4197-a68f-b9b001e8037c','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:24',NULL,'CREATE','COMPLETE','ComputeServiceConfigSettings','overcloud-ComputeServiceConfigSettings-deujwj7txhnl','state changed','OS::Heat::Value',NULL,1534),(2496,'8876a82f-7da2-405b-af8a-e002aaf5e7e5','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:24',NULL,'CREATE','IN_PROGRESS','NetworkerServiceConfigSettings','overcloud-NetworkerServiceConfigSettings-bvich4mfm33g','state changed','OS::Heat::Value',NULL,1535),(2497,'29fcb206-c9dc-4293-8984-e5b75f8f7325','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:24',NULL,'CREATE','COMPLETE','NetworkerServiceConfigSettings','overcloud-NetworkerServiceConfigSettings-bvich4mfm33g','state changed','OS::Heat::Value',NULL,1535),(2498,'76da06d5-94bf-4056-af76-9f61a6ca3bb6','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:24',NULL,'CREATE','IN_PROGRESS','NetworkerConfigData','overcloud-NetworkerConfigData-ko3mcsdpqy2q','state changed','OS::Heat::Value',NULL,1537),(2499,'c143f556-c2e7-4a23-9b01-34f908bcb6f4','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:24',NULL,'CREATE','COMPLETE','NetworkerConfigData','overcloud-NetworkerConfigData-ko3mcsdpqy2q','state changed','OS::Heat::Value',NULL,1537),(2500,'e2919e9e-a76f-47e3-bad7-ed094895a5ef','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:25',NULL,'CREATE','IN_PROGRESS','ComputeConfigData','overcloud-ComputeConfigData-2zgrbccfnsvc','state changed','OS::Heat::Value',NULL,1540),(2501,'a102b112-20b1-4047-876b-32708d023e3a','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:25',NULL,'CREATE','COMPLETE','ComputeConfigData','overcloud-ComputeConfigData-2zgrbccfnsvc','state changed','OS::Heat::Value',NULL,1540),(2502,'6c8e7a65-e1f6-484a-94c9-b8c9045023e7','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:25',NULL,'CREATE','IN_PROGRESS','GlobalConfig','overcloud-GlobalConfig-4c7bww6q36yk','state changed','OS::Heat::Value',NULL,1539),(2503,'aaf1d3ee-780e-45e3-839c-eb11422e7367','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:25',NULL,'CREATE','COMPLETE','GlobalConfig','overcloud-GlobalConfig-4c7bww6q36yk','state changed','OS::Heat::Value',NULL,1539),(2504,'909f74de-c392-411b-9fde-c91062bcf4f0','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:25',NULL,'CREATE','IN_PROGRESS','CephStorageServiceConfigSettings','overcloud-CephStorageServiceConfigSettings-quupol7izgas','state changed','OS::Heat::Value',NULL,1541),(2505,'0586ce77-4e35-413e-86c0-801a889d6689','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:25',NULL,'CREATE','COMPLETE','CephStorageServiceConfigSettings','overcloud-CephStorageServiceConfigSettings-quupol7izgas','state changed','OS::Heat::Value',NULL,1541),(2506,'3e91f5fa-f668-4352-bbaf-536e9e5143de','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:25',NULL,'CREATE','IN_PROGRESS','CephStorageConfigData','overcloud-CephStorageConfigData-gtmgriefcuke','state changed','OS::Heat::Value',NULL,1543),(2507,'98daa3d6-ceb6-4509-b78e-29d59c544e03','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:25',NULL,'CREATE','COMPLETE','CephStorageConfigData','overcloud-CephStorageConfigData-gtmgriefcuke','state changed','OS::Heat::Value',NULL,1543),(2508,'0facc446-52dc-4a7d-b210-b5b38ecbe5b7','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:26',NULL,'CREATE','IN_PROGRESS','CellControllerComputeServiceConfigSettings','overcloud-CellControllerComputeServiceConfigSettings-5zx7uph3rqql','state changed','OS::Heat::Value',NULL,1544),(2509,'d999cb0f-569a-47c0-8a7d-11ccc7f0eccc','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:26',NULL,'CREATE','COMPLETE','CellControllerComputeServiceConfigSettings','overcloud-CellControllerComputeServiceConfigSettings-5zx7uph3rqql','state changed','OS::Heat::Value',NULL,1544),(2510,'1b212d08-0075-4d8c-969c-aba6351af475','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:26',NULL,'CREATE','IN_PROGRESS','FirewallFrontendRules','overcloud-FirewallFrontendRules-bwghpxuatbtd','state changed','OS::Heat::Value',NULL,1545),(2511,'b7859c2e-6a9e-471e-baa1-3f6db6bdacc8','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:26',NULL,'CREATE','COMPLETE','FirewallFrontendRules','overcloud-FirewallFrontendRules-bwghpxuatbtd','state changed','OS::Heat::Value',NULL,1545),(2512,'d9b1557c-d2fc-486c-95d7-17097c903114','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:26',NULL,'CREATE','IN_PROGRESS','CellControllerComputeGroupVars','overcloud-CellControllerComputeGroupVars-scep7ouad6d2','state changed','OS::Heat::Value',NULL,1548),(2513,'502a0927-dd48-42a7-a8cd-ab331126330a','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:26',NULL,'CREATE','IN_PROGRESS','ControllerServiceNames','overcloud-ControllerServiceNames-bssmrjhhz5m6','state changed','OS::Heat::Value',NULL,1549),(2514,'d2ae3df5-e596-4536-bcf8-f9c5ea5caa76','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:26',NULL,'CREATE','COMPLETE','ControllerServiceNames','overcloud-ControllerServiceNames-bssmrjhhz5m6','state changed','OS::Heat::Value',NULL,1549),(2515,'f61f44d1-5769-43fb-b103-14b0779b5145','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:26',NULL,'CREATE','COMPLETE','CellControllerComputeGroupVars','overcloud-CellControllerComputeGroupVars-scep7ouad6d2','state changed','OS::Heat::Value',NULL,1548),(2516,'bb55e747-1844-411c-9556-c67b297435c6','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:26',NULL,'CREATE','IN_PROGRESS','CellControllerComputeConfigData','overcloud-CellControllerComputeConfigData-qe6q2miimzj3','state changed','OS::Heat::Value',NULL,1547),(2517,'59f3bfe3-8d8e-4217-8c0a-ceab6d61f075','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:26',NULL,'CREATE','COMPLETE','CellControllerComputeConfigData','overcloud-CellControllerComputeConfigData-qe6q2miimzj3','state changed','OS::Heat::Value',NULL,1547),(2518,'6a7b6adc-2809-4fe4-ad8d-4abe9ba07f53','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:26',NULL,'CREATE','IN_PROGRESS','ControllerGroupVars','overcloud-ControllerGroupVars-mf3yzxr6t5em','state changed','OS::Heat::Value',NULL,1554),(2519,'ec11d444-31ab-45a4-9987-60e1e74e9824','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:26',NULL,'CREATE','IN_PROGRESS','BlockStorageGroupVars','overcloud-BlockStorageGroupVars-zwrerzrbxebe','state changed','OS::Heat::Value',NULL,1553),(2520,'8cbdc46b-1f28-473e-ab04-45d493cd1a1d','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:26',NULL,'CREATE','IN_PROGRESS','ObjectStorageGroupVars','overcloud-ObjectStorageGroupVars-b7vqorur6e7y','state changed','OS::Heat::Value',NULL,1550),(2521,'f31c1702-dbb8-48f6-90ae-0fdd5007a10f','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:26',NULL,'CREATE','IN_PROGRESS','CellControllerGroupVars','overcloud-CellControllerGroupVars-ue3inji7cjnw','state changed','OS::Heat::Value',NULL,1552),(2522,'1b4a9122-30b5-49e3-81ba-c29a78cc029c','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:26',NULL,'CREATE','IN_PROGRESS','NetworkerGroupVars','overcloud-NetworkerGroupVars-qll4qvfop7b3','state changed','OS::Heat::Value',NULL,1555),(2523,'32fed67a-6597-4a45-b5dc-9fa56dd02c24','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:26',NULL,'CREATE','COMPLETE','ObjectStorageGroupVars','overcloud-ObjectStorageGroupVars-b7vqorur6e7y','state changed','OS::Heat::Value',NULL,1550),(2524,'a4bafa46-efac-4617-b51a-a2d6f79fdb04','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:26',NULL,'CREATE','COMPLETE','NetworkerGroupVars','overcloud-NetworkerGroupVars-qll4qvfop7b3','state changed','OS::Heat::Value',NULL,1555),(2525,'3a728410-43d3-45b4-99d0-6f32298e0fca','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:26',NULL,'CREATE','COMPLETE','BlockStorageGroupVars','overcloud-BlockStorageGroupVars-zwrerzrbxebe','state changed','OS::Heat::Value',NULL,1553),(2526,'febe973e-b876-499e-b035-4c7798662578','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:26',NULL,'CREATE','IN_PROGRESS','ObjectStorageServiceConfigSettings','overcloud-ObjectStorageServiceConfigSettings-t2jjkop3uds5','state changed','OS::Heat::Value',NULL,1558),(2527,'87d1b9c2-0796-4ae8-b9ac-daf0fb0a186e','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:26',NULL,'CREATE','COMPLETE','ControllerGroupVars','overcloud-ControllerGroupVars-mf3yzxr6t5em','state changed','OS::Heat::Value',NULL,1554),(2528,'ffefe1d4-de53-490b-963b-9415f3376f5b','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:26',NULL,'CREATE','COMPLETE','ObjectStorageServiceConfigSettings','overcloud-ObjectStorageServiceConfigSettings-t2jjkop3uds5','state changed','OS::Heat::Value',NULL,1558),(2529,'fc7ec5f8-6b5b-4d34-859c-3f692f5c3dbb','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:26',NULL,'CREATE','IN_PROGRESS','ComputeGroupVars','overcloud-ComputeGroupVars-pyurrvqzugrw','state changed','OS::Heat::Value',NULL,1559),(2530,'d33b5244-2e9f-4962-8454-9c4e6cf84ba7','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:26',NULL,'CREATE','COMPLETE','ComputeGroupVars','overcloud-ComputeGroupVars-pyurrvqzugrw','state changed','OS::Heat::Value',NULL,1559),(2531,'01d3ff5f-acb2-415f-bf62-66de872495da','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:26',NULL,'CREATE','IN_PROGRESS','CephStorageGroupVars','overcloud-CephStorageGroupVars-kv4d3zaice4x','state changed','OS::Heat::Value',NULL,1557),(2532,'daa796bd-e4a7-4714-ab5e-c757d4800435','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:26',NULL,'CREATE','COMPLETE','CellControllerGroupVars','overcloud-CellControllerGroupVars-ue3inji7cjnw','state changed','OS::Heat::Value',NULL,1552),(2533,'7a62ff4e-9edb-41be-bdf8-b54ec3f48153','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:27',NULL,'CREATE','COMPLETE','CephStorageGroupVars','overcloud-CephStorageGroupVars-kv4d3zaice4x','state changed','OS::Heat::Value',NULL,1557),(2534,'e5795839-aa7f-4801-bbee-15618c738052','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:27',NULL,'CREATE','IN_PROGRESS','ObjectStorageConfigData','overcloud-ObjectStorageConfigData-vqhethcbj6s7','state changed','OS::Heat::Value',NULL,1561),(2535,'5e0f93b6-1a83-41d8-aba5-0393bfc5e004','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:27',NULL,'CREATE','COMPLETE','ObjectStorageConfigData','overcloud-ObjectStorageConfigData-vqhethcbj6s7','state changed','OS::Heat::Value',NULL,1561),(2536,'f603a387-9343-43ea-a10a-576d22583f23','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:27',NULL,'CREATE','IN_PROGRESS','Controller','overcloud-Controller-6r6ux5bcpsr3','state changed','OS::Heat::ResourceGroup',NULL,1562),(2537,'ac5e6a5b-ecc8-45e2-94a0-0d4445fb647f','7927cabd-5ac4-4f35-a20d-00f65e92d2bf','2026-06-09 08:03:27',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-6r6ux5bcpsr3','7927cabd-5ac4-4f35-a20d-00f65e92d2bf','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2538,'e91d473e-28dd-49e9-b7e0-87e37df48a88','7927cabd-5ac4-4f35-a20d-00f65e92d2bf','2026-06-09 08:03:27',NULL,'CREATE','COMPLETE','overcloud-Controller-6r6ux5bcpsr3','7927cabd-5ac4-4f35-a20d-00f65e92d2bf','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2539,'a295b800-a35d-4c05-9ef9-d13cbf2d0936','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:27',NULL,'CREATE','IN_PROGRESS','ControllerServiceConfigSettings','overcloud-ControllerServiceConfigSettings-2hwq4x3yl4be','state changed','OS::Heat::Value',NULL,1563),(2540,'7c94fcfa-4366-4d94-9c6a-39e6e1236225','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:27',NULL,'CREATE','COMPLETE','ControllerServiceConfigSettings','overcloud-ControllerServiceConfigSettings-2hwq4x3yl4be','state changed','OS::Heat::Value',NULL,1563),(2541,'d90d7e31-3a01-4783-b4c2-6cab67edd974','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:27',NULL,'CREATE','IN_PROGRESS','ControllerConfigData','overcloud-ControllerConfigData-gu4uxqtfwrwo','state changed','OS::Heat::Value',NULL,1566),(2542,'87798a95-6a4d-4b9f-a8fb-7f5d3bc39f71','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:27',NULL,'CREATE','COMPLETE','ControllerConfigData','overcloud-ControllerConfigData-gu4uxqtfwrwo','state changed','OS::Heat::Value',NULL,1566),(2543,'435fa2f7-d2c6-4d70-9677-ca5178974e68','7927cabd-5ac4-4f35-a20d-00f65e92d2bf','2026-06-09 08:03:28',NULL,'UPDATE','IN_PROGRESS','overcloud-Controller-6r6ux5bcpsr3','7927cabd-5ac4-4f35-a20d-00f65e92d2bf','Stack UPDATE started','OS::Heat::Stack',NULL,NULL),(2544,'cd09a3cb-39cb-4b45-bd44-5c119c5dba58','7927cabd-5ac4-4f35-a20d-00f65e92d2bf','2026-06-09 08:03:28',NULL,'CREATE','IN_PROGRESS','1','overcloud-Controller-6r6ux5bcpsr3-1-xvry4cw4dkno','state changed','OS::TripleO::Controller',NULL,1567),(2545,'f4c2aa40-060f-4bb2-9251-5b1383f4f82e','627c87c4-2e4c-4189-a029-0b9e9797e97a','2026-06-09 08:03:28',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-6r6ux5bcpsr3-1-xvry4cw4dkno','627c87c4-2e4c-4189-a029-0b9e9797e97a','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2546,'b3fb6113-3fb0-46f2-9094-63aa52e6f59b','627c87c4-2e4c-4189-a029-0b9e9797e97a','2026-06-09 08:03:29',NULL,'CREATE','IN_PROGRESS','DeploymentActions','overcloud-Controller-6r6ux5bcpsr3-1-xvry4cw4dkno-DeploymentActions-wsx2rpqh6x5z','state changed','OS::Heat::Value',NULL,1568),(2547,'81467782-1453-4149-8ded-06390e76dd0e','627c87c4-2e4c-4189-a029-0b9e9797e97a','2026-06-09 08:03:29',NULL,'CREATE','COMPLETE','DeploymentActions','overcloud-Controller-6r6ux5bcpsr3-1-xvry4cw4dkno-DeploymentActions-wsx2rpqh6x5z','state changed','OS::Heat::Value',NULL,1568),(2548,'723b8215-9772-4d7e-9f4c-ad30deb21ce7','7927cabd-5ac4-4f35-a20d-00f65e92d2bf','2026-06-09 08:03:29',NULL,'CREATE','IN_PROGRESS','0','overcloud-Controller-6r6ux5bcpsr3-0-gxtwjyggi57i','state changed','OS::TripleO::Controller',NULL,1570),(2549,'83dfa754-cd06-4e26-96f9-139c3900c24c','329b2c0f-9c6e-4d8d-9d05-0cc1b0d601fc','2026-06-09 08:03:29',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-6r6ux5bcpsr3-0-gxtwjyggi57i','329b2c0f-9c6e-4d8d-9d05-0cc1b0d601fc','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2550,'ae1de487-94db-4d21-a851-a314a77acd02','329b2c0f-9c6e-4d8d-9d05-0cc1b0d601fc','2026-06-09 08:03:29',NULL,'CREATE','IN_PROGRESS','DeploymentActions','overcloud-Controller-6r6ux5bcpsr3-0-gxtwjyggi57i-DeploymentActions-u4itioh7phgl','state changed','OS::Heat::Value',NULL,1571),(2551,'0927eac5-7500-4dad-a3a8-ae139dcbb558','329b2c0f-9c6e-4d8d-9d05-0cc1b0d601fc','2026-06-09 08:03:30',NULL,'CREATE','COMPLETE','DeploymentActions','overcloud-Controller-6r6ux5bcpsr3-0-gxtwjyggi57i-DeploymentActions-u4itioh7phgl','state changed','OS::Heat::Value',NULL,1571),(2552,'b5891d21-03c5-43fb-b584-6085e1b1051d','627c87c4-2e4c-4189-a029-0b9e9797e97a','2026-06-09 08:03:30',NULL,'CREATE','IN_PROGRESS','Controller','overcloud-Controller-6r6ux5bcpsr3-1-xvry4cw4dkno-Controller-6iph6r3433ut','state changed','OS::TripleO::ControllerServer',NULL,1573),(2553,'6f0483cd-09f7-4937-9930-461bd90ac9b7','34040aa5-06f0-4820-9d3b-06c649085a0e','2026-06-09 08:03:30',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-6r6ux5bcpsr3-1-xvry4cw4dkno-Controller-6iph6r3433ut','34040aa5-06f0-4820-9d3b-06c649085a0e','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2554,'40500039-4d2d-4ea0-8e77-046ad033e330','34040aa5-06f0-4820-9d3b-06c649085a0e','2026-06-09 08:03:30',NULL,'CREATE','IN_PROGRESS','ControlPlanePort','overcloud-Controller-6r6ux5bcpsr3-1-xvry4cw4dkno-Controller-6iph6r3433ut-ControlPlanePort-5njbh3kiuls5','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1574),(2555,'9eeedf4a-5289-40ca-80a4-e88c5bb72e48','691a9450-dace-40bb-b918-e9710ad33224','2026-06-09 08:03:30',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-6r6ux5bcpsr3-1-xvry4cw4dkno-Controller-6iph6r3433ut-ControlPlanePort-5njbh3kiuls5','691a9450-dace-40bb-b918-e9710ad33224','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2556,'8b221711-7da1-44b9-aedd-1e466a36d6d3','691a9450-dace-40bb-b918-e9710ad33224','2026-06-09 08:03:30',NULL,'CREATE','COMPLETE','overcloud-Controller-6r6ux5bcpsr3-1-xvry4cw4dkno-Controller-6iph6r3433ut-ControlPlanePort-5njbh3kiuls5','691a9450-dace-40bb-b918-e9710ad33224','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2557,'aea23b6b-cf07-402b-90bc-c21db3f12291','7927cabd-5ac4-4f35-a20d-00f65e92d2bf','2026-06-09 08:03:30',NULL,'CREATE','IN_PROGRESS','2','overcloud-Controller-6r6ux5bcpsr3-2-bvtivffc4ip5','state changed','OS::TripleO::Controller',NULL,1575),(2558,'7104869f-4747-444b-b37a-aee221a9c8d7','fe6daf36-029c-4429-898d-a3c4dba4da9b','2026-06-09 08:03:30',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-6r6ux5bcpsr3-2-bvtivffc4ip5','fe6daf36-029c-4429-898d-a3c4dba4da9b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2559,'d9db8511-7b9f-4f9d-8e64-3a05b41272fd','fe6daf36-029c-4429-898d-a3c4dba4da9b','2026-06-09 08:03:30',NULL,'CREATE','IN_PROGRESS','DeploymentActions','overcloud-Controller-6r6ux5bcpsr3-2-bvtivffc4ip5-DeploymentActions-46aytgcqfa64','state changed','OS::Heat::Value',NULL,1576),(2560,'c6dcbab7-45d1-4a18-ab11-a3b1a5e49f2f','fe6daf36-029c-4429-898d-a3c4dba4da9b','2026-06-09 08:03:30',NULL,'CREATE','COMPLETE','DeploymentActions','overcloud-Controller-6r6ux5bcpsr3-2-bvtivffc4ip5-DeploymentActions-46aytgcqfa64','state changed','OS::Heat::Value',NULL,1576),(2561,'edb55849-dc7d-4e39-a568-6e24909a3c05','329b2c0f-9c6e-4d8d-9d05-0cc1b0d601fc','2026-06-09 08:03:31',NULL,'CREATE','IN_PROGRESS','Controller','overcloud-Controller-6r6ux5bcpsr3-0-gxtwjyggi57i-Controller-elz25wuw6zdd','state changed','OS::TripleO::ControllerServer',NULL,1578),(2562,'bc4048ad-c419-46f1-a9b1-3b85130c7efe','a64d6ead-aadf-49fa-b752-6a0efa17c62c','2026-06-09 08:03:31',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-6r6ux5bcpsr3-0-gxtwjyggi57i-Controller-elz25wuw6zdd','a64d6ead-aadf-49fa-b752-6a0efa17c62c','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2563,'a4e4d1ba-6922-4de0-9017-3d6d24a437cd','a64d6ead-aadf-49fa-b752-6a0efa17c62c','2026-06-09 08:03:31',NULL,'CREATE','IN_PROGRESS','ControlPlanePort','overcloud-Controller-6r6ux5bcpsr3-0-gxtwjyggi57i-Controller-elz25wuw6zdd-ControlPlanePort-mfvcw7ocytv7','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1579),(2564,'feed693b-581c-44ab-a1f4-efc988ea062a','8fc938fa-9938-46a4-90ec-8c355e575f35','2026-06-09 08:03:31',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-6r6ux5bcpsr3-0-gxtwjyggi57i-Controller-elz25wuw6zdd-ControlPlanePort-mfvcw7ocytv7','8fc938fa-9938-46a4-90ec-8c355e575f35','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2565,'db3d3d43-8045-4410-9978-13c6f57ecec3','8fc938fa-9938-46a4-90ec-8c355e575f35','2026-06-09 08:03:31',NULL,'CREATE','COMPLETE','overcloud-Controller-6r6ux5bcpsr3-0-gxtwjyggi57i-Controller-elz25wuw6zdd-ControlPlanePort-mfvcw7ocytv7','8fc938fa-9938-46a4-90ec-8c355e575f35','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2566,'79f58862-119c-41bf-98ab-ff864cc96488','34040aa5-06f0-4820-9d3b-06c649085a0e','2026-06-09 08:03:31',NULL,'CREATE','IN_PROGRESS','deployed-server','ov-ntroller-6iph6r3433ut-deployed-server-i33qtqdm2ssf','state changed','OS::Heat::DeployedServer',NULL,1580),(2567,'bb362861-dabe-431d-b3ed-1fb9d896279d','34040aa5-06f0-4820-9d3b-06c649085a0e','2026-06-09 08:03:31',NULL,'CREATE','COMPLETE','deployed-server','06cd4a45-709c-446f-a6b3-3a628d955353','state changed','OS::Heat::DeployedServer',NULL,1580),(2568,'aed0bfd9-cfe1-4d3c-991e-287f647dc2b5','34040aa5-06f0-4820-9d3b-06c649085a0e','2026-06-09 08:03:31',NULL,'CREATE','COMPLETE','ControlPlanePort','691a9450-dace-40bb-b918-e9710ad33224','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1574),(2569,'3218f0da-48ef-44e5-a8d1-0ed7498f2a77','34040aa5-06f0-4820-9d3b-06c649085a0e','2026-06-09 08:03:31',NULL,'CREATE','COMPLETE','overcloud-Controller-6r6ux5bcpsr3-1-xvry4cw4dkno-Controller-6iph6r3433ut','34040aa5-06f0-4820-9d3b-06c649085a0e','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2570,'9f8e920e-5608-483b-ab89-13d6a1972d97','fe6daf36-029c-4429-898d-a3c4dba4da9b','2026-06-09 08:03:31',NULL,'CREATE','IN_PROGRESS','Controller','overcloud-Controller-6r6ux5bcpsr3-2-bvtivffc4ip5-Controller-42mngssjfrsh','state changed','OS::TripleO::ControllerServer',NULL,1581),(2571,'582cd788-a6e3-42de-9637-e6579dd20103','43ca2825-836b-4ed2-b313-6364b8c53516','2026-06-09 08:03:32',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-6r6ux5bcpsr3-2-bvtivffc4ip5-Controller-42mngssjfrsh','43ca2825-836b-4ed2-b313-6364b8c53516','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2572,'da95789b-3a32-4999-bf1d-e76b7df7f107','43ca2825-836b-4ed2-b313-6364b8c53516','2026-06-09 08:03:32',NULL,'CREATE','IN_PROGRESS','deployed-server','ov-ntroller-42mngssjfrsh-deployed-server-bcqko3dcvov6','state changed','OS::Heat::DeployedServer',NULL,1582),(2573,'68c65d5c-d2cc-4274-836e-974ff4ba3b21','43ca2825-836b-4ed2-b313-6364b8c53516','2026-06-09 08:03:32',NULL,'CREATE','COMPLETE','deployed-server','c62ababe-0a76-408a-896b-858079a93f73','state changed','OS::Heat::DeployedServer',NULL,1582),(2574,'20b43323-b8a4-4404-980a-a2ecac1e73da','a64d6ead-aadf-49fa-b752-6a0efa17c62c','2026-06-09 08:03:32',NULL,'CREATE','IN_PROGRESS','deployed-server','ov-ntroller-elz25wuw6zdd-deployed-server-phuxixv6o2es','state changed','OS::Heat::DeployedServer',NULL,1583),(2575,'b515d8b4-b82b-460b-8b4a-5aff04c9f691','a64d6ead-aadf-49fa-b752-6a0efa17c62c','2026-06-09 08:03:32',NULL,'CREATE','COMPLETE','deployed-server','ebe76892-9745-479e-b066-ef2891374344','state changed','OS::Heat::DeployedServer',NULL,1583),(2576,'251e85a3-c121-490e-b51b-af40af8b3ada','627c87c4-2e4c-4189-a029-0b9e9797e97a','2026-06-09 08:03:32',NULL,'CREATE','COMPLETE','Controller','34040aa5-06f0-4820-9d3b-06c649085a0e','state changed','OS::TripleO::ControllerServer',NULL,1573),(2577,'4dc552ff-88da-4d69-9c3a-9357db176744','a64d6ead-aadf-49fa-b752-6a0efa17c62c','2026-06-09 08:03:32',NULL,'CREATE','COMPLETE','ControlPlanePort','8fc938fa-9938-46a4-90ec-8c355e575f35','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1579),(2578,'7e71dbd8-908a-4323-bc15-01f4fb0a57f3','a64d6ead-aadf-49fa-b752-6a0efa17c62c','2026-06-09 08:03:32',NULL,'CREATE','COMPLETE','overcloud-Controller-6r6ux5bcpsr3-0-gxtwjyggi57i-Controller-elz25wuw6zdd','a64d6ead-aadf-49fa-b752-6a0efa17c62c','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2579,'4003db77-ebe5-4b45-9299-9bf541fbf402','627c87c4-2e4c-4189-a029-0b9e9797e97a','2026-06-09 08:03:32',NULL,'CREATE','IN_PROGRESS','NetHostMap','overcloud-Controller-6r6ux5bcpsr3-1-xvry4cw4dkno-NetHostMap-oz6btyzxvanl','state changed','OS::Heat::Value',NULL,1585),(2580,'ed9c9eb2-3210-4221-9b5d-4a1e936741e6','627c87c4-2e4c-4189-a029-0b9e9797e97a','2026-06-09 08:03:32',NULL,'CREATE','COMPLETE','NetHostMap','overcloud-Controller-6r6ux5bcpsr3-1-xvry4cw4dkno-NetHostMap-oz6btyzxvanl','state changed','OS::Heat::Value',NULL,1585),(2581,'b3fb6ecb-30bc-4e40-946c-bd3117a4155e','627c87c4-2e4c-4189-a029-0b9e9797e97a','2026-06-09 08:03:32',NULL,'CREATE','IN_PROGRESS','ExternalPort','overcloud-Controller-6r6ux5bcpsr3-1-xvry4cw4dkno-ExternalPort-kwbvvpsq4icy','state changed','OS::TripleO::Controller::Ports::ExternalPort',NULL,1586),(2582,'5f6531cf-522a-49cc-96c4-05577293e849','627c87c4-2e4c-4189-a029-0b9e9797e97a','2026-06-09 08:03:32',NULL,'CREATE','IN_PROGRESS','StorageMgmtPort','overcloud-Controller-6r6ux5bcpsr3-1-xvry4cw4dkno-StorageMgmtPort-bcltavwgibk3','state changed','OS::TripleO::Controller::Ports::StorageMgmtPort',NULL,1587),(2583,'b4b0348f-8633-421b-b11f-4a9ec8516dfc','627c87c4-2e4c-4189-a029-0b9e9797e97a','2026-06-09 08:03:32',NULL,'CREATE','IN_PROGRESS','NodeTLSCAData','overcloud-Controller-6r6ux5bcpsr3-1-xvry4cw4dkno-NodeTLSCAData-axu76cua5how','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(2584,'b2f274be-7267-447f-9a28-ce1e8f09f71a','627c87c4-2e4c-4189-a029-0b9e9797e97a','2026-06-09 08:03:32',NULL,'CREATE','IN_PROGRESS','ControllerAnsibleHostVars','overcloud-Controller-6r6ux5bcpsr3-1-xvry4cw4dkno-ControllerAnsibleHostVars-nor34mrfd35j','state changed','OS::Heat::Value',NULL,1589),(2585,'ed739939-c14a-4a35-8adc-e866f4feb216','627c87c4-2e4c-4189-a029-0b9e9797e97a','2026-06-09 08:03:32',NULL,'CREATE','COMPLETE','NodeTLSCAData','0ed28e20-c04f-4057-b4ac-a82889162cb0','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(2586,'f67405f5-2fc4-4012-8f59-8a3e30b72575','627c87c4-2e4c-4189-a029-0b9e9797e97a','2026-06-09 08:03:32',NULL,'CREATE','COMPLETE','ControllerAnsibleHostVars','overcloud-Controller-6r6ux5bcpsr3-1-xvry4cw4dkno-ControllerAnsibleHostVars-nor34mrfd35j','state changed','OS::Heat::Value',NULL,1589),(2587,'9cffb45d-bf69-402d-925e-b9809fc945f4','627c87c4-2e4c-4189-a029-0b9e9797e97a','2026-06-09 08:03:32',NULL,'CREATE','IN_PROGRESS','TenantPort','overcloud-Controller-6r6ux5bcpsr3-1-xvry4cw4dkno-TenantPort-oo6txugiq7hf','state changed','OS::TripleO::Controller::Ports::TenantPort',NULL,1590),(2588,'b88c4850-3a61-49b8-be06-2d36f1d8ddee','bff6819f-18e9-45d3-86a9-68cabade06c1','2026-06-09 08:03:32',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-6r6ux5bcpsr3-1-xvry4cw4dkno-StorageMgmtPort-bcltavwgibk3','bff6819f-18e9-45d3-86a9-68cabade06c1','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2589,'28ae43e0-3386-435d-a461-8fc9979eac6a','25b6a4bd-bb6c-4721-8670-41dc0238aba6','2026-06-09 08:03:32',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-6r6ux5bcpsr3-1-xvry4cw4dkno-TenantPort-oo6txugiq7hf','25b6a4bd-bb6c-4721-8670-41dc0238aba6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2590,'019ba867-692c-4d8f-97e7-d10dfb99e97d','627c87c4-2e4c-4189-a029-0b9e9797e97a','2026-06-09 08:03:32',NULL,'CREATE','IN_PROGRESS','ControllerExtraConfigPre','overcloud-Controller-6r6ux5bcpsr3-1-xvry4cw4dkno-ControllerExtraConfigPre-2jwl5eykty6w','state changed','OS::TripleO::ControllerExtraConfigPre',NULL,1591),(2591,'6276fbc7-3f0a-46df-8c95-4663ffac98f2','c4256080-174f-43c6-b2d2-796ebb483ba7','2026-06-09 08:03:32',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-6r6ux5bcpsr3-1-xvry4cw4dkno-ExternalPort-kwbvvpsq4icy','c4256080-174f-43c6-b2d2-796ebb483ba7','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2592,'e383d38e-00fb-4f4c-87e2-df28e4e0addf','bff6819f-18e9-45d3-86a9-68cabade06c1','2026-06-09 08:03:32',NULL,'CREATE','IN_PROGRESS','StorageMgmtDeployedPort','overcloud-Controller-6r6ux5bcpsr3-1-xvry4cw4dkno-StorageMgmtPort-bcltavwgibk3-StorageMgmtDeployedPort-luhe7d6f3wgt','state changed','OS::Heat::Value',NULL,1592),(2593,'b8c85118-ed90-43ce-ad66-cbc86d36158d','627c87c4-2e4c-4189-a029-0b9e9797e97a','2026-06-09 08:03:32',NULL,'CREATE','IN_PROGRESS','InternalApiPort','overcloud-Controller-6r6ux5bcpsr3-1-xvry4cw4dkno-InternalApiPort-6knebscw3wy2','state changed','OS::TripleO::Controller::Ports::InternalApiPort',NULL,1593),(2594,'bfea0173-89fe-4b17-ada5-a51be96df341','bff6819f-18e9-45d3-86a9-68cabade06c1','2026-06-09 08:03:32',NULL,'CREATE','COMPLETE','StorageMgmtDeployedPort','overcloud-Controller-6r6ux5bcpsr3-1-xvry4cw4dkno-StorageMgmtPort-bcltavwgibk3-StorageMgmtDeployedPort-luhe7d6f3wgt','state changed','OS::Heat::Value',NULL,1592),(2595,'403db76d-6ea7-481f-943f-fd77ab8102eb','bff6819f-18e9-45d3-86a9-68cabade06c1','2026-06-09 08:03:32',NULL,'CREATE','COMPLETE','overcloud-Controller-6r6ux5bcpsr3-1-xvry4cw4dkno-StorageMgmtPort-bcltavwgibk3','bff6819f-18e9-45d3-86a9-68cabade06c1','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2596,'33ae3291-3ad5-464f-a8de-82ccfc76cd05','627c87c4-2e4c-4189-a029-0b9e9797e97a','2026-06-09 08:03:32',NULL,'CREATE','IN_PROGRESS','PreNetworkConfig','overcloud-Controller-6r6ux5bcpsr3-1-xvry4cw4dkno-PreNetworkConfig-53ltojikpp5f','state changed','OS::TripleO::Controller::PreNetworkConfig',NULL,NULL),(2597,'3ed73bc1-9958-4f75-8526-73a6da5e1324','627c87c4-2e4c-4189-a029-0b9e9797e97a','2026-06-09 08:03:32',NULL,'CREATE','COMPLETE','PreNetworkConfig','04045116-ad86-4fde-93e3-0102b7fe3362','state changed','OS::TripleO::Controller::PreNetworkConfig',NULL,NULL),(2598,'8427d71c-e9c3-4336-86c9-005207fef18b','25b6a4bd-bb6c-4721-8670-41dc0238aba6','2026-06-09 08:03:32',NULL,'CREATE','IN_PROGRESS','TenantDeployedPort','overcloud-Controller-6r6ux5bcpsr3-1-xvry4cw4dkno-TenantPort-oo6txugiq7hf-TenantDeployedPort-i4u72fz47p4w','state changed','OS::Heat::Value',NULL,1595),(2599,'1aa1a070-3474-432d-a601-28a5fd5d3923','627c87c4-2e4c-4189-a029-0b9e9797e97a','2026-06-09 08:03:32',NULL,'CREATE','IN_PROGRESS','StoragePort','overcloud-Controller-6r6ux5bcpsr3-1-xvry4cw4dkno-StoragePort-5yrvnk35jgl3','state changed','OS::TripleO::Controller::Ports::StoragePort',NULL,1596),(2600,'00fb7554-88b1-4d65-bf8a-9b72652767ed','b4f46341-992c-4a44-9e07-244ed01f4e9f','2026-06-09 08:03:32',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-6r6ux5bcpsr3-1-xvry4cw4dkno-InternalApiPort-6knebscw3wy2','b4f46341-992c-4a44-9e07-244ed01f4e9f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2601,'ed109a84-21d0-46ef-9798-b245bd526e7a','fb256d0a-ee2c-4f6f-b334-28ac09fdc2b8','2026-06-09 08:03:32',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-6r6ux5bcpsr3-1-xvry4cw4dkno-ControllerExtraConfigPre-2jwl5eykty6w','fb256d0a-ee2c-4f6f-b334-28ac09fdc2b8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2602,'fa16145a-f696-4c42-b108-d640398175e8','25b6a4bd-bb6c-4721-8670-41dc0238aba6','2026-06-09 08:03:32',NULL,'CREATE','COMPLETE','TenantDeployedPort','overcloud-Controller-6r6ux5bcpsr3-1-xvry4cw4dkno-TenantPort-oo6txugiq7hf-TenantDeployedPort-i4u72fz47p4w','state changed','OS::Heat::Value',NULL,1595),(2603,'c5ea607c-c137-4dab-84cf-8ccffb1b8366','fb256d0a-ee2c-4f6f-b334-28ac09fdc2b8','2026-06-09 08:03:32',NULL,'CREATE','COMPLETE','overcloud-Controller-6r6ux5bcpsr3-1-xvry4cw4dkno-ControllerExtraConfigPre-2jwl5eykty6w','fb256d0a-ee2c-4f6f-b334-28ac09fdc2b8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2604,'10560109-fea0-4fb8-a774-306c0299efe5','25b6a4bd-bb6c-4721-8670-41dc0238aba6','2026-06-09 08:03:32',NULL,'CREATE','COMPLETE','overcloud-Controller-6r6ux5bcpsr3-1-xvry4cw4dkno-TenantPort-oo6txugiq7hf','25b6a4bd-bb6c-4721-8670-41dc0238aba6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2605,'b4000219-0a55-4ad0-a230-cc2d0f0248b5','c4256080-174f-43c6-b2d2-796ebb483ba7','2026-06-09 08:03:32',NULL,'CREATE','IN_PROGRESS','ExternalDeployedPort','overcloud-Controller-6r6ux5bcpsr3-1-xvry4cw4dkno-ExternalPort-kwbvvpsq4icy-ExternalDeployedPort-zblf2g5xto3m','state changed','OS::Heat::Value',NULL,1597),(2606,'abe1a27e-a382-486f-a89b-e728f6b92139','b9c335af-59a1-44f4-b2a0-278714d2c692','2026-06-09 08:03:32',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-6r6ux5bcpsr3-1-xvry4cw4dkno-StoragePort-5yrvnk35jgl3','b9c335af-59a1-44f4-b2a0-278714d2c692','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2607,'c8d73a00-6587-4a9a-a85a-47ca1db3c4e4','c4256080-174f-43c6-b2d2-796ebb483ba7','2026-06-09 08:03:32',NULL,'CREATE','COMPLETE','ExternalDeployedPort','overcloud-Controller-6r6ux5bcpsr3-1-xvry4cw4dkno-ExternalPort-kwbvvpsq4icy-ExternalDeployedPort-zblf2g5xto3m','state changed','OS::Heat::Value',NULL,1597),(2608,'69add1c4-013f-426b-bb4b-36dfddce6f21','c4256080-174f-43c6-b2d2-796ebb483ba7','2026-06-09 08:03:32',NULL,'CREATE','COMPLETE','overcloud-Controller-6r6ux5bcpsr3-1-xvry4cw4dkno-ExternalPort-kwbvvpsq4icy','c4256080-174f-43c6-b2d2-796ebb483ba7','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2609,'ad915fed-b585-4d91-8211-dfd49683409e','b4f46341-992c-4a44-9e07-244ed01f4e9f','2026-06-09 08:03:32',NULL,'CREATE','IN_PROGRESS','InternalApiDeployedPort','overcloud-Controller-6r6ux5bcpsr3-1-xvry4cw4dkno-InternalApiPort-6knebscw3wy2-InternalApiDeployedPort-pf2ac2ywpfef','state changed','OS::Heat::Value',NULL,1598),(2610,'7816534c-a672-468b-a78c-d8c4e6d26559','b4f46341-992c-4a44-9e07-244ed01f4e9f','2026-06-09 08:03:32',NULL,'CREATE','COMPLETE','InternalApiDeployedPort','overcloud-Controller-6r6ux5bcpsr3-1-xvry4cw4dkno-InternalApiPort-6knebscw3wy2-InternalApiDeployedPort-pf2ac2ywpfef','state changed','OS::Heat::Value',NULL,1598),(2611,'fbdebf17-4de3-46c8-9e46-5bb0db019527','b4f46341-992c-4a44-9e07-244ed01f4e9f','2026-06-09 08:03:32',NULL,'CREATE','COMPLETE','overcloud-Controller-6r6ux5bcpsr3-1-xvry4cw4dkno-InternalApiPort-6knebscw3wy2','b4f46341-992c-4a44-9e07-244ed01f4e9f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2612,'57ba44ec-ae21-438e-87ea-a2e0c4ddf3a1','b9c335af-59a1-44f4-b2a0-278714d2c692','2026-06-09 08:03:32',NULL,'CREATE','IN_PROGRESS','StorageDeployedPort','overcloud-Controller-6r6ux5bcpsr3-1-xvry4cw4dkno-StoragePort-5yrvnk35jgl3-StorageDeployedPort-2ozyv456vo2f','state changed','OS::Heat::Value',NULL,1599),(2613,'5c04529e-be27-49b7-905d-febf63d617f0','b9c335af-59a1-44f4-b2a0-278714d2c692','2026-06-09 08:03:32',NULL,'CREATE','COMPLETE','StorageDeployedPort','overcloud-Controller-6r6ux5bcpsr3-1-xvry4cw4dkno-StoragePort-5yrvnk35jgl3-StorageDeployedPort-2ozyv456vo2f','state changed','OS::Heat::Value',NULL,1599),(2614,'8eba882e-1675-4511-bb9d-dec0b58ce016','b9c335af-59a1-44f4-b2a0-278714d2c692','2026-06-09 08:03:32',NULL,'CREATE','COMPLETE','overcloud-Controller-6r6ux5bcpsr3-1-xvry4cw4dkno-StoragePort-5yrvnk35jgl3','b9c335af-59a1-44f4-b2a0-278714d2c692','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2615,'ccf3183c-d193-4668-82b6-38e28aba5027','43ca2825-836b-4ed2-b313-6364b8c53516','2026-06-09 08:03:33',NULL,'CREATE','IN_PROGRESS','ControlPlanePort','overcloud-Controller-6r6ux5bcpsr3-2-bvtivffc4ip5-Controller-42mngssjfrsh-ControlPlanePort-2c2rwvx32ycy','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1600),(2616,'5391eccd-6cf3-4bfd-b189-4d38f2711274','329b2c0f-9c6e-4d8d-9d05-0cc1b0d601fc','2026-06-09 08:03:33',NULL,'CREATE','COMPLETE','Controller','a64d6ead-aadf-49fa-b752-6a0efa17c62c','state changed','OS::TripleO::ControllerServer',NULL,1578),(2617,'513bd414-534d-4cc0-a4f9-69c96895c5cf','db609c9e-1ee9-41f8-8d47-6038e1af1a1d','2026-06-09 08:03:33',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-6r6ux5bcpsr3-2-bvtivffc4ip5-Controller-42mngssjfrsh-ControlPlanePort-2c2rwvx32ycy','db609c9e-1ee9-41f8-8d47-6038e1af1a1d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2618,'be88ac04-b4f2-47ab-8a20-5b26fb0e0fbf','db609c9e-1ee9-41f8-8d47-6038e1af1a1d','2026-06-09 08:03:33',NULL,'CREATE','COMPLETE','overcloud-Controller-6r6ux5bcpsr3-2-bvtivffc4ip5-Controller-42mngssjfrsh-ControlPlanePort-2c2rwvx32ycy','db609c9e-1ee9-41f8-8d47-6038e1af1a1d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2619,'ddb36c44-703b-484f-a903-daf084de5458','329b2c0f-9c6e-4d8d-9d05-0cc1b0d601fc','2026-06-09 08:03:33',NULL,'CREATE','IN_PROGRESS','NodeTLSCAData','overcloud-Controller-6r6ux5bcpsr3-0-gxtwjyggi57i-NodeTLSCAData-ybmolz6ta5jx','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(2620,'4147c3ea-81e5-4440-a46a-3b9512d560db','329b2c0f-9c6e-4d8d-9d05-0cc1b0d601fc','2026-06-09 08:03:33',NULL,'CREATE','IN_PROGRESS','StorageMgmtPort','overcloud-Controller-6r6ux5bcpsr3-0-gxtwjyggi57i-StorageMgmtPort-nby2pfg7bb4e','state changed','OS::TripleO::Controller::Ports::StorageMgmtPort',NULL,1602),(2621,'7e03c751-7b85-4a49-bf59-dbcafcda6099','329b2c0f-9c6e-4d8d-9d05-0cc1b0d601fc','2026-06-09 08:03:33',NULL,'CREATE','IN_PROGRESS','NetHostMap','overcloud-Controller-6r6ux5bcpsr3-0-gxtwjyggi57i-NetHostMap-2gn4uzsm37cs','state changed','OS::Heat::Value',NULL,1603),(2622,'5fce3c9f-d708-4c30-bcf8-f9f2b1ed20a4','329b2c0f-9c6e-4d8d-9d05-0cc1b0d601fc','2026-06-09 08:03:33',NULL,'CREATE','COMPLETE','NodeTLSCAData','c0e55669-5410-4682-990a-81750e7f8268','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(2623,'e94ccb2d-8bca-462e-a8a9-0a50a60cce6b','329b2c0f-9c6e-4d8d-9d05-0cc1b0d601fc','2026-06-09 08:03:33',NULL,'CREATE','IN_PROGRESS','StoragePort','overcloud-Controller-6r6ux5bcpsr3-0-gxtwjyggi57i-StoragePort-yfexcq2pkjdo','state changed','OS::TripleO::Controller::Ports::StoragePort',NULL,1604),(2624,'e74e017c-f718-4f1c-8c19-c96cc81ffd0f','329b2c0f-9c6e-4d8d-9d05-0cc1b0d601fc','2026-06-09 08:03:33',NULL,'CREATE','COMPLETE','NetHostMap','overcloud-Controller-6r6ux5bcpsr3-0-gxtwjyggi57i-NetHostMap-2gn4uzsm37cs','state changed','OS::Heat::Value',NULL,1603),(2625,'9edd10c8-186f-4d06-95a2-fe7c63588a98','329b2c0f-9c6e-4d8d-9d05-0cc1b0d601fc','2026-06-09 08:03:33',NULL,'CREATE','IN_PROGRESS','PreNetworkConfig','overcloud-Controller-6r6ux5bcpsr3-0-gxtwjyggi57i-PreNetworkConfig-w6hcswsmoorm','state changed','OS::TripleO::Controller::PreNetworkConfig',NULL,NULL),(2626,'6e1f45e2-b90b-40f9-9b80-7816786b6810','329b2c0f-9c6e-4d8d-9d05-0cc1b0d601fc','2026-06-09 08:03:33',NULL,'CREATE','IN_PROGRESS','TenantPort','overcloud-Controller-6r6ux5bcpsr3-0-gxtwjyggi57i-TenantPort-bzahzuk7lhz6','state changed','OS::TripleO::Controller::Ports::TenantPort',NULL,1605),(2627,'40a15843-625f-42bf-bf66-79d361759277','329b2c0f-9c6e-4d8d-9d05-0cc1b0d601fc','2026-06-09 08:03:33',NULL,'CREATE','COMPLETE','PreNetworkConfig','57b77c6b-5b92-45c6-bb99-dd7a07a5ce3f','state changed','OS::TripleO::Controller::PreNetworkConfig',NULL,NULL),(2628,'d32c6633-a255-475c-b9ea-5e0d900edfb6','329b2c0f-9c6e-4d8d-9d05-0cc1b0d601fc','2026-06-09 08:03:33',NULL,'CREATE','IN_PROGRESS','ControllerExtraConfigPre','overcloud-Controller-6r6ux5bcpsr3-0-gxtwjyggi57i-ControllerExtraConfigPre-dobixtfe4u6l','state changed','OS::TripleO::ControllerExtraConfigPre',NULL,1606),(2629,'e21b7c04-3b07-4f74-a35c-d4583ca94c89','329b2c0f-9c6e-4d8d-9d05-0cc1b0d601fc','2026-06-09 08:03:33',NULL,'CREATE','IN_PROGRESS','InternalApiPort','overcloud-Controller-6r6ux5bcpsr3-0-gxtwjyggi57i-InternalApiPort-lsg5upy2bndg','state changed','OS::TripleO::Controller::Ports::InternalApiPort',NULL,1608),(2630,'122ba891-cbb1-47d0-a294-d8c3d9dfd6ed','fa54a3eb-6bdd-4c04-9444-3072b7477034','2026-06-09 08:03:33',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-6r6ux5bcpsr3-0-gxtwjyggi57i-StorageMgmtPort-nby2pfg7bb4e','fa54a3eb-6bdd-4c04-9444-3072b7477034','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2631,'6602ccbb-11a4-4432-8fec-78a009ec4fc4','efc4b16e-a9b5-4199-af15-efba6a2c3b25','2026-06-09 08:03:33',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-6r6ux5bcpsr3-0-gxtwjyggi57i-TenantPort-bzahzuk7lhz6','efc4b16e-a9b5-4199-af15-efba6a2c3b25','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2632,'98e71c81-644f-4240-a799-dc9d1a072ef0','329b2c0f-9c6e-4d8d-9d05-0cc1b0d601fc','2026-06-09 08:03:33',NULL,'CREATE','IN_PROGRESS','ControllerAnsibleHostVars','overcloud-Controller-6r6ux5bcpsr3-0-gxtwjyggi57i-ControllerAnsibleHostVars-hiv4hj6ocf47','state changed','OS::Heat::Value',NULL,1609),(2633,'144f1d3f-9169-40db-9baf-4c13c18447c4','329b2c0f-9c6e-4d8d-9d05-0cc1b0d601fc','2026-06-09 08:03:33',NULL,'CREATE','IN_PROGRESS','ExternalPort','overcloud-Controller-6r6ux5bcpsr3-0-gxtwjyggi57i-ExternalPort-3kxbz4tn5du5','state changed','OS::TripleO::Controller::Ports::ExternalPort',NULL,1610),(2634,'12beff88-9bcf-4a86-a9ed-c72d4c996127','97a8f25d-a9b1-48b4-b8d7-33a48b9b1577','2026-06-09 08:03:33',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-6r6ux5bcpsr3-0-gxtwjyggi57i-ControllerExtraConfigPre-dobixtfe4u6l','97a8f25d-a9b1-48b4-b8d7-33a48b9b1577','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2635,'b5a8bff0-80b3-4df2-9e03-903610aca5a5','c1b2c851-47b4-4f94-bd0f-fb76ab77b7a7','2026-06-09 08:03:33',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-6r6ux5bcpsr3-0-gxtwjyggi57i-StoragePort-yfexcq2pkjdo','c1b2c851-47b4-4f94-bd0f-fb76ab77b7a7','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2636,'37bae5b7-4345-4658-b0ba-07d90a1ed560','329b2c0f-9c6e-4d8d-9d05-0cc1b0d601fc','2026-06-09 08:03:33',NULL,'CREATE','COMPLETE','ControllerAnsibleHostVars','overcloud-Controller-6r6ux5bcpsr3-0-gxtwjyggi57i-ControllerAnsibleHostVars-hiv4hj6ocf47','state changed','OS::Heat::Value',NULL,1609),(2637,'b98d1e95-01e1-4f24-a559-1f5128b361b1','31c4ecb1-566e-4af5-bc33-cb9baf90e6ac','2026-06-09 08:03:33',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-6r6ux5bcpsr3-0-gxtwjyggi57i-InternalApiPort-lsg5upy2bndg','31c4ecb1-566e-4af5-bc33-cb9baf90e6ac','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2638,'987940ee-80c0-4a61-b86b-68761d93e84f','97a8f25d-a9b1-48b4-b8d7-33a48b9b1577','2026-06-09 08:03:33',NULL,'CREATE','COMPLETE','overcloud-Controller-6r6ux5bcpsr3-0-gxtwjyggi57i-ControllerExtraConfigPre-dobixtfe4u6l','97a8f25d-a9b1-48b4-b8d7-33a48b9b1577','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2639,'4c20475e-aad6-44b0-9986-072529199e9b','53f028a2-83c8-4a58-8e98-0397ae8637a8','2026-06-09 08:03:33',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-6r6ux5bcpsr3-0-gxtwjyggi57i-ExternalPort-3kxbz4tn5du5','53f028a2-83c8-4a58-8e98-0397ae8637a8','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2640,'d3f0e795-1036-4d9d-b37f-661e26552b76','fa54a3eb-6bdd-4c04-9444-3072b7477034','2026-06-09 08:03:33',NULL,'CREATE','IN_PROGRESS','StorageMgmtDeployedPort','overcloud-Controller-6r6ux5bcpsr3-0-gxtwjyggi57i-StorageMgmtPort-nby2pfg7bb4e-StorageMgmtDeployedPort-2wyxlwkbfhw5','state changed','OS::Heat::Value',NULL,1612),(2641,'96b3b792-a0bd-4dcc-80f5-3b1309065b31','fa54a3eb-6bdd-4c04-9444-3072b7477034','2026-06-09 08:03:33',NULL,'CREATE','COMPLETE','StorageMgmtDeployedPort','overcloud-Controller-6r6ux5bcpsr3-0-gxtwjyggi57i-StorageMgmtPort-nby2pfg7bb4e-StorageMgmtDeployedPort-2wyxlwkbfhw5','state changed','OS::Heat::Value',NULL,1612),(2642,'bab854fe-0a6a-4ae8-8ac7-fd2a487c0dbd','627c87c4-2e4c-4189-a029-0b9e9797e97a','2026-06-09 08:03:33',NULL,'CREATE','COMPLETE','TenantPort','25b6a4bd-bb6c-4721-8670-41dc0238aba6','state changed','OS::TripleO::Controller::Ports::TenantPort',NULL,1590),(2643,'8926f625-440b-4890-9c04-435788225feb','c1b2c851-47b4-4f94-bd0f-fb76ab77b7a7','2026-06-09 08:03:33',NULL,'CREATE','IN_PROGRESS','StorageDeployedPort','overcloud-Controller-6r6ux5bcpsr3-0-gxtwjyggi57i-StoragePort-yfexcq2pkjdo-StorageDeployedPort-i37lhuyu66bd','state changed','OS::Heat::Value',NULL,1613),(2644,'d00b9798-6048-437a-9ad0-8bc5fec31f14','fa54a3eb-6bdd-4c04-9444-3072b7477034','2026-06-09 08:03:33',NULL,'CREATE','COMPLETE','overcloud-Controller-6r6ux5bcpsr3-0-gxtwjyggi57i-StorageMgmtPort-nby2pfg7bb4e','fa54a3eb-6bdd-4c04-9444-3072b7477034','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2645,'3f647260-8001-45df-ac86-72a8aba54920','627c87c4-2e4c-4189-a029-0b9e9797e97a','2026-06-09 08:03:33',NULL,'CREATE','COMPLETE','StorageMgmtPort','bff6819f-18e9-45d3-86a9-68cabade06c1','state changed','OS::TripleO::Controller::Ports::StorageMgmtPort',NULL,1587),(2646,'80462f43-c1f5-46cc-acb3-8ec654a37287','c1b2c851-47b4-4f94-bd0f-fb76ab77b7a7','2026-06-09 08:03:33',NULL,'CREATE','COMPLETE','StorageDeployedPort','overcloud-Controller-6r6ux5bcpsr3-0-gxtwjyggi57i-StoragePort-yfexcq2pkjdo-StorageDeployedPort-i37lhuyu66bd','state changed','OS::Heat::Value',NULL,1613),(2647,'c4f7e61a-1378-4fde-90be-da9e27dca882','31c4ecb1-566e-4af5-bc33-cb9baf90e6ac','2026-06-09 08:03:33',NULL,'CREATE','IN_PROGRESS','InternalApiDeployedPort','overcloud-Controller-6r6ux5bcpsr3-0-gxtwjyggi57i-InternalApiPort-lsg5upy2bndg-InternalApiDeployedPort-tdsj46yw6jus','state changed','OS::Heat::Value',NULL,1614),(2648,'de2abfa2-ede9-4f35-b084-a297c9d0cb6d','c1b2c851-47b4-4f94-bd0f-fb76ab77b7a7','2026-06-09 08:03:33',NULL,'CREATE','COMPLETE','overcloud-Controller-6r6ux5bcpsr3-0-gxtwjyggi57i-StoragePort-yfexcq2pkjdo','c1b2c851-47b4-4f94-bd0f-fb76ab77b7a7','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2649,'cca053d8-9bc3-4a7f-abb0-8e545d39f814','31c4ecb1-566e-4af5-bc33-cb9baf90e6ac','2026-06-09 08:03:33',NULL,'CREATE','COMPLETE','InternalApiDeployedPort','overcloud-Controller-6r6ux5bcpsr3-0-gxtwjyggi57i-InternalApiPort-lsg5upy2bndg-InternalApiDeployedPort-tdsj46yw6jus','state changed','OS::Heat::Value',NULL,1614),(2650,'940f7454-e6ec-4ea1-8650-f340cb2d63d1','efc4b16e-a9b5-4199-af15-efba6a2c3b25','2026-06-09 08:03:33',NULL,'CREATE','IN_PROGRESS','TenantDeployedPort','overcloud-Controller-6r6ux5bcpsr3-0-gxtwjyggi57i-TenantPort-bzahzuk7lhz6-TenantDeployedPort-i6yasftl3klh','state changed','OS::Heat::Value',NULL,1617),(2651,'fe42698a-133c-44f4-a1d5-88771837ca7e','31c4ecb1-566e-4af5-bc33-cb9baf90e6ac','2026-06-09 08:03:33',NULL,'CREATE','COMPLETE','overcloud-Controller-6r6ux5bcpsr3-0-gxtwjyggi57i-InternalApiPort-lsg5upy2bndg','31c4ecb1-566e-4af5-bc33-cb9baf90e6ac','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2652,'cfaf80f1-78b6-4dc6-bf42-82b86724fac9','efc4b16e-a9b5-4199-af15-efba6a2c3b25','2026-06-09 08:03:33',NULL,'CREATE','COMPLETE','TenantDeployedPort','overcloud-Controller-6r6ux5bcpsr3-0-gxtwjyggi57i-TenantPort-bzahzuk7lhz6-TenantDeployedPort-i6yasftl3klh','state changed','OS::Heat::Value',NULL,1617),(2653,'f1bfa026-b46e-42c1-88a5-dd58201a8116','efc4b16e-a9b5-4199-af15-efba6a2c3b25','2026-06-09 08:03:33',NULL,'CREATE','COMPLETE','overcloud-Controller-6r6ux5bcpsr3-0-gxtwjyggi57i-TenantPort-bzahzuk7lhz6','efc4b16e-a9b5-4199-af15-efba6a2c3b25','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2654,'ff13f256-d591-4cc7-bff0-b6f434abc894','627c87c4-2e4c-4189-a029-0b9e9797e97a','2026-06-09 08:03:33',NULL,'CREATE','COMPLETE','ExternalPort','c4256080-174f-43c6-b2d2-796ebb483ba7','state changed','OS::TripleO::Controller::Ports::ExternalPort',NULL,1586),(2655,'8da4bf0e-033d-4f1d-961d-8ee18efd51b9','53f028a2-83c8-4a58-8e98-0397ae8637a8','2026-06-09 08:03:33',NULL,'CREATE','IN_PROGRESS','ExternalDeployedPort','overcloud-Controller-6r6ux5bcpsr3-0-gxtwjyggi57i-ExternalPort-3kxbz4tn5du5-ExternalDeployedPort-orj7m6td4sng','state changed','OS::Heat::Value',NULL,1619),(2656,'ac9da53f-246d-4fd4-bc92-0c51e355c8b8','53f028a2-83c8-4a58-8e98-0397ae8637a8','2026-06-09 08:03:33',NULL,'CREATE','COMPLETE','ExternalDeployedPort','overcloud-Controller-6r6ux5bcpsr3-0-gxtwjyggi57i-ExternalPort-3kxbz4tn5du5-ExternalDeployedPort-orj7m6td4sng','state changed','OS::Heat::Value',NULL,1619),(2657,'b805e60f-f330-4c71-9b8e-7ac55c03b5de','53f028a2-83c8-4a58-8e98-0397ae8637a8','2026-06-09 08:03:33',NULL,'CREATE','COMPLETE','overcloud-Controller-6r6ux5bcpsr3-0-gxtwjyggi57i-ExternalPort-3kxbz4tn5du5','53f028a2-83c8-4a58-8e98-0397ae8637a8','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2658,'06a22c03-398f-4d98-934f-8d711ce4aac8','627c87c4-2e4c-4189-a029-0b9e9797e97a','2026-06-09 08:03:33',NULL,'CREATE','COMPLETE','InternalApiPort','b4f46341-992c-4a44-9e07-244ed01f4e9f','state changed','OS::TripleO::Controller::Ports::InternalApiPort',NULL,1593),(2659,'e4a54149-4f2c-4cc8-ba80-e3f8ae85cc95','627c87c4-2e4c-4189-a029-0b9e9797e97a','2026-06-09 08:03:33',NULL,'CREATE','COMPLETE','ControllerExtraConfigPre','fb256d0a-ee2c-4f6f-b334-28ac09fdc2b8','state changed','OS::TripleO::ControllerExtraConfigPre',NULL,1591),(2660,'b2c967e7-6a0d-4d57-8859-a61b1ff7ed50','627c87c4-2e4c-4189-a029-0b9e9797e97a','2026-06-09 08:03:33',NULL,'CREATE','COMPLETE','StoragePort','b9c335af-59a1-44f4-b2a0-278714d2c692','state changed','OS::TripleO::Controller::Ports::StoragePort',NULL,1596),(2661,'92f87357-e8dc-4884-9696-29bb3e4d1712','627c87c4-2e4c-4189-a029-0b9e9797e97a','2026-06-09 08:03:33',NULL,'CREATE','IN_PROGRESS','NodeExtraConfig','overcloud-Controller-6r6ux5bcpsr3-1-xvry4cw4dkno-NodeExtraConfig-gyzn6cspemew','state changed','OS::TripleO::NodeExtraConfig',NULL,1625),(2662,'ba1ef4c1-0ee9-415f-bc77-c9e57be9e8ac','fb278e14-0511-46b9-9572-43267144f8c4','2026-06-09 08:03:33',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-6r6ux5bcpsr3-1-xvry4cw4dkno-NodeExtraConfig-gyzn6cspemew','fb278e14-0511-46b9-9572-43267144f8c4','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2663,'46e1180a-cec7-4933-b4f5-ef415464b12a','fb278e14-0511-46b9-9572-43267144f8c4','2026-06-09 08:03:33',NULL,'CREATE','COMPLETE','overcloud-Controller-6r6ux5bcpsr3-1-xvry4cw4dkno-NodeExtraConfig-gyzn6cspemew','fb278e14-0511-46b9-9572-43267144f8c4','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2664,'84e6da3a-4b9e-4353-b400-5d0494e75739','627c87c4-2e4c-4189-a029-0b9e9797e97a','2026-06-09 08:03:33',NULL,'CREATE','IN_PROGRESS','NetIpMap','overcloud-Controller-6r6ux5bcpsr3-1-xvry4cw4dkno-NetIpMap-lorv6j6v5mdg','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1629),(2665,'4059efb2-050e-4986-8a7d-c8c4dae587a0','879fda76-85a0-4625-aa8f-a47f7fd5c329','2026-06-09 08:03:34',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-6r6ux5bcpsr3-1-xvry4cw4dkno-NetIpMap-lorv6j6v5mdg','879fda76-85a0-4625-aa8f-a47f7fd5c329','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2666,'c1712bee-82ea-46d5-98a7-3eff5c118a8d','879fda76-85a0-4625-aa8f-a47f7fd5c329','2026-06-09 08:03:34',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-Controller-6r6ux5bcpsr3-1-xvry4cw4dkno-NetIpMap-lorv6j6v5mdg-NetIpMapValue-vi3lbbi4mu5b','state changed','OS::Heat::Value',NULL,1630),(2667,'d763f9bd-c4b1-4a93-92a0-53a1a6f54fc9','879fda76-85a0-4625-aa8f-a47f7fd5c329','2026-06-09 08:03:34',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-Controller-6r6ux5bcpsr3-1-xvry4cw4dkno-NetIpMap-lorv6j6v5mdg-NetIpMapValue-vi3lbbi4mu5b','state changed','OS::Heat::Value',NULL,1630),(2668,'10efce8f-c000-434d-a7eb-500b65aeb65d','879fda76-85a0-4625-aa8f-a47f7fd5c329','2026-06-09 08:03:34',NULL,'CREATE','COMPLETE','overcloud-Controller-6r6ux5bcpsr3-1-xvry4cw4dkno-NetIpMap-lorv6j6v5mdg','879fda76-85a0-4625-aa8f-a47f7fd5c329','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2669,'b0801c7e-afbc-4395-84ea-dd1abe2df1f5','43ca2825-836b-4ed2-b313-6364b8c53516','2026-06-09 08:03:34',NULL,'CREATE','COMPLETE','ControlPlanePort','db609c9e-1ee9-41f8-8d47-6038e1af1a1d','state changed','OS::TripleO::DeployedServer::ControlPlanePort',NULL,1600),(2670,'190cca04-057a-4e29-9879-45778723b770','43ca2825-836b-4ed2-b313-6364b8c53516','2026-06-09 08:03:34',NULL,'CREATE','COMPLETE','overcloud-Controller-6r6ux5bcpsr3-2-bvtivffc4ip5-Controller-42mngssjfrsh','43ca2825-836b-4ed2-b313-6364b8c53516','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2671,'97f55134-0b10-4fa1-9caf-b74ba486a141','329b2c0f-9c6e-4d8d-9d05-0cc1b0d601fc','2026-06-09 08:03:34',NULL,'CREATE','COMPLETE','StorageMgmtPort','fa54a3eb-6bdd-4c04-9444-3072b7477034','state changed','OS::TripleO::Controller::Ports::StorageMgmtPort',NULL,1602),(2672,'a80a0706-ee31-4a25-809e-ad119e2319dc','329b2c0f-9c6e-4d8d-9d05-0cc1b0d601fc','2026-06-09 08:03:34',NULL,'CREATE','COMPLETE','ControllerExtraConfigPre','97a8f25d-a9b1-48b4-b8d7-33a48b9b1577','state changed','OS::TripleO::ControllerExtraConfigPre',NULL,1606),(2673,'57a8e250-75fd-409e-b726-496e48785d68','329b2c0f-9c6e-4d8d-9d05-0cc1b0d601fc','2026-06-09 08:03:34',NULL,'CREATE','COMPLETE','TenantPort','efc4b16e-a9b5-4199-af15-efba6a2c3b25','state changed','OS::TripleO::Controller::Ports::TenantPort',NULL,1605),(2674,'27f95f55-e1bf-4f2e-94b7-26f3643c756a','329b2c0f-9c6e-4d8d-9d05-0cc1b0d601fc','2026-06-09 08:03:34',NULL,'CREATE','COMPLETE','InternalApiPort','31c4ecb1-566e-4af5-bc33-cb9baf90e6ac','state changed','OS::TripleO::Controller::Ports::InternalApiPort',NULL,1608),(2675,'53eff948-cbe0-4a94-810b-cc50fbc61e1f','329b2c0f-9c6e-4d8d-9d05-0cc1b0d601fc','2026-06-09 08:03:34',NULL,'CREATE','COMPLETE','StoragePort','c1b2c851-47b4-4f94-bd0f-fb76ab77b7a7','state changed','OS::TripleO::Controller::Ports::StoragePort',NULL,1604),(2676,'55c99605-34a4-4a49-9dc3-f9cf57f6a878','329b2c0f-9c6e-4d8d-9d05-0cc1b0d601fc','2026-06-09 08:03:34',NULL,'CREATE','COMPLETE','ExternalPort','53f028a2-83c8-4a58-8e98-0397ae8637a8','state changed','OS::TripleO::Controller::Ports::ExternalPort',NULL,1610),(2677,'0d2ca7f8-5656-4754-b429-0c303731ff2f','329b2c0f-9c6e-4d8d-9d05-0cc1b0d601fc','2026-06-09 08:03:34',NULL,'CREATE','IN_PROGRESS','NodeExtraConfig','overcloud-Controller-6r6ux5bcpsr3-0-gxtwjyggi57i-NodeExtraConfig-tnio5hc7sh2s','state changed','OS::TripleO::NodeExtraConfig',NULL,1639),(2678,'1f9c27cd-3bc5-4db8-9f64-c97ba3402237','329b2c0f-9c6e-4d8d-9d05-0cc1b0d601fc','2026-06-09 08:03:34',NULL,'CREATE','IN_PROGRESS','NetIpMap','overcloud-Controller-6r6ux5bcpsr3-0-gxtwjyggi57i-NetIpMap-7psu7tj43jan','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1643),(2679,'1e1b1046-d5f1-4ea7-8d01-b8b273c5d6e3','a2cf7ab8-e34d-4ee9-a025-6eca3592592b','2026-06-09 08:03:34',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-6r6ux5bcpsr3-0-gxtwjyggi57i-NodeExtraConfig-tnio5hc7sh2s','a2cf7ab8-e34d-4ee9-a025-6eca3592592b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2680,'fbd84cdb-5edd-4150-94f3-4cd4fb411e46','a2cf7ab8-e34d-4ee9-a025-6eca3592592b','2026-06-09 08:03:34',NULL,'CREATE','COMPLETE','overcloud-Controller-6r6ux5bcpsr3-0-gxtwjyggi57i-NodeExtraConfig-tnio5hc7sh2s','a2cf7ab8-e34d-4ee9-a025-6eca3592592b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2681,'c084a1fe-af77-41e7-9e6f-50a7d46d7ec1','d82d9a9c-b41f-4711-b4ad-bdc056df491b','2026-06-09 08:03:34',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-6r6ux5bcpsr3-0-gxtwjyggi57i-NetIpMap-7psu7tj43jan','d82d9a9c-b41f-4711-b4ad-bdc056df491b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2682,'4e20ea83-8c35-4353-8125-553cb66a1ad2','627c87c4-2e4c-4189-a029-0b9e9797e97a','2026-06-09 08:03:34',NULL,'CREATE','COMPLETE','NodeExtraConfig','fb278e14-0511-46b9-9572-43267144f8c4','state changed','OS::TripleO::NodeExtraConfig',NULL,1625),(2683,'16c806c6-4108-4ab3-a291-0b7cc100330f','d82d9a9c-b41f-4711-b4ad-bdc056df491b','2026-06-09 08:03:34',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-Controller-6r6ux5bcpsr3-0-gxtwjyggi57i-NetIpMap-7psu7tj43jan-NetIpMapValue-5f4v2lortrx4','state changed','OS::Heat::Value',NULL,1644),(2684,'b1703e60-a638-4820-8156-21e3bce06a12','d82d9a9c-b41f-4711-b4ad-bdc056df491b','2026-06-09 08:03:34',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-Controller-6r6ux5bcpsr3-0-gxtwjyggi57i-NetIpMap-7psu7tj43jan-NetIpMapValue-5f4v2lortrx4','state changed','OS::Heat::Value',NULL,1644),(2685,'0af55e6b-a042-4628-8c53-dec87c54bb2b','d82d9a9c-b41f-4711-b4ad-bdc056df491b','2026-06-09 08:03:35',NULL,'CREATE','COMPLETE','overcloud-Controller-6r6ux5bcpsr3-0-gxtwjyggi57i-NetIpMap-7psu7tj43jan','d82d9a9c-b41f-4711-b4ad-bdc056df491b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2686,'13a1da48-917f-4777-b7a3-c3fa7aacb6d6','627c87c4-2e4c-4189-a029-0b9e9797e97a','2026-06-09 08:03:35',NULL,'CREATE','COMPLETE','NetIpMap','879fda76-85a0-4625-aa8f-a47f7fd5c329','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1629),(2687,'63fc2c7d-7b4e-460f-80f3-ef562e3ce1a8','627c87c4-2e4c-4189-a029-0b9e9797e97a','2026-06-09 08:03:35',NULL,'CREATE','COMPLETE','overcloud-Controller-6r6ux5bcpsr3-1-xvry4cw4dkno','627c87c4-2e4c-4189-a029-0b9e9797e97a','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2688,'794d3c98-a260-4153-9e77-e186dd99bc65','fe6daf36-029c-4429-898d-a3c4dba4da9b','2026-06-09 08:03:35',NULL,'CREATE','COMPLETE','Controller','43ca2825-836b-4ed2-b313-6364b8c53516','state changed','OS::TripleO::ControllerServer',NULL,1581),(2689,'0813f7cd-b025-4db2-a797-0a91a0e1d677','fe6daf36-029c-4429-898d-a3c4dba4da9b','2026-06-09 08:03:35',NULL,'CREATE','IN_PROGRESS','InternalApiPort','overcloud-Controller-6r6ux5bcpsr3-2-bvtivffc4ip5-InternalApiPort-i7j44m2iq5pf','state changed','OS::TripleO::Controller::Ports::InternalApiPort',NULL,1646),(2690,'7f417d68-6033-4e82-a8be-400a582034bf','fe6daf36-029c-4429-898d-a3c4dba4da9b','2026-06-09 08:03:35',NULL,'CREATE','IN_PROGRESS','NodeTLSCAData','overcloud-Controller-6r6ux5bcpsr3-2-bvtivffc4ip5-NodeTLSCAData-6m52roftuonh','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(2691,'c7e05a1d-47ba-4fa2-b6a2-7923a3d05aa3','fe6daf36-029c-4429-898d-a3c4dba4da9b','2026-06-09 08:03:35',NULL,'CREATE','IN_PROGRESS','TenantPort','overcloud-Controller-6r6ux5bcpsr3-2-bvtivffc4ip5-TenantPort-nksgf3q7s4nq','state changed','OS::TripleO::Controller::Ports::TenantPort',NULL,1647),(2692,'f2364df0-3a4b-4ddf-aa6a-812d14c10da5','fe6daf36-029c-4429-898d-a3c4dba4da9b','2026-06-09 08:03:35',NULL,'CREATE','IN_PROGRESS','StoragePort','overcloud-Controller-6r6ux5bcpsr3-2-bvtivffc4ip5-StoragePort-xuj45oc77j75','state changed','OS::TripleO::Controller::Ports::StoragePort',NULL,1648),(2693,'cd352523-3cb6-4e9f-b4d1-4ab91b847287','fe6daf36-029c-4429-898d-a3c4dba4da9b','2026-06-09 08:03:35',NULL,'CREATE','IN_PROGRESS','ControllerExtraConfigPre','overcloud-Controller-6r6ux5bcpsr3-2-bvtivffc4ip5-ControllerExtraConfigPre-apyiecfz7g32','state changed','OS::TripleO::ControllerExtraConfigPre',NULL,1649),(2694,'49c6674f-e075-4482-b29a-66624928e448','fe6daf36-029c-4429-898d-a3c4dba4da9b','2026-06-09 08:03:35',NULL,'CREATE','IN_PROGRESS','PreNetworkConfig','overcloud-Controller-6r6ux5bcpsr3-2-bvtivffc4ip5-PreNetworkConfig-alyvtcmmu4vd','state changed','OS::TripleO::Controller::PreNetworkConfig',NULL,NULL),(2695,'6d333824-9c21-46da-a1c4-6b72edb7f66b','fe6daf36-029c-4429-898d-a3c4dba4da9b','2026-06-09 08:03:35',NULL,'CREATE','IN_PROGRESS','NetHostMap','overcloud-Controller-6r6ux5bcpsr3-2-bvtivffc4ip5-NetHostMap-6jbkcgkeglky','state changed','OS::Heat::Value',NULL,1650),(2696,'787a6922-f0bf-442f-aef1-d6108e0e9de8','fe6daf36-029c-4429-898d-a3c4dba4da9b','2026-06-09 08:03:35',NULL,'CREATE','COMPLETE','NodeTLSCAData','3b5b1ef7-c729-424e-b0b9-b68a557c009f','state changed','OS::TripleO::NodeTLSCAData',NULL,NULL),(2697,'5d1833c4-7d59-4a32-aa5f-b526954382e9','c22ee87e-f18e-4c4f-a2bf-9f4342643377','2026-06-09 08:03:35',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-6r6ux5bcpsr3-2-bvtivffc4ip5-InternalApiPort-i7j44m2iq5pf','c22ee87e-f18e-4c4f-a2bf-9f4342643377','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2698,'3c8b9e31-a564-4f32-b025-3d2c04145ead','a561e0f8-adfe-4bb1-8245-14fed0c9c02b','2026-06-09 08:03:35',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-6r6ux5bcpsr3-2-bvtivffc4ip5-TenantPort-nksgf3q7s4nq','a561e0f8-adfe-4bb1-8245-14fed0c9c02b','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2699,'1c11b428-c3c8-4bb7-95d4-e1b4f84463ed','fe6daf36-029c-4429-898d-a3c4dba4da9b','2026-06-09 08:03:35',NULL,'CREATE','COMPLETE','NetHostMap','overcloud-Controller-6r6ux5bcpsr3-2-bvtivffc4ip5-NetHostMap-6jbkcgkeglky','state changed','OS::Heat::Value',NULL,1650),(2700,'349f5ff8-7328-4d79-ac63-2b13b2ea0871','fe6daf36-029c-4429-898d-a3c4dba4da9b','2026-06-09 08:03:35',NULL,'CREATE','IN_PROGRESS','ExternalPort','overcloud-Controller-6r6ux5bcpsr3-2-bvtivffc4ip5-ExternalPort-zogvbc7ccz4n','state changed','OS::TripleO::Controller::Ports::ExternalPort',NULL,1652),(2701,'39d5869b-84d6-4b4c-9f89-c3a6a927375a','17c2f708-c63d-49af-9059-95cbfb30273d','2026-06-09 08:03:35',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-6r6ux5bcpsr3-2-bvtivffc4ip5-StoragePort-xuj45oc77j75','17c2f708-c63d-49af-9059-95cbfb30273d','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2702,'d80b7601-eba4-4c12-9598-8d744ba12385','fe6daf36-029c-4429-898d-a3c4dba4da9b','2026-06-09 08:03:35',NULL,'CREATE','IN_PROGRESS','StorageMgmtPort','overcloud-Controller-6r6ux5bcpsr3-2-bvtivffc4ip5-StorageMgmtPort-5jleclcba2wq','state changed','OS::TripleO::Controller::Ports::StorageMgmtPort',NULL,1653),(2703,'2ed2724c-f2a3-4533-926e-785e9bc9d597','8e9d99e7-5b9f-43d9-b357-dfe456c33684','2026-06-09 08:03:35',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-6r6ux5bcpsr3-2-bvtivffc4ip5-ControllerExtraConfigPre-apyiecfz7g32','8e9d99e7-5b9f-43d9-b357-dfe456c33684','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2704,'99d29995-11f4-48ff-aba0-8c4dc326c98a','a561e0f8-adfe-4bb1-8245-14fed0c9c02b','2026-06-09 08:03:35',NULL,'CREATE','IN_PROGRESS','TenantDeployedPort','overcloud-Controller-6r6ux5bcpsr3-2-bvtivffc4ip5-TenantPort-nksgf3q7s4nq-TenantDeployedPort-ttv7rld3foyu','state changed','OS::Heat::Value',NULL,1655),(2705,'902b9776-da94-4b7a-81a9-3ac91806005a','17c2f708-c63d-49af-9059-95cbfb30273d','2026-06-09 08:03:35',NULL,'CREATE','IN_PROGRESS','StorageDeployedPort','overcloud-Controller-6r6ux5bcpsr3-2-bvtivffc4ip5-StoragePort-xuj45oc77j75-StorageDeployedPort-pxi4hiqec3fq','state changed','OS::Heat::Value',NULL,1656),(2706,'08ccca95-36e8-4b74-8a82-ee2b6f69f2d4','fe6daf36-029c-4429-898d-a3c4dba4da9b','2026-06-09 08:03:35',NULL,'CREATE','COMPLETE','PreNetworkConfig','5ef44a40-0abf-47d8-a31e-d21314f3fb4e','state changed','OS::TripleO::Controller::PreNetworkConfig',NULL,NULL),(2707,'1e2b66e1-ab20-427b-b03a-4273b47e3ad3','fe6daf36-029c-4429-898d-a3c4dba4da9b','2026-06-09 08:03:35',NULL,'CREATE','IN_PROGRESS','ControllerAnsibleHostVars','overcloud-Controller-6r6ux5bcpsr3-2-bvtivffc4ip5-ControllerAnsibleHostVars-cijtqj22hqrw','state changed','OS::Heat::Value',NULL,1657),(2708,'e272081b-2b57-4021-8f85-b953ddff97d5','8e9d99e7-5b9f-43d9-b357-dfe456c33684','2026-06-09 08:03:35',NULL,'CREATE','COMPLETE','overcloud-Controller-6r6ux5bcpsr3-2-bvtivffc4ip5-ControllerExtraConfigPre-apyiecfz7g32','8e9d99e7-5b9f-43d9-b357-dfe456c33684','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2709,'63e10b44-d10c-484e-9c7c-899633f45eaa','17c2f708-c63d-49af-9059-95cbfb30273d','2026-06-09 08:03:35',NULL,'CREATE','COMPLETE','StorageDeployedPort','overcloud-Controller-6r6ux5bcpsr3-2-bvtivffc4ip5-StoragePort-xuj45oc77j75-StorageDeployedPort-pxi4hiqec3fq','state changed','OS::Heat::Value',NULL,1656),(2710,'a4622c29-08ef-4051-9f9b-70f7e21d7b53','c354a11a-2239-41fa-907f-5a187c41c88f','2026-06-09 08:03:35',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-6r6ux5bcpsr3-2-bvtivffc4ip5-StorageMgmtPort-5jleclcba2wq','c354a11a-2239-41fa-907f-5a187c41c88f','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2711,'c54b4c45-5bda-4a2f-8778-96e4180e1932','a561e0f8-adfe-4bb1-8245-14fed0c9c02b','2026-06-09 08:03:35',NULL,'CREATE','COMPLETE','TenantDeployedPort','overcloud-Controller-6r6ux5bcpsr3-2-bvtivffc4ip5-TenantPort-nksgf3q7s4nq-TenantDeployedPort-ttv7rld3foyu','state changed','OS::Heat::Value',NULL,1655),(2712,'b5120b31-cd43-4d61-8b77-fcf71f11c987','d3da9348-b768-4364-b586-6015cf9968a6','2026-06-09 08:03:35',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-6r6ux5bcpsr3-2-bvtivffc4ip5-ExternalPort-zogvbc7ccz4n','d3da9348-b768-4364-b586-6015cf9968a6','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2713,'fdf81f56-375c-4c4a-899b-c826c4a7436e','17c2f708-c63d-49af-9059-95cbfb30273d','2026-06-09 08:03:35',NULL,'CREATE','COMPLETE','overcloud-Controller-6r6ux5bcpsr3-2-bvtivffc4ip5-StoragePort-xuj45oc77j75','17c2f708-c63d-49af-9059-95cbfb30273d','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2714,'dad885c7-a31a-411b-b8ec-0bf90fab32d9','a561e0f8-adfe-4bb1-8245-14fed0c9c02b','2026-06-09 08:03:35',NULL,'CREATE','COMPLETE','overcloud-Controller-6r6ux5bcpsr3-2-bvtivffc4ip5-TenantPort-nksgf3q7s4nq','a561e0f8-adfe-4bb1-8245-14fed0c9c02b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2715,'23cf52f5-91d6-4c8b-9127-2af0b1cde235','fe6daf36-029c-4429-898d-a3c4dba4da9b','2026-06-09 08:03:35',NULL,'CREATE','COMPLETE','ControllerAnsibleHostVars','overcloud-Controller-6r6ux5bcpsr3-2-bvtivffc4ip5-ControllerAnsibleHostVars-cijtqj22hqrw','state changed','OS::Heat::Value',NULL,1657),(2716,'7abaaff5-93e0-4d8b-b9d6-f9c6c01cb535','c22ee87e-f18e-4c4f-a2bf-9f4342643377','2026-06-09 08:03:35',NULL,'CREATE','IN_PROGRESS','InternalApiDeployedPort','overcloud-Controller-6r6ux5bcpsr3-2-bvtivffc4ip5-InternalApiPort-i7j44m2iq5pf-InternalApiDeployedPort-afg2xfa6nz3x','state changed','OS::Heat::Value',NULL,1658),(2717,'63d158cb-8192-4cc0-93b5-00f87a1d8dcb','c22ee87e-f18e-4c4f-a2bf-9f4342643377','2026-06-09 08:03:35',NULL,'CREATE','COMPLETE','InternalApiDeployedPort','overcloud-Controller-6r6ux5bcpsr3-2-bvtivffc4ip5-InternalApiPort-i7j44m2iq5pf-InternalApiDeployedPort-afg2xfa6nz3x','state changed','OS::Heat::Value',NULL,1658),(2718,'2fd971b1-bdf6-424f-9fef-8b4bd1f477c6','c354a11a-2239-41fa-907f-5a187c41c88f','2026-06-09 08:03:35',NULL,'CREATE','IN_PROGRESS','StorageMgmtDeployedPort','overcloud-Controller-6r6ux5bcpsr3-2-bvtivffc4ip5-StorageMgmtPort-5jleclcba2wq-StorageMgmtDeployedPort-4eofrjit3qon','state changed','OS::Heat::Value',NULL,1659),(2719,'8e9f0325-52a8-45ff-a1df-313431d22f59','c22ee87e-f18e-4c4f-a2bf-9f4342643377','2026-06-09 08:03:35',NULL,'CREATE','COMPLETE','overcloud-Controller-6r6ux5bcpsr3-2-bvtivffc4ip5-InternalApiPort-i7j44m2iq5pf','c22ee87e-f18e-4c4f-a2bf-9f4342643377','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2720,'30cd1952-5ec6-40e9-bee9-91fbdf69736c','d3da9348-b768-4364-b586-6015cf9968a6','2026-06-09 08:03:35',NULL,'CREATE','IN_PROGRESS','ExternalDeployedPort','overcloud-Controller-6r6ux5bcpsr3-2-bvtivffc4ip5-ExternalPort-zogvbc7ccz4n-ExternalDeployedPort-ptjdrftzpkyh','state changed','OS::Heat::Value',NULL,1660),(2721,'ecb121d9-f8e7-4a37-bc34-5e4c7f0e3a30','c354a11a-2239-41fa-907f-5a187c41c88f','2026-06-09 08:03:35',NULL,'CREATE','COMPLETE','StorageMgmtDeployedPort','overcloud-Controller-6r6ux5bcpsr3-2-bvtivffc4ip5-StorageMgmtPort-5jleclcba2wq-StorageMgmtDeployedPort-4eofrjit3qon','state changed','OS::Heat::Value',NULL,1659),(2722,'a2d5c13d-ea84-4377-8c97-95a040feb7f9','d3da9348-b768-4364-b586-6015cf9968a6','2026-06-09 08:03:35',NULL,'CREATE','COMPLETE','ExternalDeployedPort','overcloud-Controller-6r6ux5bcpsr3-2-bvtivffc4ip5-ExternalPort-zogvbc7ccz4n-ExternalDeployedPort-ptjdrftzpkyh','state changed','OS::Heat::Value',NULL,1660),(2723,'1fc66b95-69d0-41e7-bd18-d723bef53320','c354a11a-2239-41fa-907f-5a187c41c88f','2026-06-09 08:03:35',NULL,'CREATE','COMPLETE','overcloud-Controller-6r6ux5bcpsr3-2-bvtivffc4ip5-StorageMgmtPort-5jleclcba2wq','c354a11a-2239-41fa-907f-5a187c41c88f','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2724,'f9976ebb-6627-4293-a5d1-2f86668de29f','d3da9348-b768-4364-b586-6015cf9968a6','2026-06-09 08:03:35',NULL,'CREATE','COMPLETE','overcloud-Controller-6r6ux5bcpsr3-2-bvtivffc4ip5-ExternalPort-zogvbc7ccz4n','d3da9348-b768-4364-b586-6015cf9968a6','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2725,'2026b84f-06d6-48bd-8746-9226874af540','7927cabd-5ac4-4f35-a20d-00f65e92d2bf','2026-06-09 08:03:35',NULL,'CREATE','COMPLETE','1','627c87c4-2e4c-4189-a029-0b9e9797e97a','state changed','OS::TripleO::Controller',NULL,1567),(2726,'fe692679-1c35-44d4-b953-0b63990db18b','329b2c0f-9c6e-4d8d-9d05-0cc1b0d601fc','2026-06-09 08:03:35',NULL,'CREATE','COMPLETE','NodeExtraConfig','a2cf7ab8-e34d-4ee9-a025-6eca3592592b','state changed','OS::TripleO::NodeExtraConfig',NULL,1639),(2727,'26d7b60c-bb88-4e76-a132-8d7fc9e8a915','329b2c0f-9c6e-4d8d-9d05-0cc1b0d601fc','2026-06-09 08:03:35',NULL,'CREATE','COMPLETE','NetIpMap','d82d9a9c-b41f-4711-b4ad-bdc056df491b','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1643),(2728,'699f0e10-f66e-47b4-a6c7-442021131cb3','329b2c0f-9c6e-4d8d-9d05-0cc1b0d601fc','2026-06-09 08:03:35',NULL,'CREATE','COMPLETE','overcloud-Controller-6r6ux5bcpsr3-0-gxtwjyggi57i','329b2c0f-9c6e-4d8d-9d05-0cc1b0d601fc','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2729,'b9e63ce5-7e9d-43bf-a0e6-0ef6f1324829','fe6daf36-029c-4429-898d-a3c4dba4da9b','2026-06-09 08:03:36',NULL,'CREATE','COMPLETE','TenantPort','a561e0f8-adfe-4bb1-8245-14fed0c9c02b','state changed','OS::TripleO::Controller::Ports::TenantPort',NULL,1647),(2730,'96aa5ecd-fc5f-422c-b507-f4b0c6ad25d7','fe6daf36-029c-4429-898d-a3c4dba4da9b','2026-06-09 08:03:36',NULL,'CREATE','COMPLETE','StoragePort','17c2f708-c63d-49af-9059-95cbfb30273d','state changed','OS::TripleO::Controller::Ports::StoragePort',NULL,1648),(2731,'aaef1b9f-0a4c-41c0-82ba-b0422db268cc','fe6daf36-029c-4429-898d-a3c4dba4da9b','2026-06-09 08:03:36',NULL,'CREATE','COMPLETE','InternalApiPort','c22ee87e-f18e-4c4f-a2bf-9f4342643377','state changed','OS::TripleO::Controller::Ports::InternalApiPort',NULL,1646),(2732,'b4678d41-49fb-4d16-b572-92ebf8b4a2df','fe6daf36-029c-4429-898d-a3c4dba4da9b','2026-06-09 08:03:36',NULL,'CREATE','COMPLETE','ControllerExtraConfigPre','8e9d99e7-5b9f-43d9-b357-dfe456c33684','state changed','OS::TripleO::ControllerExtraConfigPre',NULL,1649),(2733,'ca65d2fb-93c1-43a2-8c64-34af08c2e991','fe6daf36-029c-4429-898d-a3c4dba4da9b','2026-06-09 08:03:36',NULL,'CREATE','COMPLETE','StorageMgmtPort','c354a11a-2239-41fa-907f-5a187c41c88f','state changed','OS::TripleO::Controller::Ports::StorageMgmtPort',NULL,1653),(2734,'f49f6ebe-fb62-4036-9e94-6ad5a6d08fa9','fe6daf36-029c-4429-898d-a3c4dba4da9b','2026-06-09 08:03:36',NULL,'CREATE','COMPLETE','ExternalPort','d3da9348-b768-4364-b586-6015cf9968a6','state changed','OS::TripleO::Controller::Ports::ExternalPort',NULL,1652),(2735,'be8d69b8-02a9-41f6-a6e3-723c946161db','fe6daf36-029c-4429-898d-a3c4dba4da9b','2026-06-09 08:03:36',NULL,'CREATE','IN_PROGRESS','NodeExtraConfig','overcloud-Controller-6r6ux5bcpsr3-2-bvtivffc4ip5-NodeExtraConfig-3wntszfwqqzp','state changed','OS::TripleO::NodeExtraConfig',NULL,1670),(2736,'22f62420-3890-437a-bae9-5a416597da94','7927cabd-5ac4-4f35-a20d-00f65e92d2bf','2026-06-09 08:03:36',NULL,'CREATE','COMPLETE','0','329b2c0f-9c6e-4d8d-9d05-0cc1b0d601fc','state changed','OS::TripleO::Controller',NULL,1570),(2737,'c4a98a1e-1064-41d8-9c50-3fdab99ad37b','fe6daf36-029c-4429-898d-a3c4dba4da9b','2026-06-09 08:03:36',NULL,'CREATE','IN_PROGRESS','NetIpMap','overcloud-Controller-6r6ux5bcpsr3-2-bvtivffc4ip5-NetIpMap-4jnqdibvtvpb','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1673),(2738,'646d98fc-679c-4d6d-91b5-0dca777ac7c1','50346583-e8f1-4496-9c53-7fd9e5009f16','2026-06-09 08:03:36',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-6r6ux5bcpsr3-2-bvtivffc4ip5-NodeExtraConfig-3wntszfwqqzp','50346583-e8f1-4496-9c53-7fd9e5009f16','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2739,'d7040314-03e1-4ab7-87f9-676cffd6035e','50346583-e8f1-4496-9c53-7fd9e5009f16','2026-06-09 08:03:36',NULL,'CREATE','COMPLETE','overcloud-Controller-6r6ux5bcpsr3-2-bvtivffc4ip5-NodeExtraConfig-3wntszfwqqzp','50346583-e8f1-4496-9c53-7fd9e5009f16','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2740,'fb6fc7e2-b21d-4ac9-ba15-e719a5783fbf','8186aa24-5f40-470c-9b71-040b3d35dbbf','2026-06-09 08:03:36',NULL,'CREATE','IN_PROGRESS','overcloud-Controller-6r6ux5bcpsr3-2-bvtivffc4ip5-NetIpMap-4jnqdibvtvpb','8186aa24-5f40-470c-9b71-040b3d35dbbf','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2741,'6dd0281c-80a8-4db1-a495-28b129c307d0','8186aa24-5f40-470c-9b71-040b3d35dbbf','2026-06-09 08:03:36',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-Controller-6r6ux5bcpsr3-2-bvtivffc4ip5-NetIpMap-4jnqdibvtvpb-NetIpMapValue-ery3aszswwzw','state changed','OS::Heat::Value',NULL,1674),(2742,'d535cb35-cb41-4120-973f-aa9211e1e9e6','8186aa24-5f40-470c-9b71-040b3d35dbbf','2026-06-09 08:03:36',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-Controller-6r6ux5bcpsr3-2-bvtivffc4ip5-NetIpMap-4jnqdibvtvpb-NetIpMapValue-ery3aszswwzw','state changed','OS::Heat::Value',NULL,1674),(2743,'83d32308-bada-4911-826b-b159facc96b8','8186aa24-5f40-470c-9b71-040b3d35dbbf','2026-06-09 08:03:37',NULL,'CREATE','COMPLETE','overcloud-Controller-6r6ux5bcpsr3-2-bvtivffc4ip5-NetIpMap-4jnqdibvtvpb','8186aa24-5f40-470c-9b71-040b3d35dbbf','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2744,'fd4903cd-610a-46e5-9d42-13673562a2e4','fe6daf36-029c-4429-898d-a3c4dba4da9b','2026-06-09 08:03:37',NULL,'CREATE','COMPLETE','NodeExtraConfig','50346583-e8f1-4496-9c53-7fd9e5009f16','state changed','OS::TripleO::NodeExtraConfig',NULL,1670),(2745,'914de68f-bb16-488d-b06e-da475c3b9a11','fe6daf36-029c-4429-898d-a3c4dba4da9b','2026-06-09 08:03:37',NULL,'CREATE','COMPLETE','NetIpMap','8186aa24-5f40-470c-9b71-040b3d35dbbf','state changed','OS::TripleO::Network::Ports::NetIpMap',NULL,1673),(2746,'4160f3c4-bc39-4d13-8198-884ff6523504','fe6daf36-029c-4429-898d-a3c4dba4da9b','2026-06-09 08:03:37',NULL,'CREATE','COMPLETE','overcloud-Controller-6r6ux5bcpsr3-2-bvtivffc4ip5','fe6daf36-029c-4429-898d-a3c4dba4da9b','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2747,'449d6ec1-ab5b-4533-9105-611a5a05df2d','7927cabd-5ac4-4f35-a20d-00f65e92d2bf','2026-06-09 08:03:38',NULL,'CREATE','COMPLETE','2','fe6daf36-029c-4429-898d-a3c4dba4da9b','state changed','OS::TripleO::Controller',NULL,1575),(2748,'056cb05b-a788-4abf-9c89-64229c55b6fc','7927cabd-5ac4-4f35-a20d-00f65e92d2bf','2026-06-09 08:03:38',NULL,'UPDATE','COMPLETE','overcloud-Controller-6r6ux5bcpsr3','7927cabd-5ac4-4f35-a20d-00f65e92d2bf','Stack UPDATE completed successfully','OS::Heat::Stack',NULL,NULL),(2749,'1de9a71f-1f22-4525-b39f-e7fedf3eeb8d','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:39',NULL,'CREATE','COMPLETE','Controller','7927cabd-5ac4-4f35-a20d-00f65e92d2bf','state changed','OS::Heat::ResourceGroup',NULL,1562),(2750,'31c7add8-5e6b-45dc-83e0-1b6854f84fd8','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:40',NULL,'CREATE','IN_PROGRESS','HostsEntryValue','overcloud-HostsEntryValue-ggbvckdueufw','state changed','OS::Heat::Value',NULL,1690),(2751,'8de5d49b-53e3-45e8-a9f5-345138c674b6','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:40',NULL,'CREATE','COMPLETE','HostsEntryValue','overcloud-HostsEntryValue-ggbvckdueufw','state changed','OS::Heat::Value',NULL,1690),(2752,'d5e9fadb-3ddb-4b20-a63e-6443a6eb186f','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:40',NULL,'CREATE','IN_PROGRESS','ControllerNetworkHostnameMap','overcloud-ControllerNetworkHostnameMap-vlu3rrgigrpg','state changed','OS::Heat::Value',NULL,1691),(2753,'29247a0e-1229-459b-a056-68d22976948f','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:40',NULL,'CREATE','IN_PROGRESS','ControllerServers','overcloud-ControllerServers-das5t4oxzmq7','state changed','OS::Heat::Value',NULL,1692),(2754,'a332a8f9-4931-44a9-9fe3-d21ff5f797e4','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:40',NULL,'CREATE','COMPLETE','ControllerServers','overcloud-ControllerServers-das5t4oxzmq7','state changed','OS::Heat::Value',NULL,1692),(2755,'98ca6a74-5d01-4210-9d02-4160b90c650b','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:40',NULL,'CREATE','COMPLETE','ControllerNetworkHostnameMap','overcloud-ControllerNetworkHostnameMap-vlu3rrgigrpg','state changed','OS::Heat::Value',NULL,1691),(2756,'88495c72-f137-4747-b737-834a6265959b','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:40',NULL,'CREATE','IN_PROGRESS','ServerIdMap','overcloud-ServerIdMap-hxx5nszdp35q','state changed','OS::Heat::Value',NULL,1693),(2757,'ff13d74d-639d-49a7-8a99-9bbf1da69dd3','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:40',NULL,'CREATE','COMPLETE','ServerIdMap','overcloud-ServerIdMap-hxx5nszdp35q','state changed','OS::Heat::Value',NULL,1693),(2758,'8cf06cf6-cdbe-41a1-8770-0a7a883806a6','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:40',NULL,'CREATE','IN_PROGRESS','AnsibleHostVars','overcloud-AnsibleHostVars-u6r2dorvflrq','state changed','OS::Heat::Value',NULL,1695),(2759,'6848e914-e40a-4c44-be41-cc078fbcce35','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:40',NULL,'CREATE','IN_PROGRESS','BlacklistedHostnames','overcloud-BlacklistedHostnames-mhmk4edywclc','state changed','OS::Heat::Value',NULL,1697),(2760,'691c5da3-45dd-4b81-b05f-d6da3f711b0f','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:40',NULL,'CREATE','IN_PROGRESS','AllNodesExtraConfig','overcloud-AllNodesExtraConfig-4akubf7ezwd3','state changed','OS::TripleO::AllNodesExtraConfig',NULL,NULL),(2761,'80215e2a-baa8-42a2-956d-21ed42a0796a','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:40',NULL,'CREATE','IN_PROGRESS','ControllerIpListMap','overcloud-ControllerIpListMap-deyfmqfy2et4','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,1698),(2762,'59848b1b-19c9-4e40-a410-e17e8d8abe25','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:40',NULL,'CREATE','COMPLETE','BlacklistedHostnames','overcloud-BlacklistedHostnames-mhmk4edywclc','state changed','OS::Heat::Value',NULL,1697),(2763,'a9a762e6-a07d-4d1b-ae82-6b6a5fe1efad','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:40',NULL,'CREATE','COMPLETE','AnsibleHostVars','overcloud-AnsibleHostVars-u6r2dorvflrq','state changed','OS::Heat::Value',NULL,1695),(2764,'57c0c2a0-f238-4c73-9a13-e0dc1ea5de80','5739df5f-b24a-496b-b490-d08c6c6f2dfc','2026-06-09 08:03:40',NULL,'CREATE','IN_PROGRESS','overcloud-ControllerIpListMap-deyfmqfy2et4','5739df5f-b24a-496b-b490-d08c6c6f2dfc','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2765,'c8f1df1e-7c88-4c9b-8f1e-ccbe569e6e4b','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:40',NULL,'CREATE','COMPLETE','AllNodesExtraConfig','235913c4-17f4-4bde-9b99-8f111e039883','state changed','OS::TripleO::AllNodesExtraConfig',NULL,NULL),(2766,'196b5eae-58a4-4c7f-a447-2bf3ff81bc31','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:40',NULL,'CREATE','IN_PROGRESS','BlacklistedIpAddresses','overcloud-BlacklistedIpAddresses-7lc7do5uzmir','state changed','OS::Heat::Value',NULL,1699),(2767,'927916eb-ab37-4c20-929d-c9b92f38c144','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:40',NULL,'CREATE','COMPLETE','BlacklistedIpAddresses','overcloud-BlacklistedIpAddresses-7lc7do5uzmir','state changed','OS::Heat::Value',NULL,1699),(2768,'6690a47b-883b-4ee6-b748-5a51d2a8cf97','5739df5f-b24a-496b-b490-d08c6c6f2dfc','2026-06-09 08:03:40',NULL,'CREATE','IN_PROGRESS','NetIpMapValue','overcloud-ControllerIpListMap-deyfmqfy2et4-NetIpMapValue-uaunqfhcdyzl','state changed','OS::Heat::Value',NULL,1701),(2769,'a2602f01-d135-4e4e-8a48-5dc1adfde79b','5739df5f-b24a-496b-b490-d08c6c6f2dfc','2026-06-09 08:03:40',NULL,'CREATE','COMPLETE','NetIpMapValue','overcloud-ControllerIpListMap-deyfmqfy2et4-NetIpMapValue-uaunqfhcdyzl','state changed','OS::Heat::Value',NULL,1701),(2770,'cd164e4c-9db5-4d8d-8be5-c07c03227ec7','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:41',NULL,'CREATE','IN_PROGRESS','AllNodesDeploySteps','overcloud-AllNodesDeploySteps-lbn7zn2hqpja','state changed','OS::TripleO::PostDeploySteps',NULL,1703),(2771,'9bd53aa6-c038-4ba1-b748-d86e33d53c4f','496dd31a-a11e-4590-8b57-a0ccc694b8d0','2026-06-09 08:03:41',NULL,'CREATE','IN_PROGRESS','overcloud-AllNodesDeploySteps-lbn7zn2hqpja','496dd31a-a11e-4590-8b57-a0ccc694b8d0','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2772,'be1b8136-56aa-4d13-91ee-891c82e75ae9','5739df5f-b24a-496b-b490-d08c6c6f2dfc','2026-06-09 08:03:41',NULL,'CREATE','IN_PROGRESS','EnabledServicesValue','overcloud-ControllerIpListMap-deyfmqfy2et4-EnabledServicesValue-tyayid2qa4lj','state changed','OS::Heat::Value',NULL,1704),(2773,'69cd2f96-8aae-43ef-b3e3-09884cf77a86','5739df5f-b24a-496b-b490-d08c6c6f2dfc','2026-06-09 08:03:41',NULL,'CREATE','COMPLETE','EnabledServicesValue','overcloud-ControllerIpListMap-deyfmqfy2et4-EnabledServicesValue-tyayid2qa4lj','state changed','OS::Heat::Value',NULL,1704),(2774,'b8a53266-ea13-41bb-bdf8-d7d8d1a76444','5739df5f-b24a-496b-b490-d08c6c6f2dfc','2026-06-09 08:03:41',NULL,'CREATE','COMPLETE','overcloud-ControllerIpListMap-deyfmqfy2et4','5739df5f-b24a-496b-b490-d08c6c6f2dfc','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2775,'dbc848ad-2803-42b0-b4e0-7704a6da1ebb','496dd31a-a11e-4590-8b57-a0ccc694b8d0','2026-06-09 08:03:42',NULL,'CREATE','IN_PROGRESS','ComputeExtraConfigPost','overcloud-AllNodesDeploySteps-lbn7zn2hqpja-ComputeExtraConfigPost-j2uzbz53z53p','state changed','OS::TripleO::NodeExtraConfigPost',NULL,1705),(2776,'cd85e678-473f-42ac-b0c2-c9dd2d40fd93','eddff08f-2fb5-4edb-96f3-a6c5249e0534','2026-06-09 08:03:42',NULL,'CREATE','IN_PROGRESS','overcloud-AllNodesDeploySteps-lbn7zn2hqpja-ComputeExtraConfigPost-j2uzbz53z53p','eddff08f-2fb5-4edb-96f3-a6c5249e0534','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2777,'7730e7a3-1237-46b2-be24-97d5dd911e5e','eddff08f-2fb5-4edb-96f3-a6c5249e0534','2026-06-09 08:03:42',NULL,'CREATE','COMPLETE','overcloud-AllNodesDeploySteps-lbn7zn2hqpja-ComputeExtraConfigPost-j2uzbz53z53p','eddff08f-2fb5-4edb-96f3-a6c5249e0534','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2778,'4aeb38ff-d2db-4d0c-9d7b-1a2b1816bc49','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:42',NULL,'CREATE','COMPLETE','ControllerIpListMap','5739df5f-b24a-496b-b490-d08c6c6f2dfc','state changed','OS::TripleO::Network::Ports::NetIpListMap',NULL,1698),(2779,'8ae9cb0d-8bf5-4c35-9b33-d18a5c6d3fd5','496dd31a-a11e-4590-8b57-a0ccc694b8d0','2026-06-09 08:03:43',NULL,'CREATE','IN_PROGRESS','ScaleTasks','overcloud-AllNodesDeploySteps-lbn7zn2hqpja-ScaleTasks-tcthbw7ccq6y','state changed','OS::Heat::Value',NULL,1706),(2780,'dc435a85-7581-4d6f-a5b6-a5bd0e0336d7','496dd31a-a11e-4590-8b57-a0ccc694b8d0','2026-06-09 08:03:43',NULL,'CREATE','COMPLETE','ScaleTasks','overcloud-AllNodesDeploySteps-lbn7zn2hqpja-ScaleTasks-tcthbw7ccq6y','state changed','OS::Heat::Value',NULL,1706),(2781,'71905809-d169-4da2-ad7f-554f716f5b86','496dd31a-a11e-4590-8b57-a0ccc694b8d0','2026-06-09 08:03:43',NULL,'CREATE','COMPLETE','ComputeExtraConfigPost','eddff08f-2fb5-4edb-96f3-a6c5249e0534','state changed','OS::TripleO::NodeExtraConfigPost',NULL,1705),(2782,'1366c7fb-4ed8-452b-b3be-b05d06f10df4','496dd31a-a11e-4590-8b57-a0ccc694b8d0','2026-06-09 08:03:44',NULL,'CREATE','IN_PROGRESS','ControllerExtraConfigPost','overcloud-AllNodesDeploySteps-lbn7zn2hqpja-ControllerExtraConfigPost-nz4ghjrd6s4t','state changed','OS::TripleO::NodeExtraConfigPost',NULL,1708),(2783,'57cb7244-fdaf-4721-acef-0de458ea558b','b5f4feb3-31cc-460b-8665-c10363f87e98','2026-06-09 08:03:44',NULL,'CREATE','IN_PROGRESS','overcloud-AllNodesDeploySteps-lbn7zn2hqpja-ControllerExtraConfigPost-nz4ghjrd6s4t','b5f4feb3-31cc-460b-8665-c10363f87e98','Stack CREATE started','OS::Heat::Stack',NULL,NULL),(2784,'aae13bff-c3bc-4fe7-b526-a0449eaf805d','b5f4feb3-31cc-460b-8665-c10363f87e98','2026-06-09 08:03:44',NULL,'CREATE','COMPLETE','overcloud-AllNodesDeploySteps-lbn7zn2hqpja-ControllerExtraConfigPost-nz4ghjrd6s4t','b5f4feb3-31cc-460b-8665-c10363f87e98','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2785,'75358495-dd35-45b5-8671-6035d079dbc5','496dd31a-a11e-4590-8b57-a0ccc694b8d0','2026-06-09 08:03:45',NULL,'CREATE','IN_PROGRESS','ExternalUpgradeTasks','overcloud-AllNodesDeploySteps-lbn7zn2hqpja-ExternalUpgradeTasks-ar6jadhuee6u','state changed','OS::Heat::Value',NULL,1709),(2786,'fefbe1f6-7ada-48da-b259-dce127d6f400','496dd31a-a11e-4590-8b57-a0ccc694b8d0','2026-06-09 08:03:45',NULL,'CREATE','COMPLETE','ExternalUpgradeTasks','overcloud-AllNodesDeploySteps-lbn7zn2hqpja-ExternalUpgradeTasks-ar6jadhuee6u','state changed','OS::Heat::Value',NULL,1709),(2787,'eb069667-52aa-428c-a6f7-844e9c60d2b5','496dd31a-a11e-4590-8b57-a0ccc694b8d0','2026-06-09 08:03:45',NULL,'CREATE','COMPLETE','ControllerExtraConfigPost','b5f4feb3-31cc-460b-8665-c10363f87e98','state changed','OS::TripleO::NodeExtraConfigPost',NULL,1708),(2788,'712412e5-4b9c-40b5-9a92-867511709c81','496dd31a-a11e-4590-8b57-a0ccc694b8d0','2026-06-09 08:03:45',NULL,'CREATE','IN_PROGRESS','ControllerPostConfig','overcloud-AllNodesDeploySteps-lbn7zn2hqpja-ControllerPostConfig-h5oip7lvds64','state changed','OS::TripleO::Tasks::ControllerPostConfig',NULL,NULL),(2789,'bf56f3bb-bc49-480e-ba1b-4d53633f4a84','496dd31a-a11e-4590-8b57-a0ccc694b8d0','2026-06-09 08:03:45',NULL,'CREATE','IN_PROGRESS','ComputePostConfig','overcloud-AllNodesDeploySteps-lbn7zn2hqpja-ComputePostConfig-34mm6kqmjrwl','state changed','OS::TripleO::Tasks::ComputePostConfig',NULL,NULL),(2790,'63637841-865f-477b-af08-167a6ec81b97','496dd31a-a11e-4590-8b57-a0ccc694b8d0','2026-06-09 08:03:45',NULL,'CREATE','COMPLETE','ControllerPostConfig','1eb93d65-4809-490f-8a28-0622c9ac9b6d','state changed','OS::TripleO::Tasks::ControllerPostConfig',NULL,NULL),(2791,'91f3f962-02e0-4541-bd7b-f1d3a9ff205d','496dd31a-a11e-4590-8b57-a0ccc694b8d0','2026-06-09 08:03:45',NULL,'CREATE','COMPLETE','ComputePostConfig','4e695330-1662-44e5-9982-36a9a67ff3df','state changed','OS::TripleO::Tasks::ComputePostConfig',NULL,NULL),(2792,'f197332b-f700-4f88-863b-96f903b8bdd1','496dd31a-a11e-4590-8b57-a0ccc694b8d0','2026-06-09 08:03:46',NULL,'CREATE','IN_PROGRESS','ExternalPostDeployTasks','overcloud-AllNodesDeploySteps-lbn7zn2hqpja-ExternalPostDeployTasks-or2kuns4cph2','state changed','OS::Heat::Value',NULL,1711),(2793,'ee731d21-6dbf-4c4a-a409-80f00d16c42f','496dd31a-a11e-4590-8b57-a0ccc694b8d0','2026-06-09 08:03:46',NULL,'CREATE','COMPLETE','ExternalPostDeployTasks','overcloud-AllNodesDeploySteps-lbn7zn2hqpja-ExternalPostDeployTasks-or2kuns4cph2','state changed','OS::Heat::Value',NULL,1711),(2794,'634329a8-5b30-49ca-ba9f-155d6549c985','496dd31a-a11e-4590-8b57-a0ccc694b8d0','2026-06-09 08:03:47',NULL,'CREATE','IN_PROGRESS','PreDeployStepTasks','overcloud-AllNodesDeploySteps-lbn7zn2hqpja-PreDeployStepTasks-4pc7daxbbv6x','state changed','OS::Heat::Value',NULL,1712),(2795,'1d21caf2-26c2-49c9-865e-a60fc8ec81d8','496dd31a-a11e-4590-8b57-a0ccc694b8d0','2026-06-09 08:03:47',NULL,'CREATE','COMPLETE','PreDeployStepTasks','overcloud-AllNodesDeploySteps-lbn7zn2hqpja-PreDeployStepTasks-4pc7daxbbv6x','state changed','OS::Heat::Value',NULL,1712),(2796,'85aacb83-ab58-4725-8870-06de06950464','496dd31a-a11e-4590-8b57-a0ccc694b8d0','2026-06-09 08:03:48',NULL,'CREATE','IN_PROGRESS','ExternalUpdateTasks','overcloud-AllNodesDeploySteps-lbn7zn2hqpja-ExternalUpdateTasks-fr5rpkqigqej','state changed','OS::Heat::Value',NULL,1713),(2797,'f0f2f5dd-dd6b-4dbe-ba75-4a566c084eef','496dd31a-a11e-4590-8b57-a0ccc694b8d0','2026-06-09 08:03:48',NULL,'CREATE','COMPLETE','ExternalUpdateTasks','overcloud-AllNodesDeploySteps-lbn7zn2hqpja-ExternalUpdateTasks-fr5rpkqigqej','state changed','OS::Heat::Value',NULL,1713),(2798,'c8c49d13-5dbb-4e12-b5b6-fbc2d610b266','496dd31a-a11e-4590-8b57-a0ccc694b8d0','2026-06-09 08:03:49',NULL,'CREATE','IN_PROGRESS','BootstrapServerId','overcloud-AllNodesDeploySteps-lbn7zn2hqpja-BootstrapServerId-qe252bflhtho','state changed','OS::Heat::Value',NULL,1714),(2799,'5a17a522-2dc1-4b1d-8cd8-7aa7a1a896b2','496dd31a-a11e-4590-8b57-a0ccc694b8d0','2026-06-09 08:03:49',NULL,'CREATE','COMPLETE','BootstrapServerId','overcloud-AllNodesDeploySteps-lbn7zn2hqpja-BootstrapServerId-qe252bflhtho','state changed','OS::Heat::Value',NULL,1714),(2800,'53aa016c-cd30-44f8-a581-5983801b7e92','496dd31a-a11e-4590-8b57-a0ccc694b8d0','2026-06-09 08:03:50',NULL,'CREATE','IN_PROGRESS','ExternalDeployTasks','overcloud-AllNodesDeploySteps-lbn7zn2hqpja-ExternalDeployTasks-o4yk42vupu6y','state changed','OS::Heat::Value',NULL,1715),(2801,'bb76f99c-eb3c-4a64-8dab-2b53d02ef911','496dd31a-a11e-4590-8b57-a0ccc694b8d0','2026-06-09 08:03:50',NULL,'CREATE','COMPLETE','ExternalDeployTasks','overcloud-AllNodesDeploySteps-lbn7zn2hqpja-ExternalDeployTasks-o4yk42vupu6y','state changed','OS::Heat::Value',NULL,1715),(2802,'2c107df3-c0e9-41a7-9133-5c1408aaeb59','496dd31a-a11e-4590-8b57-a0ccc694b8d0','2026-06-09 08:03:50',NULL,'CREATE','COMPLETE','overcloud-AllNodesDeploySteps-lbn7zn2hqpja','496dd31a-a11e-4590-8b57-a0ccc694b8d0','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL),(2803,'f2ba7f3c-0671-49d8-b1ff-799b97a2b15f','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:50',NULL,'CREATE','COMPLETE','AllNodesDeploySteps','496dd31a-a11e-4590-8b57-a0ccc694b8d0','state changed','OS::TripleO::PostDeploySteps',NULL,1703),(2804,'815bfa2e-4fbe-4414-b195-1cce4ab95e83','4a12592d-7930-4580-a032-c1f97514e693','2026-06-09 08:03:50',NULL,'CREATE','COMPLETE','overcloud','4a12592d-7930-4580-a032-c1f97514e693','Stack CREATE completed successfully','OS::Heat::Stack',NULL,NULL);
/*!40000 ALTER TABLE `event` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `migrate_version`
--

DROP TABLE IF EXISTS `migrate_version`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `migrate_version` (
  `repository_id` varchar(250) NOT NULL,
  `repository_path` text DEFAULT NULL,
  `version` int(11) DEFAULT NULL,
  PRIMARY KEY (`repository_id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1 COLLATE=latin1_swedish_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `migrate_version`
--

LOCK TABLES `migrate_version` WRITE;
/*!40000 ALTER TABLE `migrate_version` DISABLE KEYS */;
INSERT INTO `migrate_version` VALUES ('heat','/usr/lib/python3.9/site-packages/heat/db/sqlalchemy/migrate_repo',86);
/*!40000 ALTER TABLE `migrate_version` ENABLE KEYS */;
UNLOCK TABLES;

--
-- Table structure for table `raw_template`
--

DROP TABLE IF EXISTS `raw_template`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `raw_template` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `created_at` datetime DEFAULT NULL,
  `updated_at` datetime DEFAULT NULL,
  `template` longtext DEFAULT NULL,
  `files` longtext DEFAULT NULL,
  `environment` longtext DEFAULT NULL,
  `files_id` int(11) DEFAULT NULL,
  PRIMARY KEY (`id`),
  KEY `raw_tmpl_files_fkey_ref` (`files_id`),
  CONSTRAINT `raw_tmpl_files_fkey_ref` FOREIGN KEY (`files_id`) REFERENCES `raw_template_files` (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=408 DEFAULT CHARSET=utf8 COLLATE=utf8_general_ci;
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping data for table `raw_template`
--

LOCK TABLES `raw_template` WRITE;
/*!40000 ALTER TABLE `raw_template` DISABLE KEYS */;
INSERT INTO `raw_template` VALUES (1,'2026-06-09 08:01:33',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deploy an OpenStack environment, consisting of several node types (roles), Controller, Compute, BlockStorage, SwiftStorage and CephStorage. The Storage roles enable independent scaling of the storage components, but the minimal deployment is one Controller and one Compute node.\\n\", \"parameters\": {\"CloudNameStorage\": {\"default\": \"overcloud.storage.localdomain\", \"description\": \"The DNS name of this cloud\'s storage endpoint. E.g. \'ci-overcloud.storage.tripleo.org\'.\\n\", \"type\": \"string\"}, \"StorageVirtualFixedIPs\": {\"default\": [], \"description\": \"Control the IP allocation for the StorageVirtualInterface port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"type\": \"json\"}, \"CloudNameStorageManagement\": {\"default\": \"overcloud.storagemgmt.localdomain\", \"description\": \"The DNS name of this cloud\'s storage_mgmt endpoint. E.g. \'ci-overcloud.storagemgmt.tripleo.org\'.\\n\", \"type\": \"string\"}, \"StorageMgmtVirtualFixedIPs\": {\"default\": [], \"description\": \"Control the IP allocation for the StorageMgmtVirtualInterface port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"type\": \"json\"}, \"CloudNameInternal\": {\"default\": \"overcloud.internalapi.localdomain\", \"description\": \"The DNS name of this cloud\'s internal_api endpoint. E.g. \'ci-overcloud.internalapi.tripleo.org\'.\\n\", \"type\": \"string\"}, \"InternalApiVirtualFixedIPs\": {\"default\": [], \"description\": \"Control the IP allocation for the InternalApiVirtualInterface port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"type\": \"json\"}, \"CloudName\": {\"default\": \"overcloud.localdomain\", \"description\": \"The DNS name of this cloud. E.g. ci-overcloud.tripleo.org\", \"type\": \"string\"}, \"PublicVirtualFixedIPs\": {\"default\": [], \"description\": \"Control the IP allocation for the PublicVirtualInterface port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"type\": \"json\"}, \"ExternalVirtualFixedIPs\": {\"default\": [], \"description\": \"Control the IP allocation for the ExternalVirtualInterface port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"type\": \"json\"}, \"CloudNameCtlplane\": {\"default\": \"overcloud.ctlplane.localdomain\", \"description\": \"The DNS name of this cloud\'s provisioning network endpoint. E.g. \'ci-overcloud.ctlplane.tripleo.org\'.\\n\", \"type\": \"string\"}, \"ExtraHostFileEntries\": {\"default\": [], \"description\": \"List of extra hosts entries to be appended to /etc/hosts\", \"type\": \"comma_delimited_list\"}, \"UndercloudHostsEntries\": {\"default\": [], \"description\": \"List of undercloud hosts entries to be appended to /etc/hosts. The value is populated with the HEAT_HOSTS entries on the undercloud by tripleoclient when running deploy.\\n\", \"type\": \"comma_delimited_list\"}, \"EndpointMapOverride\": {\"default\": {}, \"description\": \"Can be used to override the calcluated EndpointMap\", \"type\": \"json\"}, \"ExtraConfig\": {\"default\": {}, \"description\": \"Additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"DeployedServerPortMap\": {\"default\": {}, \"type\": \"json\"}, \"NeutronControlPlaneID\": {\"default\": \"ctlplane\", \"type\": \"string\", \"description\": \"Neutron ID or name for ctlplane network.\"}, \"NeutronPhysicalBridge\": {\"default\": \"br-ex\", \"description\": \"An OVS bridge to create for accessing external networks.\", \"type\": \"string\"}, \"NeutronPublicInterface\": {\"default\": \"nic1\", \"description\": \"Which interface to add to the NeutronPhysicalBridge.\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"DnsSearchDomains\": {\"default\": [], \"description\": \"A list of DNS search domains to be added (in order) to resolv.conf.\", \"type\": \"comma_delimited_list\"}, \"ControlFixedIPs\": {\"default\": [], \"description\": \"Control the IP allocation for the ControlVirtualIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"type\": \"json\"}, \"RabbitCookieSalt\": {\"type\": \"string\", \"default\": \"unset\", \"description\": \"Salt for the rabbit cookie, change this to force the randomly generated rabbit cookie to change.\"}, \"CloudDomain\": {\"default\": \"localdomain\", \"type\": \"string\", \"description\": \"The DNS domain used for the hosts. This must match the overcloud_domain_name configured on the undercloud.\\n\"}, \"ServerMetadata\": {\"default\": {}, \"description\": \"Extra properties or metadata passed to Nova for the created nodes in the overcloud. It\'s accessible via the Nova metadata API.\\n\", \"type\": \"json\"}, \"HypervisorNeutronPhysicalBridge\": {\"default\": \"br-ex\", \"description\": \"An OVS bridge to create on each hypervisor. This defaults to br-ex the same as the control plane nodes, as we have a uniform configuration of the openvswitch agent. Typically should not need to be changed.\\n\", \"type\": \"string\"}, \"HypervisorNeutronPublicInterface\": {\"default\": \"nic1\", \"description\": \"What interface to add to the HypervisorNeutronPhysicalBridge.\", \"type\": \"string\"}, \"NodeCreateBatchSize\": {\"default\": 30, \"description\": \"Maxiumum batch size for creating nodes\", \"type\": \"number\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"NovaLocalMetadataPerCell\": {\"default\": false, \"description\": \"Indicates that the nova-metadata API service has been deployed per-cell, so that we can have better performance and data isolation in a multi-cell deployment. Users should consider the use of this configuration depending on how neutron is setup. If networks span cells, you might need to run nova-metadata API service globally. If your networks are segmented along cell boundaries, then you can run nova-metadata API service per cell. When running nova-metadata API service per cell, you should also configure each Neutron metadata-agent to point to the corresponding nova-metadata API service.\\n\", \"type\": \"boolean\"}, \"BondInterfaceOvsOptions\": {\"default\": \"\", \"description\": \"The ovs_options or bonding_options string for the bond interface. Set things like lacp=active and/or bond_mode=balance-slb for OVS bonds or like mode=4 for Linux bonds using this option.\", \"type\": \"string\", \"constraints\": [{\"allowed_pattern\": \"^((?!balance.tcp).)*$\", \"description\": \"The balance-tcp bond mode is known to cause packet loss and should not be used in BondInterfaceOvsOptions.\"}]}, \"NetworkConfigWithAnsible\": {\"description\": \"NetworkConfig with ansible flag\", \"type\": \"boolean\", \"default\": true}, \"ControllerLocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"ControllerNetworkConfigTemplate\": {\"description\": \"Controller NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"ControllerExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"controllerExtraConfig\": {\"default\": {}, \"description\": \"DEPRECATED use CellControllerComputeExtraConfig instead\\n\", \"type\": \"json\"}, \"ControllerServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the Controller role.\", \"type\": \"comma_delimited_list\"}, \"ControllerNetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"ControllerUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"ControllerIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"ControllerUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"ControllerAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"ControllerMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"ControllerCount\": {\"description\": \"Number of Controller nodes to deploy\", \"type\": \"number\", \"default\": 1}, \"ControllerHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for Controller node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-controller-%index%\"}, \"ControllerRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from Controller ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"ControllerRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for Controller ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"ControllerSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"ControllerParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"ControllerExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"ControllerControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"ControllerServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nControllerServiceChain resource and the Controller resource group.\\nFor example:\\nControllerServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"ControllerNetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"CellControllerLocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"CellControllerNetworkConfigTemplate\": {\"description\": \"CellController NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"CellControllerExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"CellControllerServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the CellController role.\", \"type\": \"comma_delimited_list\"}, \"CellControllerNetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"CellControllerUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"CellControllerIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"CellControllerUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"CellControllerAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"CellControllerMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"CellControllerCount\": {\"description\": \"Number of CellController nodes to deploy\", \"type\": \"number\", \"default\": 1}, \"CellControllerHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for CellController node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-controller-%index%\"}, \"CellControllerRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from CellController ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"CellControllerRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for CellController ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"CellControllerSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"CellControllerParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"CellControllerExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"CellControllerControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"CellControllerServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nCellControllerServiceChain resource and the CellController resource group.\\nFor example:\\nCellControllerServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"CellControllerNetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"CellControllerComputeLocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"CellControllerComputeNetworkConfigTemplate\": {\"description\": \"CellControllerCompute NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"CellControllerComputeExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"CellControllerComputeServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the CellControllerCompute role.\", \"type\": \"comma_delimited_list\"}, \"CellControllerComputeNetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"CellControllerComputeUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"CellControllerComputeIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"CellControllerComputeUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"CellControllerComputeAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"CellControllerComputeMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"CellControllerComputeCount\": {\"description\": \"Number of CellControllerCompute nodes to deploy\", \"type\": \"number\", \"default\": 1}, \"CellControllerComputeHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for CellControllerCompute node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-controller-compute-%index%\"}, \"CellControllerComputeRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from CellControllerCompute ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"CellControllerComputeRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for CellControllerCompute ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"CellControllerComputeSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"CellControllerComputeParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"CellControllerComputeExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"CellControllerComputeControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"CellControllerComputeServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nCellControllerComputeServiceChain resource and the CellControllerCompute resource group.\\nFor example:\\nCellControllerComputeServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"CellControllerComputeNetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"ComputeLocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"ComputeNetworkConfigTemplate\": {\"description\": \"Compute NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"ComputeExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"NovaComputeExtraConfig\": {\"default\": {}, \"description\": \"DEPRECATED use ComputeExtraConfig instead\\n\", \"type\": \"json\"}, \"ComputeServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the Compute role.\", \"type\": \"comma_delimited_list\"}, \"ComputeNetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"ComputeUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"ComputeIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"ComputeUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"ComputeAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"ComputeMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"ComputeCount\": {\"description\": \"Number of Compute nodes to deploy\", \"type\": \"number\", \"default\": 1}, \"ComputeHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for Compute node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-novacompute-%index%\"}, \"ComputeRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from Compute ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"ComputeRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for Compute ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"ComputeSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"NovaComputeSchedulerHints\": {\"type\": \"json\", \"description\": \"DEPRECATED - use ComputeSchedulerHints instead\", \"default\": {}}, \"ComputeParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"ComputeExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"ComputeControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"ComputeServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nComputeServiceChain resource and the Compute resource group.\\nFor example:\\nComputeServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"ComputeNetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"BlockStorageLocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"BlockStorageNetworkConfigTemplate\": {\"description\": \"BlockStorage NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"BlockStorageExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"BlockStorageServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the BlockStorage role.\", \"type\": \"comma_delimited_list\"}, \"BlockStorageNetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"BlockStorageUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"BlockStorageIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"BlockStorageUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"BlockStorageAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"BlockStorageMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"BlockStorageCount\": {\"description\": \"Number of BlockStorage nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"BlockStorageHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for BlockStorage node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-blockstorage-%index%\"}, \"BlockStorageRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from BlockStorage ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"BlockStorageRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for BlockStorage ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"BlockStorageSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"BlockStorageParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"BlockStorageExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"BlockStorageControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"BlockStorageServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nBlockStorageServiceChain resource and the BlockStorage resource group.\\nFor example:\\nBlockStorageServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"BlockStorageNetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"ObjectStorageLocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"ObjectStorageNetworkConfigTemplate\": {\"description\": \"ObjectStorage NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"ObjectStorageExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"ObjectStorageServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the ObjectStorage role.\", \"type\": \"comma_delimited_list\"}, \"ObjectStorageNetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"ObjectStorageUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"ObjectStorageIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"ObjectStorageUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"ObjectStorageAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"ObjectStorageMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"ObjectStorageCount\": {\"description\": \"Number of ObjectStorage nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"ObjectStorageHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for ObjectStorage node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-objectstorage-%index%\"}, \"ObjectStorageRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from ObjectStorage ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"ObjectStorageRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for ObjectStorage ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"ObjectStorageSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"ObjectStorageParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"ObjectStorageExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"ObjectStorageControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"ObjectStorageServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nObjectStorageServiceChain resource and the ObjectStorage resource group.\\nFor example:\\nObjectStorageServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"ObjectStorageNetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"CephStorageLocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"CephStorageNetworkConfigTemplate\": {\"description\": \"CephStorage NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"CephStorageExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"CephStorageServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the CephStorage role.\", \"type\": \"comma_delimited_list\"}, \"CephStorageNetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"CephStorageUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"CephStorageIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"CephStorageUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"CephStorageAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"CephStorageMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"CephStorageCount\": {\"description\": \"Number of CephStorage nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"CephStorageHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for CephStorage node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-cephstorage-%index%\"}, \"CephStorageRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from CephStorage ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"CephStorageRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for CephStorage ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"CephStorageSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"CephStorageParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"CephStorageExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"CephStorageControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"CephStorageServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nCephStorageServiceChain resource and the CephStorage resource group.\\nFor example:\\nCephStorageServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"CephStorageNetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"NetworkerLocalMtu\": {\"default\": 1500, \"description\": \"MTU to use for the Undercloud local_interface.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1000, \"max\": 65536}}]}, \"NetworkerNetworkConfigTemplate\": {\"description\": \"Networker NetworkConfig Template\", \"type\": \"string\", \"default\": \"\"}, \"NetworkerExtraConfig\": {\"default\": {}, \"description\": \"Role specific additional hiera configuration to inject into the cluster.\\n\", \"type\": \"json\"}, \"NetworkerServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the Networker role.\", \"type\": \"comma_delimited_list\"}, \"NetworkerNetworkConfigUpdate\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", existing networks will be updated on the overcloud. This parameter replaces the functionality previously provided by NetworkDeploymentActions. Defaults to \\\"False\\\" so that only new nodes will have their networks configured. This is a role based parameter.\\n\", \"default\": false}, \"NetworkerUseNMState\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", NMState provider is used in os-net-config command to apply the network configuration. This is a role based parameter.\\n\", \"default\": false}, \"NetworkerIfcfgPurge\": {\"type\": \"boolean\", \"description\": \"When set to \\\"True\\\", os-net-config will remove the ifcfg-* provider based configurations and apply the same network_configuration using nmstate provider. This flag is intended to be used along with \\\"NetworkerUseNMState: True\\\" ONLY for provider migration use-case. This is a role based parameter.\\n\", \"default\": false}, \"NetworkerAnyErrorsFatal\": {\"default\": true, \"type\": \"string\"}, \"NetworkerMaxFailPercentage\": {\"default\": 0, \"type\": \"number\"}, \"NetworkerCount\": {\"description\": \"Number of Networker nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"NetworkerHostnameFormat\": {\"type\": \"string\", \"description\": \"Format for Networker node hostnames Note %index% is translated into the index of the node, e.g 0/1/2 etc and %stackname% is replaced with the stack name e.g overcloud\\n\", \"default\": \"%stackname%-networker-%index%\"}, \"NetworkerRemovalPolicies\": {\"default\": [], \"type\": \"json\", \"description\": \"List of resources to be removed from Networker ResourceGroup when doing an update which requires removal of specific resources. Example format ComputeRemovalPolicies: [{\'resource_list\': [\'0\']}]\\n\"}, \"NetworkerRemovalPoliciesMode\": {\"default\": \"append\", \"type\": \"string\", \"description\": \"How to handle change to RemovalPolicies for Networker ResourceGroup when doing an update. Default mode \'append\' will append to the existing blacklist and \'update\' would replace the blacklist.\\n\"}, \"NetworkerSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"NetworkerParameters\": {\"type\": \"json\", \"description\": \"Optional Role Specific parameters to be provided to service\", \"default\": {}}, \"NetworkerExtraGroupVars\": {\"type\": \"json\", \"description\": \"Optional extra Ansible group vars\", \"default\": {}}, \"NetworkerControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"NetworkerServiceNetMap\": {\"default\": {}, \"description\": \"Role specific ServiceNetMap overrides, the map provided will be merged\\nwith the global ServiceNetMap when passing the ServiceNetMap to the\\nNetworkerServiceChain resource and the Networker resource group.\\nFor example:\\nNetworkerServiceNetMap:\\n  NovaLibvirtNetwork: internal_api_leaf2\\n\", \"type\": \"json\"}, \"NetworkerNetConfigOverride\": {\"default\": {}, \"description\": \"Custom JSON data to be used to override the os-net-config config.\\nThis is meant to be used by net_config_override parameter in tripleoclient\\nto provide an easy means to pass in custom net configs for the Undercloud.\\n\", \"type\": \"json\"}, \"UpdateIdentifier\": {\"default\": \"\", \"type\": \"string\", \"description\": \"Setting to a previously unused value during stack-update will trigger package update on all nodes\\n\"}, \"DeployIdentifier\": {\"default\": \"\", \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"AddVipsToEtcHosts\": {\"default\": true, \"type\": \"boolean\", \"description\": \"Set to true to append per network Vips to /etc/hosts on each node.\\n\"}, \"DeploymentServerBlacklist\": {\"default\": [], \"type\": \"comma_delimited_list\", \"description\": \"List of server hostnames to blacklist from any triggered deployments.\\n\"}, \"GlobalConfigExtraMapData\": {\"type\": \"json\", \"default\": {}, \"description\": \"Map of extra global_config_settings data to set on each node.\"}, \"NetConfigDataLookup\": {\"type\": \"json\", \"default\": {}, \"description\": \"Configure os-net-config mappings for specific nodes Your environment file needs to look like:\\n  parameter_defaults:\\n    NetConfigDataLookup:\\n      node1:\\n        nic1: \\\"00:c8:7c:e6:f0:2e\\\"\\n      node2:\\n        nic1: \\\"00:18:7d:99:0c:b6\\\"\\n      node3:\\n        dmiString: \'system-uuid\'\\n        id: \'A8C85861-1B16-4803-8689-AFC62984F8F6\'\\n        nic1: em3\\n      # Dell PowerEdge\\n      nodegroup1:\\n        dmiString: \\\"system-product-name\\\"\\n        id: \\\"PowerEdge R630\\\"\\n        nic1: em3\\n        nic2: em1\\n        nic3: em2\\n      # Cisco UCS B200-M4\\\"\\n      nodegroup2:\\n        dmiString: \\\"system-product-name\\\"\\n        id: \\\"UCSB-B200-M4\\\"\\n        nic1: enp7s0\\n        nic2: enp6s0\\n\\nThis will result in the first node* entry where either a mac matches a local device or a DMI String matches the specified id being written as a mapping file for os-net-config. (/etc/os-net-config/mapping.yaml)\\n\"}, \"DnsServers\": {\"default\": [], \"description\": \"DNS servers to use for the Overcloud (2 max for some implementations). If not set the nameservers configured in the ctlplane subnet\'s dns_nameservers attribute will be used.\\n\", \"type\": \"comma_delimited_list\"}, \"RootStackName\": {\"description\": \"The name of the stack/plan.\", \"type\": \"string\"}, \"AdminPassword\": {\"description\": \"The password for the keystone admin account, used for monitoring, querying neutron etc.\", \"type\": \"string\", \"hidden\": true}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"Do not use deprecated params, they will be removed.\", \"parameters\": [\"DnsServers\", \"NovaComputeSchedulerHints\", \"NovaComputeExtraConfig\"]}], \"conditions\": {\"add_vips_to_etc_hosts\": {\"equals\": [{\"get_param\": \"AddVipsToEtcHosts\"}, true]}, \"control_fixed_ip_not_set\": {\"equals\": [{\"get_param\": \"ControlFixedIPs\"}, []]}, \"storage_virtual_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": \"StorageVirtualFixedIPs\"}, []]}}, \"storage_mgmt_virtual_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": \"StorageMgmtVirtualFixedIPs\"}, []]}}, \"internal_api_virtual_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": \"InternalApiVirtualFixedIPs\"}, []]}}, \"tenant_virtual_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": \"TenantVirtualFixedIPs\"}, []]}}, \"public_virtual_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": \"PublicVirtualFixedIPs\"}, []]}}, \"set_default_mysql_cell_internal\": {\"or\": [{\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}, {\"and\": [{\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, false]}, {\"equals\": [{\"get_param\": [\"EndpointMapOverride\", \"MysqlCellInternal\"]}, \"\"]}]}]}, \"set_default_nova_vnc_proxy_cell_public\": {\"or\": [{\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}, {\"and\": [{\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, false]}, {\"equals\": [{\"get_param\": [\"EndpointMapOverride\", \"NovaVNCProxyCellPublic\"]}, \"\"]}]}]}, \"set_default_nova_metadata_cell_internal\": {\"or\": [{\"equals\": [{\"get_param\": \"NovaLocalMetadataPerCell\"}, true]}, {\"and\": [{\"equals\": [{\"get_param\": \"NovaLocalMetadataPerCell\"}, false]}, {\"equals\": [{\"get_param\": [\"EndpointMapOverride\", \"NovaMetadataCellInternal\"]}, \"\"]}]}]}, \"dnsservers_set\": {\"not\": {\"equals\": [{\"get_param\": \"DnsServers\"}, []]}}}, \"resources\": {\"VipHosts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": [{\"str_replace\": {\"template\": \"IP  HOST\", \"params\": {\"IP\": {\"get_attr\": [\"VipMap\", \"net_ip_map\", \"ctlplane\"]}, \"HOST\": {\"get_param\": \"CloudNameCtlplane\"}}}}, {\"str_replace\": {\"template\": \"IP  HOST\", \"params\": {\"IP\": {\"get_attr\": [\"VipMap\", \"net_ip_map\", \"storage\"]}, \"HOST\": {\"get_param\": \"CloudNameStorage\"}}}}, {\"str_replace\": {\"template\": \"IP  HOST\", \"params\": {\"IP\": {\"get_attr\": [\"VipMap\", \"net_ip_map\", \"storage_mgmt\"]}, \"HOST\": {\"get_param\": \"CloudNameStorageManagement\"}}}}, {\"str_replace\": {\"template\": \"IP  HOST\", \"params\": {\"IP\": {\"get_attr\": [\"VipMap\", \"net_ip_map\", \"internal_api\"]}, \"HOST\": {\"get_param\": \"CloudNameInternal\"}}}}, {\"str_replace\": {\"template\": \"IP  HOST\", \"params\": {\"IP\": {\"get_attr\": [\"VipMap\", \"net_ip_map\", \"external\"]}, \"HOST\": {\"get_param\": \"CloudName\"}}}}]}}, \"NetCidrMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_merge\": [{\"get_attr\": [\"Networks\", \"net_cidr_map\"]}, {\"ctlplane\": {\"get_attr\": [\"ControlVirtualIP\", \"network\", \"tags\"]}}]}, {\"keys\": {\"ctlplane\": {\"get_param\": \"NeutronControlPlaneID\"}}}]}}}, \"NetIpVersionMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_merge\": [{\"get_attr\": [\"Networks\", \"net_ip_version_map\"]}, {\"ctlplane\": {\"get_attr\": [\"ControlVirtualIP\", \"subnets\", 0, \"ip_version\"]}}]}, {\"keys\": {\"ctlplane\": {\"get_param\": \"NeutronControlPlaneID\"}}}]}}}, \"ServiceNetMap\": {\"type\": \"OS::TripleO::ServiceNetMap\"}, \"EndpointMap\": {\"type\": \"OS::TripleO::EndpointMap\", \"properties\": {\"CloudEndpoints\": {\"ctlplane\": {\"get_param\": \"CloudNameCtlplane\"}, \"storage\": {\"get_param\": \"CloudNameStorage\"}, \"storage_mgmt\": {\"get_param\": \"CloudNameStorageManagement\"}, \"internal_api\": {\"get_param\": \"CloudNameInternal\"}, \"external\": {\"get_param\": \"CloudName\"}}, \"NetIpMap\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"ServiceNetMap\": {\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}}}, \"EndpointMapData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_attr\": [\"EndpointMap\", \"endpoint_map\"]}, {\"get_param\": \"EndpointMapOverride\"}, {\"if\": [\"set_default_mysql_cell_internal\", {\"MysqlCellInternal\": {\"get_attr\": [\"EndpointMap\", \"endpoint_map\", \"MysqlInternal\"]}}, {}]}, {\"if\": [\"set_default_nova_vnc_proxy_cell_public\", {\"NovaVNCProxyCellPublic\": {\"get_attr\": [\"EndpointMap\", \"endpoint_map\", \"NovaVNCProxyPublic\"]}}, {}]}, {\"if\": [\"set_default_nova_metadata_cell_internal\", {\"NovaMetadataCellInternal\": {\"get_attr\": [\"EndpointMap\", \"endpoint_map\", \"NovaMetadataInternal\"]}}, {}]}]}}}, \"NodeAdminUserData\": {\"type\": \"OS::TripleO::NodeAdminUserData\"}, \"NodeTimesyncUserData\": {\"type\": \"OS::TripleO::NodeTimesyncUserData\"}, \"NodeUserData\": {\"type\": \"OS::TripleO::NodeUserData\"}, \"ControllerServiceChain\": {\"type\": \"OS::TripleO::ControllerServices\", \"properties\": {\"Services\": {\"get_param\": \"ControllerServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"ControllerServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"map_merge\": [{\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, {\"get_param\": \"ControllerParameters\"}]}}}, \"ControllerServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"ControllerServiceChain\", \"role_data\"]}}}, \"ControllerConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"ControllerServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"ControllerServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"controllerExtraConfig\"}, {\"get_param\": \"ControllerExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"ControllerServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"ControllerServiceNames\", \"value\"]}}}}]}}}, \"ControllerServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"ControllerServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"ControllerServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"ControllerServiceNetMap\"}}}}]}}}, \"ControllerIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"Controller\", \"ip_address\"]}, \"StorageIpList\": {\"get_attr\": [\"Controller\", \"storage_ip_address\"]}, \"StorageMgmtIpList\": {\"get_attr\": [\"Controller\", \"storage_mgmt_ip_address\"]}, \"InternalApiIpList\": {\"get_attr\": [\"Controller\", \"internal_api_ip_address\"]}, \"TenantIpList\": {\"get_attr\": [\"Controller\", \"tenant_ip_address\"]}, \"ExternalIpList\": {\"get_attr\": [\"Controller\", \"external_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"tenant\", \"external\"], \"EnabledServices\": {\"get_attr\": [\"ControllerServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"ControllerServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"Controller\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"ControllerNetworkHostnameMap\", \"value\"]}}}, \"ControllerNetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"Controller\", \"hostname_map\"]}]}}}}, \"ControllerUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"ControllerRoleUserData\"}, \"type\": \"multipart\"}]}}, \"ControllerRoleUserData\": {\"type\": \"OS::TripleO::Controller::NodeUserData\"}, \"Controller\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"ControllerCount\"}, \"removal_policies\": {\"get_param\": \"ControllerRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"ControllerRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::Controller\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"ControllerServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"ControllerHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"ControllerSchedulerHints\": {\"map_merge\": [{\"get_param\": \"ControllerSchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"ControllerServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, {\"get_param\": \"ControllerParameters\"}]}, \"UserData\": {\"get_resource\": \"ControllerUserData\"}}}}}, \"CellControllerServiceChain\": {\"type\": \"OS::TripleO::CellControllerServices\", \"properties\": {\"Services\": {\"get_param\": \"CellControllerServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"CellControllerServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"map_merge\": [{\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, {\"get_param\": \"CellControllerParameters\"}]}}}, \"CellControllerServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"CellControllerServiceChain\", \"role_data\"]}}}, \"CellControllerConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"CellControllerServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"CellControllerServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"controllerExtraConfig\"}, {\"get_param\": \"CellControllerExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"CellControllerServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"CellControllerServiceNames\", \"value\"]}}}}]}}}, \"CellControllerServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"CellControllerServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"CellControllerServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"CellControllerServiceNetMap\"}}}}]}}}, \"CellControllerIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"CellController\", \"ip_address\"]}, \"StorageIpList\": {\"get_attr\": [\"CellController\", \"storage_ip_address\"]}, \"StorageMgmtIpList\": {\"get_attr\": [\"CellController\", \"storage_mgmt_ip_address\"]}, \"InternalApiIpList\": {\"get_attr\": [\"CellController\", \"internal_api_ip_address\"]}, \"TenantIpList\": {\"get_attr\": [\"CellController\", \"tenant_ip_address\"]}, \"ExternalIpList\": {\"get_attr\": [\"CellController\", \"external_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"tenant\", \"external\"], \"EnabledServices\": {\"get_attr\": [\"CellControllerServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"CellControllerServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"CellController\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"CellControllerNetworkHostnameMap\", \"value\"]}}}, \"CellControllerNetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"CellController\", \"hostname_map\"]}]}}}}, \"CellControllerUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"CellControllerRoleUserData\"}, \"type\": \"multipart\"}]}}, \"CellControllerRoleUserData\": {\"type\": \"OS::TripleO::CellController::NodeUserData\"}, \"CellController\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"CellControllerCount\"}, \"removal_policies\": {\"get_param\": \"CellControllerRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"CellControllerRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::CellController\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"CellControllerServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"CellControllerHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"CellControllerSchedulerHints\": {\"map_merge\": [{\"get_param\": \"CellControllerSchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"CellControllerServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, {\"get_param\": \"CellControllerParameters\"}]}, \"UserData\": {\"get_resource\": \"CellControllerUserData\"}}}}}, \"CellControllerComputeServiceChain\": {\"type\": \"OS::TripleO::CellControllerComputeServices\", \"properties\": {\"Services\": {\"get_param\": \"CellControllerComputeServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"CellControllerComputeServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"CellControllerCompute\", \"RoleParameters\": {\"map_merge\": [{\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, {\"get_param\": \"CellControllerComputeParameters\"}]}}}, \"CellControllerComputeServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"CellControllerComputeServiceChain\", \"role_data\"]}}}, \"CellControllerComputeConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"CellControllerComputeServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"CellControllerComputeServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"controllerExtraConfig\"}, {\"get_param\": \"CellControllerComputeExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"CellControllerComputeServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"CellControllerComputeServiceNames\", \"value\"]}}}}]}}}, \"CellControllerComputeServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"CellControllerComputeServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"CellControllerComputeServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"CellControllerComputeServiceNetMap\"}}}}]}}}, \"CellControllerComputeIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"CellControllerCompute\", \"ip_address\"]}, \"StorageIpList\": {\"get_attr\": [\"CellControllerCompute\", \"storage_ip_address\"]}, \"StorageMgmtIpList\": {\"get_attr\": [\"CellControllerCompute\", \"storage_mgmt_ip_address\"]}, \"InternalApiIpList\": {\"get_attr\": [\"CellControllerCompute\", \"internal_api_ip_address\"]}, \"TenantIpList\": {\"get_attr\": [\"CellControllerCompute\", \"tenant_ip_address\"]}, \"ExternalIpList\": {\"get_attr\": [\"CellControllerCompute\", \"external_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"tenant\", \"external\"], \"EnabledServices\": {\"get_attr\": [\"CellControllerComputeServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"CellControllerComputeServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"CellControllerCompute\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"CellControllerComputeNetworkHostnameMap\", \"value\"]}}}, \"CellControllerComputeNetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"CellControllerCompute\", \"hostname_map\"]}]}}}}, \"CellControllerComputeUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"CellControllerComputeRoleUserData\"}, \"type\": \"multipart\"}]}}, \"CellControllerComputeRoleUserData\": {\"type\": \"OS::TripleO::CellControllerCompute::NodeUserData\"}, \"CellControllerCompute\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"CellControllerComputeCount\"}, \"removal_policies\": {\"get_param\": \"CellControllerComputeRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"CellControllerComputeRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::CellControllerCompute\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"CellControllerComputeServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"CellControllerComputeHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"CellControllerComputeSchedulerHints\": {\"map_merge\": [{\"get_param\": \"CellControllerComputeSchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"CellControllerComputeServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, {\"get_param\": \"CellControllerComputeParameters\"}]}, \"UserData\": {\"get_resource\": \"CellControllerComputeUserData\"}}}}}, \"ComputeServiceChain\": {\"type\": \"OS::TripleO::ComputeServices\", \"properties\": {\"Services\": {\"get_param\": \"ComputeServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"ComputeServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"map_merge\": [{\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, {\"get_param\": \"ComputeParameters\"}]}}}, \"ComputeServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"ComputeServiceChain\", \"role_data\"]}}}, \"ComputeConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"ComputeServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"ComputeServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"NovaComputeExtraConfig\"}, {\"get_param\": \"ComputeExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"ComputeServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"ComputeServiceNames\", \"value\"]}}}}]}}}, \"ComputeServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"ComputeServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"ComputeServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"ComputeServiceNetMap\"}}}}]}}}, \"ComputeIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"Compute\", \"ip_address\"]}, \"StorageIpList\": {\"get_attr\": [\"Compute\", \"storage_ip_address\"]}, \"InternalApiIpList\": {\"get_attr\": [\"Compute\", \"internal_api_ip_address\"]}, \"TenantIpList\": {\"get_attr\": [\"Compute\", \"tenant_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"storage\", \"internal_api\", \"tenant\"], \"EnabledServices\": {\"get_attr\": [\"ComputeServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"ComputeServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"Compute\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"ComputeNetworkHostnameMap\", \"value\"]}}}, \"ComputeNetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"Compute\", \"hostname_map\"]}]}}}}, \"ComputeUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"ComputeRoleUserData\"}, \"type\": \"multipart\"}]}}, \"ComputeRoleUserData\": {\"type\": \"OS::TripleO::Compute::NodeUserData\"}, \"Compute\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"ComputeCount\"}, \"removal_policies\": {\"get_param\": \"ComputeRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"ComputeRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::Compute\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"ComputeServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"ComputeHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"ComputeSchedulerHints\": {\"map_merge\": [{\"get_param\": \"NovaComputeSchedulerHints\"}, {\"get_param\": \"ComputeSchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"ComputeServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, {\"get_param\": \"ComputeParameters\"}]}, \"UserData\": {\"get_resource\": \"ComputeUserData\"}}}}}, \"BlockStorageServiceChain\": {\"type\": \"OS::TripleO::BlockStorageServices\", \"properties\": {\"Services\": {\"get_param\": \"BlockStorageServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"BlockStorageServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"BlockStorage\", \"RoleParameters\": {\"map_merge\": [{}, {\"get_param\": \"BlockStorageParameters\"}]}}}, \"BlockStorageServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"BlockStorageServiceChain\", \"role_data\"]}}}, \"BlockStorageConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"BlockStorageServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"BlockStorageServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"BlockStorageExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"BlockStorageServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"BlockStorageServiceNames\", \"value\"]}}}}]}}}, \"BlockStorageServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"BlockStorageServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"BlockStorageServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"BlockStorageServiceNetMap\"}}}}]}}}, \"BlockStorageIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"BlockStorage\", \"ip_address\"]}, \"StorageIpList\": {\"get_attr\": [\"BlockStorage\", \"storage_ip_address\"]}, \"StorageMgmtIpList\": {\"get_attr\": [\"BlockStorage\", \"storage_mgmt_ip_address\"]}, \"InternalApiIpList\": {\"get_attr\": [\"BlockStorage\", \"internal_api_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"EnabledServices\": {\"get_attr\": [\"BlockStorageServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"BlockStorageServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"BlockStorage\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"BlockStorageNetworkHostnameMap\", \"value\"]}}}, \"BlockStorageNetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"BlockStorage\", \"hostname_map\"]}]}}}}, \"BlockStorageUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"BlockStorageRoleUserData\"}, \"type\": \"multipart\"}]}}, \"BlockStorageRoleUserData\": {\"type\": \"OS::TripleO::BlockStorage::NodeUserData\"}, \"BlockStorage\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"BlockStorageCount\"}, \"removal_policies\": {\"get_param\": \"BlockStorageRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"BlockStorageRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::BlockStorage\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"BlockStorageServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"BlockStorageHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"BlockStorageSchedulerHints\": {\"map_merge\": [{\"get_param\": \"BlockStorageSchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"BlockStorageServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{}, {\"get_param\": \"BlockStorageParameters\"}]}, \"UserData\": {\"get_resource\": \"BlockStorageUserData\"}}}}}, \"ObjectStorageServiceChain\": {\"type\": \"OS::TripleO::ObjectStorageServices\", \"properties\": {\"Services\": {\"get_param\": \"ObjectStorageServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"ObjectStorageServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"ObjectStorage\", \"RoleParameters\": {\"map_merge\": [{}, {\"get_param\": \"ObjectStorageParameters\"}]}}}, \"ObjectStorageServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"ObjectStorageServiceChain\", \"role_data\"]}}}, \"ObjectStorageConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"ObjectStorageServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"ObjectStorageServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"ObjectStorageExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"ObjectStorageServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"ObjectStorageServiceNames\", \"value\"]}}}}]}}}, \"ObjectStorageServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"ObjectStorageServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"ObjectStorageServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"ObjectStorageServiceNetMap\"}}}}]}}}, \"ObjectStorageIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"ObjectStorage\", \"ip_address\"]}, \"StorageIpList\": {\"get_attr\": [\"ObjectStorage\", \"storage_ip_address\"]}, \"StorageMgmtIpList\": {\"get_attr\": [\"ObjectStorage\", \"storage_mgmt_ip_address\"]}, \"InternalApiIpList\": {\"get_attr\": [\"ObjectStorage\", \"internal_api_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"EnabledServices\": {\"get_attr\": [\"ObjectStorageServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"ObjectStorageServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"ObjectStorage\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"ObjectStorageNetworkHostnameMap\", \"value\"]}}}, \"ObjectStorageNetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"ObjectStorage\", \"hostname_map\"]}]}}}}, \"ObjectStorageUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"ObjectStorageRoleUserData\"}, \"type\": \"multipart\"}]}}, \"ObjectStorageRoleUserData\": {\"type\": \"OS::TripleO::ObjectStorage::NodeUserData\"}, \"ObjectStorage\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"ObjectStorageCount\"}, \"removal_policies\": {\"get_param\": \"ObjectStorageRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"ObjectStorageRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::ObjectStorage\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"ObjectStorageServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"ObjectStorageHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"ObjectStorageSchedulerHints\": {\"map_merge\": [{\"get_param\": \"ObjectStorageSchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"ObjectStorageServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{}, {\"get_param\": \"ObjectStorageParameters\"}]}, \"UserData\": {\"get_resource\": \"ObjectStorageUserData\"}}}}}, \"CephStorageServiceChain\": {\"type\": \"OS::TripleO::CephStorageServices\", \"properties\": {\"Services\": {\"get_param\": \"CephStorageServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"CephStorageServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"CephStorage\", \"RoleParameters\": {\"map_merge\": [{}, {\"get_param\": \"CephStorageParameters\"}]}}}, \"CephStorageServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"CephStorageServiceChain\", \"role_data\"]}}}, \"CephStorageConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"CephStorageServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"CephStorageServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"CephStorageExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"CephStorageServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"CephStorageServiceNames\", \"value\"]}}}}]}}}, \"CephStorageServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"CephStorageServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"CephStorageServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"CephStorageServiceNetMap\"}}}}]}}}, \"CephStorageIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"CephStorage\", \"ip_address\"]}, \"StorageIpList\": {\"get_attr\": [\"CephStorage\", \"storage_ip_address\"]}, \"StorageMgmtIpList\": {\"get_attr\": [\"CephStorage\", \"storage_mgmt_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"storage\", \"storage_mgmt\"], \"EnabledServices\": {\"get_attr\": [\"CephStorageServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"CephStorageServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"CephStorage\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"CephStorageNetworkHostnameMap\", \"value\"]}}}, \"CephStorageNetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"CephStorage\", \"hostname_map\"]}]}}}}, \"CephStorageUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"CephStorageRoleUserData\"}, \"type\": \"multipart\"}]}}, \"CephStorageRoleUserData\": {\"type\": \"OS::TripleO::CephStorage::NodeUserData\"}, \"CephStorage\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"CephStorageCount\"}, \"removal_policies\": {\"get_param\": \"CephStorageRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"CephStorageRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::CephStorage\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"CephStorageServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"CephStorageHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"CephStorageSchedulerHints\": {\"map_merge\": [{\"get_param\": \"CephStorageSchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"CephStorageServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{}, {\"get_param\": \"CephStorageParameters\"}]}, \"UserData\": {\"get_resource\": \"CephStorageUserData\"}}}}}, \"NetworkerServiceChain\": {\"type\": \"OS::TripleO::NetworkerServices\", \"properties\": {\"Services\": {\"get_param\": \"NetworkerServices\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"NetworkerServiceNetMap\"}]}, \"ServiceData\": {\"net_cidr_map\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}, \"net_vip_map\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"net_ip_version_map\": {\"get_attr\": [\"NetIpVersionMapValue\", \"value\"]}, \"vip_subnet_map\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"RoleName\": \"Networker\", \"RoleParameters\": {\"map_merge\": [{\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, {\"get_param\": \"NetworkerParameters\"}]}}}, \"NetworkerServiceChainRoleData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"get_attr\": [\"NetworkerServiceChain\", \"role_data\"]}}}, \"NetworkerConfigData\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"service_configs\": {\"get_attr\": [\"NetworkerServiceConfigSettings\", \"value\"]}, \"service_names\": {\"get_attr\": [\"NetworkerServiceNames\", \"value\"]}, \"role_extraconfig\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::sensubility::subscriptions\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"tripleo_collectd_sensubility_subscriptions\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"monitoring_subscriptions\"]}}, {\"get_param\": \"NetworkerExtraConfig\"}]}, \"extraconfig\": {\"get_param\": \"ExtraConfig\"}, \"hieradata_files\": [\"%{::uuid}\", \"fqdn\", \"docker_puppet\", \"ansible_managed\", \"heat_config_%{::deploy_config_name}\", \"config_step\", \"role_extraconfig\", \"extraconfig\", \"pci_passthrough_whitelist\", \"service_names\", \"service_configs\", \"cloud_domain\", \"bootstrap_node\", \"all_nodes\", \"vip_data\", \"net_ip_map\", \"ovn_chassis_mac_map\", \"%{::osfamily}\", \"neutron_bigswitch_data\", \"upgrade\"]}}}, \"NetworkerServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_param\": \"GlobalConfigExtraMapData\"}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"config_settings\"]}, {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"yaql\": {\"expression\": \"let(root => $) -> $.data.map.items().where($[0] in coalesce($root.data.services, [])).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"map\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_config_settings\"]}]}}, \"services\": {\"get_attr\": [\"NetworkerServiceNames\", \"value\"]}}}}]}}}, \"NetworkerServiceNames\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"NetworkerServiceChain\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> distinct($.data.extra_services.items().where($[0] in coalesce($root.data.enabled_services, [])).select($[1]).flatten() + coalesce($root.data.enabled_services, []))\", \"data\": {\"enabled_services\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_names\"]}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"NetworkerServiceNetMapLower\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_param\": \"NetworkerServiceNetMap\"}}}}]}}}, \"NetworkerIpListMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpListMap\", \"properties\": {\"ControlPlaneIpList\": {\"get_attr\": [\"Networker\", \"ip_address\"]}, \"InternalApiIpList\": {\"get_attr\": [\"Networker\", \"internal_api_ip_address\"]}, \"TenantIpList\": {\"get_attr\": [\"Networker\", \"tenant_ip_address\"]}, \"RoleNetworks\": [\"ctlplane\", \"internal_api\", \"tenant\"], \"EnabledServices\": {\"get_attr\": [\"NetworkerServiceNames\", \"value\"]}, \"ServiceNetMap\": {\"get_attr\": [\"NetworkerServiceNetMapLower\", \"value\"]}, \"ServiceHostnameList\": {\"get_attr\": [\"Networker\", \"hostname\"]}, \"NetworkHostnameMap\": {\"get_attr\": [\"NetworkerNetworkHostnameMap\", \"value\"]}}}, \"NetworkerNetworkHostnameMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict($.data.where($ != null).flatten().selectMany($.items()).groupBy($[0], $[1]).select([$[0], $[1].flatten()]))\", \"data\": [{\"get_attr\": [\"Networker\", \"hostname_map\"]}]}}}}, \"NetworkerUserData\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"NodeAdminUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeTimesyncUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NodeUserData\"}, \"type\": \"multipart\"}, {\"config\": {\"get_resource\": \"NetworkerRoleUserData\"}, \"type\": \"multipart\"}]}}, \"NetworkerRoleUserData\": {\"type\": \"OS::TripleO::Networker::NodeUserData\"}, \"Networker\": {\"type\": \"OS::Heat::ResourceGroup\", \"depends_on\": \"Networks\", \"update_policy\": {\"batch_create\": {\"max_batch_size\": {\"get_param\": \"NodeCreateBatchSize\"}}}, \"properties\": {\"count\": {\"get_param\": \"NetworkerCount\"}, \"removal_policies\": {\"get_param\": \"NetworkerRemovalPolicies\"}, \"removal_policies_mode\": {\"get_param\": \"NetworkerRemovalPoliciesMode\"}, \"resource_def\": {\"type\": \"OS::TripleO::Networker\", \"properties\": {\"CloudDomain\": {\"get_param\": \"CloudDomain\"}, \"ServiceNetMap\": {\"map_merge\": [{\"get_attr\": [\"ServiceNetMap\", \"service_net_map\"]}, {\"get_param\": \"NetworkerServiceNetMap\"}]}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"Hostname\": {\"str_replace\": {\"template\": {\"get_param\": \"NetworkerHostnameFormat\"}, \"params\": {\"%stackname%\": {\"get_param\": \"OS::stack_name\"}}}}, \"NodeIndex\": \"%index%\", \"NetworkerSchedulerHints\": {\"map_merge\": [{\"get_param\": \"NetworkerSchedulerHints\"}]}, \"ServiceNames\": {\"get_attr\": [\"NetworkerServiceNames\", \"value\"]}, \"ServiceMetadataSettings\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"OVNBridgeMappings\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"config_settings\", \"ovn::controller::ovn_bridge_mappings\"]}, \"DeploymentServerBlacklistDict\": {\"get_attr\": [\"DeploymentServerBlacklistDict\", \"value\"]}, \"RoleParameters\": {\"map_merge\": [{\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, {\"get_param\": \"NetworkerParameters\"}]}, \"UserData\": {\"get_resource\": \"NetworkerUserData\"}}}}}, \"ControllerServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"Controller\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"Controller\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"CellControllerServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"CellController\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"CellController\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"CellControllerComputeServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"CellControllerCompute\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"CellControllerCompute\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"ComputeServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"Compute\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"Compute\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"BlockStorageServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"BlockStorage\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"BlockStorage\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"ObjectStorageServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"ObjectStorage\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"ObjectStorage\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"CephStorageServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"CephStorage\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"CephStorage\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"NetworkerServers\": {\"type\": \"OS::Heat::Value\", \"depends_on\": \"Networker\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"let(servers=>switch(isDict($.data.servers) => $.data.servers, true => {})) -> $servers.deleteAll($servers.keys().where($servers[$] = null))\", \"data\": {\"servers\": {\"get_attr\": [\"Networker\", \"attributes\", \"nova_server_resource\"]}}}}}}, \"ServerIdMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"server_ids\": {\"Controller\": {\"get_attr\": [\"Controller\", \"nova_server_resource\"]}, \"CellController\": {\"get_attr\": [\"CellController\", \"nova_server_resource\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerCompute\", \"nova_server_resource\"]}, \"Compute\": {\"get_attr\": [\"Compute\", \"nova_server_resource\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorage\", \"nova_server_resource\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorage\", \"nova_server_resource\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorage\", \"nova_server_resource\"]}, \"Networker\": {\"get_attr\": [\"Networker\", \"nova_server_resource\"]}}, \"bootstrap_server_id\": {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellControllerCompute\", \"nova_server_resource\"]}}}}}}, \"DeploymentServerBlacklistDict\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"repeat\": {\"template\": {\"hostname\": 1}, \"for_each\": {\"hostname\": {\"get_param\": \"DeploymentServerBlacklist\"}}}}}}}, \"HostsEntryValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"list_concat_unique\": {\"list_concat\": [[{\"get_param\": \"UndercloudHostsEntries\"}], [{\"if\": [\"add_vips_to_etc_hosts\", {\"get_attr\": [\"VipHosts\", \"value\"]}, []]}], {\"get_attr\": [\"Controller\", \"hosts_entry\"]}, {\"get_attr\": [\"CellController\", \"hosts_entry\"]}, {\"get_attr\": [\"CellControllerCompute\", \"hosts_entry\"]}, {\"get_attr\": [\"Compute\", \"hosts_entry\"]}, {\"get_attr\": [\"BlockStorage\", \"hosts_entry\"]}, {\"get_attr\": [\"ObjectStorage\", \"hosts_entry\"]}, {\"get_attr\": [\"CephStorage\", \"hosts_entry\"]}, {\"get_attr\": [\"Networker\", \"hosts_entry\"]}, [{\"get_param\": \"ExtraHostFileEntries\"}]]}}}}, \"CloudNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"cloud_name_storage\": {\"get_param\": \"CloudNameStorage\"}, \"cloud_name_storage_mgmt\": {\"get_param\": \"CloudNameStorageManagement\"}, \"cloud_name_internal_api\": {\"get_param\": \"CloudNameInternal\"}, \"cloud_name_external\": {\"get_param\": \"CloudName\"}, \"cloud_name_ctlplane\": {\"get_param\": \"CloudNameCtlplane\"}}}}, \"GlobalConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"global_config_settings\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"global_config_settings\"]}]}}}, \"Networks\": {\"type\": \"OS::TripleO::Network\", \"depends_on\": \"ServiceNetMap\", \"properties\": {\"CtlplaneNetworkCidrs\": {\"get_attr\": [\"ControlVirtualIP\", \"network\", \"tags\"]}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"firewall_frontend_rules\"]}]}, \"ssl_frontend\": {\"map_merge\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"firewall_ssl_frontend_rules\"]}]}, \"edge_frontend\": {\"map_merge\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"firewall_edge_frontend_rules\"]}]}, \"edge_ssl_frontend\": {\"map_merge\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"firewall_edge_ssl_frontend_rules\"]}]}}}}, \"ControllerGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"storage_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, \"storage_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"storage_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"storage_mgmt_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, \"storage_mgmt_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"storage_mgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"storage_mgmt_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"internal_api_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, \"internal_api_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"internal_api_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"internal_api_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"tenant_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}, \"tenant_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}, \"tenant_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}, \"external_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"gateway_ip\"]}, \"external_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"host_routes\"]}]}, \"external_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"cidr\"]}, 1]}, \"external_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"Storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"StorageMgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"InternalApi_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"Tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}, \"External_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"ControllerLocalMtu\"}, \"role_networks\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"ControllerNetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"primary\", \"controller\", \"external_bridge\"], \"service_net_map\": {\"get_attr\": [\"ControllerServiceNetMapLower\", \"value\"]}}}}, \"ControllerNetworkConfig\": {\"type\": \"OS::TripleO::Controller::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"StorageIpSubnet\": \"{{ storage_ip ~ \'/\' ~ storage_cidr }}\", \"StorageInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"StorageMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"StorageNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"StorageMgmtIpSubnet\": \"{{ storage_mgmt_ip ~ \'/\' ~ storage_mgmt_cidr }}\", \"StorageMgmtInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"StorageMgmtMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"StorageMgmtNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"InternalApiIpSubnet\": \"{{ internal_api_ip ~ \'/\' ~ internal_api_cidr }}\", \"InternalApiInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"InternalApiMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"InternalApiNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"TenantIpSubnet\": \"{{ tenant_ip ~ \'/\' ~ tenant_cidr }}\", \"TenantInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"TenantMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"TenantNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}, \"ExternalIpSubnet\": \"{{ external_ip ~ \'/\' ~ external_cidr }}\", \"ExternalInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"host_routes\"]}]}, \"ExternalMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"ExternalNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"tags\"]}}}}}, \"CellControllerGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"storage_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, \"storage_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"storage_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"storage_mgmt_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, \"storage_mgmt_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"storage_mgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"storage_mgmt_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"internal_api_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, \"internal_api_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"internal_api_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"internal_api_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"tenant_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}, \"tenant_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}, \"tenant_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}, \"external_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"gateway_ip\"]}, \"external_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"host_routes\"]}]}, \"external_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"cidr\"]}, 1]}, \"external_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"Storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"StorageMgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"InternalApi_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"Tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}, \"External_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"CellControllerLocalMtu\"}, \"role_networks\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"CellControllerNetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"primary\", \"controller\"], \"service_net_map\": {\"get_attr\": [\"CellControllerServiceNetMapLower\", \"value\"]}}}}, \"CellControllerNetworkConfig\": {\"type\": \"OS::TripleO::CellController::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"StorageIpSubnet\": \"{{ storage_ip ~ \'/\' ~ storage_cidr }}\", \"StorageInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"StorageMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"StorageNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"StorageMgmtIpSubnet\": \"{{ storage_mgmt_ip ~ \'/\' ~ storage_mgmt_cidr }}\", \"StorageMgmtInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"StorageMgmtMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"StorageMgmtNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"InternalApiIpSubnet\": \"{{ internal_api_ip ~ \'/\' ~ internal_api_cidr }}\", \"InternalApiInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"InternalApiMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"InternalApiNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"TenantIpSubnet\": \"{{ tenant_ip ~ \'/\' ~ tenant_cidr }}\", \"TenantInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"TenantMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"TenantNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}, \"ExternalIpSubnet\": \"{{ external_ip ~ \'/\' ~ external_cidr }}\", \"ExternalInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"host_routes\"]}]}, \"ExternalMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"ExternalNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"tags\"]}}}}}, \"CellControllerComputeGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"storage_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, \"storage_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"storage_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"storage_mgmt_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, \"storage_mgmt_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"storage_mgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"storage_mgmt_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"internal_api_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, \"internal_api_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"internal_api_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"internal_api_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"tenant_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}, \"tenant_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}, \"tenant_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}, \"external_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"gateway_ip\"]}, \"external_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"host_routes\"]}]}, \"external_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"cidr\"]}, 1]}, \"external_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"Storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"StorageMgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"InternalApi_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"Tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}, \"External_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"CellControllerComputeLocalMtu\"}, \"role_networks\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"CellControllerComputeNetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"primary\", \"controller\", \"external_bridge\"], \"service_net_map\": {\"get_attr\": [\"CellControllerComputeServiceNetMapLower\", \"value\"]}}}}, \"CellControllerComputeNetworkConfig\": {\"type\": \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"StorageIpSubnet\": \"{{ storage_ip ~ \'/\' ~ storage_cidr }}\", \"StorageInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"StorageMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"StorageNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"StorageMgmtIpSubnet\": \"{{ storage_mgmt_ip ~ \'/\' ~ storage_mgmt_cidr }}\", \"StorageMgmtInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"StorageMgmtMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"StorageMgmtNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"InternalApiIpSubnet\": \"{{ internal_api_ip ~ \'/\' ~ internal_api_cidr }}\", \"InternalApiInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"InternalApiMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"InternalApiNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"TenantIpSubnet\": \"{{ tenant_ip ~ \'/\' ~ tenant_cidr }}\", \"TenantInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"TenantMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"TenantNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}, \"ExternalIpSubnet\": \"{{ external_ip ~ \'/\' ~ external_cidr }}\", \"ExternalInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"host_routes\"]}]}, \"ExternalMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"ExternalNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"tags\"]}}}}}, \"ComputeGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"storage_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, \"storage_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"storage_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"internal_api_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, \"internal_api_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"internal_api_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"internal_api_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"tenant_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}, \"tenant_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}, \"tenant_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"Storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"InternalApi_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"Tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"ComputeLocalMtu\"}, \"role_networks\": [\"Storage\", \"InternalApi\", \"Tenant\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"ComputeNetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"compute\", \"external_bridge\"], \"service_net_map\": {\"get_attr\": [\"ComputeServiceNetMapLower\", \"value\"]}}}}, \"ComputeNetworkConfig\": {\"type\": \"OS::TripleO::Compute::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"StorageIpSubnet\": \"{{ storage_ip ~ \'/\' ~ storage_cidr }}\", \"StorageInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"StorageMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"StorageNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"InternalApiIpSubnet\": \"{{ internal_api_ip ~ \'/\' ~ internal_api_cidr }}\", \"InternalApiInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"InternalApiMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"InternalApiNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"TenantIpSubnet\": \"{{ tenant_ip ~ \'/\' ~ tenant_cidr }}\", \"TenantInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"TenantMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"TenantNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}}}, \"BlockStorageGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"storage_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, \"storage_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"storage_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"storage_mgmt_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, \"storage_mgmt_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"storage_mgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"storage_mgmt_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"internal_api_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, \"internal_api_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"internal_api_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"internal_api_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"Storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"StorageMgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"InternalApi_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"BlockStorageLocalMtu\"}, \"role_networks\": [\"Storage\", \"StorageMgmt\", \"InternalApi\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"BlockStorageNetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"storage\"], \"service_net_map\": {\"get_attr\": [\"BlockStorageServiceNetMapLower\", \"value\"]}}}}, \"BlockStorageNetworkConfig\": {\"type\": \"OS::TripleO::BlockStorage::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"StorageIpSubnet\": \"{{ storage_ip ~ \'/\' ~ storage_cidr }}\", \"StorageInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"StorageMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"StorageNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"StorageMgmtIpSubnet\": \"{{ storage_mgmt_ip ~ \'/\' ~ storage_mgmt_cidr }}\", \"StorageMgmtInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"StorageMgmtMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"StorageMgmtNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"InternalApiIpSubnet\": \"{{ internal_api_ip ~ \'/\' ~ internal_api_cidr }}\", \"InternalApiInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"InternalApiMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"InternalApiNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}}}, \"ObjectStorageGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"storage_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, \"storage_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"storage_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"storage_mgmt_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, \"storage_mgmt_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"storage_mgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"storage_mgmt_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"internal_api_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, \"internal_api_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"internal_api_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"internal_api_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"Storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"StorageMgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"InternalApi_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"ObjectStorageLocalMtu\"}, \"role_networks\": [\"Storage\", \"StorageMgmt\", \"InternalApi\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"ObjectStorageNetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"storage\"], \"service_net_map\": {\"get_attr\": [\"ObjectStorageServiceNetMapLower\", \"value\"]}}}}, \"ObjectStorageNetworkConfig\": {\"type\": \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"StorageIpSubnet\": \"{{ storage_ip ~ \'/\' ~ storage_cidr }}\", \"StorageInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"StorageMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"StorageNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"StorageMgmtIpSubnet\": \"{{ storage_mgmt_ip ~ \'/\' ~ storage_mgmt_cidr }}\", \"StorageMgmtInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"StorageMgmtMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"StorageMgmtNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"InternalApiIpSubnet\": \"{{ internal_api_ip ~ \'/\' ~ internal_api_cidr }}\", \"InternalApiInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"InternalApiMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"InternalApiNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}}}, \"CephStorageGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"storage_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, \"storage_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"storage_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"storage_mgmt_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, \"storage_mgmt_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"storage_mgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}, \"storage_mgmt_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"Storage_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"cidr\"]}, 1]}, \"StorageMgmt_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"CephStorageLocalMtu\"}, \"role_networks\": [\"Storage\", \"StorageMgmt\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"CephStorageNetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"ceph\", \"storage\"], \"service_net_map\": {\"get_attr\": [\"CephStorageServiceNetMapLower\", \"value\"]}}}}, \"CephStorageNetworkConfig\": {\"type\": \"OS::TripleO::CephStorage::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"StorageIpSubnet\": \"{{ storage_ip ~ \'/\' ~ storage_cidr }}\", \"StorageInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"host_routes\"]}]}, \"StorageMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"StorageNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"tags\"]}}}, \"StorageMgmtIpSubnet\": \"{{ storage_mgmt_ip ~ \'/\' ~ storage_mgmt_cidr }}\", \"StorageMgmtInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"host_routes\"]}]}, \"StorageMgmtMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"StorageMgmtNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"tags\"]}}}}}, \"NetworkerGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"ctlplane_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"ctlplane_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ctlplane_dns_nameservers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"ctlplane_subnet_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ctlplane_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"storage_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"network\", \"mtu\"]}, \"storage_mgmt_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"network\", \"mtu\"]}, \"internal_api_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"tenant_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"external_mtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"network\", \"mtu\"]}, \"internal_api_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, \"internal_api_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"internal_api_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"internal_api_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"tenant_gateway_ip\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}, \"tenant_host_routes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}, \"tenant_vlan_id\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}, \"network_cidrs\": {\"InternalApi_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"cidr\"]}, 1]}, \"Tenant_cidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"cidr\"]}, 1]}}, \"dns_search_domains\": {\"get_param\": \"DnsSearchDomains\"}, \"bond_interface_ovs_options\": {\"get_param\": \"BondInterfaceOvsOptions\"}, \"local_mtu\": {\"get_param\": \"NetworkerLocalMtu\"}, \"role_networks\": [\"InternalApi\", \"Tenant\"], \"networks_lower\": {\"Storage\": \"storage\", \"StorageMgmt\": \"storage_mgmt\", \"InternalApi\": \"internal_api\", \"Tenant\": \"tenant\", \"External\": \"external\"}, \"networks_all\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"service_metadata_settings\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"service_metadata_settings\"]}, \"tripleo_network_config_template\": {\"get_param\": \"NetworkerNetworkConfigTemplate\"}, \"tripleo_network_config_with_ansible\": {\"get_param\": \"NetworkConfigWithAnsible\"}, \"default_route_networks\": [\"ControlPlane\"], \"networks_skip_config\": [], \"tripleo_firewall_rules\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"firewall_rules\"]}, \"tripleo_firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"tripleo_firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"tripleo_firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"tripleo_firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"role_tags\": [\"external_bridge\"], \"service_net_map\": {\"get_attr\": [\"NetworkerServiceNetMapLower\", \"value\"]}}}}, \"NetworkerNetworkConfig\": {\"type\": \"OS::TripleO::Networker::Net::SoftwareConfig\", \"properties\": {\"ControlPlaneIp\": \"{{ ctlplane_ip }}\", \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"cidr\"]}, 1]}, \"ControlPlaneDefaultRoute\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"gateway_ip\"]}, \"ControlPlaneStaticRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"host_routes\"]}, [{\"default\": true, \"next_hop\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"gateway_ip\"]}}]]}, \"ControlPlaneMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"network\", \"mtu\"]}, \"DnsServers\": {\"if\": [\"dnsservers_set\", {\"get_param\": \"DnsServers\"}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"dns_nameservers\"]}]}, \"InternalApiIpSubnet\": \"{{ internal_api_ip ~ \'/\' ~ internal_api_cidr }}\", \"InternalApiInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"host_routes\"]}]}, \"InternalApiMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"network\", \"mtu\"]}, \"InternalApiNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"tags\"]}}}, \"TenantIpSubnet\": \"{{ tenant_ip ~ \'/\' ~ tenant_cidr }}\", \"TenantInterfaceRoutes\": {\"list_concat_unique\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"host_routes\"]}]}, \"TenantMtu\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"network\", \"mtu\"]}, \"TenantNetworkVlanID\": {\"yaql\": {\"expression\": \"switch(not isList($.data) => 1,\\n       not $.data.where($.startsWith(\'tripleo_vlan_id\')).len() => 1,\\n       true => int($.data.where($.startsWith(\'tripleo_vlan_id\')).first().split(\'=\').last()))\\n\", \"data\": {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"tags\"]}}}}}, \"ControlVirtualIP\": {\"depends_on\": \"ServiceNetMap\", \"type\": \"OS::TripleO::Network::Ports::ControlPlaneVipPort\", \"properties\": {\"name\": \"control_virtual_ip\", \"dns_name\": {\"str_split\": [\".\", {\"get_param\": \"CloudNameCtlplane\"}, 0]}, \"network\": {\"get_param\": \"NeutronControlPlaneID\"}, \"fixed_ips\": {\"if\": [\"control_fixed_ip_not_set\", [{\"subnet\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"ctlplane\"]}}], {\"get_param\": \"ControlFixedIPs\"}]}, \"replacement_policy\": \"AUTO\", \"tags\": [\"tripleo_vip_net=ctlplane\", {\"str_replace\": {\"template\": \"tripleo_stack_name=$STACK_NAME\", \"params\": {\"$STACK_NAME\": {\"get_param\": \"OS::stack_name\"}}}}]}}, \"StorageVirtualIP\": {\"depends_on\": [\"Networks\", \"ServiceNetMap\"], \"type\": \"OS::TripleO::Network::Ports::StorageVipPort\", \"properties\": {\"ControlPlaneIP\": {\"get_attr\": [\"ControlVirtualIP\", \"fixed_ips\", 0, \"ip_address\"]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"ctlplane\"]}, \"cidr\"]}, 1]}, \"PortName\": \"storage_virtual_ip\", \"DnsName\": {\"str_split\": [\".\", {\"get_param\": \"CloudNameStorage\"}, 0]}, \"FixedIPs\": {\"if\": [\"storage_virtual_fixed_ip_set\", {\"get_param\": \"StorageVirtualFixedIPs\"}, [{\"subnet\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"Storage\"]}}]]}, \"IsVirtualIP\": true}}, \"StorageMgmtVirtualIP\": {\"depends_on\": [\"Networks\", \"ServiceNetMap\"], \"type\": \"OS::TripleO::Network::Ports::StorageMgmtVipPort\", \"properties\": {\"ControlPlaneIP\": {\"get_attr\": [\"ControlVirtualIP\", \"fixed_ips\", 0, \"ip_address\"]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"ctlplane\"]}, \"cidr\"]}, 1]}, \"PortName\": \"storage_mgmt_virtual_ip\", \"DnsName\": {\"str_split\": [\".\", {\"get_param\": \"CloudNameStorageManagement\"}, 0]}, \"FixedIPs\": {\"if\": [\"storage_mgmt_virtual_fixed_ip_set\", {\"get_param\": \"StorageMgmtVirtualFixedIPs\"}, [{\"subnet\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"StorageMgmt\"]}}]]}, \"IsVirtualIP\": true}}, \"InternalApiVirtualIP\": {\"depends_on\": [\"Networks\", \"ServiceNetMap\"], \"type\": \"OS::TripleO::Network::Ports::InternalApiVipPort\", \"properties\": {\"ControlPlaneIP\": {\"get_attr\": [\"ControlVirtualIP\", \"fixed_ips\", 0, \"ip_address\"]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"ctlplane\"]}, \"cidr\"]}, 1]}, \"PortName\": \"internal_api_virtual_ip\", \"DnsName\": {\"str_split\": [\".\", {\"get_param\": \"CloudNameInternal\"}, 0]}, \"FixedIPs\": {\"if\": [\"internal_api_virtual_fixed_ip_set\", {\"get_param\": \"InternalApiVirtualFixedIPs\"}, [{\"subnet\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"InternalApi\"]}}]]}, \"IsVirtualIP\": true}}, \"PublicVirtualIP\": {\"depends_on\": [\"Networks\", \"ServiceNetMap\"], \"type\": \"OS::TripleO::Network::Ports::ExternalVipPort\", \"properties\": {\"ControlPlaneIP\": {\"get_attr\": [\"ControlVirtualIP\", \"fixed_ips\", 0, \"ip_address\"]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"ctlplane\"]}, \"cidr\"]}, 1]}, \"PortName\": \"external_virtual_ip\", \"DnsName\": {\"str_split\": [\".\", {\"get_param\": \"CloudName\"}, 0]}, \"FixedIPs\": {\"if\": [\"public_virtual_fixed_ip_set\", {\"get_param\": \"PublicVirtualFixedIPs\"}, [{\"subnet\": {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"External\"]}}]]}, \"IsVirtualIP\": true}}, \"VipMap\": {\"type\": \"OS::TripleO::Network::Ports::NetVipMap\", \"properties\": {\"ControlPlaneIp\": {\"get_attr\": [\"ControlVirtualIP\", \"fixed_ips\", 0, \"ip_address\"]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_attr\": [\"ServiceNetMap\", \"vip_subnet_map\", \"ctlplane\"]}, \"cidr\"]}, 1]}, \"StorageIp\": {\"get_attr\": [\"StorageVirtualIP\", \"ip_address\"]}, \"StorageIpUri\": {\"get_attr\": [\"StorageVirtualIP\", \"ip_address_uri\"]}, \"StorageMgmtIp\": {\"get_attr\": [\"StorageMgmtVirtualIP\", \"ip_address\"]}, \"StorageMgmtIpUri\": {\"get_attr\": [\"StorageMgmtVirtualIP\", \"ip_address_uri\"]}, \"InternalApiIp\": {\"get_attr\": [\"InternalApiVirtualIP\", \"ip_address\"]}, \"InternalApiIpUri\": {\"get_attr\": [\"InternalApiVirtualIP\", \"ip_address_uri\"]}, \"ExternalIp\": {\"get_attr\": [\"PublicVirtualIP\", \"ip_address\"]}, \"ExternalIpUri\": {\"get_attr\": [\"PublicVirtualIP\", \"ip_address_uri\"]}}, \"depends_on\": \"ServiceNetMap\"}, \"AllNodesExtraConfig\": {\"type\": \"OS::TripleO::AllNodesExtraConfig\", \"properties\": {\"servers\": {\"Controller\": {\"get_attr\": [\"ControllerServers\", \"value\"]}, \"CellController\": {\"get_attr\": [\"CellControllerServers\", \"value\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerComputeServers\", \"value\"]}, \"Compute\": {\"get_attr\": [\"ComputeServers\", \"value\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorageServers\", \"value\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorageServers\", \"value\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorageServers\", \"value\"]}, \"Networker\": {\"get_attr\": [\"NetworkerServers\", \"value\"]}}}}, \"BlacklistedIpAddresses\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"list_concat\": [{\"get_attr\": [\"Controller\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"CellController\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"CellControllerCompute\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"Compute\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"BlockStorage\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"ObjectStorage\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"CephStorage\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"Networker\", \"blacklist_ip_address\"]}]}}}, \"AnsibleHostVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"Controller\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"Controller\", \"ansible_host_vars_map\"]}]}}, \"CellController\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"CellController\", \"ansible_host_vars_map\"]}]}}, \"CellControllerCompute\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"CellControllerCompute\", \"ansible_host_vars_map\"]}]}}, \"Compute\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"Compute\", \"ansible_host_vars_map\"]}]}}, \"BlockStorage\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"BlockStorage\", \"ansible_host_vars_map\"]}]}}, \"ObjectStorage\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"ObjectStorage\", \"ansible_host_vars_map\"]}]}}, \"CephStorage\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"CephStorage\", \"ansible_host_vars_map\"]}]}}, \"Networker\": {\"map_merge\": {\"list_concat\": [{\"get_attr\": [\"Networker\", \"ansible_host_vars_map\"]}]}}}}}, \"BlacklistedHostnames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"list_concat\": [{\"get_attr\": [\"Controller\", \"blacklist_hostname\"]}, {\"get_attr\": [\"CellController\", \"blacklist_hostname\"]}, {\"get_attr\": [\"CellControllerCompute\", \"blacklist_hostname\"]}, {\"get_attr\": [\"Compute\", \"blacklist_hostname\"]}, {\"get_attr\": [\"BlockStorage\", \"blacklist_hostname\"]}, {\"get_attr\": [\"ObjectStorage\", \"blacklist_hostname\"]}, {\"get_attr\": [\"CephStorage\", \"blacklist_hostname\"]}, {\"get_attr\": [\"Networker\", \"blacklist_hostname\"]}]}}}, \"AllNodesDeploySteps\": {\"type\": \"OS::TripleO::PostDeploySteps\", \"depends_on\": [\"AllNodesExtraConfig\"], \"properties\": {\"servers\": {\"Controller\": {\"get_attr\": [\"ControllerServers\", \"value\"]}, \"CellController\": {\"get_attr\": [\"CellControllerServers\", \"value\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerComputeServers\", \"value\"]}, \"Compute\": {\"get_attr\": [\"ComputeServers\", \"value\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorageServers\", \"value\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorageServers\", \"value\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorageServers\", \"value\"]}, \"Networker\": {\"get_attr\": [\"NetworkerServers\", \"value\"]}}, \"EndpointMap\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}, \"role_data\": {\"Controller\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\"]}, \"CellController\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\"]}, \"Compute\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\"]}, \"Networker\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\"]}}, \"ControllerCount\": {\"get_param\": \"ControllerCount\"}, \"CellControllerCount\": {\"get_param\": \"CellControllerCount\"}, \"CellControllerComputeCount\": {\"get_param\": \"CellControllerComputeCount\"}, \"ComputeCount\": {\"get_param\": \"ComputeCount\"}, \"BlockStorageCount\": {\"get_param\": \"BlockStorageCount\"}, \"ObjectStorageCount\": {\"get_param\": \"ObjectStorageCount\"}, \"CephStorageCount\": {\"get_param\": \"CephStorageCount\"}, \"NetworkerCount\": {\"get_param\": \"NetworkerCount\"}, \"ServiceNetMapLower\": {\"get_attr\": [\"ServiceNetMap\", \"service_net_map_lower\"]}, \"PingTestGatewayIPsMap\": {\"Controller\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ControllerControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"gateway_ip\"]}]}}, \"CellController\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"gateway_ip\"]}]}}, \"CellControllerCompute\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CellControllerComputeControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"external\", \"subnets\", \"external_subnet\", \"gateway_ip\"]}]}}, \"Compute\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}]}}, \"BlockStorage\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"BlockStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}]}}, \"ObjectStorage\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"ObjectStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}]}}, \"CephStorage\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"CephStorageControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage\", \"subnets\", \"storage_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"storage_mgmt\", \"subnets\", \"storage_mgmt_subnet\", \"gateway_ip\"]}]}}, \"Networker\": {\"yaql\": {\"expression\": \"list($.data.where($ != null and len($) > 0)).flatten()\", \"data\": [{\"get_attr\": [\"Networks\", \"net_attributes_map\", \"ctlplane\", \"subnets\", {\"get_param\": \"NetworkerControlPlaneSubnet\"}, \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"internal_api\", \"subnets\", \"internal_api_subnet\", \"gateway_ip\"]}, {\"get_attr\": [\"Networks\", \"net_attributes_map\", \"tenant\", \"subnets\", \"tenant_subnet\", \"gateway_ip\"]}]}}}, \"PingTestIpsMap\": {\"Controller\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Controller\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Controller\", \"storage_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Controller\", \"storage_mgmt_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Controller\", \"internal_api_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Controller\", \"tenant_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Controller\", \"external_ip_address\"]}}}]]}, \"CellController\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellController\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellController\", \"storage_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellController\", \"storage_mgmt_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellController\", \"internal_api_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellController\", \"tenant_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellController\", \"external_ip_address\"]}}}]]}, \"CellControllerCompute\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellControllerCompute\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellControllerCompute\", \"storage_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellControllerCompute\", \"storage_mgmt_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellControllerCompute\", \"internal_api_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellControllerCompute\", \"tenant_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CellControllerCompute\", \"external_ip_address\"]}}}]]}, \"Compute\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Compute\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Compute\", \"storage_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Compute\", \"internal_api_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Compute\", \"tenant_ip_address\"]}}}]]}, \"BlockStorage\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"BlockStorage\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"BlockStorage\", \"storage_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"BlockStorage\", \"storage_mgmt_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"BlockStorage\", \"internal_api_ip_address\"]}}}]]}, \"ObjectStorage\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"ObjectStorage\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"ObjectStorage\", \"storage_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"ObjectStorage\", \"storage_mgmt_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"ObjectStorage\", \"internal_api_ip_address\"]}}}]]}, \"CephStorage\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CephStorage\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CephStorage\", \"storage_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"CephStorage\", \"storage_mgmt_ip_address\"]}}}]]}, \"Networker\": {\"list_join\": [\" \", [{\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Networker\", \"ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Networker\", \"internal_api_ip_address\"]}}}, {\"yaql\": {\"expression\": \"coalesce($.data, []).first(null)\", \"data\": {\"get_attr\": [\"Networker\", \"tenant_ip_address\"]}}}]]}}, \"HostsEntry\": {\"get_attr\": [\"HostsEntryValue\", \"value\"]}, \"EnabledServices\": {\"list_concat\": [{\"get_attr\": [\"ControllerServiceNames\", \"value\"]}, {\"get_attr\": [\"CellControllerServiceNames\", \"value\"]}, {\"get_attr\": [\"CellControllerComputeServiceNames\", \"value\"]}, {\"get_attr\": [\"ComputeServiceNames\", \"value\"]}, {\"get_attr\": [\"BlockStorageServiceNames\", \"value\"]}, {\"get_attr\": [\"ObjectStorageServiceNames\", \"value\"]}, {\"get_attr\": [\"CephStorageServiceNames\", \"value\"]}, {\"get_attr\": [\"NetworkerServiceNames\", \"value\"]}]}, \"ControlVirtualIP\": {\"get_attr\": [\"ControlVirtualIP\", \"fixed_ips\", 0, \"ip_address\"]}, \"EnabledNetworks\": [\"Storage\", \"StorageMgmt\", \"InternalApi\", \"Tenant\", \"External\"], \"NetVipMap\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}, \"CloudNames\": {\"get_attr\": [\"CloudNames\", \"value\"]}, \"UndercloudHostsEntries\": {\"get_param\": \"UndercloudHostsEntries\"}, \"ExtraHostsEntries\": {\"get_param\": \"ExtraHostFileEntries\"}, \"VipHostsEntries\": {\"if\": [\"add_vips_to_etc_hosts\", {\"get_attr\": [\"VipHosts\", \"value\"]}, []]}, \"KeystoneResourcesConfigs\": {\"map_merge\": [{\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\", \"keystone_resources\"]}, {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\", \"keystone_resources\"]}, {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\", \"keystone_resources\"]}, {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\", \"keystone_resources\"]}, {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\", \"keystone_resources\"]}, {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\", \"keystone_resources\"]}, {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\", \"keystone_resources\"]}, {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\", \"keystone_resources\"]}]}, \"NetCidrMap\": {\"get_attr\": [\"NetCidrMapValue\", \"value\"]}}}}, \"outputs\": {\"ManagedEndpoints\": {\"description\": \"Asserts that the keystone endpoints have been provisioned.\", \"value\": true}, \"KeystoneURL\": {\"description\": \"URL for the Overcloud Keystone service\", \"value\": {\"get_attr\": [\"EndpointMapData\", \"value\", \"KeystonePublic\", \"uri_no_suffix\"]}}, \"KeystoneAdminVip\": {\"description\": \"Keystone Admin VIP endpoint\", \"value\": {\"get_attr\": [\"VipMap\", \"net_ip_map\", {\"get_attr\": [\"ServiceNetMap\", \"service_net_map\", \"KeystoneAdminApiNetwork\"]}]}}, \"EndpointMap\": {\"description\": \"Mapping of the resources with the needed info for their endpoints.\\nThis includes the protocol used, the IP, port and also a full\\nrepresentation of the URI.\\n\", \"value\": {\"get_attr\": [\"EndpointMapData\", \"value\"]}}, \"HostsEntry\": {\"description\": \"The content that should be appended to your /etc/hosts if you want to get\\nhostname-based access to the deployed nodes (useful for testing without\\nsetting up a DNS).\\n\", \"value\": {\"list_concat_unique\": [{\"get_attr\": [\"HostsEntryValue\", \"value\"]}, {\"get_attr\": [\"VipHosts\", \"value\"]}]}}, \"EnabledServices\": {\"description\": \"The services enabled on each role\", \"value\": {\"Controller\": {\"get_attr\": [\"ControllerServiceNames\", \"value\"]}, \"CellController\": {\"get_attr\": [\"CellControllerServiceNames\", \"value\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerComputeServiceNames\", \"value\"]}, \"Compute\": {\"get_attr\": [\"ComputeServiceNames\", \"value\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorageServiceNames\", \"value\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorageServiceNames\", \"value\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorageServiceNames\", \"value\"]}, \"Networker\": {\"get_attr\": [\"NetworkerServiceNames\", \"value\"]}}}, \"RoleData\": {\"description\": \"The configuration data associated with each role\", \"value\": {\"Controller\": {\"get_attr\": [\"ControllerServiceChainRoleData\", \"value\"]}, \"CellController\": {\"get_attr\": [\"CellControllerServiceChainRoleData\", \"value\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerComputeServiceChainRoleData\", \"value\"]}, \"Compute\": {\"get_attr\": [\"ComputeServiceChainRoleData\", \"value\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorageServiceChainRoleData\", \"value\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorageServiceChainRoleData\", \"value\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorageServiceChainRoleData\", \"value\"]}, \"Networker\": {\"get_attr\": [\"NetworkerServiceChainRoleData\", \"value\"]}}}, \"RoleConfig\": {\"description\": \"The configuration workflows associated with each role\", \"value\": {\"get_attr\": [\"AllNodesDeploySteps\", \"RoleConfig\"]}}, \"RoleNetIpMap\": {\"description\": \"Mapping of each network to a list of IPs for each role\", \"value\": {\"Controller\": {\"get_attr\": [\"ControllerIpListMap\", \"net_ip_map\"]}, \"CellController\": {\"get_attr\": [\"CellControllerIpListMap\", \"net_ip_map\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerComputeIpListMap\", \"net_ip_map\"]}, \"Compute\": {\"get_attr\": [\"ComputeIpListMap\", \"net_ip_map\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorageIpListMap\", \"net_ip_map\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorageIpListMap\", \"net_ip_map\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorageIpListMap\", \"net_ip_map\"]}, \"Networker\": {\"get_attr\": [\"NetworkerIpListMap\", \"net_ip_map\"]}}}, \"RoleGroupVars\": {\"description\": \"Mapping of roles to ansible group_vars to be applied config in those roles\", \"value\": {\"Controller\": {\"map_merge\": [{\"get_attr\": [\"ControllerGroupVars\", \"value\"]}, {\"get_attr\": [\"ControllerConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"ControllerAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"ControllerMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"ControllerNetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"ControllerUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"ControllerIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"ControllerNetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"ControllerExtraGroupVars\"}]}, \"CellController\": {\"map_merge\": [{\"get_attr\": [\"CellControllerGroupVars\", \"value\"]}, {\"get_attr\": [\"CellControllerConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"CellControllerAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"CellControllerMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"CellControllerNetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"CellControllerUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"CellControllerIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"CellControllerNetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"CellControllerExtraGroupVars\"}]}, \"CellControllerCompute\": {\"map_merge\": [{\"get_attr\": [\"CellControllerComputeGroupVars\", \"value\"]}, {\"get_attr\": [\"CellControllerComputeConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"CellControllerComputeAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"CellControllerComputeMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"CellControllerComputeNetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"CellControllerComputeUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"CellControllerComputeIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"CellControllerComputeNetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"CellControllerComputeExtraGroupVars\"}]}, \"Compute\": {\"map_merge\": [{\"get_attr\": [\"ComputeGroupVars\", \"value\"]}, {\"get_attr\": [\"ComputeConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"ComputeAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"ComputeMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"ComputeNetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"ComputeUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"ComputeIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"ComputeNetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"ComputeExtraGroupVars\"}]}, \"BlockStorage\": {\"map_merge\": [{\"get_attr\": [\"BlockStorageGroupVars\", \"value\"]}, {\"get_attr\": [\"BlockStorageConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"BlockStorageAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"BlockStorageMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"BlockStorageNetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"BlockStorageUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"BlockStorageIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"BlockStorageNetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"BlockStorageExtraGroupVars\"}]}, \"ObjectStorage\": {\"map_merge\": [{\"get_attr\": [\"ObjectStorageGroupVars\", \"value\"]}, {\"get_attr\": [\"ObjectStorageConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"ObjectStorageAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"ObjectStorageMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"ObjectStorageNetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"ObjectStorageUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"ObjectStorageIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"ObjectStorageNetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"ObjectStorageExtraGroupVars\"}]}, \"CephStorage\": {\"map_merge\": [{\"get_attr\": [\"CephStorageGroupVars\", \"value\"]}, {\"get_attr\": [\"CephStorageConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"CephStorageAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"CephStorageMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"CephStorageNetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"CephStorageUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"CephStorageIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"CephStorageNetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"CephStorageExtraGroupVars\"}]}, \"Networker\": {\"map_merge\": [{\"get_attr\": [\"NetworkerGroupVars\", \"value\"]}, {\"get_attr\": [\"NetworkerConfigData\", \"value\"]}, {\"any_errors_fatal\": {\"get_param\": \"NetworkerAnyErrorsFatal\"}, \"max_fail_percentage\": {\"get_param\": \"NetworkerMaxFailPercentage\"}, \"neutron_physical_bridge_name\": {\"get_param\": \"NeutronPhysicalBridge\"}, \"neutron_public_interface_name\": {\"get_param\": \"NeutronPublicInterface\"}, \"network_config_update\": {\"get_param\": \"NetworkerNetworkConfigUpdate\"}, \"use_nmstate\": {\"get_param\": \"NetworkerUseNMState\"}, \"ifcfg_purge\": {\"get_param\": \"NetworkerIfcfgPurge\"}, \"tripleo_network_config_os_net_config_mappings\": {\"get_param\": \"NetConfigDataLookup\"}, \"deployed_server_port_map\": {\"get_param\": \"DeployedServerPortMap\"}, \"tripleo_network_config_override\": {\"get_param\": \"NetworkerNetConfigOverride\"}, \"tripleo_stack_name\": {\"get_param\": \"RootStackName\"}}, {\"get_param\": \"NetworkerExtraGroupVars\"}]}}}, \"RoleNetHostnameMap\": {\"description\": \"Mapping of each network to a list of hostnames for each role\", \"value\": {\"Controller\": {\"get_attr\": [\"ControllerNetworkHostnameMap\", \"value\"]}, \"CellController\": {\"get_attr\": [\"CellControllerNetworkHostnameMap\", \"value\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerComputeNetworkHostnameMap\", \"value\"]}, \"Compute\": {\"get_attr\": [\"ComputeNetworkHostnameMap\", \"value\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorageNetworkHostnameMap\", \"value\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorageNetworkHostnameMap\", \"value\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorageNetworkHostnameMap\", \"value\"]}, \"Networker\": {\"get_attr\": [\"NetworkerNetworkHostnameMap\", \"value\"]}}}, \"RoleTags\": {\"description\": \"Tags for each role, as defined in roles_data.yaml\", \"value\": {\"Controller\": [\"primary\", \"controller\", \"external_bridge\"], \"CellController\": [\"primary\", \"controller\"], \"CellControllerCompute\": [\"primary\", \"controller\", \"external_bridge\"], \"Compute\": [\"compute\", \"external_bridge\"], \"BlockStorage\": [\"storage\"], \"ObjectStorage\": [\"storage\"], \"CephStorage\": [\"ceph\", \"storage\"], \"Networker\": [\"external_bridge\"]}}, \"VipMap\": {\"description\": \"Mapping of each network to VIP addresses. Also includes the Redis and OVN DBs VIPs.\", \"value\": {\"get_attr\": [\"VipMap\", \"net_ip_map\"]}}, \"ServerIdData\": {\"description\": \"Mapping of each role to a list of nova server IDs and the bootstrap ID\", \"value\": {\"get_attr\": [\"ServerIdMap\", \"value\"]}}, \"BlacklistedHostnames\": {\"description\": \"List of blacklisted hostnames\", \"value\": {\"get_attr\": [\"BlacklistedHostnames\", \"value\"]}}, \"BlacklistedIpAddresses\": {\"description\": \"List of blacklisted ctlplane IP addresses\", \"value\": {\"get_attr\": [\"BlacklistedIpAddresses\", \"value\"]}}, \"GlobalConfig\": {\"description\": \"The global_config (hieradata).\", \"value\": {\"get_attr\": [\"GlobalConfig\", \"value\"]}}, \"RoleNetworkConfigMap\": {\"description\": \"Mapping of roles to network config\", \"value\": {\"Controller\": {\"get_attr\": [\"ControllerNetworkConfig\", \"config\"]}, \"CellController\": {\"get_attr\": [\"CellControllerNetworkConfig\", \"config\"]}, \"CellControllerCompute\": {\"get_attr\": [\"CellControllerComputeNetworkConfig\", \"config\"]}, \"Compute\": {\"get_attr\": [\"ComputeNetworkConfig\", \"config\"]}, \"BlockStorage\": {\"get_attr\": [\"BlockStorageNetworkConfig\", \"config\"]}, \"ObjectStorage\": {\"get_attr\": [\"ObjectStorageNetworkConfig\", \"config\"]}, \"CephStorage\": {\"get_attr\": [\"CephStorageNetworkConfig\", \"config\"]}, \"Networker\": {\"get_attr\": [\"NetworkerNetworkConfig\", \"config\"]}}}, \"AnsibleHostVarsMap\": {\"description\": \"Map of Ansible Host variables per role\", \"value\": {\"get_attr\": [\"AnsibleHostVars\", \"value\"]}}, \"TripleoHeatTemplatesJinja2RenderingDataSources\": {\"description\": \"The role_data and the network_data used when rendering the THT Jinja2 templates\", \"value\": {\"roles_data\": [{\"name\": \"Controller\", \"description\": \"Controller role that has all the controler services loaded and handles\\\\nDatabase, Messaging and Network functions.\\\\n\", \"CountDefault\": 1, \"tags\": [\"primary\", \"controller\", \"external_bridge\"], \"networks\": {\"External\": {\"subnet\": \"external_subnet\"}, \"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-controller-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"uses_deprecated_params\": true, \"deprecated_param_extraconfig\": \"controllerExtraConfig\", \"deprecated_param_flavor\": \"OvercloudControlFlavor\", \"deprecated_param_image\": \"controllerImage\", \"deprecated_nic_config_name\": \"controller.yaml\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BarbicanApi\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\", \"OS::TripleO::Services::BarbicanBackendDogtag\", \"OS::TripleO::Services::BarbicanBackendKmip\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephExternal\", \"OS::TripleO::Services::CephGrafana\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CephNfs\", \"OS::TripleO::Services::CephRbdMirror\", \"OS::TripleO::Services::CephRgw\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackendDellSc\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\", \"OS::TripleO::Services::CinderBackendDellEMCSc\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\", \"OS::TripleO::Services::CinderBackendNetApp\", \"OS::TripleO::Services::CinderBackendPure\", \"OS::TripleO::Services::CinderBackendScaleIO\", \"OS::TripleO::Services::CinderBackendNVMeOF\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::DesignateApi\", \"OS::TripleO::Services::DesignateCentral\", \"OS::TripleO::Services::DesignateProducer\", \"OS::TripleO::Services::DesignateWorker\", \"OS::TripleO::Services::DesignateMDNS\", \"OS::TripleO::Services::DesignateSink\", \"OS::TripleO::Services::DesignateBind\", \"OS::TripleO::Services::Etcd\", \"OS::TripleO::Services::ExternalSwiftProxy\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::IronicApi\", \"OS::TripleO::Services::IronicConductor\", \"OS::TripleO::Services::IronicInspector\", \"OS::TripleO::Services::IronicPxe\", \"OS::TripleO::Services::IronicNeutronAgent\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaBackendFlashBlade\", \"OS::TripleO::Services::ManilaBackendIsilon\", \"OS::TripleO::Services::ManilaBackendNetapp\", \"OS::TripleO::Services::ManilaBackendPowerMax\", \"OS::TripleO::Services::ManilaBackendUnity\", \"OS::TripleO::Services::ManilaBackendVNX\", \"OS::TripleO::Services::ManilaBackendVMAX\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronBgpVpnApi\", \"OS::TripleO::Services::NeutronSfcApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NeutronDhcpAgent\", \"OS::TripleO::Services::NeutronL2gwAgent\", \"OS::TripleO::Services::NeutronL2gwApi\", \"OS::TripleO::Services::NeutronL3Agent\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NeutronOvsAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::NeutronAgentsIBConfig\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaIronic\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OctaviaApi\", \"OS::TripleO::Services::OctaviaDeploymentConfig\", \"OS::TripleO::Services::OctaviaHealthManager\", \"OS::TripleO::Services::OctaviaHousekeeping\", \"OS::TripleO::Services::OctaviaWorker\", \"OS::TripleO::Services::OpenStackClients\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftDispersion\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Unbound\", \"OS::TripleO::Services::Vpp\"]}, {\"name\": \"CellController\", \"description\": \"Controller role that has the cell controler specific\\\\nservices and handles Database, Messaging and Network functions.\\\\n\", \"CountDefault\": 1, \"tags\": [\"primary\", \"controller\"], \"networks\": {\"External\": {\"subnet\": \"external_subnet\"}, \"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-controller-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"uses_deprecated_params\": true, \"deprecated_param_extraconfig\": \"controllerExtraConfig\", \"deprecated_param_flavor\": \"OvercloudControlFlavor\", \"deprecated_param_image\": \"controllerImage\", \"deprecated_nic_config_name\": \"controller.yaml\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Ptp\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Vpp\"]}, {\"name\": \"CellControllerCompute\", \"description\": \"Controller and Compute AIO role that has compute and cell controler specific\\\\nservices loaded and handles Database, Messaging and Network functions.\\\\n\", \"CountDefault\": 1, \"tags\": [\"primary\", \"controller\", \"external_bridge\"], \"networks\": {\"External\": {\"subnet\": \"external_subnet\"}, \"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-controller-compute-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"uses_deprecated_params\": true, \"deprecated_param_extraconfig\": \"controllerExtraConfig\", \"deprecated_param_flavor\": \"OvercloudControlFlavor\", \"deprecated_param_image\": \"controllerImage\", \"deprecated_nic_config_name\": \"controller.yaml\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephExternal\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\", \"OS::TripleO::Services::ComputeNeutronL3Agent\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::NovaAZConfig\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Ptp\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Vpp\"]}, {\"name\": \"Compute\", \"description\": \"Basic Compute Node role\\\\n\", \"CountDefault\": 1, \"tags\": [\"compute\", \"external_bridge\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-novacompute-%index%\", \"RoleParametersDefault\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"uses_deprecated_params\": true, \"deprecated_param_image\": \"NovaImage\", \"deprecated_param_extraconfig\": \"NovaComputeExtraConfig\", \"deprecated_param_metadata\": \"NovaComputeServerMetadata\", \"deprecated_param_scheduler_hints\": \"NovaComputeSchedulerHints\", \"deprecated_param_ips\": \"NovaComputeIPs\", \"deprecated_server_resource_name\": \"NovaCompute\", \"deprecated_nic_config_name\": \"compute.yaml\", \"update_serial\": 25, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephExternal\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\", \"OS::TripleO::Services::ComputeNeutronL3Agent\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::NovaAZConfig\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Vpp\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"]}, {\"name\": \"BlockStorage\", \"description\": \"Cinder Block Storage node role\\\\n\", \"tags\": [\"storage\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}}, \"uses_deprecated_params\": false, \"deprecated_nic_config_name\": \"cinder-storage.yaml\", \"update_serial\": 25, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BlockStorageCinderVolume\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"]}, {\"name\": \"ObjectStorage\", \"description\": \"Swift Object Storage node role\\\\n\", \"tags\": [\"storage\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}}, \"uses_deprecated_params\": true, \"deprecated_param_metadata\": \"SwiftStorageServerMetadata\", \"deprecated_param_ips\": \"SwiftStorageIPs\", \"deprecated_param_image\": \"SwiftStorageImage\", \"deprecated_param_flavor\": \"OvercloudSwiftStorageFlavor\", \"deprecated_nic_config_name\": \"swift-storage.yaml\", \"deprecated_server_resource_name\": \"SwiftStorage\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Ptp\"]}, {\"name\": \"CephStorage\", \"description\": \"Ceph OSD Storage node role\\\\n\", \"tags\": [\"ceph\", \"storage\"], \"networks\": {\"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}}, \"uses_deprecated_params\": false, \"HostnameFormatDefault\": \"%stackname%-cephstorage-%index%\", \"deprecated_nic_config_name\": \"ceph-storage.yaml\", \"update_serial\": 1, \"rhsm_enforce\": false, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"]}, {\"name\": \"Networker\", \"description\": \"Standalone networking role to run Neutron agents on their own.\\\\n\", \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"tags\": [\"external_bridge\"], \"HostnameFormatDefault\": \"%stackname%-networker-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::IronicNeutronAgent\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronDhcpAgent\", \"OS::TripleO::Services::NeutronL2gwAgent\", \"OS::TripleO::Services::NeutronL3Agent\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NeutronOvsAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OctaviaDeploymentConfig\", \"OS::TripleO::Services::OctaviaHealthManager\", \"OS::TripleO::Services::OctaviaHousekeeping\", \"OS::TripleO::Services::OctaviaWorker\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"]}], \"networks_data\": [{\"name\": \"Storage\", \"mtu\": 1500, \"vip\": true, \"name_lower\": \"storage\", \"dns_domain\": \"storage.ooo.test.\", \"service_net_map_replace\": \"storage\", \"subnets\": {\"storage_subnet\": {\"vlan\": 21, \"ip_subnet\": \"172.18.0.0/24\", \"allocation_pools\": [{\"start\": \"172.18.0.120\", \"end\": \"172.18.0.250\"}]}}, \"idx\": 0}, {\"name\": \"StorageMgmt\", \"mtu\": 1500, \"vip\": true, \"name_lower\": \"storage_mgmt\", \"dns_domain\": \"storagemgmt.ooo.test.\", \"service_net_map_replace\": \"storage_mgmt\", \"subnets\": {\"storage_mgmt_subnet\": {\"vlan\": 23, \"ip_subnet\": \"172.20.0.0/24\", \"allocation_pools\": [{\"start\": \"172.20.0.120\", \"end\": \"172.20.0.250\"}]}}, \"idx\": 1}, {\"name\": \"InternalApi\", \"mtu\": 1500, \"vip\": true, \"name_lower\": \"internal_api\", \"dns_domain\": \"internal-api.ooo.test.\", \"service_net_map_replace\": \"internal_api\", \"subnets\": {\"internal_api_subnet\": {\"vlan\": 20, \"ip_subnet\": \"172.17.0.0/24\", \"allocation_pools\": [{\"start\": \"172.17.0.120\", \"end\": \"172.17.0.250\"}]}}, \"idx\": 2}, {\"name\": \"Tenant\", \"mtu\": 1500, \"vip\": false, \"name_lower\": \"tenant\", \"dns_domain\": \"tenant.ooo.test.\", \"service_net_map_replace\": \"tenant\", \"subnets\": {\"tenant_subnet\": {\"vlan\": 22, \"ip_subnet\": \"172.19.0.0/24\", \"allocation_pools\": [{\"start\": \"172.19.0.120\", \"end\": \"172.19.0.250\"}]}}, \"idx\": 3}, {\"name\": \"External\", \"mtu\": 1500, \"vip\": true, \"name_lower\": \"external\", \"dns_domain\": \"external.ooo.test.\", \"service_net_map_replace\": \"external\", \"subnets\": {\"external_subnet\": {\"vlan\": 44, \"ip_subnet\": \"172.21.0.0/24\", \"allocation_pools\": [{\"start\": \"172.21.0.120\", \"end\": \"172.21.0.250\"}]}}, \"idx\": 4}]}}, \"AdminPassword\": {\"description\": \"The password for the keystone admin account, used for monitoring, querying neutron etc.\", \"value\": {\"get_param\": \"AdminPassword\"}}, \"KeystoneRegion\": {\"description\": \"Keystone region for endpoint\", \"value\": {\"get_param\": \"KeystoneRegion\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(2,'2026-06-09 08:01:36',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(3,'2026-06-09 08:01:37',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mapping of service_name_network -> network name\\n\", \"parameters\": {\"ServiceNetMap\": {\"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults. Note that the key in this map must match the service_name in the service template, e.g if the service_name is heat_api the key must be either heat_api_network, or optionally HeatApiNetwork (which will be internally converted to transform captalization to underscores).\", \"type\": \"json\", \"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"VipSubnetMap\": {\"description\": \"Map of (network_name or service_name) -> subnet_name that defines which subnet to host the VIP. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\", \"default\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMapDeprecatedMapping\": {\"default\": {\"RabbitMqNetwork\": \"RabbitmqNetwork\", \"CephPublicNetwork\": \"CephMonNetwork\", \"SwiftMgmtNetwork\": \"SwiftStorageNetwork\"}, \"description\": \"Mapping older deprecated service names, intended for internal use only, this will be removed in future.\", \"type\": \"json\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"Do not use deprecated params, they will be removed.\", \"parameters\": [\"ServiceNetMapDeprecatedMapping\"]}], \"resources\": {\"ServiceNetMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": [{\"map_replace\": [{\"get_param\": \"ServiceNetMap\"}, {\"values\": {\"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"external\": {\"get_param\": \"ExternalNetName\"}}, \"keys\": {\"get_param\": \"ServiceNetMapDeprecatedMapping\"}}]}, {\"NovaVncProxyNetwork\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}]}}}}, \"outputs\": {\"service_net_map\": {\"value\": {\"get_attr\": [\"ServiceNetMapValue\", \"value\"]}}, \"service_net_map_lower\": {\"value\": {\"yaql\": {\"expression\": \"dict($.data.map.items().select([ regex(`([a-z0-9])([A-Z])`).replace($[0], \'\\\\\\\\1_\\\\\\\\2\').toLower(), $[1]]))\", \"data\": {\"map\": {\"get_attr\": [\"ServiceNetMapValue\", \"value\"]}}}}}, \"vip_subnet_map\": {\"value\": {\"map_replace\": [{\"get_param\": \"VipSubnetMap\"}, {\"values\": {\"ctlplane-subnet\": {\"get_param\": \"ControlPlaneSubnet\"}}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(4,'2026-06-09 08:01:39',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(5,'2026-06-09 08:01:39',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed VIP port on the Control Plane network.\\n\", \"parameters\": {\"name\": {\"default\": \"\", \"type\": \"string\"}, \"dns_name\": {\"default\": \"\", \"type\": \"string\"}, \"network\": {\"default\": \"\", \"type\": \"string\"}, \"fixed_ips\": {\"default\": \"\", \"type\": \"comma_delimited_list\"}, \"replacement_policy\": {\"default\": \"\", \"type\": \"string\"}, \"tags\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ControlPlaneVipData\": {\"description\": \"Control Plane Virtual IP data\\n\", \"default\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"type\": \"json\"}}, \"outputs\": {\"name\": {\"value\": {\"get_param\": [\"ControlPlaneVipData\", \"name\"]}}, \"fixed_ips\": {\"value\": {\"get_param\": [\"ControlPlaneVipData\", \"fixed_ips\"]}}, \"network\": {\"value\": {\"get_param\": [\"ControlPlaneVipData\", \"network\"]}}, \"subnets\": {\"value\": {\"get_param\": [\"ControlPlaneVipData\", \"subnets\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"name\": \"control_virtual_ip\", \"dns_name\": \"overcloud\", \"network\": \"ctlplane\", \"fixed_ips\": \".member.0.subnet=ctlplane-subnet\", \"replacement_policy\": \"AUTO\", \"tags\": \"tripleo_vip_net=ctlplane,tripleo_stack_name=overcloud\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(6,'2026-06-09 08:01:41',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Create networks to split out Overcloud traffic\", \"parameters\": {\"DeployedNetworkEnvironment\": {\"type\": \"json\", \"description\": \"Deployed network environment\", \"default\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}}, \"CtlplaneNetworkCidrs\": {\"type\": \"json\", \"description\": \"Cidrs for the ctlplane network.\"}, \"CtlplaneNetworkAttributes\": {\"type\": \"json\", \"default\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"description\": \"A map containing attributes of the undercloud ctlplane network and subnets. NOTE: The value for this parameter is automatically populated in the plan environment by tripleoclient.\\n\"}}, \"resources\": {\"NetworkExtraConfig\": {\"type\": \"OS::TripleO::Network::ExtraConfig\"}, \"NetworkAttributesMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"ctlplane\": {\"get_param\": \"CtlplaneNetworkAttributes\"}}, {\"get_param\": [\"DeployedNetworkEnvironment\", \"net_attributes_map\"]}]}}}, \"NetworkCidrMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"ctlplane\": {\"get_param\": \"CtlplaneNetworkCidrs\"}}, {\"get_param\": [\"DeployedNetworkEnvironment\", \"net_cidr_map\"]}]}}}, \"NetworkIpVersionMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"map_merge\": [{\"ctlplane\": {\"yaql\": {\"expression\": \"$.data.items().first().last().ip_version\", \"data\": {\"get_param\": [\"CtlplaneNetworkAttributes\", \"subnets\"]}}}}, {\"get_param\": [\"DeployedNetworkEnvironment\", \"net_ip_version_map\"]}]}}}}, \"outputs\": {\"net_cidr_map\": {\"value\": {\"get_attr\": [\"NetworkCidrMap\", \"value\"]}}, \"net_ip_version_map\": {\"value\": {\"get_attr\": [\"NetworkIpVersionMap\", \"value\"]}}, \"net_attributes_map\": {\"value\": {\"get_attr\": [\"NetworkAttributesMap\", \"value\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"CtlplaneNetworkCidrs\": \"[\\\"192.168.122.0/24\\\"]\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(7,'2026-06-09 08:01:41',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(8,'2026-06-09 08:01:42',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (9,'2026-06-09 08:01:43',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"NtpServer\": {\"default\": \"pool.ntp.org\", \"description\": \"NTP servers list. Defaulted to a set of pool.ntp.org servers in order to have a sane default for Pacemaker deployments when not configuring this parameter by default.\", \"type\": \"comma_delimited_list\"}, \"NtpPool\": {\"default\": [], \"description\": \"NTP pool list.  Defaults to [], so only NtpServer is used by default.\", \"type\": \"comma_delimited_list\"}, \"NtpService\": {\"default\": \"chrony\", \"description\": \"NTP Service to use for the timesync bootstrap.\", \"type\": \"string\"}}, \"description\": \"Uses cloud-init to bootstrap timesync configuration to ensure it is done as soon as possible. We do additional and more complex configurations as part of the deployment itself.\\n\", \"conditions\": {\"use_chrony\": {\"equals\": [{\"get_param\": \"NtpService\"}, \"chrony\"]}}, \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"timesync_chrony\"}}, {\"config\": {\"get_resource\": \"timesync_sync\"}}]}}, \"timesync_chrony\": {\"type\": \"OS::Heat::SoftwareConfig\", \"properties\": {\"config\": {\"str_replace\": {\"template\": \"#!/bin/bash\\nif [ \\\"$service\\\" != \\\"chrony\\\" ]; then\\n  exit 0\\nfi\\nset -x\\nSERVERS=\\\"$ntp_servers\\\"\\nPOOLS=\\\"$ntp_pools\\\"\\nsystemctl is-active --quiet chronyd || systemctl start chronyd\\nfor server in $SERVERS; do\\n  chronyc add server \\\"${server}\\\" iburst\\ndone\\nfor pool in $POOLS; do\\n  chronyc add server \\\"${pool}\\\" iburst\\ndone\\nchronyc sources\\n\", \"params\": {\"$ntp_servers\": {\"list_join\": [\" \", {\"get_param\": \"NtpServer\"}]}, \"$ntp_pools\": {\"list_join\": [\" \", {\"get_param\": \"NtpPool\"}]}, \"$service\": {\"get_param\": \"NtpService\"}}}}}}, \"timesync_sync\": {\"type\": \"OS::Heat::SoftwareConfig\", \"properties\": {\"config\": {\"str_replace\": {\"template\": \"#!/bin/bash\\nset -x\\nif [ \\\"$service\\\" = \\\"chrony\\\" ]; then\\n    if command -v chronyc >/dev/null; then\\n        chronyc makestep\\n        chronyc waitsync 30\\n    else\\n        echo \\\"No chronyc available, skipping sync\\\"\\n    fi\\nelif [ \\\"$service\\\" = \\\"ntp\\\" ]; then\\n    if command -v ntpdate >/dev/null; then\\n        ntpdate -u $ntp_servers\\n    else\\n        echo \\\"No ntpdate available, skipping sync\\\"\\n    fi\\nfi\\nhwclock --systohc --utc\\n\", \"params\": {\"$service\": {\"get_param\": \"NtpService\"}, \"$ntp_servers\": {\"list_join\": [\" \", {\"get_param\": \"NtpServer\"}]}}}}}}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(10,'2026-06-09 08:01:44',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(11,'2026-06-09 08:01:45',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"node_admin_username\": {\"type\": \"string\", \"default\": \"heat-admin\"}, \"node_admin_extra_ssh_keys\": {\"type\": \"comma_delimited_list\", \"default\": []}}, \"description\": \"Uses cloud-init to create an additional user with a known name, in addition to the distro-default user created by the cloud-init default.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\", \"properties\": {\"parts\": [{\"config\": {\"get_resource\": \"user_config\"}}]}}, \"user_config\": {\"type\": \"OS::Heat::CloudConfig\", \"properties\": {\"cloud_config\": {\"user\": {\"get_param\": \"node_admin_username\"}, \"ssh_authorized_keys\": {\"get_param\": \"node_admin_extra_ssh_keys\"}}}}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(12,'2026-06-09 08:01:45',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed VIP port on the Storage network.\\n\", \"parameters\": {\"StackName\": {\"description\": \"Name of the overcloud heat stack\", \"default\": \"overcloud\", \"type\": \"string\"}, \"PortName\": {\"description\": \"Name of the port\", \"default\": \"\", \"type\": \"string\"}, \"DnsName\": {\"description\": \"DNS name of the port\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneIP\": {\"description\": \"IP address on the control plane\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ControlPlaneNetwork\": {\"description\": \"The name of the undercloud Neutron control plane\", \"default\": \"ctlplane\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"FixedIPs\": {\"description\": \"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"default\": [], \"type\": \"json\"}, \"IPPool\": {\"default\": {}, \"type\": \"json\"}, \"NodeIndex\": {\"default\": 0, \"type\": \"number\"}, \"IsVirtualIP\": {\"type\": \"boolean\", \"default\": false}, \"VipPortMap\": {\"description\": \"A map of deployed port data\\n\", \"default\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"type\": \"json\"}}, \"outputs\": {\"ip_address\": {\"description\": \"Storage network VIP\", \"value\": {\"get_param\": [\"VipPortMap\", \"storage\", \"ip_address\"]}}, \"ip_address_uri\": {\"description\": \"Storage network VIP (with brackets for IPv6 URLs)\", \"value\": {\"get_param\": [\"VipPortMap\", \"storage\", \"ip_address_uri\"]}}, \"ip_subnet\": {\"description\": \"IP/Subnet CIDR for the Storage network VIP\", \"value\": {\"get_param\": [\"VipPortMap\", \"storage\", \"ip_subnet\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"PortName\": \"storage_virtual_ip\", \"DnsName\": \"overcloud\", \"ControlPlaneIP\": \"192.168.122.99\", \"ControlPlaneSubnetCidr\": \"24\", \"FixedIPs\": \"[{\\\"subnet\\\": \\\"storage_subnet\\\"}]\", \"IsVirtualIP\": true}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(13,'2026-06-09 08:01:45',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed VIP port on the External network.\\n\", \"parameters\": {\"StackName\": {\"description\": \"Name of the overcloud heat stack\", \"default\": \"overcloud\", \"type\": \"string\"}, \"PortName\": {\"description\": \"Name of the port\", \"default\": \"\", \"type\": \"string\"}, \"DnsName\": {\"description\": \"DNS name of the port\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneIP\": {\"description\": \"IP address on the control plane\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ControlPlaneNetwork\": {\"description\": \"The name of the undercloud Neutron control plane\", \"default\": \"ctlplane\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"FixedIPs\": {\"description\": \"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"default\": [], \"type\": \"json\"}, \"IPPool\": {\"default\": {}, \"type\": \"json\"}, \"NodeIndex\": {\"default\": 0, \"type\": \"number\"}, \"IsVirtualIP\": {\"type\": \"boolean\", \"default\": false}, \"VipPortMap\": {\"description\": \"A map of deployed port data\\n\", \"default\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"type\": \"json\"}}, \"outputs\": {\"ip_address\": {\"description\": \"External network VIP\", \"value\": {\"get_param\": [\"VipPortMap\", \"external\", \"ip_address\"]}}, \"ip_address_uri\": {\"description\": \"External network VIP (with brackets for IPv6 URLs)\", \"value\": {\"get_param\": [\"VipPortMap\", \"external\", \"ip_address_uri\"]}}, \"ip_subnet\": {\"description\": \"IP/Subnet CIDR for the External network VIP\", \"value\": {\"get_param\": [\"VipPortMap\", \"external\", \"ip_subnet\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"PortName\": \"external_virtual_ip\", \"DnsName\": \"overcloud\", \"ControlPlaneIP\": \"192.168.122.99\", \"ControlPlaneSubnetCidr\": \"24\", \"FixedIPs\": \"[{\\\"subnet\\\": \\\"external_subnet\\\"}]\", \"IsVirtualIP\": true}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(14,'2026-06-09 08:01:45',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed VIP port on the InternalApi network.\\n\", \"parameters\": {\"StackName\": {\"description\": \"Name of the overcloud heat stack\", \"default\": \"overcloud\", \"type\": \"string\"}, \"PortName\": {\"description\": \"Name of the port\", \"default\": \"\", \"type\": \"string\"}, \"DnsName\": {\"description\": \"DNS name of the port\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneIP\": {\"description\": \"IP address on the control plane\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ControlPlaneNetwork\": {\"description\": \"The name of the undercloud Neutron control plane\", \"default\": \"ctlplane\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"FixedIPs\": {\"description\": \"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"default\": [], \"type\": \"json\"}, \"IPPool\": {\"default\": {}, \"type\": \"json\"}, \"NodeIndex\": {\"default\": 0, \"type\": \"number\"}, \"IsVirtualIP\": {\"type\": \"boolean\", \"default\": false}, \"VipPortMap\": {\"description\": \"A map of deployed port data\\n\", \"default\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"type\": \"json\"}}, \"outputs\": {\"ip_address\": {\"description\": \"InternalApi network VIP\", \"value\": {\"get_param\": [\"VipPortMap\", \"internal_api\", \"ip_address\"]}}, \"ip_address_uri\": {\"description\": \"InternalApi network VIP (with brackets for IPv6 URLs)\", \"value\": {\"get_param\": [\"VipPortMap\", \"internal_api\", \"ip_address_uri\"]}}, \"ip_subnet\": {\"description\": \"IP/Subnet CIDR for the InternalApi network VIP\", \"value\": {\"get_param\": [\"VipPortMap\", \"internal_api\", \"ip_subnet\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"PortName\": \"internal_api_virtual_ip\", \"DnsName\": \"overcloud\", \"ControlPlaneIP\": \"192.168.122.99\", \"ControlPlaneSubnetCidr\": \"24\", \"FixedIPs\": \"[{\\\"subnet\\\": \\\"internal_api_subnet\\\"}]\", \"IsVirtualIP\": true}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(15,'2026-06-09 08:01:45',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Deployed VIP port on the StorageMgmt network.\\n\", \"parameters\": {\"StackName\": {\"description\": \"Name of the overcloud heat stack\", \"default\": \"overcloud\", \"type\": \"string\"}, \"PortName\": {\"description\": \"Name of the port\", \"default\": \"\", \"type\": \"string\"}, \"DnsName\": {\"description\": \"DNS name of the port\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneIP\": {\"description\": \"IP address on the control plane\", \"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ControlPlaneNetwork\": {\"description\": \"The name of the undercloud Neutron control plane\", \"default\": \"ctlplane\", \"type\": \"string\"}, \"ControlPlaneSubnet\": {\"description\": \"The name of the undercloud Neutron control plane subnet\", \"default\": \"ctlplane-subnet\", \"type\": \"string\"}, \"FixedIPs\": {\"description\": \"Control the IP allocation for the VIP port. E.g. [{\'ip_address\':\'1.2.3.4\'}]\\n\", \"default\": [], \"type\": \"json\"}, \"IPPool\": {\"default\": {}, \"type\": \"json\"}, \"NodeIndex\": {\"default\": 0, \"type\": \"number\"}, \"IsVirtualIP\": {\"type\": \"boolean\", \"default\": false}, \"VipPortMap\": {\"description\": \"A map of deployed port data\\n\", \"default\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"type\": \"json\"}}, \"outputs\": {\"ip_address\": {\"description\": \"StorageMgmt network VIP\", \"value\": {\"get_param\": [\"VipPortMap\", \"storage_mgmt\", \"ip_address\"]}}, \"ip_address_uri\": {\"description\": \"StorageMgmt network VIP (with brackets for IPv6 URLs)\", \"value\": {\"get_param\": [\"VipPortMap\", \"storage_mgmt\", \"ip_address_uri\"]}}, \"ip_subnet\": {\"description\": \"IP/Subnet CIDR for the StorageMgmt network VIP\", \"value\": {\"get_param\": [\"VipPortMap\", \"storage_mgmt\", \"ip_subnet\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"PortName\": \"storage_mgmt_virtual_ip\", \"DnsName\": \"overcloud\", \"ControlPlaneIP\": \"192.168.122.99\", \"ControlPlaneSubnetCidr\": \"24\", \"FixedIPs\": \"[{\\\"subnet\\\": \\\"storage_mgmt_subnet\\\"}]\", \"IsVirtualIP\": true}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(16,'2026-06-09 08:01:46',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(17,'2026-06-09 08:01:47',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(18,'2026-06-09 08:01:47',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"ControlPlaneIp\": {\"default\": \"\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"StorageIp\": {\"default\": \"\", \"type\": \"string\"}, \"StorageIpSubnet\": {\"description\": \"IP address/subnet on the storage network\", \"default\": \"\", \"type\": \"string\"}, \"StorageIpUri\": {\"default\": \"\", \"type\": \"string\", \"description\": \"IP address with brackets in case of IPv6\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtIp\": {\"default\": \"\", \"type\": \"string\"}, \"StorageMgmtIpSubnet\": {\"description\": \"IP address/subnet on the storage_mgmt network\", \"default\": \"\", \"type\": \"string\"}, \"StorageMgmtIpUri\": {\"default\": \"\", \"type\": \"string\", \"description\": \"IP address with brackets in case of IPv6\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiIp\": {\"default\": \"\", \"type\": \"string\"}, \"InternalApiIpSubnet\": {\"description\": \"IP address/subnet on the internal_api network\", \"default\": \"\", \"type\": \"string\"}, \"InternalApiIpUri\": {\"default\": \"\", \"type\": \"string\", \"description\": \"IP address with brackets in case of IPv6\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantIp\": {\"default\": \"\", \"type\": \"string\"}, \"TenantIpSubnet\": {\"description\": \"IP address/subnet on the tenant network\", \"default\": \"\", \"type\": \"string\"}, \"TenantIpUri\": {\"default\": \"\", \"type\": \"string\", \"description\": \"IP address with brackets in case of IPv6\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalIp\": {\"default\": \"\", \"type\": \"string\"}, \"ExternalIpSubnet\": {\"description\": \"IP address/subnet on the external network\", \"default\": \"\", \"type\": \"string\"}, \"ExternalIpUri\": {\"default\": \"\", \"type\": \"string\", \"description\": \"IP address with brackets in case of IPv6\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}}, \"resources\": {\"NetIpMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"ctlplane\": {\"get_param\": \"ControlPlaneIp\"}, \"ctlplane_subnet\": {\"list_join\": [\"\", [{\"get_param\": \"ControlPlaneIp\"}, \"/\", {\"get_param\": \"ControlPlaneSubnetCidr\"}]]}, \"ctlplane_uri\": {\"str_replace\": {\"template\": {\"make_url\": {\"host\": {\"get_param\": \"ControlPlaneIp\"}}}, \"params\": {\"//\": \"\"}}}, \"storage\": {\"get_param\": \"StorageIp\"}, \"storage_subnet\": {\"get_param\": \"StorageIpSubnet\"}, \"storage_uri\": {\"get_param\": \"StorageIpUri\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtIp\"}, \"storage_mgmt_subnet\": {\"get_param\": \"StorageMgmtIpSubnet\"}, \"storage_mgmt_uri\": {\"get_param\": \"StorageMgmtIpUri\"}, \"internal_api\": {\"get_param\": \"InternalApiIp\"}, \"internal_api_subnet\": {\"get_param\": \"InternalApiIpSubnet\"}, \"internal_api_uri\": {\"get_param\": \"InternalApiIpUri\"}, \"tenant\": {\"get_param\": \"TenantIp\"}, \"tenant_subnet\": {\"get_param\": \"TenantIpSubnet\"}, \"tenant_uri\": {\"get_param\": \"TenantIpUri\"}, \"external\": {\"get_param\": \"ExternalIp\"}, \"external_subnet\": {\"get_param\": \"ExternalIpSubnet\"}, \"external_uri\": {\"get_param\": \"ExternalIpUri\"}}, {\"keys\": {\"ctlplane\": \"ctlplane\", \"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_subnet\": {\"str_replace\": {\"template\": \"NAME_subnet\", \"params\": {\"NAME\": {\"get_param\": \"StorageNetName\"}}}}, \"storage_uri\": {\"str_replace\": {\"template\": \"NAME_uri\", \"params\": {\"NAME\": {\"get_param\": \"StorageNetName\"}}}}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"storage_mgmt_subnet\": {\"str_replace\": {\"template\": \"NAME_subnet\", \"params\": {\"NAME\": {\"get_param\": \"StorageMgmtNetName\"}}}}, \"storage_mgmt_uri\": {\"str_replace\": {\"template\": \"NAME_uri\", \"params\": {\"NAME\": {\"get_param\": \"StorageMgmtNetName\"}}}}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"internal_api_subnet\": {\"str_replace\": {\"template\": \"NAME_subnet\", \"params\": {\"NAME\": {\"get_param\": \"InternalApiNetName\"}}}}, \"internal_api_uri\": {\"str_replace\": {\"template\": \"NAME_uri\", \"params\": {\"NAME\": {\"get_param\": \"InternalApiNetName\"}}}}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"tenant_subnet\": {\"str_replace\": {\"template\": \"NAME_subnet\", \"params\": {\"NAME\": {\"get_param\": \"TenantNetName\"}}}}, \"tenant_uri\": {\"str_replace\": {\"template\": \"NAME_uri\", \"params\": {\"NAME\": {\"get_param\": \"TenantNetName\"}}}}, \"external\": {\"get_param\": \"ExternalNetName\"}, \"external_subnet\": {\"str_replace\": {\"template\": \"NAME_subnet\", \"params\": {\"NAME\": {\"get_param\": \"ExternalNetName\"}}}}, \"external_uri\": {\"str_replace\": {\"template\": \"NAME_uri\", \"params\": {\"NAME\": {\"get_param\": \"ExternalNetName\"}}}}}}]}}}}, \"outputs\": {\"net_ip_map\": {\"description\": \"A Hash containing a mapping of network names to assigned IPs for a specific machine.\\n\", \"value\": {\"get_attr\": [\"NetIpMapValue\", \"value\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ControlPlaneIp\": \"192.168.122.99\", \"ControlPlaneSubnetCidr\": \"24\", \"StorageIp\": \"172.18.0.129\", \"StorageIpUri\": \"172.18.0.129\", \"StorageMgmtIp\": \"172.20.0.181\", \"StorageMgmtIpUri\": \"172.20.0.181\", \"InternalApiIp\": \"172.17.0.205\", \"InternalApiIpUri\": \"172.17.0.205\", \"ExternalIp\": \"172.21.0.163\", \"ExternalIpUri\": \"172.21.0.163\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(19,'2026-06-09 08:01:48',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (20,'2026-06-09 08:01:48',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"A map of OpenStack endpoints. Since the endpoints are URLs, we need to have brackets around IPv6 IP addresses. The inputs to these parameters come from net_ip_uri_map, which will include these brackets in IPv6 addresses.\", \"parameters\": {\"NetIpMap\": {\"type\": \"json\", \"default\": {}, \"description\": \"The Net IP map\"}, \"ServiceNetMap\": {\"type\": \"json\", \"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"The Service Net map\"}, \"EndpointMap\": {\"type\": \"json\", \"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}, \"CloudEndpoints\": {\"type\": \"json\", \"default\": {}, \"description\": \"A map containing the DNS names for the different endpoints (external, internal_api, etc.)\"}}, \"outputs\": {\"endpoint_map\": {\"value\": {\"AodhAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhAdmin\", \"port\"]}}}}, \"AodhInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"AodhApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhInternal\", \"port\"]}}}}, \"AodhPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"AodhPublic\", \"port\"]}}}}, \"BarbicanAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanAdmin\", \"port\"]}}}}, \"BarbicanInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"BarbicanApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanInternal\", \"port\"]}}}}, \"BarbicanPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"BarbicanPublic\", \"port\"]}}}}, \"CephDashboardInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephDashboardNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephDashboardInternal\", \"port\"]}}}}, \"CephGrafanaInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephGrafanaNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephGrafanaNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephGrafanaNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CephGrafanaNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephGrafanaNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephGrafanaNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephGrafanaNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephGrafanaNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephGrafanaInternal\", \"port\"]}}}}, \"CephRgwAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"port\"]}, \"path\": \"/swift/v1/AUTH_\"}}, \"%(project_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwAdmin\", \"port\"]}}}}, \"CephRgwInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"port\"]}, \"path\": \"/swift/v1/AUTH_\"}}, \"%(project_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CephRgwNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwInternal\", \"port\"]}}}}, \"CephRgwPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"port\"]}, \"path\": \"/swift/v1/AUTH_\"}}, \"%(project_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CephRgwPublic\", \"port\"]}}}}, \"CinderAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}}}}, \"CinderInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}}}}, \"CinderPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}}}}, \"CinderV2Admin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}, \"path\": \"/v2/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}}}}, \"CinderV2Internal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}, \"path\": \"/v2/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}}}}, \"CinderV2Public\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}, \"path\": \"/v2/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}}}}, \"CinderV3Admin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}, \"path\": \"/v3/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderAdmin\", \"port\"]}}}}, \"CinderV3Internal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}, \"path\": \"/v3/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderInternal\", \"port\"]}}}}, \"CinderV3Public\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}, \"path\": \"/v3/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"CinderPublic\", \"port\"]}}}}, \"DesignateAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"port\"]}, \"path\": \"/v2\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignateAdmin\", \"port\"]}}}}, \"DesignateInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"port\"]}, \"path\": \"/v2\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DesignateApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignateInternal\", \"port\"]}}}}, \"DesignatePublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"port\"]}, \"path\": \"/v2\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DesignatePublic\", \"port\"]}}}}, \"DockerRegistryInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DockerRegistryNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DockerRegistryNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DockerRegistryNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"DockerRegistryNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DockerRegistryNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DockerRegistryNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"DockerRegistryNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"DockerRegistryNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"DockerRegistryInternal\", \"port\"]}}}}, \"GaneshaInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GaneshaNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GaneshaNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GaneshaNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"GaneshaNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GaneshaNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GaneshaNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GaneshaNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GaneshaNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GaneshaInternal\", \"port\"]}}}}, \"GlanceAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"port\"]}}}}, \"GlanceInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}}}}, \"GlancePublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"port\"]}}}}, \"GnocchiAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiAdmin\", \"port\"]}}}}, \"GnocchiInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GnocchiApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiInternal\", \"port\"]}}}}, \"GnocchiPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"GnocchiPublic\", \"port\"]}}}}, \"HeatAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"port\"]}}}}, \"HeatInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"port\"]}}}}, \"HeatPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"port\"]}}}}, \"HeatCfnAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"port\"]}}}}, \"HeatCfnInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"port\"]}}}}, \"HeatCfnPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"port\"]}}}}, \"HorizonPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"port\"]}, \"path\": \"/dashboard\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"HorizonPublic\", \"port\"]}}}}, \"IronicAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicAdmin\", \"port\"]}}}}, \"IronicInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInternal\", \"port\"]}}}}, \"IronicPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicPublic\", \"port\"]}}}}, \"IronicInspectorAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorAdmin\", \"port\"]}}}}, \"IronicInspectorInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"IronicInspectorNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorInternal\", \"port\"]}}}}, \"IronicInspectorPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"IronicInspectorPublic\", \"port\"]}}}}, \"KeystoneAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}, \"path\": \"/\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}}}}, \"KeystoneInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"port\"]}, \"path\": \"/\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"port\"]}}}}, \"KeystonePublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"port\"]}, \"path\": \"/\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"port\"]}}}}, \"KeystoneV3Admin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}, \"path\": \"/v3\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}}}}, \"KeystoneV3Internal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"port\"]}, \"path\": \"/v3\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"port\"]}}}}, \"KeystoneV3Public\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"port\"]}, \"path\": \"/v3\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"port\"]}}}}, \"ManilaAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"port\"]}, \"path\": \"/v2\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"port\"]}}}}, \"ManilaInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"port\"]}, \"path\": \"/v2\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"port\"]}}}}, \"ManilaPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"port\"]}, \"path\": \"/v2\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"port\"]}}}}, \"ManilaV1Admin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"port\"]}}}}, \"ManilaV1Internal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"port\"]}}}}, \"ManilaV1Public\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"port\"]}, \"path\": \"/v1/\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"port\"]}}}}, \"MetricsQdrPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"MetricsQdrPublic\", \"port\"]}}}}, \"MysqlInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"port\"]}}}}, \"NeutronAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronAdmin\", \"port\"]}}}}, \"NeutronInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NeutronApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronInternal\", \"port\"]}}}}, \"NeutronPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NeutronPublic\", \"port\"]}}}}, \"NovaAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"port\"]}, \"path\": \"/v2.1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaAdmin\", \"port\"]}}}}, \"NovaInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"port\"]}, \"path\": \"/v2.1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaInternal\", \"port\"]}}}}, \"NovaPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"port\"]}, \"path\": \"/v2.1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"port\"]}}}}, \"NovaMetadataInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaMetadataNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataInternal\", \"port\"]}}}}, \"NovaVNCProxyAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyAdmin\", \"port\"]}}}}, \"NovaVNCProxyInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyInternal\", \"port\"]}}}}, \"NovaVNCProxyPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyPublic\", \"port\"]}}}}, \"NovajoinAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinAdmin\", \"port\"]}}}}, \"NovajoinInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovajoinNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinInternal\", \"port\"]}}}}, \"NovajoinPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"port\"]}, \"path\": \"/v1\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"NovajoinPublic\", \"port\"]}}}}, \"OctaviaAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaAdmin\", \"port\"]}}}}, \"OctaviaInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OctaviaApiNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaInternal\", \"port\"]}}}}, \"OctaviaPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"OctaviaPublic\", \"port\"]}}}}, \"PlacementAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"port\"]}, \"path\": \"/placement\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementAdmin\", \"port\"]}}}}, \"PlacementInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"port\"]}, \"path\": \"/placement\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PlacementNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementInternal\", \"port\"]}}}}, \"PlacementPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"port\"]}, \"path\": \"/placement\"}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"PlacementPublic\", \"port\"]}}}}, \"SwiftAdmin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"port\"]}}}}, \"SwiftInternal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"port\"]}, \"path\": \"/v1/AUTH_\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"port\"]}}}}, \"SwiftPublic\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"protocol\"]}, \"uri\": {\"list_join\": [\"\", [{\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"port\"]}, \"path\": \"/v1/AUTH_\"}}, \"%(tenant_id)s\"]]}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"port\"]}}}}, \"SwiftS3Admin\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftAdmin\", \"port\"]}}}}, \"SwiftS3Internal\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"SwiftProxyNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftInternal\", \"port\"]}}}}, \"SwiftS3Public\": {\"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"host_nobrackets\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"port\"]}, \"protocol\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"protocol\"]}, \"uri\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"port\"]}}}, \"uri_no_suffix\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"protocol\"]}, \"host\": {\"str_replace\": {\"template\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"host\"]}, \"params\": {\"CLOUDNAME\": {\"get_param\": [\"CloudEndpoints\", {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}]}, \"IP_ADDRESS\": {\"get_param\": [\"NetIpMap\", {\"str_replace\": {\"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}, \"template\": \"NETWORK_uri\"}}]}}}}, \"port\": {\"get_param\": [\"EndpointMap\", \"SwiftPublic\", \"port\"]}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"NetIpMap\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"CloudEndpoints\": {\"ctlplane\": \"overcloud.ctlplane.ooo.test\", \"storage\": \"overcloud.storage.ooo.test\", \"storage_mgmt\": \"overcloud.storagemgmt.ooo.test\", \"internal_api\": \"overcloud.internalapi.ooo.test\", \"external\": \"overcloud.ooo.test\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(21,'2026-06-09 08:01:49',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"This is a default no-op template which provides empty user-data which can be passed to the OS::Nova::Server resources. This template can be replaced with a different implementation via the resource registry, such that deployers may customize their first-boot configuration.\\n\", \"resources\": {\"userdata\": {\"type\": \"OS::Heat::MultipartMime\"}}, \"outputs\": {\"OS::stack_id\": {\"value\": {\"get_resource\": \"userdata\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(22,'2026-06-09 08:01:50',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"CellControllerCompute\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(23,'2026-06-09 08:01:50',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::ObjectStorageServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"ObjectStorage\", \"RoleParameters\": {}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(24,'2026-06-09 08:01:50',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::CellControllerServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"CellController\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(25,'2026-06-09 08:01:50',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::ControllerServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"OS::TripleO::Services::BootParams,OS::TripleO::Services::CACerts,OS::TripleO::Services::CeilometerAgentCentral,OS::TripleO::Services::CeilometerAgentNotification,OS::TripleO::Services::CinderApi,OS::TripleO::Services::CinderBackup,OS::TripleO::Services::CinderScheduler,OS::TripleO::Services::CinderVolume,OS::TripleO::Services::Clustercheck,OS::TripleO::Services::Collectd,OS::TripleO::Services::ContainerImagePrepare,OS::TripleO::Services::GlanceApi,OS::TripleO::Services::GlanceApiInternal,OS::TripleO::Services::HAproxy,OS::TripleO::Services::HeatApi,OS::TripleO::Services::HeatApiCloudwatch,OS::TripleO::Services::HeatApiCfn,OS::TripleO::Services::HeatEngine,OS::TripleO::Services::Horizon,OS::TripleO::Services::IpaClient,OS::TripleO::Services::Iscsid,OS::TripleO::Services::Kernel,OS::TripleO::Services::Keystone,OS::TripleO::Services::ManilaApi,OS::TripleO::Services::ManilaBackendCephFs,OS::TripleO::Services::ManilaScheduler,OS::TripleO::Services::ManilaShare,OS::TripleO::Services::Memcached,OS::TripleO::Services::MetricsQdr,OS::TripleO::Services::MySQL,OS::TripleO::Services::MySQLClient,OS::TripleO::Services::NeutronApi,OS::TripleO::Services::NeutronCorePlugin,OS::TripleO::Services::NovaApi,OS::TripleO::Services::NovaConductor,OS::TripleO::Services::NovaMetadata,OS::TripleO::Services::NovaScheduler,OS::TripleO::Services::NovaVncProxy,OS::TripleO::Services::ContainersLogrotateCrond,OS::TripleO::Services::OVNDBs,OS::TripleO::Services::OVNController,OS::TripleO::Services::Pacemaker,OS::TripleO::Services::PlacementApi,OS::TripleO::Services::OsloMessagingRpc,OS::TripleO::Services::OsloMessagingNotify,OS::TripleO::Services::Podman,OS::TripleO::Services::Redis,OS::TripleO::Services::Rsyslog,OS::TripleO::Services::Snmp,OS::TripleO::Services::Sshd,OS::TripleO::Services::SwiftProxy,OS::TripleO::Services::SwiftRingBuilder,OS::TripleO::Services::SwiftStorage,OS::TripleO::Services::Timesync,OS::TripleO::Services::Timezone,OS::TripleO::Services::TripleoFirewall,OS::TripleO::Services::TripleoPackages,OS::TripleO::Services::Tuned\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (26,'2026-06-09 08:01:50',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::BlockStorageServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"BlockStorage\", \"RoleParameters\": {}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(27,'2026-06-09 08:01:50',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::ComputeServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"OS::TripleO::Services::BootParams,OS::TripleO::Services::CACerts,OS::TripleO::Services::Collectd,OS::TripleO::Services::ComputeCeilometerAgent,OS::TripleO::Services::CeilometerAgentIpmi,OS::TripleO::Services::IpaClient,OS::TripleO::Services::Iscsid,OS::TripleO::Services::Kernel,OS::TripleO::Services::MetricsQdr,OS::TripleO::Services::MySQLClient,OS::TripleO::Services::NovaCompute,OS::TripleO::Services::NovaLibvirt,OS::TripleO::Services::NovaLibvirtGuests,OS::TripleO::Services::NovaMigrationTarget,OS::TripleO::Services::ContainersLogrotateCrond,OS::TripleO::Services::Podman,OS::TripleO::Services::Rsyslog,OS::TripleO::Services::Snmp,OS::TripleO::Services::Sshd,OS::TripleO::Services::Timesync,OS::TripleO::Services::Timezone,OS::TripleO::Services::TripleoFirewall,OS::TripleO::Services::TripleoPackages,OS::TripleO::Services::Tuned,OS::TripleO::Services::OVNController,OS::TripleO::Services::OVNMetadataAgent\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(28,'2026-06-09 08:01:51',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::CephStorageServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"CephStorage\", \"RoleParameters\": {}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(29,'2026-06-09 08:01:51',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Utility stack to convert an array of services into a set of combined role configs.\\n\", \"parameters\": {\"Services\": {\"default\": [], \"description\": \"List nested stack service templates.\\n\", \"type\": \"comma_delimited_list\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"description\": \"Parameters specific to the role\", \"default\": {}, \"type\": \"json\"}}, \"resources\": {\"ServiceChain\": {\"type\": \"OS::Heat::ResourceChain\", \"properties\": {\"resources\": {\"get_param\": \"Services\"}, \"concurrent\": true, \"resource_properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"ServiceServerMetadataHook\": {\"type\": \"OS::TripleO::NetworkerServiceServerMetadataHook\", \"properties\": {\"RoleData\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}, \"PuppetStepConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.step_config, []), coalesce($.data.docker_config, [])).where($[2] = null).where($[1] != null).select($[1]).join(\\\"\\\\n\\\")\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}, \"step_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"step_config\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.docker_config, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"docker_config\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"docker_config\"]}}}}}}, \"DockerConfigScripts\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.service_names, []).zip(coalesce($.data.container_config_scripts, [])).where($[1] != null).select($[1]).reduce($1.mergeWith($2), {})\", \"data\": {\"service_names\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_names\"]}, \"container_config_scripts\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"container_config_scripts\"]}}}}}}, \"MonitoringSubscriptionsConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'monitoring_subscription\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"ServiceNames\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"filter\": [[null], {\"get_attr\": [\"ServiceChain\", \"role_data\", \"service_name\"]}]}}}, \"GlobalConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'global_config_settings\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"KeystoneResourcesConfigs\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'keystone_resources\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"ServiceConfigSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'service_config_settings\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DeployStepsTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'deploy_steps_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalPostDeployTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_post_deploy_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ScaleTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'scale_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ExternalUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'external_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreUpgradeRollingTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_upgrade_rolling_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpgradeTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_upgrade_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PostUpdateTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'post_update_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"UpgradeBatchTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'upgrade_batch_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PuppetConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'puppet_config\')).where($ != null).distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"KollaConfig\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data.role_data, []).where($ != null).select($.get(\'kolla_config\')).where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}, \"DockerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'docker_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ContainerPuppetTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null).select([$.get(\'container_puppet_tasks\'), $.get(\'service_name\')]).where($[0] != null).select([$[0], dict($[0].keys().zip(dict(service_name=>$[1]).repeat(len($[0].keys()))))]).select($[0].mergeWith($[1])).selectMany($.items()).groupBy($[0], $[1]))\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostFirewallTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_firewall_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"HostPrepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'host_prep_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"PreDeployStepTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'pre_deploy_step_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"IpaRegistrationTasks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"coalesce($.data, []).where($ != null).select($.get(\'ipa_registration_tasks\')).where($ != null).flatten().distinct()\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"AnsibleGroupVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'ansible_group_vars\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}, \"FirewallFrontendRules\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"ssl_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_frontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}, \"edge_sslfrontend\": {\"map_merge\": {\"yaql\": {\"expression\": \"list(coalesce($.data.role_data, []).where($ != null).select($.get(\'firewall_edge_ssl_frontend_rules\')).where($ != null)).flatten()\", \"data\": {\"role_data\": {\"get_attr\": [\"ServiceChain\", \"role_data\"]}}}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Combined Role data for this set of services.\", \"value\": {\"service_names\": {\"get_attr\": [\"ServiceNames\", \"value\"]}, \"monitoring_subscriptions\": {\"get_attr\": [\"MonitoringSubscriptionsConfig\", \"value\"]}, \"config_settings\": {\"yaql\": {\"expression\": \"$.data.where($ != null).reduce($1.mergeWith($2), {})\", \"data\": {\"get_attr\": [\"ServiceChain\", \"role_data\", \"config_settings\"]}}}, \"global_config_settings\": {\"get_attr\": [\"GlobalConfigSettings\", \"value\"]}, \"service_config_settings\": {\"get_attr\": [\"ServiceConfigSettings\", \"value\"]}, \"step_config\": {\"get_attr\": [\"PuppetStepConfig\", \"value\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"DeployStepsTasks\", \"value\"]}, \"external_deploy_tasks\": {\"get_attr\": [\"ExternalDeployTasks\", \"value\"]}, \"external_post_deploy_tasks\": {\"get_attr\": [\"ExternalPostDeployTasks\", \"value\"]}, \"external_update_tasks\": {\"get_attr\": [\"ExternalUpdateTasks\", \"value\"]}, \"external_upgrade_tasks\": {\"get_attr\": [\"ExternalUpgradeTasks\", \"value\"]}, \"scale_tasks\": {\"get_attr\": [\"ScaleTasks\", \"value\"]}, \"pre_upgrade_rolling_tasks\": {\"get_attr\": [\"PreUpgradeRollingTasks\", \"value\"]}, \"upgrade_tasks\": {\"get_attr\": [\"UpgradeTasks\", \"value\"]}, \"post_upgrade_tasks\": {\"get_attr\": [\"PostUpgradeTasks\", \"value\"]}, \"update_tasks\": {\"get_attr\": [\"UpdateTasks\", \"value\"]}, \"post_update_tasks\": {\"get_attr\": [\"PostUpdateTasks\", \"value\"]}, \"upgrade_batch_tasks\": {\"get_attr\": [\"UpgradeBatchTasks\", \"value\"]}, \"service_metadata_settings\": {\"get_attr\": [\"ServiceServerMetadataHook\", \"metadata\"]}, \"ansible_group_vars\": {\"map_merge\": [{\"ansible_async_dir\": \"/tmp/.ansible_async\"}, {\"get_attr\": [\"AnsibleGroupVars\", \"value\"]}]}, \"keystone_resources\": {\"get_attr\": [\"KeystoneResourcesConfigs\", \"value\"]}, \"firewall_rules\": {\"get_attr\": [\"FirewallRules\", \"value\"]}, \"firewall_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"frontend\"]}, \"firewall_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"ssl_frontend\"]}, \"firewall_edge_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_frontend\"]}, \"firewall_edge_ssl_frontend_rules\": {\"get_attr\": [\"FirewallFrontendRules\", \"value\", \"edge_ssl_frontend\"]}, \"puppet_config\": {\"get_attr\": [\"PuppetConfig\", \"value\"]}, \"kolla_config\": {\"get_attr\": [\"KollaConfig\", \"value\"]}, \"docker_config\": {\"get_attr\": [\"DockerConfig\", \"value\"]}, \"container_config_scripts\": {\"get_attr\": [\"DockerConfigScripts\", \"value\"]}, \"container_puppet_tasks\": {\"map_merge\": [{\"get_attr\": [\"ContainerPuppetTasks\", \"value\"]}, {\"get_attr\": [\"DockerPuppetTasks\", \"value\"]}]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HostFirewallTasks\", \"value\"]}, {\"get_attr\": [\"HostPrepTasks\", \"value\"]}]}, \"pre_deploy_step_tasks\": {\"list_concat\": [{\"get_attr\": [\"PreDeployStepTasks\", \"value\"]}, {\"get_attr\": [\"IpaRegistrationTasks\", \"value\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"Services\": \"\", \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Networker\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(30,'2026-06-09 08:01:51',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"role_data, service_name\": {\"value\": []}, \"role_data, docker_config\": {\"value\": []}, \"role_data\": {\"value\": []}, \"role_data, service_names\": {\"value\": []}, \"role_data, container_config_scripts\": {\"value\": []}, \"role_data, step_config\": {\"value\": []}, \"role_data, config_settings\": {\"value\": []}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(31,'2026-06-09 08:01:52',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"role_data, service_name\": {\"value\": []}, \"role_data, docker_config\": {\"value\": []}, \"role_data\": {\"value\": []}, \"role_data, service_names\": {\"value\": []}, \"role_data, container_config_scripts\": {\"value\": []}, \"role_data, step_config\": {\"value\": []}, \"role_data, config_settings\": {\"value\": []}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(32,'2026-06-09 08:01:52',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"role_data, service_name\": {\"value\": []}, \"role_data, docker_config\": {\"value\": []}, \"role_data\": {\"value\": []}, \"role_data, service_names\": {\"value\": []}, \"role_data, container_config_scripts\": {\"value\": []}, \"role_data, step_config\": {\"value\": []}, \"role_data, config_settings\": {\"value\": []}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (33,'2026-06-09 08:01:52',NULL,'{\"heat_template_version\": \"2015-04-30\", \"resources\": {\"0\": {\"type\": \"OS::TripleO::Services::BootParams\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}}, \"1\": {\"type\": \"OS::TripleO::Services::CACerts\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}}, \"2\": {\"type\": \"OS::TripleO::Services::CeilometerAgentCentral\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}}, \"3\": {\"type\": \"OS::TripleO::Services::CeilometerAgentNotification\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}}, \"4\": {\"type\": \"OS::TripleO::Services::CinderApi\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"0\"]}, \"5\": {\"type\": \"OS::TripleO::Services::CinderBackup\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"1\"]}, \"6\": {\"type\": \"OS::TripleO::Services::CinderScheduler\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"2\"]}, \"7\": {\"type\": \"OS::TripleO::Services::CinderVolume\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"3\"]}, \"8\": {\"type\": \"OS::TripleO::Services::Clustercheck\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"4\"]}, \"9\": {\"type\": \"OS::TripleO::Services::Collectd\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"5\"]}, \"10\": {\"type\": \"OS::TripleO::Services::ContainerImagePrepare\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"6\"]}, \"11\": {\"type\": \"OS::TripleO::Services::GlanceApi\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"7\"]}, \"12\": {\"type\": \"OS::TripleO::Services::GlanceApiInternal\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"8\"]}, \"13\": {\"type\": \"OS::TripleO::Services::HAproxy\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"9\"]}, \"14\": {\"type\": \"OS::TripleO::Services::HeatApi\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"10\"]}, \"15\": {\"type\": \"OS::TripleO::Services::HeatApiCloudwatch\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"11\"]}, \"16\": {\"type\": \"OS::TripleO::Services::HeatApiCfn\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"12\"]}, \"17\": {\"type\": \"OS::TripleO::Services::HeatEngine\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"13\"]}, \"18\": {\"type\": \"OS::TripleO::Services::Horizon\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"14\"]}, \"19\": {\"type\": \"OS::TripleO::Services::IpaClient\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"15\"]}, \"20\": {\"type\": \"OS::TripleO::Services::Iscsid\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"16\"]}, \"21\": {\"type\": \"OS::TripleO::Services::Kernel\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"17\"]}, \"22\": {\"type\": \"OS::TripleO::Services::Keystone\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"18\"]}, \"23\": {\"type\": \"OS::TripleO::Services::ManilaApi\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"19\"]}, \"24\": {\"type\": \"OS::TripleO::Services::ManilaBackendCephFs\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"20\"]}, \"25\": {\"type\": \"OS::TripleO::Services::ManilaScheduler\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"21\"]}, \"26\": {\"type\": \"OS::TripleO::Services::ManilaShare\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"22\"]}, \"27\": {\"type\": \"OS::TripleO::Services::Memcached\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"23\"]}, \"28\": {\"type\": \"OS::TripleO::Services::MetricsQdr\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"24\"]}, \"29\": {\"type\": \"OS::TripleO::Services::MySQL\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"25\"]}, \"30\": {\"type\": \"OS::TripleO::Services::MySQLClient\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"26\"]}, \"31\": {\"type\": \"OS::TripleO::Services::NeutronApi\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"27\"]}, \"32\": {\"type\": \"OS::TripleO::Services::NeutronCorePlugin\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"28\"]}, \"33\": {\"type\": \"OS::TripleO::Services::NovaApi\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"29\"]}, \"34\": {\"type\": \"OS::TripleO::Services::NovaConductor\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"30\"]}, \"35\": {\"type\": \"OS::TripleO::Services::NovaMetadata\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"31\"]}, \"36\": {\"type\": \"OS::TripleO::Services::NovaScheduler\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"32\"]}, \"37\": {\"type\": \"OS::TripleO::Services::NovaVncProxy\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"33\"]}, \"38\": {\"type\": \"OS::TripleO::Services::ContainersLogrotateCrond\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"34\"]}, \"39\": {\"type\": \"OS::TripleO::Services::OVNDBs\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"35\"]}, \"40\": {\"type\": \"OS::TripleO::Services::OVNController\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"36\"]}, \"41\": {\"type\": \"OS::TripleO::Services::Pacemaker\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"37\"]}, \"42\": {\"type\": \"OS::TripleO::Services::PlacementApi\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"38\"]}, \"43\": {\"type\": \"OS::TripleO::Services::OsloMessagingRpc\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"39\"]}, \"44\": {\"type\": \"OS::TripleO::Services::OsloMessagingNotify\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"40\"]}, \"45\": {\"type\": \"OS::TripleO::Services::Podman\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"41\"]}, \"46\": {\"type\": \"OS::TripleO::Services::Redis\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"42\"]}, \"47\": {\"type\": \"OS::TripleO::Services::Rsyslog\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"43\"]}, \"48\": {\"type\": \"OS::TripleO::Services::Snmp\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"44\"]}, \"49\": {\"type\": \"OS::TripleO::Services::Sshd\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"45\"]}, \"50\": {\"type\": \"OS::TripleO::Services::SwiftProxy\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"46\"]}, \"51\": {\"type\": \"OS::TripleO::Services::SwiftRingBuilder\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"47\"]}, \"52\": {\"type\": \"OS::TripleO::Services::SwiftStorage\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"48\"]}, \"53\": {\"type\": \"OS::TripleO::Services::Timesync\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"49\"]}, \"54\": {\"type\": \"OS::TripleO::Services::Timezone\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"50\"]}, \"55\": {\"type\": \"OS::TripleO::Services::TripleoFirewall\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"51\"]}, \"56\": {\"type\": \"OS::TripleO::Services::TripleoPackages\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"52\"]}, \"57\": {\"type\": \"OS::TripleO::Services::Tuned\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"depends_on\": [\"53\"]}}, \"outputs\": {\"role_data, service_name\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"1\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"2\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"3\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"4\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"5\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"6\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"7\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"8\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"9\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"10\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"11\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"12\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"13\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"14\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"15\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"16\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"17\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"18\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"19\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"20\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"21\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"22\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"23\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"24\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"25\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"26\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"27\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"28\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"29\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"30\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"31\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"32\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"33\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"34\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"35\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"36\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"37\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"38\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"39\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"40\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"41\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"42\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"43\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"44\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"45\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"46\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"47\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"48\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"49\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"50\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"51\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"52\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"53\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"54\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"55\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"56\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"57\", \"role_data\", \"service_name\"]}]}, \"role_data, docker_config\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"1\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"2\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"3\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"4\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"5\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"6\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"7\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"8\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"9\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"10\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"11\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"12\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"13\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"14\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"15\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"16\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"17\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"18\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"19\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"20\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"21\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"22\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"23\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"24\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"25\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"26\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"27\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"28\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"29\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"30\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"31\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"32\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"33\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"34\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"35\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"36\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"37\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"38\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"39\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"40\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"41\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"42\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"43\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"44\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"45\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"46\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"47\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"48\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"49\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"50\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"51\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"52\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"53\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"54\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"55\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"56\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"57\", \"role_data\", \"docker_config\"]}]}, \"role_data\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\"]}, {\"get_attr\": [\"1\", \"role_data\"]}, {\"get_attr\": [\"2\", \"role_data\"]}, {\"get_attr\": [\"3\", \"role_data\"]}, {\"get_attr\": [\"4\", \"role_data\"]}, {\"get_attr\": [\"5\", \"role_data\"]}, {\"get_attr\": [\"6\", \"role_data\"]}, {\"get_attr\": [\"7\", \"role_data\"]}, {\"get_attr\": [\"8\", \"role_data\"]}, {\"get_attr\": [\"9\", \"role_data\"]}, {\"get_attr\": [\"10\", \"role_data\"]}, {\"get_attr\": [\"11\", \"role_data\"]}, {\"get_attr\": [\"12\", \"role_data\"]}, {\"get_attr\": [\"13\", \"role_data\"]}, {\"get_attr\": [\"14\", \"role_data\"]}, {\"get_attr\": [\"15\", \"role_data\"]}, {\"get_attr\": [\"16\", \"role_data\"]}, {\"get_attr\": [\"17\", \"role_data\"]}, {\"get_attr\": [\"18\", \"role_data\"]}, {\"get_attr\": [\"19\", \"role_data\"]}, {\"get_attr\": [\"20\", \"role_data\"]}, {\"get_attr\": [\"21\", \"role_data\"]}, {\"get_attr\": [\"22\", \"role_data\"]}, {\"get_attr\": [\"23\", \"role_data\"]}, {\"get_attr\": [\"24\", \"role_data\"]}, {\"get_attr\": [\"25\", \"role_data\"]}, {\"get_attr\": [\"26\", \"role_data\"]}, {\"get_attr\": [\"27\", \"role_data\"]}, {\"get_attr\": [\"28\", \"role_data\"]}, {\"get_attr\": [\"29\", \"role_data\"]}, {\"get_attr\": [\"30\", \"role_data\"]}, {\"get_attr\": [\"31\", \"role_data\"]}, {\"get_attr\": [\"32\", \"role_data\"]}, {\"get_attr\": [\"33\", \"role_data\"]}, {\"get_attr\": [\"34\", \"role_data\"]}, {\"get_attr\": [\"35\", \"role_data\"]}, {\"get_attr\": [\"36\", \"role_data\"]}, {\"get_attr\": [\"37\", \"role_data\"]}, {\"get_attr\": [\"38\", \"role_data\"]}, {\"get_attr\": [\"39\", \"role_data\"]}, {\"get_attr\": [\"40\", \"role_data\"]}, {\"get_attr\": [\"41\", \"role_data\"]}, {\"get_attr\": [\"42\", \"role_data\"]}, {\"get_attr\": [\"43\", \"role_data\"]}, {\"get_attr\": [\"44\", \"role_data\"]}, {\"get_attr\": [\"45\", \"role_data\"]}, {\"get_attr\": [\"46\", \"role_data\"]}, {\"get_attr\": [\"47\", \"role_data\"]}, {\"get_attr\": [\"48\", \"role_data\"]}, {\"get_attr\": [\"49\", \"role_data\"]}, {\"get_attr\": [\"50\", \"role_data\"]}, {\"get_attr\": [\"51\", \"role_data\"]}, {\"get_attr\": [\"52\", \"role_data\"]}, {\"get_attr\": [\"53\", \"role_data\"]}, {\"get_attr\": [\"54\", \"role_data\"]}, {\"get_attr\": [\"55\", \"role_data\"]}, {\"get_attr\": [\"56\", \"role_data\"]}, {\"get_attr\": [\"57\", \"role_data\"]}]}, \"role_data, service_names\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"1\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"2\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"3\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"4\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"5\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"6\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"7\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"8\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"9\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"10\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"11\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"12\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"13\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"14\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"15\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"16\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"17\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"18\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"19\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"20\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"21\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"22\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"23\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"24\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"25\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"26\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"27\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"28\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"29\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"30\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"31\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"32\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"33\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"34\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"35\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"36\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"37\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"38\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"39\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"40\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"41\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"42\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"43\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"44\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"45\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"46\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"47\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"48\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"49\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"50\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"51\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"52\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"53\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"54\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"55\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"56\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"57\", \"role_data\", \"service_names\"]}]}, \"role_data, container_config_scripts\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"1\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"2\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"3\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"4\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"5\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"6\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"7\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"8\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"9\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"10\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"11\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"12\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"13\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"14\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"15\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"16\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"17\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"18\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"19\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"20\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"21\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"22\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"23\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"24\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"25\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"26\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"27\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"28\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"29\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"30\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"31\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"32\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"33\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"34\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"35\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"36\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"37\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"38\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"39\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"40\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"41\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"42\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"43\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"44\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"45\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"46\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"47\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"48\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"49\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"50\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"51\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"52\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"53\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"54\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"55\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"56\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"57\", \"role_data\", \"container_config_scripts\"]}]}, \"role_data, step_config\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"1\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"2\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"3\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"4\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"5\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"6\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"7\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"8\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"9\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"10\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"11\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"12\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"13\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"14\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"15\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"16\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"17\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"18\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"19\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"20\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"21\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"22\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"23\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"24\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"25\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"26\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"27\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"28\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"29\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"30\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"31\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"32\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"33\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"34\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"35\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"36\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"37\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"38\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"39\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"40\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"41\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"42\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"43\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"44\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"45\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"46\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"47\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"48\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"49\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"50\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"51\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"52\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"53\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"54\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"55\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"56\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"57\", \"role_data\", \"step_config\"]}]}, \"role_data, config_settings\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"1\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"2\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"3\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"4\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"5\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"6\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"7\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"8\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"9\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"10\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"11\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"12\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"13\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"14\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"15\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"16\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"17\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"18\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"19\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"20\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"21\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"22\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"23\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"24\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"25\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"26\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"27\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"28\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"29\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"30\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"31\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"32\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"33\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"34\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"35\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"36\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"37\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"38\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"39\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"40\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"41\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"42\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"43\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"44\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"45\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"46\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"47\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"48\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"49\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"50\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"51\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"52\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"53\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"54\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"55\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"56\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"57\", \"role_data\", \"config_settings\"]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (34,'2026-06-09 08:01:52',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"role_data, service_name\": {\"value\": []}, \"role_data, docker_config\": {\"value\": []}, \"role_data\": {\"value\": []}, \"role_data, service_names\": {\"value\": []}, \"role_data, container_config_scripts\": {\"value\": []}, \"role_data, step_config\": {\"value\": []}, \"role_data, config_settings\": {\"value\": []}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(35,'2026-06-09 08:01:52',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"role_data, service_name\": {\"value\": []}, \"role_data, docker_config\": {\"value\": []}, \"role_data\": {\"value\": []}, \"role_data, service_names\": {\"value\": []}, \"role_data, container_config_scripts\": {\"value\": []}, \"role_data, step_config\": {\"value\": []}, \"role_data, config_settings\": {\"value\": []}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(36,'2026-06-09 08:01:52',NULL,'{\"heat_template_version\": \"2015-04-30\", \"resources\": {\"0\": {\"type\": \"OS::TripleO::Services::BootParams\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}}, \"1\": {\"type\": \"OS::TripleO::Services::CACerts\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}}, \"2\": {\"type\": \"OS::TripleO::Services::Collectd\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}}, \"3\": {\"type\": \"OS::TripleO::Services::ComputeCeilometerAgent\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}}, \"4\": {\"type\": \"OS::TripleO::Services::CeilometerAgentIpmi\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"0\"]}, \"5\": {\"type\": \"OS::TripleO::Services::IpaClient\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"1\"]}, \"6\": {\"type\": \"OS::TripleO::Services::Iscsid\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"2\"]}, \"7\": {\"type\": \"OS::TripleO::Services::Kernel\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"3\"]}, \"8\": {\"type\": \"OS::TripleO::Services::MetricsQdr\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"4\"]}, \"9\": {\"type\": \"OS::TripleO::Services::MySQLClient\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"5\"]}, \"10\": {\"type\": \"OS::TripleO::Services::NovaCompute\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"6\"]}, \"11\": {\"type\": \"OS::TripleO::Services::NovaLibvirt\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"7\"]}, \"12\": {\"type\": \"OS::TripleO::Services::NovaLibvirtGuests\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"8\"]}, \"13\": {\"type\": \"OS::TripleO::Services::NovaMigrationTarget\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"9\"]}, \"14\": {\"type\": \"OS::TripleO::Services::ContainersLogrotateCrond\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"10\"]}, \"15\": {\"type\": \"OS::TripleO::Services::Podman\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"11\"]}, \"16\": {\"type\": \"OS::TripleO::Services::Rsyslog\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"12\"]}, \"17\": {\"type\": \"OS::TripleO::Services::Snmp\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"13\"]}, \"18\": {\"type\": \"OS::TripleO::Services::Sshd\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"14\"]}, \"19\": {\"type\": \"OS::TripleO::Services::Timesync\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"15\"]}, \"20\": {\"type\": \"OS::TripleO::Services::Timezone\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"16\"]}, \"21\": {\"type\": \"OS::TripleO::Services::TripleoFirewall\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"17\"]}, \"22\": {\"type\": \"OS::TripleO::Services::TripleoPackages\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"18\"]}, \"23\": {\"type\": \"OS::TripleO::Services::Tuned\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"19\"]}, \"24\": {\"type\": \"OS::TripleO::Services::OVNController\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"20\"]}, \"25\": {\"type\": \"OS::TripleO::Services::OVNMetadataAgent\", \"properties\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"depends_on\": [\"21\"]}}, \"outputs\": {\"role_data, service_name\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"1\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"2\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"3\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"4\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"5\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"6\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"7\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"8\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"9\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"10\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"11\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"12\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"13\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"14\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"15\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"16\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"17\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"18\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"19\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"20\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"21\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"22\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"23\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"24\", \"role_data\", \"service_name\"]}, {\"get_attr\": [\"25\", \"role_data\", \"service_name\"]}]}, \"role_data, docker_config\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"1\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"2\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"3\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"4\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"5\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"6\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"7\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"8\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"9\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"10\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"11\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"12\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"13\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"14\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"15\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"16\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"17\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"18\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"19\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"20\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"21\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"22\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"23\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"24\", \"role_data\", \"docker_config\"]}, {\"get_attr\": [\"25\", \"role_data\", \"docker_config\"]}]}, \"role_data\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\"]}, {\"get_attr\": [\"1\", \"role_data\"]}, {\"get_attr\": [\"2\", \"role_data\"]}, {\"get_attr\": [\"3\", \"role_data\"]}, {\"get_attr\": [\"4\", \"role_data\"]}, {\"get_attr\": [\"5\", \"role_data\"]}, {\"get_attr\": [\"6\", \"role_data\"]}, {\"get_attr\": [\"7\", \"role_data\"]}, {\"get_attr\": [\"8\", \"role_data\"]}, {\"get_attr\": [\"9\", \"role_data\"]}, {\"get_attr\": [\"10\", \"role_data\"]}, {\"get_attr\": [\"11\", \"role_data\"]}, {\"get_attr\": [\"12\", \"role_data\"]}, {\"get_attr\": [\"13\", \"role_data\"]}, {\"get_attr\": [\"14\", \"role_data\"]}, {\"get_attr\": [\"15\", \"role_data\"]}, {\"get_attr\": [\"16\", \"role_data\"]}, {\"get_attr\": [\"17\", \"role_data\"]}, {\"get_attr\": [\"18\", \"role_data\"]}, {\"get_attr\": [\"19\", \"role_data\"]}, {\"get_attr\": [\"20\", \"role_data\"]}, {\"get_attr\": [\"21\", \"role_data\"]}, {\"get_attr\": [\"22\", \"role_data\"]}, {\"get_attr\": [\"23\", \"role_data\"]}, {\"get_attr\": [\"24\", \"role_data\"]}, {\"get_attr\": [\"25\", \"role_data\"]}]}, \"role_data, service_names\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"1\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"2\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"3\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"4\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"5\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"6\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"7\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"8\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"9\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"10\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"11\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"12\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"13\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"14\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"15\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"16\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"17\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"18\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"19\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"20\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"21\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"22\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"23\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"24\", \"role_data\", \"service_names\"]}, {\"get_attr\": [\"25\", \"role_data\", \"service_names\"]}]}, \"role_data, container_config_scripts\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"1\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"2\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"3\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"4\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"5\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"6\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"7\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"8\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"9\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"10\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"11\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"12\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"13\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"14\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"15\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"16\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"17\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"18\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"19\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"20\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"21\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"22\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"23\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"24\", \"role_data\", \"container_config_scripts\"]}, {\"get_attr\": [\"25\", \"role_data\", \"container_config_scripts\"]}]}, \"role_data, step_config\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"1\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"2\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"3\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"4\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"5\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"6\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"7\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"8\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"9\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"10\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"11\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"12\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"13\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"14\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"15\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"16\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"17\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"18\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"19\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"20\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"21\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"22\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"23\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"24\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"25\", \"role_data\", \"step_config\"]}]}, \"role_data, config_settings\": {\"value\": [{\"get_attr\": [\"0\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"1\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"2\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"3\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"4\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"5\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"6\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"7\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"8\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"9\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"10\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"11\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"12\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"13\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"14\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"15\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"16\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"17\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"18\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"19\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"20\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"21\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"22\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"23\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"24\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"25\", \"role_data\", \"config_settings\"]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (37,'2026-06-09 08:01:53',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Generates the relevant service principals for a CellController server\", \"parameters\": {\"RoleData\": {\"type\": \"json\", \"description\": \"the list containing the \'role_data\' output for the ServiceChain\"}, \"CloudNameStorage\": {\"default\": \"overcloud.storage.ooo.test\", \"description\": \"The DNS name of this cloud\'s storage endpoint. E.g. \'ci-overcloud.storage.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameStorageManagement\": {\"default\": \"overcloud.storagemgmt.ooo.test\", \"description\": \"The DNS name of this cloud\'s storage_mgmt endpoint. E.g. \'ci-overcloud.storagemgmt.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameInternal\": {\"default\": \"overcloud.internalapi.ooo.test\", \"description\": \"The DNS name of this cloud\'s internal_api endpoint. E.g. \'ci-overcloud.internalapi.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudName\": {\"default\": \"overcloud.ooo.test\", \"description\": \"The DNS name of this cloud. E.g. ci-overcloud.tripleo.org\", \"type\": \"string\"}, \"CloudNameCtlplane\": {\"default\": \"overcloud.ctlplane.ooo.test\", \"description\": \"The DNS name of this cloud\'s provisioning network endpoint. E.g. \'ci-overcloud.ctlplane.tripleo.org\'.\\n\", \"type\": \"string\"}}, \"resources\": {\"IncomingMetadataSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"let(role_networks => $.data.role_networks) -> list(coalesce($.data.role_data, []).where($ != null).where($.containsKey(\'metadata_settings\')).metadata_settings.flatten().distinct().where($ != null and $.containsKey(\'network\')).where($role_networks.contains($.network))).flatten()\", \"data\": {\"role_data\": {\"get_param\": \"RoleData\"}, \"role_networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"tenant\", \"external\"]}}}}}, \"IndividualServices\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"let(fqdns => $.data.fqdns) -> dict(coalesce($.data.metadata, []).where($ != null and $.type = \'vip\').select([concat(\'managed_service_\', $.service, $.network), concat($.service, \'/\', $fqdns.get($.network))]))\", \"data\": {\"metadata\": {\"get_attr\": [\"IncomingMetadataSettings\", \"value\"]}, \"fqdns\": {\"storage\": {\"get_param\": \"CloudNameStorage\"}, \"storage_mgmt\": {\"get_param\": \"CloudNameStorageManagement\"}, \"internal_api\": {\"get_param\": \"CloudNameInternal\"}, \"external\": {\"get_param\": \"CloudName\"}, \"ctlplane\": {\"get_param\": \"CloudNameCtlplane\"}}}}}}}, \"CompactServices\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null and $.type = \'node\').groupBy(concat(\'compact_service_\', $.service), $.network.replace(\'_\', \'\')))\", \"data\": {\"get_attr\": [\"IncomingMetadataSettings\", \"value\"]}}}}}}, \"outputs\": {\"metadata\": {\"description\": \"actual metadata entries that will be passed to the server.\", \"value\": {\"map_merge\": [{\"get_attr\": [\"IndividualServices\", \"value\"]}, {\"get_attr\": [\"CompactServices\", \"value\"]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"RoleData\": \"[]\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(38,'2026-06-09 08:01:53',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"role_data, service_name\": {\"value\": []}, \"role_data, docker_config\": {\"value\": []}, \"role_data\": {\"value\": []}, \"role_data, service_names\": {\"value\": []}, \"role_data, container_config_scripts\": {\"value\": []}, \"role_data, step_config\": {\"value\": []}, \"role_data, config_settings\": {\"value\": []}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(39,'2026-06-09 08:01:53',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Generates the relevant service principals for a CellControllerCompute server\", \"parameters\": {\"RoleData\": {\"type\": \"json\", \"description\": \"the list containing the \'role_data\' output for the ServiceChain\"}, \"CloudNameStorage\": {\"default\": \"overcloud.storage.ooo.test\", \"description\": \"The DNS name of this cloud\'s storage endpoint. E.g. \'ci-overcloud.storage.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameStorageManagement\": {\"default\": \"overcloud.storagemgmt.ooo.test\", \"description\": \"The DNS name of this cloud\'s storage_mgmt endpoint. E.g. \'ci-overcloud.storagemgmt.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameInternal\": {\"default\": \"overcloud.internalapi.ooo.test\", \"description\": \"The DNS name of this cloud\'s internal_api endpoint. E.g. \'ci-overcloud.internalapi.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudName\": {\"default\": \"overcloud.ooo.test\", \"description\": \"The DNS name of this cloud. E.g. ci-overcloud.tripleo.org\", \"type\": \"string\"}, \"CloudNameCtlplane\": {\"default\": \"overcloud.ctlplane.ooo.test\", \"description\": \"The DNS name of this cloud\'s provisioning network endpoint. E.g. \'ci-overcloud.ctlplane.tripleo.org\'.\\n\", \"type\": \"string\"}}, \"resources\": {\"IncomingMetadataSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"let(role_networks => $.data.role_networks) -> list(coalesce($.data.role_data, []).where($ != null).where($.containsKey(\'metadata_settings\')).metadata_settings.flatten().distinct().where($ != null and $.containsKey(\'network\')).where($role_networks.contains($.network))).flatten()\", \"data\": {\"role_data\": {\"get_param\": \"RoleData\"}, \"role_networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"tenant\", \"external\"]}}}}}, \"IndividualServices\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"let(fqdns => $.data.fqdns) -> dict(coalesce($.data.metadata, []).where($ != null and $.type = \'vip\').select([concat(\'managed_service_\', $.service, $.network), concat($.service, \'/\', $fqdns.get($.network))]))\", \"data\": {\"metadata\": {\"get_attr\": [\"IncomingMetadataSettings\", \"value\"]}, \"fqdns\": {\"storage\": {\"get_param\": \"CloudNameStorage\"}, \"storage_mgmt\": {\"get_param\": \"CloudNameStorageManagement\"}, \"internal_api\": {\"get_param\": \"CloudNameInternal\"}, \"external\": {\"get_param\": \"CloudName\"}, \"ctlplane\": {\"get_param\": \"CloudNameCtlplane\"}}}}}}}, \"CompactServices\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null and $.type = \'node\').groupBy(concat(\'compact_service_\', $.service), $.network.replace(\'_\', \'\')))\", \"data\": {\"get_attr\": [\"IncomingMetadataSettings\", \"value\"]}}}}}}, \"outputs\": {\"metadata\": {\"description\": \"actual metadata entries that will be passed to the server.\", \"value\": {\"map_merge\": [{\"get_attr\": [\"IndividualServices\", \"value\"]}, {\"get_attr\": [\"CompactServices\", \"value\"]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"RoleData\": \"[]\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(40,'2026-06-09 08:01:54',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Generates the relevant service principals for a ObjectStorage server\", \"parameters\": {\"RoleData\": {\"type\": \"json\", \"description\": \"the list containing the \'role_data\' output for the ServiceChain\"}, \"CloudNameStorage\": {\"default\": \"overcloud.storage.ooo.test\", \"description\": \"The DNS name of this cloud\'s storage endpoint. E.g. \'ci-overcloud.storage.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameStorageManagement\": {\"default\": \"overcloud.storagemgmt.ooo.test\", \"description\": \"The DNS name of this cloud\'s storage_mgmt endpoint. E.g. \'ci-overcloud.storagemgmt.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameInternal\": {\"default\": \"overcloud.internalapi.ooo.test\", \"description\": \"The DNS name of this cloud\'s internal_api endpoint. E.g. \'ci-overcloud.internalapi.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameCtlplane\": {\"default\": \"overcloud.ctlplane.ooo.test\", \"description\": \"The DNS name of this cloud\'s provisioning network endpoint. E.g. \'ci-overcloud.ctlplane.tripleo.org\'.\\n\", \"type\": \"string\"}}, \"resources\": {\"IncomingMetadataSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"let(role_networks => $.data.role_networks) -> list(coalesce($.data.role_data, []).where($ != null).where($.containsKey(\'metadata_settings\')).metadata_settings.flatten().distinct().where($ != null and $.containsKey(\'network\')).where($role_networks.contains($.network))).flatten()\", \"data\": {\"role_data\": {\"get_param\": \"RoleData\"}, \"role_networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"]}}}}}, \"IndividualServices\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"let(fqdns => $.data.fqdns) -> dict(coalesce($.data.metadata, []).where($ != null and $.type = \'vip\').select([concat(\'managed_service_\', $.service, $.network), concat($.service, \'/\', $fqdns.get($.network))]))\", \"data\": {\"metadata\": {\"get_attr\": [\"IncomingMetadataSettings\", \"value\"]}, \"fqdns\": {\"storage\": {\"get_param\": \"CloudNameStorage\"}, \"storage_mgmt\": {\"get_param\": \"CloudNameStorageManagement\"}, \"internal_api\": {\"get_param\": \"CloudNameInternal\"}, \"ctlplane\": {\"get_param\": \"CloudNameCtlplane\"}}}}}}}, \"CompactServices\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null and $.type = \'node\').groupBy(concat(\'compact_service_\', $.service), $.network.replace(\'_\', \'\')))\", \"data\": {\"get_attr\": [\"IncomingMetadataSettings\", \"value\"]}}}}}}, \"outputs\": {\"metadata\": {\"description\": \"actual metadata entries that will be passed to the server.\", \"value\": {\"map_merge\": [{\"get_attr\": [\"IndividualServices\", \"value\"]}, {\"get_attr\": [\"CompactServices\", \"value\"]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"RoleData\": \"[]\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(41,'2026-06-09 08:01:54',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Generates the relevant service principals for a Networker server\", \"parameters\": {\"RoleData\": {\"type\": \"json\", \"description\": \"the list containing the \'role_data\' output for the ServiceChain\"}, \"CloudNameInternal\": {\"default\": \"overcloud.internalapi.ooo.test\", \"description\": \"The DNS name of this cloud\'s internal_api endpoint. E.g. \'ci-overcloud.internalapi.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameCtlplane\": {\"default\": \"overcloud.ctlplane.ooo.test\", \"description\": \"The DNS name of this cloud\'s provisioning network endpoint. E.g. \'ci-overcloud.ctlplane.tripleo.org\'.\\n\", \"type\": \"string\"}}, \"resources\": {\"IncomingMetadataSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"let(role_networks => $.data.role_networks) -> list(coalesce($.data.role_data, []).where($ != null).where($.containsKey(\'metadata_settings\')).metadata_settings.flatten().distinct().where($ != null and $.containsKey(\'network\')).where($role_networks.contains($.network))).flatten()\", \"data\": {\"role_data\": {\"get_param\": \"RoleData\"}, \"role_networks\": [\"ctlplane\", \"internal_api\", \"tenant\"]}}}}}, \"IndividualServices\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"let(fqdns => $.data.fqdns) -> dict(coalesce($.data.metadata, []).where($ != null and $.type = \'vip\').select([concat(\'managed_service_\', $.service, $.network), concat($.service, \'/\', $fqdns.get($.network))]))\", \"data\": {\"metadata\": {\"get_attr\": [\"IncomingMetadataSettings\", \"value\"]}, \"fqdns\": {\"internal_api\": {\"get_param\": \"CloudNameInternal\"}, \"ctlplane\": {\"get_param\": \"CloudNameCtlplane\"}}}}}}}, \"CompactServices\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null and $.type = \'node\').groupBy(concat(\'compact_service_\', $.service), $.network.replace(\'_\', \'\')))\", \"data\": {\"get_attr\": [\"IncomingMetadataSettings\", \"value\"]}}}}}}, \"outputs\": {\"metadata\": {\"description\": \"actual metadata entries that will be passed to the server.\", \"value\": {\"map_merge\": [{\"get_attr\": [\"IndividualServices\", \"value\"]}, {\"get_attr\": [\"CompactServices\", \"value\"]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"RoleData\": \"[]\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(42,'2026-06-09 08:01:55',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Generates the relevant service principals for a BlockStorage server\", \"parameters\": {\"RoleData\": {\"type\": \"json\", \"description\": \"the list containing the \'role_data\' output for the ServiceChain\"}, \"CloudNameStorage\": {\"default\": \"overcloud.storage.ooo.test\", \"description\": \"The DNS name of this cloud\'s storage endpoint. E.g. \'ci-overcloud.storage.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameStorageManagement\": {\"default\": \"overcloud.storagemgmt.ooo.test\", \"description\": \"The DNS name of this cloud\'s storage_mgmt endpoint. E.g. \'ci-overcloud.storagemgmt.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameInternal\": {\"default\": \"overcloud.internalapi.ooo.test\", \"description\": \"The DNS name of this cloud\'s internal_api endpoint. E.g. \'ci-overcloud.internalapi.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameCtlplane\": {\"default\": \"overcloud.ctlplane.ooo.test\", \"description\": \"The DNS name of this cloud\'s provisioning network endpoint. E.g. \'ci-overcloud.ctlplane.tripleo.org\'.\\n\", \"type\": \"string\"}}, \"resources\": {\"IncomingMetadataSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"let(role_networks => $.data.role_networks) -> list(coalesce($.data.role_data, []).where($ != null).where($.containsKey(\'metadata_settings\')).metadata_settings.flatten().distinct().where($ != null and $.containsKey(\'network\')).where($role_networks.contains($.network))).flatten()\", \"data\": {\"role_data\": {\"get_param\": \"RoleData\"}, \"role_networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"]}}}}}, \"IndividualServices\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"let(fqdns => $.data.fqdns) -> dict(coalesce($.data.metadata, []).where($ != null and $.type = \'vip\').select([concat(\'managed_service_\', $.service, $.network), concat($.service, \'/\', $fqdns.get($.network))]))\", \"data\": {\"metadata\": {\"get_attr\": [\"IncomingMetadataSettings\", \"value\"]}, \"fqdns\": {\"storage\": {\"get_param\": \"CloudNameStorage\"}, \"storage_mgmt\": {\"get_param\": \"CloudNameStorageManagement\"}, \"internal_api\": {\"get_param\": \"CloudNameInternal\"}, \"ctlplane\": {\"get_param\": \"CloudNameCtlplane\"}}}}}}}, \"CompactServices\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null and $.type = \'node\').groupBy(concat(\'compact_service_\', $.service), $.network.replace(\'_\', \'\')))\", \"data\": {\"get_attr\": [\"IncomingMetadataSettings\", \"value\"]}}}}}}, \"outputs\": {\"metadata\": {\"description\": \"actual metadata entries that will be passed to the server.\", \"value\": {\"map_merge\": [{\"get_attr\": [\"IndividualServices\", \"value\"]}, {\"get_attr\": [\"CompactServices\", \"value\"]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"RoleData\": \"[]\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(43,'2026-06-09 08:01:56',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Generates the relevant service principals for a CephStorage server\", \"parameters\": {\"RoleData\": {\"type\": \"json\", \"description\": \"the list containing the \'role_data\' output for the ServiceChain\"}, \"CloudNameStorage\": {\"default\": \"overcloud.storage.ooo.test\", \"description\": \"The DNS name of this cloud\'s storage endpoint. E.g. \'ci-overcloud.storage.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameStorageManagement\": {\"default\": \"overcloud.storagemgmt.ooo.test\", \"description\": \"The DNS name of this cloud\'s storage_mgmt endpoint. E.g. \'ci-overcloud.storagemgmt.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameCtlplane\": {\"default\": \"overcloud.ctlplane.ooo.test\", \"description\": \"The DNS name of this cloud\'s provisioning network endpoint. E.g. \'ci-overcloud.ctlplane.tripleo.org\'.\\n\", \"type\": \"string\"}}, \"resources\": {\"IncomingMetadataSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"let(role_networks => $.data.role_networks) -> list(coalesce($.data.role_data, []).where($ != null).where($.containsKey(\'metadata_settings\')).metadata_settings.flatten().distinct().where($ != null and $.containsKey(\'network\')).where($role_networks.contains($.network))).flatten()\", \"data\": {\"role_data\": {\"get_param\": \"RoleData\"}, \"role_networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\"]}}}}}, \"IndividualServices\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"let(fqdns => $.data.fqdns) -> dict(coalesce($.data.metadata, []).where($ != null and $.type = \'vip\').select([concat(\'managed_service_\', $.service, $.network), concat($.service, \'/\', $fqdns.get($.network))]))\", \"data\": {\"metadata\": {\"get_attr\": [\"IncomingMetadataSettings\", \"value\"]}, \"fqdns\": {\"storage\": {\"get_param\": \"CloudNameStorage\"}, \"storage_mgmt\": {\"get_param\": \"CloudNameStorageManagement\"}, \"ctlplane\": {\"get_param\": \"CloudNameCtlplane\"}}}}}}}, \"CompactServices\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null and $.type = \'node\').groupBy(concat(\'compact_service_\', $.service), $.network.replace(\'_\', \'\')))\", \"data\": {\"get_attr\": [\"IncomingMetadataSettings\", \"value\"]}}}}}}, \"outputs\": {\"metadata\": {\"description\": \"actual metadata entries that will be passed to the server.\", \"value\": {\"map_merge\": [{\"get_attr\": [\"IndividualServices\", \"value\"]}, {\"get_attr\": [\"CompactServices\", \"value\"]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"RoleData\": \"[]\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(44,'2026-06-09 08:01:58',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"external_ip_address\": {\"value\": []}, \"ip_address\": {\"value\": []}, \"ansible_host_vars_map\": {\"value\": []}, \"storage_mgmt_ip_address\": {\"value\": []}, \"tenant_ip_address\": {\"value\": []}, \"hostname\": {\"value\": []}, \"nova_server_resource\": {\"value\": []}, \"hosts_entry\": {\"value\": []}, \"attributes, nova_server_resource\": {\"value\": {}}, \"hostname_map\": {\"value\": []}, \"blacklist_ip_address\": {\"value\": []}, \"internal_api_ip_address\": {\"value\": []}, \"blacklist_hostname\": {\"value\": []}, \"storage_ip_address\": {\"value\": []}, \"refs_map\": {\"value\": {}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(45,'2026-06-09 08:01:58',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Containerized collectd service\\n\", \"parameters\": {\"ContainerCollectdImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\"}, \"ContainerCollectdConfigImage\": {\"description\": \"The container image to use for the collectd config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"description\": \"Keystone region for endpoint\", \"default\": \"regionOne\"}, \"MetricsQdrPort\": {\"default\": 5666, \"description\": \"Service name or port number on which the qdrouterd will accept connections.\", \"type\": \"number\"}, \"MetricsQdrUsername\": {\"default\": \"guest\", \"description\": \"Username which should be used to authenticate to the deployed qdrouterd.\", \"type\": \"string\"}, \"MetricsQdrPassword\": {\"default\": \"guest\", \"description\": \"Password which should be used to authenticate to the deployed qdrouterd.\", \"type\": \"string\", \"hidden\": true}, \"MonitoringSubscriptionCollectd\": {\"default\": \"overcloud-collectd\", \"type\": \"string\"}, \"CollectdConnectionType\": {\"default\": \"amqp1\", \"description\": \"Define which write plugin should collectd use. Currently supported are \'amqp1\' and \'network\'.\", \"type\": \"string\"}, \"CollectdDefaultPollingInterval\": {\"default\": 120, \"type\": \"number\", \"description\": \"Controls how often registered read functions are called and with that the resolution of the collected data. This value can be overridden per plugin(per role) by setting \\\"::collectd::plugin::<plugin_name>::interval\\\" key in ExtraConfig(<role_name>ExtraConfig) if using puppet, and by setting \\\"collectd_plugin_<plugin_name>_interval\\\" in <role_name>ExtraConfig/CollectdVars if using ansible.\\n\"}, \"CollectdDefaultPlugins\": {\"default\": [\"cpu\", \"df\", \"disk\", \"hugepages\", \"interface\", \"load\", \"memory\", \"unixsock\", \"uptime\"], \"type\": \"comma_delimited_list\", \"description\": \"List of collectd plugins to activate on all overcloud hosts.  See the documentation for the puppet-collectd module for a list plugins supported by the module (https://github.com/voxpupuli/puppet-collectd). Set this key to override the default list of plugins.  Use CollectdExtraPlugins if you want to load additional plugins without overriding the defaults.\\n\"}, \"CollectdExtraPlugins\": {\"default\": [], \"type\": \"comma_delimited_list\", \"description\": \"List of collectd plugins to activate on all overcloud hosts.  See the documentation for the puppet-collectd module for a list plugins supported by the module (https://github.com/voxpupuli/puppet-collectd). Set this key to load plugins in addition to those in CollectdDefaultPlugins.\\n\"}, \"CollectdServer\": {\"type\": \"string\", \"description\": \"Address of remote collectd server to which we will send metrics.\\n\", \"default\": \"\"}, \"CollectdServerPort\": {\"type\": \"number\", \"default\": 25826, \"description\": \"Port on remote collectd server to which we will send metrics.\\n\"}, \"CollectdUsername\": {\"type\": \"string\", \"description\": \"Username for authenticating to the remote collectd server. The default is to not configure any authentication.\\n\", \"default\": \"\"}, \"CollectdPassword\": {\"type\": \"string\", \"hidden\": true, \"description\": \"Password for authenticating to the remote collectd server. The default is to not configure any authentication.\\n\", \"default\": \"\"}, \"CollectdSecurityLevel\": {\"type\": \"string\", \"description\": \"Security level setting for remote collectd connection. If it is set to Sign or Encrypt the CollectdPassword and CollectdUsername parameters need to be set.\\n\", \"default\": \"None\", \"constraints\": [{\"allowed_values\": [\"None\", \"Sign\", \"Encrypt\"]}]}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"CollectdSQLAlchemyLogMessages\": {\"type\": \"string\", \"description\": \"set to \\\"debug\\\" to enable message logging.\", \"default\": \"info\"}, \"CollectdSQLAlchemyBindHost\": {\"type\": \"string\", \"description\": \"hostname for SQLAlchemy-collectd plugin to bind on.  defaults to localhost.\\n\", \"default\": \"localhost\"}, \"CollectdAmqpHost\": {\"type\": \"string\", \"description\": \"Hostname or IP address of the AMQP 1.0 intermediary.\", \"default\": \"nil\"}, \"CollectdAmqpPort\": {\"type\": \"number\", \"description\": \"Service name or port number on which the AMQP 1.0 intermediary accepts connections. This argument must be a string, even if the numeric form is used.\\n\", \"default\": 5666}, \"CollectdAmqpUser\": {\"type\": \"string\", \"description\": \"User part of credentials used to authenticate to the AMQP 1.0 intermediary.\\n\", \"default\": \"guest\"}, \"CollectdAmqpPassword\": {\"type\": \"string\", \"description\": \"Password part of credentials used to authenticate to the AMQP 1.0 intermediary.\\n\", \"default\": \"guest\", \"hidden\": true}, \"CollectdAmqpTransportName\": {\"type\": \"string\", \"description\": \"Name of the AMQP 1.0 transport.\", \"default\": \"metrics\"}, \"CollectdAmqpAddress\": {\"type\": \"string\", \"description\": \"This option specifies the prefix for the send-to value in the message.\\n\", \"default\": \"collectd\"}, \"CollectdAmqpInstances\": {\"type\": \"json\", \"description\": \"Hash of hashes. Each inner hash represent Instance block in plugin configuration file. Key of outter hash represents instance name. The \'address\' value concatenated with the \'name\' given will be used as the send-to address for communications over the messaging link.\\n\", \"default\": {}}, \"CollectdAmqpRetryDelay\": {\"type\": \"number\", \"description\": \"When the AMQP 1.0 connection is lost, defines the time in seconds to wait before attempting to reconnect.\\n\", \"default\": 1}, \"CollectdAmqpInterval\": {\"type\": \"number\", \"description\": \"Interval on which metrics should be sent to AMQP intermediary. If not set the default for all collectd plugins is used.\\n\", \"default\": -666}, \"CollectdAmqpSendQueueLimit\": {\"type\": \"number\", \"description\": \"Number of data sets to be kept in memory, older sets will be discarded, if set to -1, this feature is disabled.\\n\", \"default\": -1}, \"CollectdEnableSensubility\": {\"type\": \"boolean\", \"description\": \"Set to true if sensubility should be executed by exec plugin.\", \"default\": false}, \"CollectdSensubilityExecSudoRule\": {\"type\": \"string\", \"description\": \"Given rule will be created in /etc/sudoers.d for sensubility to enable it calling restricted commands via sensubility executor.\\n\", \"default\": \"\"}, \"CollectdSensubilityLogLevel\": {\"type\": \"string\", \"description\": \"Use for override the default logging level (WARNING).\", \"default\": \"WARNING\"}, \"CollectdSensubilityConnection\": {\"type\": \"string\", \"description\": \"URL to Sensu sever side\", \"default\": \"amqp://sensu:sensu@localhost:5672//sensu\"}, \"CollectdSensubilityKeepaliveInterval\": {\"type\": \"number\", \"description\": \"Interval in seconds for sending keepalive messages to Sensu server side.\", \"default\": 20}, \"CollectdSensubilityTmpDir\": {\"type\": \"string\", \"description\": \"Path to temporary directory which is used for creation of check scripts.\", \"default\": \"/var/tmp/collectd-sensubility-checks\"}, \"CollectdSensubilityShellPath\": {\"type\": \"string\", \"description\": \"Path to shell used for executing check scripts.\", \"default\": \"/usr/bin/sh\"}, \"CollectdSensubilityWorkerCount\": {\"type\": \"number\", \"description\": \"Number of goroutines spawned for executing check scripts.\", \"default\": 2}, \"CollectdSensubilityChecks\": {\"type\": \"json\", \"description\": \"JSON formated definition of standalone checks to be scheduled on client side.\", \"default\": {}}, \"CollectdSensubilityTransport\": {\"type\": \"string\", \"description\": \"Bus type for sent data. Options are \'sensu\' (rabbitmq) and \'amqp1\'\", \"default\": \"sensu\"}, \"CollectdSensubilityResultsChannel\": {\"type\": \"string\", \"description\": \"AMQP1 channel address\", \"default\": \"collectd/notify\"}, \"CollectdSensubilityScripts\": {\"type\": \"json\", \"description\": \"List of hashes of scripts for download for sensubility usage. Value has to be in following format:\\n[{\\\"name\\\": \\\"<script name>\\\", \\\"source\\\": \\\"<http URI to download script>\\\", \\\"checksum\\\": \\\"<alogithm:sum>\\\"}]\\n\", \"default\": []}, \"CollectdEnableContainerHealthCheck\": {\"type\": \"boolean\", \"description\": \"Set to false if container health check should not be defined and attached to CollectdEnableContainerHealthCheck.\\n\", \"default\": true}, \"CollectdContainerHealthCheckCommand\": {\"type\": \"string\", \"default\": \"/config-scripts/collectd_check_health.py\"}, \"CollectdContainerHealthCheckInterval\": {\"type\": \"number\", \"description\": \"The frequency in seconds the docker health check is executed.\", \"default\": 10}, \"CollectdContainerHealthCheckHandlers\": {\"default\": [], \"description\": \"The Sensu event handler to use for events created by the docker health check.\", \"type\": \"comma_delimited_list\"}, \"CollectdContainerHealthCheckOccurrences\": {\"type\": \"number\", \"description\": \"The number of event occurrences before sensu-plugin-aware handler should take action.\", \"default\": 3}, \"CollectdContainerHealthCheckRefresh\": {\"type\": \"number\", \"description\": \"The number of seconds sensu-plugin-aware handlers should wait before taking second action.\", \"default\": 90}, \"EnableSTF\": {\"type\": \"boolean\", \"description\": \"Set to true to enable configuration for STF client.\", \"default\": false}, \"CollectdEnableMcelog\": {\"type\": \"boolean\", \"description\": \"Set to true to enable mcelog\", \"default\": false}, \"CollectdEnableLibpodstats\": {\"type\": \"boolean\", \"description\": \"Set to true if collectd should run the libpodstats plugin\", \"default\": false}, \"CollectdContainerAdditionalCapAdd\": {\"type\": \"comma_delimited_list\", \"description\": \"Additional container capabilities to add to the collectd container. By default is appended to IPC_LOCK.\", \"default\": []}, \"CollectdLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"collectd\", \"file\": \"/var/log/containers/collectd/collectd.log\"}}, \"DeployedCeph\": {\"default\": false, \"type\": \"boolean\", \"description\": \"If the Ceph cluster has already been deployed but needs to be configured\\nso that the overcloud can use it (create cephx keys, pools, configure RGW\\nwith haproxy, etc), then this parameter should be set to true. Set this\\nparameter to false to have cephadm deploy the ceph cluster during overcloud\\ndeployment. DeployedCeph and CephDynamicSpec are mutually exclusive.\\n\"}, \"CephClusterFSID\": {\"type\": \"string\", \"description\": \"The Ceph cluster FSID. Must be a UUID.\", \"default\": \"141c0b27-2417-411f-ad72-876254cd4eac\"}}, \"conditions\": {\"amqp_connection\": {\"equals\": [{\"get_param\": \"CollectdConnectionType\"}, \"amqp1\"]}, \"amqp_default_connection\": {\"equals\": [{\"get_param\": \"CollectdAmqpHost\"}, \"nil\"]}, \"amqp_default_interval\": {\"equals\": [{\"get_param\": \"CollectdAmqpInterval\"}, -666]}, \"amqp_default_send_queue_limit\": {\"equals\": [{\"get_param\": \"CollectdAmqpSendQueueLimit\"}, -1]}, \"collectd_connection\": {\"equals\": [{\"get_param\": \"CollectdConnectionType\"}, \"network\"]}, \"enable_sensubility\": {\"equals\": [{\"get_param\": \"CollectdEnableSensubility\"}, true]}, \"enable_stf\": {\"equals\": [{\"get_param\": \"EnableSTF\"}, true]}, \"enable_sqlalchemy_collectd\": {\"equals\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, true]}, \"sensubility_needs_sudo\": {\"not\": {\"equals\": [{\"get_param\": \"CollectdSensubilityExecSudoRule\"}, \"\"]}}, \"enable_libpodstats\": {\"equals\": [{\"get_param\": \"CollectdEnableLibpodstats\"}, true]}, \"ipmi_monitor\": {\"not\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"IpmiMonitor\"]}, \"\"]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCollectdImage\": \"ContainerCollectdImage\", \"ContainerCollectdConfigImage\": \"ContainerCollectdConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCollectdImage\": {\"get_param\": \"ContainerCollectdImage\"}, \"ContainerCollectdConfigImage\": {\"get_param\": \"ContainerCollectdConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the collectd role.\", \"value\": {\"service_name\": \"collectd\", \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::enable_file_logging\": true, \"collectd::plugin::logfile::log_file\": \"/var/log/collectd/collectd.log\"}, {\"collectd::manage_repo\": false, \"collectd::purge\": true, \"collectd::recurse\": true, \"collectd::purge_config\": true, \"collectd::minimum_version\": \"5.7\", \"collectd::interval\": {\"get_param\": \"CollectdDefaultPollingInterval\"}, \"collectd::plugin::unixsock::socketgroup\": \"root\", \"collectd::plugin::unixsock::socketfile\": \"/run/collectd-socket\", \"collectd::plugin::unixsock::deletesocket\": true, \"collectd::plugin::cpu::reportbycpu\": true, \"collectd::plugin::cpu::reportbystate\": true, \"collectd::plugin::cpu::reportnumcpu\": false, \"collectd::plugin::cpu::valuespercentage\": true, \"collectd::plugin::df::ignoreselected\": true, \"collectd::plugin::df::reportbydevice\": true, \"collectd::plugin::df::fstypes\": [\"xfs\"], \"collectd::plugin::load::reportrelative\": true, \"collectd::plugin::virt::connection\": \"qemu:///system\", \"collectd::plugin::virt::extra_stats\": {\"list_join\": [\" \", [\"pcpu\", \"cpu_util\", \"vcpu\", \"memory\", \"disk\", \"disk_err\", \"disk_allocation\", \"disk_capacity\", \"disk_physical\", \"domain_state\", \"job_stats_background\", \"perf\"]]}, \"collectd::plugin::virt::hostname_format\": \"hostname\", \"tripleo.collectd.plugins.collectd\": {\"yaql\": {\"data\": {\"default_plugins\": {\"get_param\": \"CollectdDefaultPlugins\"}, \"stf_plugins\": {\"if\": [\"enable_stf\", [\"cpu\", \"df\", \"load\", \"connectivity\", \"intel_rdt\", \"procevent\"], []]}, \"extra_plugins\": {\"get_param\": \"CollectdExtraPlugins\"}}, \"expression\": \"($.data.default_plugins + $.data.stf_plugins + $.data.extra_plugins) .flatten().distinct()\\n\"}}}, {\"if\": [\"amqp_connection\", {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::amqp_transport_name\": {\"get_param\": \"CollectdAmqpTransportName\"}, \"tripleo::profile::base::metrics::collectd::amqp_address\": {\"get_param\": \"CollectdAmqpAddress\"}, \"tripleo::profile::base::metrics::collectd::amqp_instances\": {\"get_param\": \"CollectdAmqpInstances\"}, \"tripleo::profile::base::metrics::collectd::amqp_retry_delay\": {\"get_param\": \"CollectdAmqpRetryDelay\"}}, {\"if\": [\"amqp_default_interval\", {}, {\"tripleo::profile::base::metrics::collectd::amqp_interval\": {\"get_param\": \"CollectdAmqpInterval\"}}]}, {\"if\": [\"amqp_default_send_queue_limit\", {}, {\"tripleo::profile::base::metrics::collectd::amqp_send_queue_limit\": {\"get_param\": \"CollectdAmqpSendQueueLimit\"}}]}, {\"if\": [\"amqp_default_connection\", {\"tripleo::profile::base::metrics::collectd::amqp_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"tripleo::profile::base::metrics::collectd::amqp_port\": {\"get_param\": \"MetricsQdrPort\"}, \"tripleo::profile::base::metrics::collectd::amqp_user\": {\"get_param\": \"MetricsQdrUsername\"}, \"tripleo::profile::base::metrics::collectd::amqp_password\": {\"get_param\": \"MetricsQdrPassword\"}}, {\"tripleo::profile::base::metrics::collectd::amqp_host\": {\"get_param\": \"CollectdAmqpHost\"}, \"tripleo::profile::base::metrics::collectd::amqp_port\": {\"get_param\": \"CollectdAmqpPort\"}, \"tripleo::profile::base::metrics::collectd::amqp_user\": {\"get_param\": \"CollectdAmqpUser\"}, \"tripleo::profile::base::metrics::collectd::amqp_password\": {\"get_param\": \"CollectdAmqpPassword\"}}]}]}, {}]}, {\"if\": [\"collectd_connection\", {\"tripleo::profile::base::metrics::collectd::collectd_server\": {\"get_param\": \"CollectdServer\"}, \"tripleo::profile::base::metrics::collectd::collectd_port\": {\"get_param\": \"CollectdServerPort\"}, \"tripleo::profile::base::metrics::collectd::collectd_username\": {\"get_param\": \"CollectdUsername\"}, \"tripleo::profile::base::metrics::collectd::collectd_password\": {\"get_param\": \"CollectdPassword\"}, \"tripleo::profile::base::metrics::collectd::collectd_securitylevel\": {\"get_param\": \"CollectdSecurityLevel\"}}, {}]}, {\"if\": [\"enable_sqlalchemy_collectd\", {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::enable_sqlalchemy_collectd\": true}, {\"tripleo::profile::base::metrics::collectd::sqlalchemy_collectd_bind_host\": {\"get_param\": \"CollectdSQLAlchemyBindHost\"}}, {\"tripleo::profile::base::metrics::collectd::sqlalchemy_collectd_log_messages\": {\"get_param\": \"CollectdSQLAlchemyLogMessages\"}}]}, {}]}, {\"if\": [\"enable_sensubility\", {\"map_merge\": [{\"if\": [\"sensubility_needs_sudo\", {\"tripleo::profile::base::metrics::collectd::sensubility::exec_sudo_rule\": {\"get_param\": \"CollectdSensubilityExecSudoRule\"}}, {}]}, {\"tripleo::profile::base::metrics::collectd::enable_sensubility\": {\"get_param\": \"CollectdEnableSensubility\"}, \"tripleo::profile::base::metrics::collectd::sensubility::connection\": {\"get_param\": \"CollectdSensubilityConnection\"}, \"tripleo::profile::base::metrics::collectd::sensubility::log_level\": {\"get_param\": \"CollectdSensubilityLogLevel\"}, \"tripleo::profile::base::metrics::collectd::sensubility::client_name\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_NETWORK\')}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"tripleo::profile::base::metrics::collectd::sensubility::client_address\": {\"str_replace\": {\"template\": \"%{hiera(\'NETWORK\')}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"tripleo::profile::base::metrics::collectd::sensubility::keepalive_interval\": {\"get_param\": \"CollectdSensubilityKeepaliveInterval\"}, \"tripleo::profile::base::metrics::collectd::sensubility::tmp_base_dir\": {\"get_param\": \"CollectdSensubilityTmpDir\"}, \"tripleo::profile::base::metrics::collectd::sensubility::shell_path\": {\"get_param\": \"CollectdSensubilityShellPath\"}, \"tripleo::profile::base::metrics::collectd::sensubility::worker_count\": {\"get_param\": \"CollectdSensubilityWorkerCount\"}, \"tripleo::profile::base::metrics::collectd::sensubility::checks\": {\"map_merge\": [{\"get_param\": \"CollectdSensubilityChecks\"}, {\"if\": [{\"get_param\": \"CollectdEnableContainerHealthCheck\"}, {\"check-container-health\": {\"standalone\": true, \"command\": {\"get_param\": \"CollectdContainerHealthCheckCommand\"}, \"interval\": {\"get_param\": \"CollectdContainerHealthCheckInterval\"}, \"handlers\": {\"get_param\": \"CollectdContainerHealthCheckHandlers\"}, \"occurrences\": {\"get_param\": \"CollectdContainerHealthCheckOccurrences\"}, \"refresh\": {\"get_param\": \"CollectdContainerHealthCheckRefresh\"}}}, {}]}]}, \"tripleo::profile::base::metrics::collectd::sensubility::results_channel\": {\"get_param\": \"CollectdSensubilityResultsChannel\"}, \"tripleo::profile::base::metrics::collectd::sensubility::transport\": {\"get_param\": \"CollectdSensubilityTransport\"}, \"tripleo::profile::base::metrics::collectd::sensubility::amqp_port\": {\"get_param\": \"CollectdAmqpPort\"}}]}, {}]}, {\"if\": [\"enable_libpodstats\", {\"tripleo::profile::base::metrics::collectd::enable_libpodstats\": {\"get_param\": \"CollectdEnableLibpodstats\"}}, {}]}, {\"if\": [{\"get_param\": \"DeployedCeph\"}, {\"collectd::plugin::ceph::ceph_fsid\": {\"get_param\": \"CephClusterFSID\"}}]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_collectd\": [{\"get_param\": \"CollectdLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"collectd\", \"puppet_tags\": \"collectd_client_config,exec\", \"step_config\": \"include tripleo::profile::base::metrics::collectd\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCollectdConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/collectd.json\": {\"command\": \"/usr/sbin/collectd -f\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/collectd.d\", \"dest\": \"/etc/\", \"merge\": false, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/collectd\", \"owner\": \"collectd:collectd\", \"recurse\": true}, {\"path\": \"/scripts\", \"owner\": \"collectd:collectd\", \"recurse\": true}, {\"path\": \"/config-scripts\", \"owner\": \"collectd:collectd\", \"recurse\": true}]}}, \"container_config_scripts\": {\"map_merge\": [{\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, {\"collectd_check_health.py\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/monitoring/collectd_check_health.py\"}}}]}, \"docker_config\": {\"step_2\": {\"if\": [{\"get_param\": \"CollectdEnableSensubility\"}, {\"collectd_init_perm\": {\"image\": {\"get_param\": \"ContainerCollectdImage\"}, \"net\": \"none\", \"user\": \"root\", \"volumes\": [\"/var/lib/tripleo-podman/collectd:/tmp/run:rw,z\"], \"command\": [\"setfacl\", \"-R\", \"-m\", \"u:collectd:rwx\", \"/tmp/run\"]}}]}, \"step_3\": {\"collectd\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCollectdImage\"]}, \"net\": \"host\", \"pid\": \"host\", \"user\": \"root\", \"restart\": \"always\", \"memory\": \"512m\", \"device\": {\"if\": [\"ipmi_monitor\", {\"get_param\": [\"RoleParameters\", \"IpmiMonitor\"]}]}, \"cap_add\": {\"list_concat\": [{\"get_param\": \"CollectdContainerAdditionalCapAdd\"}, [\"IPC_LOCK\"]]}, \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/collectd.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/containers/storage/overlay-containers:/var/lib/containers/storage/overlay-containers:ro\", \"/var/lib/config-data/puppet-generated/collectd:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/collectd:/var/log/collectd:rw,z\", \"/var/lib/container-config-scripts:/config-scripts:ro\", \"/var/lib/container-user-scripts:/scripts:z\", \"/run:/run:rw\", \"/sys/fs/cgroup:/sys/fs/cgroup:ro\"], {\"if\": [{\"get_param\": \"CollectdEnableSensubility\"}, [\"/var/lib/tripleo-podman/collectd:/run/podman:z\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/collectd\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/container-user-scripts/\", \"setype\": \"container_file_t\", \"mode\": \"0755\"}]}, {\"name\": \"import provision_mcelog\", \"include_role\": {\"name\": \"tripleo_provision_mcelog\"}, \"when\": {\"get_param\": \"CollectdEnableMcelog\"}}], \"deploy_steps_tasks\": [{\"name\": \"set enable_sensubility fact\", \"set_fact\": {\"enable_sensubility\": {\"get_param\": \"CollectdEnableSensubility\"}}}, {\"name\": \"create podman socket for sensubility purposes\", \"block\": [{\"name\": \"create podman socket and appropriate systemd service\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_service\"}, \"vars\": {\"tripleo_podman_socket_path\": \"/var/lib/tripleo-podman/collectd/podman.sock\"}}, {\"name\": \"create systemd service for ensuring socket file ACL contains collectd\", \"become\": true, \"ansible.builtin.copy\": {\"content\": \"[Unit]\\nDescription=ACL setting for /var/lib/tripleo-podman/collectd/podman.sock\\nRequires=tripleo_collectd.service\\nAfter=tripleo_podman.service\\nAfter=tripleo_collectd.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/usr/bin/podman exec -it collectd setfacl -m m:rwx /run/podman/podman.sock\\nExecStart=/usr/bin/podman exec -it collectd setfacl -R -m u:collectd:rwx /run/podman\\nExecStart=/usr/bin/podman exec -it collectd setfacl -d -m u:collectd:rwx /run/podman\\n\\n[Install]\\nWantedBy=multi-user.target\\n\", \"dest\": \"/etc/systemd/system/tripleo_podman_collectd_acl.service\", \"mode\": 420}}, {\"name\": \"enable podman.sock ACL service\", \"ansible.builtin.service\": {\"name\": \"tripleo_podman_collectd_acl.service\", \"enabled\": true}}, {\"name\": \"create directory for downloads of users\' scripts\", \"file\": {\"path\": \"/var/lib/container-user-scripts\", \"state\": \"directory\", \"setype\": \"container_file_t\", \"mode\": \"0755\"}}, {\"name\": \"download exec scripts\", \"ansible.builtin.get_url\": {\"url\": \"{{ item.source }}\", \"checksum\": \"{{ item.checksum }}\", \"dest\": \"/var/lib/container-user-scripts/{{ item.name }}\", \"mode\": \"0755\"}, \"with_items\": {\"get_param\": \"CollectdSensubilityScripts\"}}], \"when\": [\"enable_sensubility|bool\", \"step|int == 1\"]}], \"update_tasks\": [{\"name\": \"remove rsyslog configuration for podman healthcheck log\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_rsyslog_cleanup\"}}], \"upgrade_tasks\": [{\"name\": \"remove rsyslog configuration for podman healthcheck log\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_rsyslog_cleanup\"}}, {\"name\": \"Force pull image collectd\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\"], \"when\": [\"step|int == 3\"], \"containers.podman.podman_image\": {\"name\": {\"get_param\": \"ContainerCollectdImage\"}, \"force\": true}}, {\"name\": \"UBI8 to UBI9 switch of collectd\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\"], \"when\": [\"step|int == 5\"], \"block\": [{\"name\": \"Update collectd to UBI9\", \"tripleo_container_manage\": {\"config_dir\": \"/var/lib/tripleo-config/container-startup-config/step_3\", \"config_patterns\": \"collectd.json\", \"config_id\": [\"tripleo_step3\"], \"log_base_path\": \"{{ container_log_stdout_path }}\", \"debug\": \"{{ enable_debug | bool }}\", \"config_overrides\": {\"collectd\": {\"image\": {\"get_param\": \"ContainerCollectdImage\"}}}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(46,'2026-06-09 08:01:58',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"external_ip_address\": {\"value\": []}, \"ip_address\": {\"value\": []}, \"internal_api_ip_address\": {\"value\": []}, \"ansible_host_vars_map\": {\"value\": []}, \"storage_mgmt_ip_address\": {\"value\": []}, \"tenant_ip_address\": {\"value\": []}, \"hostname\": {\"value\": []}, \"nova_server_resource\": {\"value\": []}, \"hosts_entry\": {\"value\": []}, \"hostname_map\": {\"value\": []}, \"blacklist_ip_address\": {\"value\": []}, \"attributes, nova_server_resource\": {\"value\": {}}, \"blacklist_hostname\": {\"value\": []}, \"storage_ip_address\": {\"value\": []}, \"refs_map\": {\"value\": {}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (47,'2026-06-09 08:01:59',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"HAproxy service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"CAMap\": {\"description\": \"Map containing the CA certs and information needed for deploying them.\\n\", \"default\": {}, \"type\": \"json\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for injecting CA certificates.\", \"value\": {\"service_name\": \"ca_certs\", \"config_settings\": {\"tripleo::trusted_cas::ca_map\": {\"get_param\": \"CAMap\"}}, \"step_config\": \"include tripleo::trusted_cas\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(48,'2026-06-09 08:01:59',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"ip_address\": {\"value\": []}, \"ansible_host_vars_map\": {\"value\": []}, \"storage_mgmt_ip_address\": {\"value\": []}, \"hostname\": {\"value\": []}, \"nova_server_resource\": {\"value\": []}, \"hosts_entry\": {\"value\": []}, \"attributes, nova_server_resource\": {\"value\": {}}, \"hostname_map\": {\"value\": []}, \"blacklist_ip_address\": {\"value\": []}, \"internal_api_ip_address\": {\"value\": []}, \"blacklist_hostname\": {\"value\": []}, \"storage_ip_address\": {\"value\": []}, \"refs_map\": {\"value\": {}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(49,'2026-06-09 08:01:59',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(50,'2026-06-09 08:01:59',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"ControlPlaneIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}, \"EnabledServices\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"type\": \"json\"}, \"ServiceHostnameList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"NetworkHostnameMap\": {\"default\": [], \"type\": \"json\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"RoleNetworks\": {\"default\": \"ctlplane\", \"type\": \"comma_delimited_list\"}}, \"conditions\": {\"is_cell\": {\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}}, \"resources\": {\"EnabledServicesValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> $.data.extra_services.items().where($[0] in $root.data.enabled_services).select($[1]).flatten() + $root.data.enabled_services\", \"data\": {\"enabled_services\": {\"get_param\": \"EnabledServices\"}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"NetIpMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"yaql\": {\"expression\": \"let(root => $) -> dict($.data.net_ip_map.items().where($[0] in $root.data.role_networks))\", \"data\": {\"role_networks\": {\"get_param\": \"RoleNetworks\"}, \"net_ip_map\": {\"ctlplane\": {\"get_param\": \"ControlPlaneIpList\"}, \"storage\": {\"get_param\": \"StorageIpList\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtIpList\"}, \"internal_api\": {\"get_param\": \"InternalApiIpList\"}, \"tenant\": {\"get_param\": \"TenantIpList\"}, \"external\": {\"get_param\": \"ExternalIpList\"}}}}}, {\"keys\": {\"ctlplane\": \"ctlplane\", \"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"external\": {\"get_param\": \"ExternalNetName\"}}}]}}}}, \"outputs\": {\"net_ip_map\": {\"description\": \"A Hash containing a mapping of network names to assigned lists of IP addresses.\\n\", \"value\": {\"get_attr\": [\"NetIpMapValue\", \"value\"]}}, \"ctlplane_service_ips\": {\"description\": \"Map of enabled services to a list of their ctlplane IP addresses\\n\", \"value\": {\"map_merge\": {\"repeat\": {\"template\": {\"SERVICE_ctlplane_node_ips\": \"$$ groups[\'SERVICE\'] | default ([]) | map(\'extract\', hostvars, \'ctlplane_ip\') | list | to_json $$\"}, \"for_each\": {\"SERVICE\": {\"get_attr\": [\"EnabledServicesValue\", \"value\"]}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ControlPlaneIpList\": \"\", \"StorageIpList\": \"\", \"StorageMgmtIpList\": \"\", \"InternalApiIpList\": \"\", \"TenantIpList\": \"\", \"ExternalIpList\": \"\", \"EnabledServices\": \"\", \"ServiceNetMap\": {\"apache_network\": \"internal_api\", \"neutron_tenant_network\": \"tenant\", \"aodh_api_network\": \"internal_api\", \"barbican_api_network\": \"internal_api\", \"gnocchi_api_network\": \"internal_api\", \"mongodb_network\": \"internal_api\", \"cinder_api_network\": \"internal_api\", \"cinder_iscsi_network\": \"storage\", \"glance_api_network\": \"internal_api\", \"glance_api_edge_network\": \"internal_api\", \"glance_api_internal_network\": \"internal_api\", \"ironic_api_network\": \"ctlplane\", \"ironic_network\": \"ctlplane\", \"ironic_inspector_network\": \"ctlplane\", \"keystone_admin_api_network\": \"ctlplane\", \"keystone_public_api_network\": \"internal_api\", \"manila_api_network\": \"internal_api\", \"neutron_api_network\": \"internal_api\", \"octavia_api_network\": \"internal_api\", \"heat_api_network\": \"internal_api\", \"heat_api_cfn_network\": \"internal_api\", \"heat_api_cloudwatch_network\": \"internal_api\", \"nova_api_network\": \"internal_api\", \"placement_network\": \"internal_api\", \"nova_metadata_network\": \"internal_api\", \"nova_libvirt_network\": \"internal_api\", \"novajoin_network\": \"internal_api\", \"swift_storage_network\": \"storage_mgmt\", \"swift_proxy_network\": \"storage\", \"horizon_network\": \"internal_api\", \"memcached_network\": \"internal_api\", \"oslo_messaging_rpc_network\": \"internal_api\", \"oslo_messaging_notify_network\": \"internal_api\", \"rabbitmq_network\": \"internal_api\", \"rabbitmq_management_network\": \"internal_api\", \"qdr_network\": \"internal_api\", \"redis_network\": \"internal_api\", \"ganesha_network\": \"external\", \"mysql_network\": \"internal_api\", \"snmpd_network\": \"ctlplane\", \"ceph_cluster_network\": \"storage_mgmt\", \"ceph_dashboard_network\": \"ctlplane\", \"ceph_grafana_network\": \"storage\", \"ceph_mon_network\": \"storage\", \"ceph_rgw_network\": \"storage\", \"public_network\": \"external\", \"internal_api_network\": \"internal_api\", \"opendaylight_api_network\": \"internal_api\", \"ovn_dbs_network\": \"internal_api\", \"docker_registry_network\": \"ctlplane\", \"pacemaker_network\": \"internal_api\", \"pacemaker_remote_network\": \"internal_api\", \"designate_api_network\": \"internal_api\", \"designate_mdns_network\": \"internal_api\", \"designate_worker_network\": \"external\", \"designate_bind_network\": \"external\", \"bindnetwork\": \"external\", \"etcd_network\": \"internal_api\", \"haproxy_network\": \"ctlplane\", \"unbound_network\": \"external\", \"controller_hostname_resolve_network\": \"internal_api\", \"controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_hostname_resolve_network\": \"internal_api\", \"cell_controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_compute_hostname_resolve_network\": \"internal_api\", \"cell_controller_compute_metrics_qdr_network\": \"internal_api\", \"compute_hostname_resolve_network\": \"internal_api\", \"compute_metrics_qdr_network\": \"internal_api\", \"block_storage_hostname_resolve_network\": \"internal_api\", \"block_storage_metrics_qdr_network\": \"internal_api\", \"object_storage_hostname_resolve_network\": \"internal_api\", \"object_storage_metrics_qdr_network\": \"internal_api\", \"ceph_storage_hostname_resolve_network\": \"storage\", \"ceph_storage_metrics_qdr_network\": \"storage\", \"networker_hostname_resolve_network\": \"internal_api\", \"networker_metrics_qdr_network\": \"internal_api\", \"nova_vnc_proxy_network\": \"internal_api\"}, \"ServiceHostnameList\": \"\", \"NetworkHostnameMap\": {}, \"RoleNetworks\": \"ctlplane,storage,storage_mgmt,internal_api,tenant,external\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(51,'2026-06-09 08:01:59',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"ip_address\": {\"value\": []}, \"ansible_host_vars_map\": {\"value\": []}, \"storage_mgmt_ip_address\": {\"value\": []}, \"hostname\": {\"value\": []}, \"nova_server_resource\": {\"value\": []}, \"hosts_entry\": {\"value\": []}, \"hostname_map\": {\"value\": []}, \"blacklist_ip_address\": {\"value\": []}, \"attributes, nova_server_resource\": {\"value\": {}}, \"blacklist_hostname\": {\"value\": []}, \"storage_ip_address\": {\"value\": []}, \"refs_map\": {\"value\": {}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(52,'2026-06-09 08:02:00',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Add services and subhosts to IPA server\", \"parameters\": {\"RoleNetIpMap\": {\"default\": {}, \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"PythonInterpreter\": {\"type\": \"string\", \"description\": \"The python interpreter to use for python and ansible actions\", \"default\": \"$(command -v python3 || command -v python)\"}, \"IdMDomain\": {\"default\": \"ooo.test\", \"description\": \"IDM domain to register IDM client. Typically, this is discovered through DNS and does not have to be set explicitly.\", \"type\": \"string\"}, \"IdMServer\": {\"default\": \"ipa.ooo.test\", \"description\": \"FQDN for the FreeIPA server.  If you set this value, IdMDomain also has to be provided.  Typically, this is discovered through DNS and does not have to be set explicitly.\", \"type\": \"comma_delimited_list\"}, \"IdMNovaKeytab\": {\"default\": \"FILE:/etc/novajoin/krb5.keytab\", \"description\": \"keytab for the nova/[host fqdn] user on the FreeIPA server.\", \"type\": \"string\"}, \"IdMNovaCredentialCache\": {\"default\": \"/etc/novajoin/krb5.cache\", \"description\": \"credential cache for nova/[host fqdn] user\", \"type\": \"string\"}, \"MakeHomeDir\": {\"type\": \"boolean\", \"description\": \"Configure PAM to create a users home directory if it does not exist.\", \"default\": false}, \"IdMNoNtpSetup\": {\"default\": false, \"description\": \"Set to true to add --no-ntp to the IDM client install call. This will cause IDM client install not to set up NTP.\", \"type\": \"boolean\"}, \"IdMEnrollBaseServer\": {\"default\": true, \"description\": \"Set to true to enroll the base server (computes, controllers)\", \"type\": \"boolean\"}, \"IdMInstallClientPackages\": {\"default\": false, \"description\": \"Set to True to have ansible-freeipa install ipa client packages on the overcloud node.\", \"type\": \"boolean\"}, \"IdMModifyDNS\": {\"default\": true, \"description\": \"Set to false to disable DNS records manipulation in the FreeIPA server.\", \"type\": \"boolean\"}, \"IdMZoneSplitIPv4\": {\"default\": 1, \"description\": \"The level by which the PTR DNS record is split when creating zones.\", \"type\": \"string\"}, \"IdMZoneSplitIPv6\": {\"default\": 1, \"description\": \"The level by which the PTR DNS record is split when creating zones.\", \"type\": \"string\"}}, \"conditions\": {\"idm_server_provided\": {\"not\": {\"equals\": [{\"get_param\": \"IdMServer\"}, []]}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the ipaservice service\", \"value\": {\"service_name\": \"ipaservice\", \"upgrade_tasks\": [], \"step_config\": \"\", \"ipa_registration_tasks\": [{\"name\": \"Get undercloud FQDN\", \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"set_fact\": {\"undercloud_fqdn\": \"{{ ansible_facts[\'fqdn\'] }}\"}}, {\"include_role\": {\"name\": \"tripleo_ipa_registration\", \"apply\": {\"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"environment\": {\"map_merge\": [{\"IPA_USER\": \"nova/{{ undercloud_fqdn }}\", \"KRB5_CLIENT_KTNAME\": {\"get_param\": \"IdMNovaKeytab\"}, \"KRB5CCNAME\": {\"get_param\": \"IdMNovaCredentialCache\"}}, {\"if\": [\"idm_server_provided\", {\"IPA_HOST\": {\"get_param\": [\"IdMServer\", 0]}}]}]}}}, \"vars\": {\"tripleo_ipa_enroll_base_server\": {\"get_param\": \"IdMEnrollBaseServer\"}, \"tripleo_ipa_delegate_server\": \"{{ inventory_hostname }}\", \"tripleo_ipa_base_server_fqdn\": \"{{ fqdn_canonical }}\", \"tripleo_ipa_server_metadata\": \"{{ service_metadata_settings | to_json }}\"}, \"when\": \"\'ipaservice\' in group_names and \'excluded_overcloud\' not in group_names\"}, {\"name\": \"Enroll the node as an ipa client\", \"vars\": {\"ipaclient_install_packages\": {\"get_param\": \"IdMInstallClientPackages\"}, \"idm_enroll_base_server\": {\"get_param\": \"IdMEnrollBaseServer\"}}, \"block\": [{\"name\": \"check if default.conf exists\", \"stat\": {\"path\": \"/etc/ipa/default.conf\"}, \"register\": \"ipa_conf_exists\"}, {\"name\": \"install openssl-perl\", \"become\": true, \"package\": {\"name\": \"openssl-perl\", \"state\": \"present\"}, \"when\": [\"ipaclient_install_packages|bool\"]}, {\"name\": \"register as an ipa client\", \"include_role\": {\"name\": \"ipaclient\", \"apply\": {\"become\": true}}, \"vars\": {\"map_merge\": [{\"state\": \"present\", \"ipaclient_otp\": \"{{ ipa_host_otp }}\", \"ipaclient_mkhomedir\": {\"get_param\": \"MakeHomeDir\"}, \"ipaclient_no_ntp\": {\"get_param\": \"IdMNoNtpSetup\"}, \"ipaclient_force\": true, \"ipaclient_hostname\": \"{{ fqdn_canonical }}\", \"ansible_fqdn\": \"{{ ipaclient_hostname }}\", \"ipaclients\": [\"ipaclient_hostname\"], \"ansible_distribution\": \"{{ ansible_facts[\'distribution\'] }}\", \"ansible_distribution_major_version\": \"{{ ansible_facts[\'distribution_major_version\'] }}\", \"ansible_distribution_release\": \"{{ ansible_facts[\'distribution_release\'] }}\", \"ansible_distribution_version\": \"{{ ansible_facts[\'distribution_version\'] }}\", \"ansible_os_family\": \"{{ ansible_facts[\'os_family\'] }}\"}, {\"if\": [\"idm_server_provided\", {\"ipaclient_servers\": {\"get_param\": \"IdMServer\"}, \"ipaclient_domain\": {\"get_param\": \"IdMDomain\"}}]}]}, \"when\": [\"idm_enroll_base_server|bool\", \"not ipa_conf_exists.stat.exists\"]}, {\"name\": \"restart certmonger service\", \"become\": true, \"systemd\": {\"state\": \"restarted\", \"daemon_reload\": true, \"name\": \"certmonger.service\"}, \"when\": [\"idm_enroll_base_server|bool\", \"not ipa_conf_exists.stat.exists\"]}, {\"name\": \"set discovered ipa realm\", \"set_fact\": {\"idm_realm\": {\"str_replace\": {\"template\": \"{{ lookup(\'ini\', \'realm default=DEFAULT section=global file=/etc/ipa/default.conf\')}}\", \"params\": {\"DEFAULT\": {\"yaql\": {\"expression\": \"$.data.toUpper()\", \"data\": {\"get_param\": \"IdMDomain\"}}}}}}}}], \"when\": \"\'ipaservice\' in group_names and \'excluded_overcloud\' not in group_names\"}], \"external_deploy_tasks\": [{\"name\": \"add the DNS entries into IPA in step 1\", \"when\": \"step|int == 1\", \"block\": [{\"include_role\": {\"name\": \"tripleo_ipa_dns\"}, \"vars\": {\"tripleo_ipa_ptr_zone_split_ipv4\": {\"get_param\": \"IdMZoneSplitIPv4\"}, \"tripleo_ipa_ptr_zone_split_ipv6\": {\"get_param\": \"IdMZoneSplitIPv6\"}}, \"when\": {\"get_param\": \"IdMModifyDNS\"}}], \"environment\": {\"map_merge\": [{\"IPA_USER\": \"nova/{{ ansible_facts[\'fqdn\'] }}\", \"KRB5_CLIENT_KTNAME\": {\"get_param\": \"IdMNovaKeytab\"}, \"KRB5CCNAME\": {\"get_param\": \"IdMNovaCredentialCache\"}}, {\"if\": [\"idm_server_provided\", {\"IPA_HOST\": {\"get_param\": [\"IdMServer\", 0]}}]}]}}], \"scale_tasks\": [{\"when\": \"step|int == 1\", \"tags\": \"down\", \"block\": [{\"name\": \"unregister node from ipa server\", \"import_role\": {\"name\": \"tripleo_ipa_cleanup\"}, \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"vars\": {\"tripleo_ipa_keytab\": {\"get_param\": \"IdMNovaKeytab\"}, \"tripleo_ipa_hosts_to_delete\": [\"{{ fqdn_canonical }}\"]}}]}], \"external_upgrade_tasks\": [{\"when\": \"step|int == 1\", \"block\": [{\"name\": \"check if ipa server has required permissions\", \"import_role\": {\"name\": \"tls_everywhere\", \"tasks_from\": \"ipa-server-check\"}, \"tags\": [\"opendev-validation\", \"opendev-validation-tls-everywhere\"]}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(53,'2026-06-09 08:02:00',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Host config and reboot service which configures Kernel Args and reboot\", \"parameters\": {\"RoleNetIpMap\": {\"default\": {}, \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KernelArgs\": {\"default\": \"\", \"type\": \"string\", \"description\": \"Kernel Args to apply to the host\", \"tags\": [\"role_specific\"]}, \"KernelArgsDeferReboot\": {\"default\": false, \"type\": \"boolean\", \"description\": \"When enabled, nodes will not get rebooted automatically by tripleo-kernel if KernelArgs have been changed. Operators will have to manually reboot nodes after the deployment or update process is completed.\\nLeaving this enabled during a scale-up operation will prevent reboot on new nodes. This might cause deployment errors as the KernelArgs will not be applied.\\n\", \"tags\": [\"role_specific\"]}, \"TunedProfileName\": {\"default\": \"throughput-performance\", \"type\": \"string\", \"description\": \"Tuned Profile to apply to the host\", \"tags\": [\"role_specific\"]}, \"IsolCpusList\": {\"default\": \"\", \"type\": \"string\", \"description\": \"List of logical CPU ids whic need to be isolated from the host processes. This input is provided to the tuned profile cpu-partitioning to configure systemd and repin interrupts (IRQ repinning).\\n\", \"tags\": [\"role_specific\"]}, \"NodeRebootWaitTimeout\": {\"default\": 900, \"type\": \"number\", \"description\": \"Timeout in seconds to specify the wait time for ansible node reboot\"}, \"Hugepages\": {\"default\": {}, \"type\": \"json\", \"description\": \"Hash for hugepage configuration Example:\\n  Hugepages:\\n    2048:\\n      count: 100\\n      default: false\\n    1048576:\\n      count: 100\\n      default: true\\n\", \"tags\": [\"role_specific\"]}, \"ReconfigureHugepages\": {\"default\": false, \"type\": \"boolean\", \"description\": \"By default, tripleo-kernel will configure the provided Hugepages as specified by operators but it won\'t try to remove Hugepages configured on the host that are not part of the TripleO paramater. Enabling this setting will make sure everything is reconfigured exactly like the TripleO parameter, otherwise we just add the content of the Hugepages parameter to what\'s already in place.\\n\", \"tags\": [\"role_specific\"]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"tuned_profile\": \"TunedProfileName\", \"isolated_cores\": \"IsolCpusList\", \"kernel_args\": \"KernelArgs\", \"kernel_args_defer_reboot\": \"KernelArgsDeferReboot\", \"hugepages\": \"Hugepages\", \"reconfigure_hugepages\": \"ReconfigureHugepages\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"TunedProfileName\": {\"get_param\": \"TunedProfileName\"}, \"IsolCpusList\": {\"get_param\": \"IsolCpusList\"}, \"KernelArgs\": {\"get_param\": \"KernelArgs\"}, \"KernelArgsDeferReboot\": {\"get_param\": \"KernelArgsDeferReboot\"}, \"Hugepages\": {\"get_param\": \"Hugepages\"}, \"ReconfigureHugepages\": {\"get_param\": \"ReconfigureHugepages\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Host Config Service\", \"value\": {\"service_name\": \"boot_params_service\", \"deploy_steps_tasks\": [{\"name\": \"Configure tuned before reboot\", \"when\": \"step|int == 0\", \"include_role\": {\"name\": \"tuned\"}, \"vars\": {\"tuned_profile\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"tuned_profile\"]}, \"tuned_isolated_cores\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"isolated_cores\"]}}}, {\"name\": \"Configure kernel args and reboot\", \"when\": \"step|int == 0\", \"include_role\": {\"name\": \"tripleo_kernel\", \"tasks_from\": \"kernelargs.yml\"}, \"vars\": {\"tripleo_kernel_args\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"kernel_args\"]}, \"tripleo_kernel_hugepages\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"hugepages\"]}, \"tripleo_kernel_hugepages_remove\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"reconfigure_hugepages\"]}, \"tripleo_kernel_defer_reboot\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"kernel_args_defer_reboot\"]}, \"tripleo_kernel_reboot_timeout\": {\"get_param\": \"NodeRebootWaitTimeout\"}}}], \"upgrade_tasks\": [{\"name\": \"upgrade prepare for leapp to align kernel arg shortcommings in leapp\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_prepare\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"fix grub entries to have name start with GRUB_\", \"replace\": {\"path\": \"/etc/default/grub\", \"regexp\": \"^(TRIPLEO_HEAT_TEMPLATE_KERNEL_ARGS)(.*)\", \"replace\": \"GRUB_\\\\1\\\\2\"}}, {\"name\": \"fix grub entries in append statement\", \"replace\": {\"path\": \"/etc/default/grub\", \"regexp\": \"(.*){(TRIPLEO_HEAT_TEMPLATE_KERNEL_ARGS)}(.*)\", \"replace\": \"\\\\1{GRUB_\\\\2}\\\\3\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(54,'2026-06-09 08:02:00',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"ControlPlaneIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}, \"EnabledServices\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"type\": \"json\"}, \"ServiceHostnameList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"NetworkHostnameMap\": {\"default\": [], \"type\": \"json\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"RoleNetworks\": {\"default\": \"ctlplane\", \"type\": \"comma_delimited_list\"}}, \"conditions\": {\"is_cell\": {\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}}, \"resources\": {\"EnabledServicesValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> $.data.extra_services.items().where($[0] in $root.data.enabled_services).select($[1]).flatten() + $root.data.enabled_services\", \"data\": {\"enabled_services\": {\"get_param\": \"EnabledServices\"}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"NetIpMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"yaql\": {\"expression\": \"let(root => $) -> dict($.data.net_ip_map.items().where($[0] in $root.data.role_networks))\", \"data\": {\"role_networks\": {\"get_param\": \"RoleNetworks\"}, \"net_ip_map\": {\"ctlplane\": {\"get_param\": \"ControlPlaneIpList\"}, \"storage\": {\"get_param\": \"StorageIpList\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtIpList\"}, \"internal_api\": {\"get_param\": \"InternalApiIpList\"}, \"tenant\": {\"get_param\": \"TenantIpList\"}, \"external\": {\"get_param\": \"ExternalIpList\"}}}}}, {\"keys\": {\"ctlplane\": \"ctlplane\", \"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"external\": {\"get_param\": \"ExternalNetName\"}}}]}}}}, \"outputs\": {\"net_ip_map\": {\"description\": \"A Hash containing a mapping of network names to assigned lists of IP addresses.\\n\", \"value\": {\"get_attr\": [\"NetIpMapValue\", \"value\"]}}, \"ctlplane_service_ips\": {\"description\": \"Map of enabled services to a list of their ctlplane IP addresses\\n\", \"value\": {\"map_merge\": {\"repeat\": {\"template\": {\"SERVICE_ctlplane_node_ips\": \"$$ groups[\'SERVICE\'] | default ([]) | map(\'extract\', hostvars, \'ctlplane_ip\') | list | to_json $$\"}, \"for_each\": {\"SERVICE\": {\"get_attr\": [\"EnabledServicesValue\", \"value\"]}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ControlPlaneIpList\": \"\", \"StorageIpList\": \"\", \"StorageMgmtIpList\": \"\", \"InternalApiIpList\": \"\", \"TenantIpList\": \"\", \"ExternalIpList\": \"\", \"EnabledServices\": \"\", \"ServiceNetMap\": {\"apache_network\": \"internal_api\", \"neutron_tenant_network\": \"tenant\", \"aodh_api_network\": \"internal_api\", \"barbican_api_network\": \"internal_api\", \"gnocchi_api_network\": \"internal_api\", \"mongodb_network\": \"internal_api\", \"cinder_api_network\": \"internal_api\", \"cinder_iscsi_network\": \"storage\", \"glance_api_network\": \"internal_api\", \"glance_api_edge_network\": \"internal_api\", \"glance_api_internal_network\": \"internal_api\", \"ironic_api_network\": \"ctlplane\", \"ironic_network\": \"ctlplane\", \"ironic_inspector_network\": \"ctlplane\", \"keystone_admin_api_network\": \"ctlplane\", \"keystone_public_api_network\": \"internal_api\", \"manila_api_network\": \"internal_api\", \"neutron_api_network\": \"internal_api\", \"octavia_api_network\": \"internal_api\", \"heat_api_network\": \"internal_api\", \"heat_api_cfn_network\": \"internal_api\", \"heat_api_cloudwatch_network\": \"internal_api\", \"nova_api_network\": \"internal_api\", \"placement_network\": \"internal_api\", \"nova_metadata_network\": \"internal_api\", \"nova_libvirt_network\": \"internal_api\", \"novajoin_network\": \"internal_api\", \"swift_storage_network\": \"storage_mgmt\", \"swift_proxy_network\": \"storage\", \"horizon_network\": \"internal_api\", \"memcached_network\": \"internal_api\", \"oslo_messaging_rpc_network\": \"internal_api\", \"oslo_messaging_notify_network\": \"internal_api\", \"rabbitmq_network\": \"internal_api\", \"rabbitmq_management_network\": \"internal_api\", \"qdr_network\": \"internal_api\", \"redis_network\": \"internal_api\", \"ganesha_network\": \"external\", \"mysql_network\": \"internal_api\", \"snmpd_network\": \"ctlplane\", \"ceph_cluster_network\": \"storage_mgmt\", \"ceph_dashboard_network\": \"ctlplane\", \"ceph_grafana_network\": \"storage\", \"ceph_mon_network\": \"storage\", \"ceph_rgw_network\": \"storage\", \"public_network\": \"external\", \"internal_api_network\": \"internal_api\", \"opendaylight_api_network\": \"internal_api\", \"ovn_dbs_network\": \"internal_api\", \"docker_registry_network\": \"ctlplane\", \"pacemaker_network\": \"internal_api\", \"pacemaker_remote_network\": \"internal_api\", \"designate_api_network\": \"internal_api\", \"designate_mdns_network\": \"internal_api\", \"designate_worker_network\": \"external\", \"designate_bind_network\": \"external\", \"bindnetwork\": \"external\", \"etcd_network\": \"internal_api\", \"haproxy_network\": \"ctlplane\", \"unbound_network\": \"external\", \"controller_hostname_resolve_network\": \"internal_api\", \"controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_hostname_resolve_network\": \"internal_api\", \"cell_controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_compute_hostname_resolve_network\": \"internal_api\", \"cell_controller_compute_metrics_qdr_network\": \"internal_api\", \"compute_hostname_resolve_network\": \"internal_api\", \"compute_metrics_qdr_network\": \"internal_api\", \"block_storage_hostname_resolve_network\": \"internal_api\", \"block_storage_metrics_qdr_network\": \"internal_api\", \"object_storage_hostname_resolve_network\": \"internal_api\", \"object_storage_metrics_qdr_network\": \"internal_api\", \"ceph_storage_hostname_resolve_network\": \"storage\", \"ceph_storage_metrics_qdr_network\": \"storage\", \"networker_hostname_resolve_network\": \"internal_api\", \"networker_metrics_qdr_network\": \"internal_api\", \"nova_vnc_proxy_network\": \"internal_api\"}, \"ServiceHostnameList\": \"\", \"NetworkHostnameMap\": {}, \"RoleNetworks\": \"ctlplane,storage,storage_mgmt,internal_api,tenant,external\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(55,'2026-06-09 08:02:00',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Host config and reboot service which configures Kernel Args and reboot\", \"parameters\": {\"RoleNetIpMap\": {\"default\": {}, \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KernelArgs\": {\"default\": \"\", \"type\": \"string\", \"description\": \"Kernel Args to apply to the host\", \"tags\": [\"role_specific\"]}, \"KernelArgsDeferReboot\": {\"default\": false, \"type\": \"boolean\", \"description\": \"When enabled, nodes will not get rebooted automatically by tripleo-kernel if KernelArgs have been changed. Operators will have to manually reboot nodes after the deployment or update process is completed.\\nLeaving this enabled during a scale-up operation will prevent reboot on new nodes. This might cause deployment errors as the KernelArgs will not be applied.\\n\", \"tags\": [\"role_specific\"]}, \"TunedProfileName\": {\"default\": \"throughput-performance\", \"type\": \"string\", \"description\": \"Tuned Profile to apply to the host\", \"tags\": [\"role_specific\"]}, \"IsolCpusList\": {\"default\": \"\", \"type\": \"string\", \"description\": \"List of logical CPU ids whic need to be isolated from the host processes. This input is provided to the tuned profile cpu-partitioning to configure systemd and repin interrupts (IRQ repinning).\\n\", \"tags\": [\"role_specific\"]}, \"NodeRebootWaitTimeout\": {\"default\": 900, \"type\": \"number\", \"description\": \"Timeout in seconds to specify the wait time for ansible node reboot\"}, \"Hugepages\": {\"default\": {}, \"type\": \"json\", \"description\": \"Hash for hugepage configuration Example:\\n  Hugepages:\\n    2048:\\n      count: 100\\n      default: false\\n    1048576:\\n      count: 100\\n      default: true\\n\", \"tags\": [\"role_specific\"]}, \"ReconfigureHugepages\": {\"default\": false, \"type\": \"boolean\", \"description\": \"By default, tripleo-kernel will configure the provided Hugepages as specified by operators but it won\'t try to remove Hugepages configured on the host that are not part of the TripleO paramater. Enabling this setting will make sure everything is reconfigured exactly like the TripleO parameter, otherwise we just add the content of the Hugepages parameter to what\'s already in place.\\n\", \"tags\": [\"role_specific\"]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"tuned_profile\": \"TunedProfileName\", \"isolated_cores\": \"IsolCpusList\", \"kernel_args\": \"KernelArgs\", \"kernel_args_defer_reboot\": \"KernelArgsDeferReboot\", \"hugepages\": \"Hugepages\", \"reconfigure_hugepages\": \"ReconfigureHugepages\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"TunedProfileName\": {\"get_param\": \"TunedProfileName\"}, \"IsolCpusList\": {\"get_param\": \"IsolCpusList\"}, \"KernelArgs\": {\"get_param\": \"KernelArgs\"}, \"KernelArgsDeferReboot\": {\"get_param\": \"KernelArgsDeferReboot\"}, \"Hugepages\": {\"get_param\": \"Hugepages\"}, \"ReconfigureHugepages\": {\"get_param\": \"ReconfigureHugepages\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Host Config Service\", \"value\": {\"service_name\": \"boot_params_service\", \"deploy_steps_tasks\": [{\"name\": \"Configure tuned before reboot\", \"when\": \"step|int == 0\", \"include_role\": {\"name\": \"tuned\"}, \"vars\": {\"tuned_profile\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"tuned_profile\"]}, \"tuned_isolated_cores\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"isolated_cores\"]}}}, {\"name\": \"Configure kernel args and reboot\", \"when\": \"step|int == 0\", \"include_role\": {\"name\": \"tripleo_kernel\", \"tasks_from\": \"kernelargs.yml\"}, \"vars\": {\"tripleo_kernel_args\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"kernel_args\"]}, \"tripleo_kernel_hugepages\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"hugepages\"]}, \"tripleo_kernel_hugepages_remove\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"reconfigure_hugepages\"]}, \"tripleo_kernel_defer_reboot\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"kernel_args_defer_reboot\"]}, \"tripleo_kernel_reboot_timeout\": {\"get_param\": \"NodeRebootWaitTimeout\"}}}], \"upgrade_tasks\": [{\"name\": \"upgrade prepare for leapp to align kernel arg shortcommings in leapp\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_prepare\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"fix grub entries to have name start with GRUB_\", \"replace\": {\"path\": \"/etc/default/grub\", \"regexp\": \"^(TRIPLEO_HEAT_TEMPLATE_KERNEL_ARGS)(.*)\", \"replace\": \"GRUB_\\\\1\\\\2\"}}, {\"name\": \"fix grub entries in append statement\", \"replace\": {\"path\": \"/etc/default/grub\", \"regexp\": \"(.*){(TRIPLEO_HEAT_TEMPLATE_KERNEL_ARGS)}(.*)\", \"replace\": \"\\\\1{GRUB_\\\\2}\\\\3\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (56,'2026-06-09 08:02:00',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"ip_address\": {\"value\": []}, \"internal_api_ip_address\": {\"value\": []}, \"ansible_host_vars_map\": {\"value\": []}, \"tenant_ip_address\": {\"value\": []}, \"hostname\": {\"value\": []}, \"nova_server_resource\": {\"value\": []}, \"hosts_entry\": {\"value\": []}, \"hostname_map\": {\"value\": []}, \"blacklist_ip_address\": {\"value\": []}, \"attributes, nova_server_resource\": {\"value\": {}}, \"blacklist_hostname\": {\"value\": []}, \"refs_map\": {\"value\": {}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(57,'2026-06-09 08:02:01',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"ControlPlaneIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}, \"EnabledServices\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"type\": \"json\"}, \"ServiceHostnameList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"NetworkHostnameMap\": {\"default\": [], \"type\": \"json\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"RoleNetworks\": {\"default\": \"ctlplane\", \"type\": \"comma_delimited_list\"}}, \"conditions\": {\"is_cell\": {\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}}, \"resources\": {\"EnabledServicesValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> $.data.extra_services.items().where($[0] in $root.data.enabled_services).select($[1]).flatten() + $root.data.enabled_services\", \"data\": {\"enabled_services\": {\"get_param\": \"EnabledServices\"}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"NetIpMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"yaql\": {\"expression\": \"let(root => $) -> dict($.data.net_ip_map.items().where($[0] in $root.data.role_networks))\", \"data\": {\"role_networks\": {\"get_param\": \"RoleNetworks\"}, \"net_ip_map\": {\"ctlplane\": {\"get_param\": \"ControlPlaneIpList\"}, \"storage\": {\"get_param\": \"StorageIpList\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtIpList\"}, \"internal_api\": {\"get_param\": \"InternalApiIpList\"}, \"tenant\": {\"get_param\": \"TenantIpList\"}, \"external\": {\"get_param\": \"ExternalIpList\"}}}}}, {\"keys\": {\"ctlplane\": \"ctlplane\", \"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"external\": {\"get_param\": \"ExternalNetName\"}}}]}}}}, \"outputs\": {\"net_ip_map\": {\"description\": \"A Hash containing a mapping of network names to assigned lists of IP addresses.\\n\", \"value\": {\"get_attr\": [\"NetIpMapValue\", \"value\"]}}, \"ctlplane_service_ips\": {\"description\": \"Map of enabled services to a list of their ctlplane IP addresses\\n\", \"value\": {\"map_merge\": {\"repeat\": {\"template\": {\"SERVICE_ctlplane_node_ips\": \"$$ groups[\'SERVICE\'] | default ([]) | map(\'extract\', hostvars, \'ctlplane_ip\') | list | to_json $$\"}, \"for_each\": {\"SERVICE\": {\"get_attr\": [\"EnabledServicesValue\", \"value\"]}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ControlPlaneIpList\": \"\", \"StorageIpList\": \"\", \"StorageMgmtIpList\": \"\", \"EnabledServices\": \"\", \"ServiceNetMap\": {\"apache_network\": \"internal_api\", \"neutron_tenant_network\": \"tenant\", \"aodh_api_network\": \"internal_api\", \"barbican_api_network\": \"internal_api\", \"gnocchi_api_network\": \"internal_api\", \"mongodb_network\": \"internal_api\", \"cinder_api_network\": \"internal_api\", \"cinder_iscsi_network\": \"storage\", \"glance_api_network\": \"internal_api\", \"glance_api_edge_network\": \"internal_api\", \"glance_api_internal_network\": \"internal_api\", \"ironic_api_network\": \"ctlplane\", \"ironic_network\": \"ctlplane\", \"ironic_inspector_network\": \"ctlplane\", \"keystone_admin_api_network\": \"ctlplane\", \"keystone_public_api_network\": \"internal_api\", \"manila_api_network\": \"internal_api\", \"neutron_api_network\": \"internal_api\", \"octavia_api_network\": \"internal_api\", \"heat_api_network\": \"internal_api\", \"heat_api_cfn_network\": \"internal_api\", \"heat_api_cloudwatch_network\": \"internal_api\", \"nova_api_network\": \"internal_api\", \"placement_network\": \"internal_api\", \"nova_metadata_network\": \"internal_api\", \"nova_libvirt_network\": \"internal_api\", \"novajoin_network\": \"internal_api\", \"swift_storage_network\": \"storage_mgmt\", \"swift_proxy_network\": \"storage\", \"horizon_network\": \"internal_api\", \"memcached_network\": \"internal_api\", \"oslo_messaging_rpc_network\": \"internal_api\", \"oslo_messaging_notify_network\": \"internal_api\", \"rabbitmq_network\": \"internal_api\", \"rabbitmq_management_network\": \"internal_api\", \"qdr_network\": \"internal_api\", \"redis_network\": \"internal_api\", \"ganesha_network\": \"external\", \"mysql_network\": \"internal_api\", \"snmpd_network\": \"ctlplane\", \"ceph_cluster_network\": \"storage_mgmt\", \"ceph_dashboard_network\": \"ctlplane\", \"ceph_grafana_network\": \"storage\", \"ceph_mon_network\": \"storage\", \"ceph_rgw_network\": \"storage\", \"public_network\": \"external\", \"internal_api_network\": \"internal_api\", \"opendaylight_api_network\": \"internal_api\", \"ovn_dbs_network\": \"internal_api\", \"docker_registry_network\": \"ctlplane\", \"pacemaker_network\": \"internal_api\", \"pacemaker_remote_network\": \"internal_api\", \"designate_api_network\": \"internal_api\", \"designate_mdns_network\": \"internal_api\", \"designate_worker_network\": \"external\", \"designate_bind_network\": \"external\", \"bindnetwork\": \"external\", \"etcd_network\": \"internal_api\", \"haproxy_network\": \"ctlplane\", \"unbound_network\": \"external\", \"controller_hostname_resolve_network\": \"internal_api\", \"controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_hostname_resolve_network\": \"internal_api\", \"cell_controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_compute_hostname_resolve_network\": \"internal_api\", \"cell_controller_compute_metrics_qdr_network\": \"internal_api\", \"compute_hostname_resolve_network\": \"internal_api\", \"compute_metrics_qdr_network\": \"internal_api\", \"block_storage_hostname_resolve_network\": \"internal_api\", \"block_storage_metrics_qdr_network\": \"internal_api\", \"object_storage_hostname_resolve_network\": \"internal_api\", \"object_storage_metrics_qdr_network\": \"internal_api\", \"ceph_storage_hostname_resolve_network\": \"storage\", \"ceph_storage_metrics_qdr_network\": \"storage\", \"networker_hostname_resolve_network\": \"internal_api\", \"networker_metrics_qdr_network\": \"internal_api\", \"nova_vnc_proxy_network\": \"internal_api\"}, \"ServiceHostnameList\": \"\", \"NetworkHostnameMap\": {}, \"RoleNetworks\": \"ctlplane,storage,storage_mgmt\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(58,'2026-06-09 08:02:01',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Ceilometer Agent Notification service\\n\", \"parameters\": {\"ContainerCeilometerNotificationImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\"}, \"ContainerCeilometerConfigImage\": {\"description\": \"The container image to use for the ceilometer config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\"}, \"CeilometerAgentNotificationLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.ceilometer.agent.notification\", \"file\": \"/var/log/containers/ceilometer/agent-notification.log\"}}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"MonitoringSubscriptionCeilometerNotification\": {\"default\": \"overcloud-ceilometer-agent-notification\", \"type\": \"string\"}, \"MetricsQdrPort\": {\"default\": 5666, \"description\": \"Service name or port number on which the qdrouterd will accept connections.\", \"type\": \"number\"}, \"CeilometerQdrPublishEvents\": {\"default\": false, \"description\": \"Whether to send events to MetricsQdr service.\", \"type\": \"boolean\"}, \"CeilometerQdrPublishMetrics\": {\"default\": false, \"description\": \"Whether to send telemetry data to MetricsQdr service.\", \"type\": \"boolean\"}, \"CeilometerQdrEventsConfig\": {\"default\": {\"driver\": \"amqp\", \"topic\": \"event\"}, \"description\": \"Configuration for notifier publisher for events.\", \"type\": \"json\"}, \"CeilometerQdrMetricsConfig\": {\"default\": {\"driver\": \"amqp\", \"topic\": \"metering\"}, \"description\": \"Configuration for notifier publisher for metrics.\", \"type\": \"json\"}, \"ManageEventPipeline\": {\"default\": true, \"description\": \"Whether to manage event_pipeline.yaml.\", \"type\": \"boolean\"}, \"EventPipelinePublishers\": {\"default\": [], \"description\": \"A list of publishers to put in event_pipeline.yaml. When the collector is used, override this with notifier:// publisher. Set ManageEventPipeline to true for override to take effect.\\n\", \"type\": \"comma_delimited_list\"}, \"ManagePipeline\": {\"default\": false, \"description\": \"Whether to manage pipeline.yaml.\", \"type\": \"boolean\"}, \"PipelinePublishers\": {\"default\": [], \"description\": \"A list of publishers to put in pipeline.yaml. When the collector is used, override this with notifier:// publisher. Set ManagePipeline to true for override to take effect.\\n\", \"type\": \"comma_delimited_list\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CeilometerServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCeilometerNotificationImage\": \"ContainerCeilometerNotificationImage\", \"ContainerCeilometerConfigImage\": \"ContainerCeilometerConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCeilometerNotificationImage\": {\"get_param\": \"ContainerCeilometerNotificationImage\"}, \"ContainerCeilometerConfigImage\": {\"get_param\": \"ContainerCeilometerConfigImage\"}}}]}}}}, \"conditions\": {\"ceilometer_qdr_publish\": {\"or\": [{\"get_param\": \"CeilometerQdrPublishEvents\"}, {\"get_param\": \"CeilometerQdrPublishMetrics\"}]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer Agent Notification role.\", \"value\": {\"service_name\": \"ceilometer_agent_notification\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionCeilometerNotification\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CeilometerServiceBase\", \"role_data\", \"config_settings\"]}, {\"ceilometer::agent::notification::manage_event_pipeline\": {\"get_param\": \"ManageEventPipeline\"}, \"ceilometer::agent::notification::manage_pipeline\": {\"get_param\": \"ManagePipeline\"}, \"tripleo::profile::base::ceilometer::agent::notification::notifier_enabled\": {\"get_param\": \"CeilometerQdrPublishMetrics\"}, \"tripleo::profile::base::ceilometer::agent::notification::notifier_events_enabled\": {\"get_param\": \"CeilometerQdrPublishEvents\"}, \"tripleo::profile::base::ceilometer::agent::notification::pipeline_publishers\": {\"get_param\": \"PipelinePublishers\"}, \"tripleo::profile::base::ceilometer::agent::notification::event_pipeline_publishers\": {\"get_param\": \"EventPipelinePublishers\"}, \"tripleo::profile::base::ceilometer::agent::notification::notifier_params\": {\"get_param\": \"CeilometerQdrMetricsConfig\"}, \"tripleo::profile::base::ceilometer::agent::notification::notifier_event_params\": {\"get_param\": \"CeilometerQdrEventsConfig\"}}, {\"if\": [\"ceilometer_qdr_publish\", {\"tripleo::profile::base::ceilometer::agent::notification::notifier_host_addr\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"tripleo::profile::base::ceilometer::agent::notification::notifier_host_port\": {\"get_param\": \"MetricsQdrPort\"}}]}]}, \"service_config_settings\": {\"map_merge\": [{\"get_attr\": [\"CeilometerServiceBase\", \"role_data\", \"service_config_settings\"]}, {\"rsyslog\": {\"tripleo_logging_sources_ceilometer_agent_notification\": [{\"get_param\": \"CeilometerAgentNotificationLoggingSource\"}]}}]}, \"puppet_config\": {\"config_volume\": \"ceilometer\", \"puppet_tags\": \"ceilometer_config\", \"step_config\": \"include tripleo::profile::base::ceilometer::agent::notification\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/ceilometer_agent_notification.json\": {\"command\": \"/usr/bin/ceilometer-agent-notification --logfile /var/log/ceilometer/agent-notification.log\", \"config_files\": {\"list_concat\": [[{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]]}}}, \"docker_config\": {\"step_3\": {\"ceilometer_init_log\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerNotificationImage\"]}, \"net\": \"none\", \"user\": \"root\", \"command\": [\"/bin/bash\", \"-c\", \"chown -R ceilometer:ceilometer /var/log/ceilometer\"], \"volumes\": [\"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]}}, \"step_4\": {\"ceilometer_agent_notification\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerNotificationImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"get_attr\": [\"ContainersCommon\", \"healthcheck_rpc_port\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/ceilometer_agent_notification.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/ceilometer\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}, {\"name\": \"enable virt_sandbox_use_netlink for healthcheck\", \"seboolean\": {\"name\": \"virt_sandbox_use_netlink\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop ceilometer agent notification container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"ceilometer_agent_notification\"], \"tripleo_delegate_to\": \"{{ groups[\'ceilometer_agent_notification\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(59,'2026-06-09 08:02:01',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Ceilometer Agent Ipmi service\\n\", \"parameters\": {\"ContainerCeilometerIpmiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\"}, \"ContainerCeilometerConfigImage\": {\"description\": \"The container image to use for the ceilometer config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\"}, \"CeilometerAgentIpmiLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.ceilometer.agent.ipmi\", \"file\": \"/var/log/containers/ceilometer/ipmi.log\"}}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"RedisPassword\": {\"description\": \"The password for the redis service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"Qw5poqjrA95kbXlQw5cMcjZDa\"}, \"MonitoringSubscriptionCeilometerIpmi\": {\"default\": \"overcloud-ceilometer-agent-ipmi\", \"type\": \"string\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CeilometerServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"CeilometerAgentCentralBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCeilometerIpmiImage\": \"ContainerCeilometerIpmiImage\", \"ContainerCeilometerConfigImage\": \"ContainerCeilometerConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCeilometerIpmiImage\": {\"get_param\": \"ContainerCeilometerIpmiImage\"}, \"ContainerCeilometerConfigImage\": {\"get_param\": \"ContainerCeilometerConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer Agent Ipmi role.\", \"value\": {\"service_name\": \"ceilometer_agent_ipmi\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionCeilometerIpmi\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CeilometerServiceBase\", \"role_data\", \"config_settings\"]}, {\"ceilometer_redis_password\": {\"get_param\": \"RedisPassword\"}, \"ipmi_namespace\": true}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_ceilometer_agent_ipmi\": [{\"get_param\": \"CeilometerAgentIpmiLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"ceilometer\", \"puppet_tags\": \"ceilometer_config\", \"step_config\": \"include tripleo::profile::base::ceilometer::agent::polling\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/ceilometer-agent-ipmi.json\": {\"command\": \"/usr/bin/ceilometer-polling --polling-namespaces ipmi --logfile /var/log/ceilometer/ipmi.log\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}}, \"docker_config\": {\"step_3\": {\"ceilometer_init_log\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerIpmiImage\"]}, \"net\": \"none\", \"user\": \"root\", \"command\": [\"/bin/bash\", \"-c\", \"chown -R ceilometer:ceilometer /var/log/ceilometer\"], \"volumes\": [\"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]}}, \"step_4\": {\"ceilometer_agent_ipmi\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerIpmiImage\"]}, \"net\": \"host\", \"privileged\": true, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/ceilometer-agent-ipmi.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/ceilometer\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(60,'2026-06-09 08:02:01',NULL,'{\"heat_template_version\": \"2015-04-30\", \"outputs\": {\"ip_address\": {\"value\": []}, \"ansible_host_vars_map\": {\"value\": []}, \"storage_mgmt_ip_address\": {\"value\": []}, \"hostname\": {\"value\": []}, \"nova_server_resource\": {\"value\": []}, \"hosts_entry\": {\"value\": []}, \"attributes, nova_server_resource\": {\"value\": {}}, \"hostname_map\": {\"value\": []}, \"blacklist_ip_address\": {\"value\": []}, \"internal_api_ip_address\": {\"value\": []}, \"blacklist_hostname\": {\"value\": []}, \"storage_ip_address\": {\"value\": []}, \"refs_map\": {\"value\": {}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(61,'2026-06-09 08:02:01',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(62,'2026-06-09 08:02:01',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Ceilometer Agent Compute service\\n\", \"parameters\": {\"ContainerCeilometerComputeImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\"}, \"ContainerCeilometerConfigImage\": {\"description\": \"The container image to use for the ceilometer config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"MonitoringSubscriptionCeilometerCompute\": {\"default\": \"overcloud-ceilometer-agent-compute\", \"type\": \"string\"}, \"InstanceDiscoveryMethod\": {\"default\": \"libvirt_metadata\", \"description\": \"Method used to discover instances running on compute node\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"naive\", \"libvirt_metadata\", \"workload_partitioning\"]}]}, \"RedisPassword\": {\"description\": \"The password for the redis service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"Qw5poqjrA95kbXlQw5cMcjZDa\"}, \"CeilometerEnableTenantDiscovery\": {\"default\": false, \"description\": \"Identify user and project names from polled metrics.\", \"type\": \"boolean\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CeilometerServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCeilometerComputeImage\": \"ContainerCeilometerComputeImage\", \"ContainerCeilometerConfigImage\": \"ContainerCeilometerConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCeilometerComputeImage\": {\"get_param\": \"ContainerCeilometerComputeImage\"}, \"ContainerCeilometerConfigImage\": {\"get_param\": \"ContainerCeilometerConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer Agent Compute role.\", \"value\": {\"service_name\": \"ceilometer_agent_compute\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionCeilometerCompute\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CeilometerServiceBase\", \"role_data\", \"config_settings\"]}, {\"ceilometer::agent::polling::instance_discovery_method\": {\"get_param\": \"InstanceDiscoveryMethod\"}}, {\"ceilometer_redis_password\": {\"get_param\": \"RedisPassword\"}, \"compute_namespace\": true, \"ceilometer::agent::polling::tenant_name_discovery\": {\"get_param\": \"CeilometerEnableTenantDiscovery\"}}]}, \"service_config_settings\": {\"get_attr\": [\"CeilometerServiceBase\", \"role_data\", \"service_config_settings\"]}, \"puppet_config\": {\"config_volume\": \"ceilometer\", \"puppet_tags\": \"ceilometer_config\", \"step_config\": \"include tripleo::profile::base::ceilometer::agent::polling\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/ceilometer_agent_compute.json\": {\"command\": \"/usr/bin/ceilometer-polling --polling-namespaces compute --logfile /var/log/ceilometer/compute.log\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}}, \"docker_config\": {\"step_4\": {\"ceilometer_agent_compute\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerComputeImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"depends_on\": [\"tripleo_nova_libvirt.target\"], \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/ceilometer_agent_compute.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\", \"/run/libvirt:/run/libvirt:shared,z\", \"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/ceilometer\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}, {\"name\": \"enable virt_sandbox_use_netlink for healthcheck\", \"seboolean\": {\"name\": \"virt_sandbox_use_netlink\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(63,'2026-06-09 08:02:01',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"ControlPlaneIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}, \"EnabledServices\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"type\": \"json\"}, \"ServiceHostnameList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"NetworkHostnameMap\": {\"default\": [], \"type\": \"json\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"RoleNetworks\": {\"default\": \"ctlplane\", \"type\": \"comma_delimited_list\"}}, \"conditions\": {\"is_cell\": {\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}}, \"resources\": {\"EnabledServicesValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> $.data.extra_services.items().where($[0] in $root.data.enabled_services).select($[1]).flatten() + $root.data.enabled_services\", \"data\": {\"enabled_services\": {\"get_param\": \"EnabledServices\"}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"NetIpMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"yaql\": {\"expression\": \"let(root => $) -> dict($.data.net_ip_map.items().where($[0] in $root.data.role_networks))\", \"data\": {\"role_networks\": {\"get_param\": \"RoleNetworks\"}, \"net_ip_map\": {\"ctlplane\": {\"get_param\": \"ControlPlaneIpList\"}, \"storage\": {\"get_param\": \"StorageIpList\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtIpList\"}, \"internal_api\": {\"get_param\": \"InternalApiIpList\"}, \"tenant\": {\"get_param\": \"TenantIpList\"}, \"external\": {\"get_param\": \"ExternalIpList\"}}}}}, {\"keys\": {\"ctlplane\": \"ctlplane\", \"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"external\": {\"get_param\": \"ExternalNetName\"}}}]}}}}, \"outputs\": {\"net_ip_map\": {\"description\": \"A Hash containing a mapping of network names to assigned lists of IP addresses.\\n\", \"value\": {\"get_attr\": [\"NetIpMapValue\", \"value\"]}}, \"ctlplane_service_ips\": {\"description\": \"Map of enabled services to a list of their ctlplane IP addresses\\n\", \"value\": {\"map_merge\": {\"repeat\": {\"template\": {\"SERVICE_ctlplane_node_ips\": \"$$ groups[\'SERVICE\'] | default ([]) | map(\'extract\', hostvars, \'ctlplane_ip\') | list | to_json $$\"}, \"for_each\": {\"SERVICE\": {\"get_attr\": [\"EnabledServicesValue\", \"value\"]}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ControlPlaneIpList\": \"\", \"StorageIpList\": \"\", \"StorageMgmtIpList\": \"\", \"InternalApiIpList\": \"\", \"EnabledServices\": \"\", \"ServiceNetMap\": {\"apache_network\": \"internal_api\", \"neutron_tenant_network\": \"tenant\", \"aodh_api_network\": \"internal_api\", \"barbican_api_network\": \"internal_api\", \"gnocchi_api_network\": \"internal_api\", \"mongodb_network\": \"internal_api\", \"cinder_api_network\": \"internal_api\", \"cinder_iscsi_network\": \"storage\", \"glance_api_network\": \"internal_api\", \"glance_api_edge_network\": \"internal_api\", \"glance_api_internal_network\": \"internal_api\", \"ironic_api_network\": \"ctlplane\", \"ironic_network\": \"ctlplane\", \"ironic_inspector_network\": \"ctlplane\", \"keystone_admin_api_network\": \"ctlplane\", \"keystone_public_api_network\": \"internal_api\", \"manila_api_network\": \"internal_api\", \"neutron_api_network\": \"internal_api\", \"octavia_api_network\": \"internal_api\", \"heat_api_network\": \"internal_api\", \"heat_api_cfn_network\": \"internal_api\", \"heat_api_cloudwatch_network\": \"internal_api\", \"nova_api_network\": \"internal_api\", \"placement_network\": \"internal_api\", \"nova_metadata_network\": \"internal_api\", \"nova_libvirt_network\": \"internal_api\", \"novajoin_network\": \"internal_api\", \"swift_storage_network\": \"storage_mgmt\", \"swift_proxy_network\": \"storage\", \"horizon_network\": \"internal_api\", \"memcached_network\": \"internal_api\", \"oslo_messaging_rpc_network\": \"internal_api\", \"oslo_messaging_notify_network\": \"internal_api\", \"rabbitmq_network\": \"internal_api\", \"rabbitmq_management_network\": \"internal_api\", \"qdr_network\": \"internal_api\", \"redis_network\": \"internal_api\", \"ganesha_network\": \"external\", \"mysql_network\": \"internal_api\", \"snmpd_network\": \"ctlplane\", \"ceph_cluster_network\": \"storage_mgmt\", \"ceph_dashboard_network\": \"ctlplane\", \"ceph_grafana_network\": \"storage\", \"ceph_mon_network\": \"storage\", \"ceph_rgw_network\": \"storage\", \"public_network\": \"external\", \"internal_api_network\": \"internal_api\", \"opendaylight_api_network\": \"internal_api\", \"ovn_dbs_network\": \"internal_api\", \"docker_registry_network\": \"ctlplane\", \"pacemaker_network\": \"internal_api\", \"pacemaker_remote_network\": \"internal_api\", \"designate_api_network\": \"internal_api\", \"designate_mdns_network\": \"internal_api\", \"designate_worker_network\": \"external\", \"designate_bind_network\": \"external\", \"bindnetwork\": \"external\", \"etcd_network\": \"internal_api\", \"haproxy_network\": \"ctlplane\", \"unbound_network\": \"external\", \"controller_hostname_resolve_network\": \"internal_api\", \"controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_hostname_resolve_network\": \"internal_api\", \"cell_controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_compute_hostname_resolve_network\": \"internal_api\", \"cell_controller_compute_metrics_qdr_network\": \"internal_api\", \"compute_hostname_resolve_network\": \"internal_api\", \"compute_metrics_qdr_network\": \"internal_api\", \"block_storage_hostname_resolve_network\": \"internal_api\", \"block_storage_metrics_qdr_network\": \"internal_api\", \"object_storage_hostname_resolve_network\": \"internal_api\", \"object_storage_metrics_qdr_network\": \"internal_api\", \"ceph_storage_hostname_resolve_network\": \"storage\", \"ceph_storage_metrics_qdr_network\": \"storage\", \"networker_hostname_resolve_network\": \"internal_api\", \"networker_metrics_qdr_network\": \"internal_api\", \"nova_vnc_proxy_network\": \"internal_api\"}, \"ServiceHostnameList\": \"\", \"NetworkHostnameMap\": {}, \"RoleNetworks\": \"ctlplane,storage,storage_mgmt,internal_api\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(64,'2026-06-09 08:02:01',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (65,'2026-06-09 08:02:01',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Cinder API service\\n\", \"parameters\": {\"ContainerCinderApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\"}, \"ContainerCinderConfigImage\": {\"description\": \"The container image to use for the cinder config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\"}, \"CinderApiLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.cinder.api\", \"file\": \"/var/log/containers/cinder/cinder-api.log\"}}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"DeployIdentifier\": {\"default\": 1780992067, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"CinderDefaultVolumeType\": {\"default\": \"tripleo\", \"description\": \"The name of Cinder\'s default volume type.\", \"type\": \"string\", \"constraints\": [{\"allowed_pattern\": \".*\\\\S.*\", \"description\": \"The default volume type name cannot be empty.\\n\"}]}, \"CinderEnableDBPurge\": {\"default\": true, \"description\": \"Whether to create cron job for purging soft deleted rows in Cinder database.\\n\", \"type\": \"boolean\"}, \"CinderPassword\": {\"description\": \"The password for the cinder service and db account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"MonitoringSubscriptionCinderApi\": {\"default\": \"overcloud-cinder-api\", \"type\": \"string\"}, \"CinderWorkers\": {\"type\": \"string\", \"description\": \"Set the number of workers for cinder::wsgi::apache\", \"default\": 1}, \"CinderApiPolicies\": {\"description\": \"A hash of policies to configure for Cinder API.\\ne.g. { cinder-context_is_admin: { key: context_is_admin, value: \'role:admin\' } }\\n\", \"default\": {}, \"type\": \"json\"}, \"CinderApiWsgiTimeout\": {\"default\": 60, \"description\": \"The number of seconds until a Cinder API WSGI connection times out.\", \"type\": \"number\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"RootStackName\": {\"description\": \"The name of the stack/plan.\", \"type\": \"string\", \"default\": \"overcloud\"}, \"MemcacheUseAdvancedPool\": {\"type\": \"boolean\", \"description\": \"Use the advanced (eventlet safe) memcached client pool.\\n\", \"default\": true}, \"AuthCloudName\": {\"description\": \"Entry in clouds.yaml to use for authentication\", \"type\": \"string\", \"default\": \"\"}}, \"conditions\": {\"auth_cloud_name_set\": {\"not\": {\"equals\": [{\"get_param\": \"AuthCloudName\"}, \"\"]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"CinderBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"CinderCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml\"}, \"ApacheServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"EnableInternalTLS\": {\"get_param\": \"EnableInternalTLS\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCinderApiImage\": \"ContainerCinderApiImage\", \"ContainerCinderConfigImage\": \"ContainerCinderConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCinderApiImage\": {\"get_param\": \"ContainerCinderApiImage\"}, \"ContainerCinderConfigImage\": {\"get_param\": \"ContainerCinderConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder API role.\", \"value\": {\"service_name\": \"cinder_api\", \"firewall_rules\": {\"119 cinder\": {\"dport\": [8776]}}, \"firewall_frontend_rules\": {\"100 cinder_haproxy_frontend\": {\"dport\": [8776]}}, \"firewall_ssl_frontend_rules\": {\"100 cinder_haproxy_frontend_ssl\": {\"dport\": [13776]}}, \"keystone_resources\": {\"cinder\": {\"users\": {\"cinder\": {\"password\": {\"get_param\": \"CinderPassword\"}, \"roles\": [\"admin\", \"service\"]}}}, \"cinderv3\": {\"endpoints\": {\"public\": {\"get_param\": [\"EndpointMap\", \"CinderV3Public\", \"uri\"]}, \"internal\": {\"get_param\": [\"EndpointMap\", \"CinderV3Internal\", \"uri\"]}, \"admin\": {\"get_param\": [\"EndpointMap\", \"CinderV3Admin\", \"uri\"]}}, \"users\": {\"cinderv3\": {\"password\": {\"get_param\": \"CinderPassword\"}, \"roles\": [\"admin\", \"service\"]}}, \"region\": {\"get_param\": \"KeystoneRegion\"}, \"service\": \"volumev3\"}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionCinderApi\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CinderBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"config_settings\"]}, {\"keystone_resources_managed\": false}, {\"cinder::keystone::authtoken::www_authenticate_uri\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"cinder::keystone::authtoken::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"cinder::keystone::authtoken::password\": {\"get_param\": \"CinderPassword\"}, \"cinder::keystone::authtoken::project_name\": \"service\", \"cinder::keystone::authtoken::user_domain_name\": \"Default\", \"cinder::keystone::authtoken::project_domain_name\": \"Default\", \"cinder::keystone::authtoken::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"cinder::keystone::authtoken::interface\": \"internal\", \"cinder::keystone::authtoken::memcache_use_advanced_pool\": {\"get_param\": \"MemcacheUseAdvancedPool\"}, \"cinder::policy::policies\": {\"get_param\": \"CinderApiPolicies\"}, \"cinder::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"cinder::api::default_volume_type\": {\"get_param\": \"CinderDefaultVolumeType\"}, \"cinder::api::enable_proxy_headers_parsing\": true, \"tripleo::profile::base::cinder::cinder_enable_db_purge\": {\"get_param\": \"CinderEnableDBPurge\"}, \"cinder::api::bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}}}, \"cinder::wsgi::apache::ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"cinder::api::service_name\": \"httpd\", \"cinder::wsgi::apache::bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}}}, \"cinder::wsgi::apache::servername\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderApiNetwork\"]}}}}, \"cinder::wsgi::apache::vhost_custom_fragment\": {\"str_replace\": {\"template\": \"Timeout TIMEOUT\", \"params\": {\"TIMEOUT\": {\"get_param\": \"CinderApiWsgiTimeout\"}}}}, \"cinder::wsgi::apache::workers\": {\"get_param\": \"CinderWorkers\"}}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_cinder_api\": [{\"get_param\": \"CinderApiLoggingSource\"}]}, \"mysql\": {\"cinder::db::mysql::password\": {\"get_param\": \"CinderPassword\"}, \"cinder::db::mysql::user\": \"cinder\", \"cinder::db::mysql::host\": \"%\", \"cinder::db::mysql::dbname\": \"cinder\"}}, \"puppet_config\": {\"config_volume\": \"cinder\", \"puppet_tags\": \"cinder_config,file,concat,file_line,cinder_api_paste_ini\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::cinder::api\", {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/cinder_api.json\": {\"command\": \"/usr/sbin/httpd -DFOREGROUND\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}], \"permissions\": [{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/etcd.crt\", \"owner\": \"cinder:cinder\"}, {\"path\": \"/etc/pki/tls/private/etcd.key\", \"owner\": \"cinder:cinder\"}]}, \"/var/lib/kolla/config_files/cinder_api_db_sync.json\": {\"command\": \"/usr/bin/bootstrap_host_exec cinder_api su cinder -s /bin/bash -c \'cinder-manage db sync --bump-versions\'\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}], \"permissions\": [{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/etcd.crt\", \"owner\": \"cinder:cinder\"}, {\"path\": \"/etc/pki/tls/private/etcd.key\", \"owner\": \"cinder:cinder\"}]}, \"/var/lib/kolla/config_files/cinder_api_cron.json\": {\"command\": \"/usr/sbin/crond -n\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}]}}, \"docker_config\": {\"step_2\": {\"cinder_api_init_logs\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderApiImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/cinder:/var/log/cinder:z\", \"/var/log/containers/httpd/cinder-api:/var/log/httpd:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R cinder:cinder /var/log/cinder\"]}}, \"step_3\": {\"cinder_api_db_sync\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderApiImage\"]}, \"cap_add\": [\"AUDIT_WRITE\"], \"net\": \"host\", \"privileged\": false, \"detach\": false, \"user\": \"root\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/cinder_api_db_sync.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}}, \"step_4\": {\"cinder_api\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderApiImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"user\": \"root\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/cinder_api.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\", \"/var/log/containers/httpd/cinder-api:/var/log/httpd:z\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"cinder_api_cron\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderApiImage\"]}, \"net\": \"host\", \"user\": \"root\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/usr/share/openstack-tripleo-common/healthcheck/cron cinder\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/cinder_api_cron.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\", \"/var/log/containers/httpd/cinder-api:/var/log/httpd:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"metadata_settings\": {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"metadata_settings\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"deploy_steps_tasks\"]}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/log/containers/httpd/cinder-api\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}], \"external_upgrade_tasks\": [{\"when\": \"step|int == 1\", \"block\": [{\"name\": \"Online data migration for Cinder\", \"command\": \"{{ container_cli }} exec cinder_api cinder-manage db online_data_migrations\", \"delegate_to\": \"{{ (groups[\'cinder_api\'] | difference(groups[\'excluded_overcloud\']))[0] }}\", \"become\": true, \"tags\": [\"online_upgrade\", \"online_upgrade_cinder\"]}]}, {\"when\": \"step|int == 1\", \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop cinder api container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"cinder_api\", \"cinder_api_cron\"], \"tripleo_delegate_to\": \"{{ groups[\'cinder_api\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}], \"external_update_tasks\": [{\"when\": \"step|int == 1\", \"block\": [{\"name\": \"Online data migration for Cinder\", \"command\": \"{{ container_cli }} exec cinder_api cinder-manage db online_data_migrations\", \"delegate_to\": \"{{ (groups[\'cinder_api\'] | difference(groups[\'excluded_overcloud\']))[0] }}\", \"become\": true, \"tags\": [\"online_upgrade\", \"online_upgrade_cinder\"]}]}], \"external_deploy_tasks\": [{\"name\": \"Clean up legacy Cinder keystone catalog entries\", \"become\": true, \"openstack.cloud.catalog_service\": {\"cloud\": {\"if\": [\"auth_cloud_name_set\", {\"get_param\": \"AuthCloudName\"}, {\"get_param\": \"RootStackName\"}]}, \"name\": \"{{ item.service_name }}\", \"service_type\": \"{{ item.service_type }}\", \"state\": \"absent\"}, \"loop\": [{\"service_name\": \"cinderv2\", \"service_type\": \"volumev2\"}, {\"service_name\": \"cinderv3\", \"service_type\": \"volume\"}], \"loop_control\": {\"index_var\": \"cinder_api_service\"}, \"when\": [\"step|int == 4\", \"not ansible_check_mode|bool\"]}, {\"name\": \"Manage Cinder\'s default volume type\", \"become\": true, \"vars\": {\"default_volume_type\": {\"get_param\": \"CinderDefaultVolumeType\"}}, \"environment\": {\"OS_CLOUD\": {\"if\": [\"auth_cloud_name_set\", {\"get_param\": \"AuthCloudName\"}, {\"get_param\": \"RootStackName\"}]}}, \"when\": [\"step|int == 5\", \"not ansible_check_mode|bool\"], \"shell\": \"if ! openstack volume type show \\\"{{ default_volume_type }}\\\"; then\\n    openstack volume type create --public \\\"{{ default_volume_type }}\\\"\\nfi\\neval $(openstack volume type show __DEFAULT__ -f shell -c id -c description)\\nif [ -n \\\"$id\\\" ]; then\\n    if ! openstack volume type delete $id ; then\\n        tripleo_descr=\\\"For internal use, \'{{ default_volume_type }}\' is the default volume type\\\"\\n        if [ \\\"$description\\\" != \\\"$tripleo_descr\\\" ]; then\\n            openstack volume type set $id --description \\\"$tripleo_descr\\\"\\n        fi\\n    fi\\nfi\\n\", \"args\": {\"executable\": \"/bin/bash\"}, \"changed_when\": false}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(66,'2026-06-09 08:02:02',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Ceilometer Agent Central service\\n\", \"parameters\": {\"ContainerCeilometerCentralImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\"}, \"ContainerCeilometerConfigImage\": {\"description\": \"The container image to use for the ceilometer config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\"}, \"CeilometerAgentCentralLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.ceilometer.agent.central\", \"file\": \"/var/log/containers/ceilometer/central.log\"}}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"RedisPassword\": {\"description\": \"The password for the redis service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"Qw5poqjrA95kbXlQw5cMcjZDa\"}, \"MonitoringSubscriptionCeilometerCentral\": {\"default\": \"overcloud-ceilometer-agent-central\", \"type\": \"string\"}, \"CeilometerEnableGnocchi\": {\"default\": false, \"description\": \"Whether to enable gnocchi usage.\", \"type\": \"boolean\"}, \"CeilometerPassword\": {\"description\": \"The password for the ceilometer service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"6GBzmfESOACPjM70aXaIF8M8d\"}, \"CeilometerEnableTenantDiscovery\": {\"default\": false, \"description\": \"Identify user and project names from polled metrics.\", \"type\": \"boolean\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CeilometerServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCeilometerCentralImage\": \"ContainerCeilometerCentralImage\", \"ContainerCeilometerConfigImage\": \"ContainerCeilometerConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCeilometerCentralImage\": {\"get_param\": \"ContainerCeilometerCentralImage\"}, \"ContainerCeilometerConfigImage\": {\"get_param\": \"ContainerCeilometerConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer Agent Central role.\", \"value\": {\"service_name\": \"ceilometer_agent_central\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionCeilometerCentral\"}, \"keystone_resources\": {\"ceilometer\": {\"users\": {\"ceilometer\": {\"password\": {\"get_param\": \"CeilometerPassword\"}, \"roles\": [\"admin\", \"ResellerAdmin\"]}}, \"roles\": [\"ResellerAdmin\"]}}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CeilometerServiceBase\", \"role_data\", \"config_settings\"]}, {\"ceilometer_redis_password\": {\"get_param\": \"RedisPassword\"}, \"central_namespace\": true, \"ceilometer::agent::polling::tenant_name_discovery\": {\"get_param\": \"CeilometerEnableTenantDiscovery\"}}]}, \"service_config_settings\": {\"map_merge\": [{\"get_attr\": [\"CeilometerServiceBase\", \"role_data\", \"service_config_settings\"]}, {\"rsyslog\": {\"tripleo_logging_sources_ceilometer_agent_central\": [{\"get_param\": \"CeilometerAgentCentralLoggingSource\"}]}}]}, \"puppet_config\": {\"config_volume\": \"ceilometer\", \"puppet_tags\": \"ceilometer_config\", \"step_config\": \"include tripleo::profile::base::ceilometer::agent::polling\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/ceilometer_agent_central.json\": {\"command\": \"/usr/bin/ceilometer-polling --polling-namespaces central --logfile /var/log/ceilometer/central.log\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}, \"/var/lib/kolla/config_files/ceilometer_agent_gnocchi_upgrade.json\": {\"command\": \"/usr/bin/bootstrap_host_exec ceilometer_agent_central su ceilometer -s /bin/bash -c \'for n in {1..10}; do /usr/bin/ceilometer-upgrade && exit 0 || sleep 30; done; exit 1\'\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}}, \"docker_config\": {\"step_3\": {\"ceilometer_init_log\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerCentralImage\"]}, \"net\": \"none\", \"user\": \"root\", \"command\": [\"/bin/bash\", \"-c\", \"chown -R ceilometer:ceilometer /var/log/ceilometer\"], \"volumes\": [\"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]}}, \"step_4\": {\"ceilometer_agent_central\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerCentralImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/ceilometer_agent_central.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}, \"step_5\": {\"if\": [{\"get_param\": \"CeilometerEnableGnocchi\"}, {\"ceilometer_gnocchi_upgrade\": {\"start_order\": 99, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerCentralImage\"]}, \"net\": \"host\", \"detach\": false, \"privileged\": false, \"user\": \"root\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/ceilometer_agent_gnocchi_upgrade.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}]}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/ceilometer\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop ceilometer agent central container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"ceilometer_agent_central\"], \"tripleo_delegate_to\": \"{{ groups[\'ceilometer_agent_central\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(67,'2026-06-09 08:02:02',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Ceilometer service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"CeilometerMeteringSecret\": {\"description\": \"Secret shared by the ceilometer services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\"}, \"CeilometerPassword\": {\"description\": \"The password for the ceilometer service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"6GBzmfESOACPjM70aXaIF8M8d\"}, \"AmqpRpcAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for RPC addresses\", \"type\": \"string\"}, \"AmqpNotifyAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for Notification addresses\", \"type\": \"string\"}, \"ManagePolling\": {\"default\": false, \"description\": \"Whether to manage polling.yaml.\", \"type\": \"boolean\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"CeilometerDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Ceilometer services.\", \"type\": \"boolean\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"SnmpdReadonlyUserName\": {\"default\": \"ro_snmp_user\", \"description\": \"The user name for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\"}, \"SnmpdReadonlyUserPassword\": {\"description\": \"The user password for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\", \"hidden\": true, \"default\": \"IUqJgJKOidh20dco1DYKnuQ1\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"GnocchiArchivePolicy\": {\"default\": \"ceilometer-low-rate\", \"type\": \"string\", \"description\": \"(DEPRECATED) archive policy to use with gnocchi backend\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"MemcachedTLS\": {\"default\": true, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"GnocchiArchivePolicy\"]}], \"conditions\": {\"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer role.\", \"value\": {\"service_name\": \"ceilometer_base\", \"config_settings\": {\"map_merge\": [{\"ceilometer::logging::debug\": {\"if\": [{\"get_param\": \"CeilometerDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"ceilometer::agent::polling::manage_polling\": {\"get_param\": \"ManagePolling\"}, \"ceilometer::agent::service_credentials::password\": {\"get_param\": \"CeilometerPassword\"}, \"ceilometer::agent::service_credentials::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"ceilometer::agent::service_credentials::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"ceilometer::agent::service_credentials::project_name\": \"service\", \"ceilometer::agent::service_credentials::user_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::auth_project_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::interface\": \"internalURL\", \"ceilometer::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"ceilometer::amqp_rpc_address_prefix\": {\"get_param\": \"AmqpRpcAddressPrefix\"}, \"ceilometer::amqp_notify_address_prefix\": {\"get_param\": \"AmqpNotifyAddressPrefix\"}, \"ceilometer::telemetry_secret\": {\"get_param\": \"CeilometerMeteringSecret\"}, \"ceilometer::snmpd_readonly_username\": {\"get_param\": \"SnmpdReadonlyUserName\"}, \"ceilometer::snmpd_readonly_user_password\": {\"get_param\": \"SnmpdReadonlyUserPassword\"}, \"ceilometer::host\": \"%{hiera(\'fqdn_canonical\')}\", \"ceilometer::rabbit_heartbeat_in_pthread\": false, \"ceilometer::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"ceilometer::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}}, {\"if\": [\"tls_cache_enabled\", {\"ceilometer::cache::backend\": \"dogpile.cache.pymemcache\", \"ceilometer::cache::enable_socket_keepalive\": true}, {\"ceilometer::cache::backend\": \"dogpile.cache.memcached\"}]}]}, \"service_config_settings\": {\"keystone\": {\"tripleo::profile::base::keystone::ceilometer_notification_topics\": [\"notifications\"]}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(68,'2026-06-09 08:02:02',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Iscsid service\\n\", \"parameters\": {\"ContainerIscsidImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\"}, \"ContainerIscsidConfigImage\": {\"description\": \"The container image to use for the iscsid config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"LVMFilterEnabled\": {\"default\": false, \"description\": \"Enables configuration of LVM2 with a filter so that devices not in use on the host or explicitly allowed are ignored by LVM2. Can be configured per-role. When disabled, the proposed lvm.conf file will be created regardless and left in /tmp/tripleo_lvmfilter.conf for debugging purposes.\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"LVMFilterAllowlist\": {\"default\": [], \"description\": \"A list of block devices which should be allowed in the LVM2 `global_filter`. Supports regular expressions, like `/dev/sd.*` and can be configured per-role. Any block device in use at boot time will be automatically allowed.\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"LVMFilterDenylist\": {\"default\": [\".*\"], \"description\": \"A list of block devices which should be disallowed in the LVM2 `global_filter`. Supports regular expressions, like `/dev/sd.*` and can be configured per-role.\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"IscsidCHAPAlgorithms\": {\"default\": \"SHA3-256,SHA256,SHA1,MD5\", \"description\": \"A comma separated list of algorithms to be used for the CHAP algorithm.\", \"type\": \"string\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"tripleo_tripleo_lvmfilter_enabled\": \"LVMFilterEnabled\", \"tripleo_tripleo_lvmfilter_devices_allowlist\": \"LVMFilterAllowlist\", \"tripleo_tripleo_lvmfilter_devices_denylist\": \"LVMFilterDenylist\", \"ContainerIscsidImage\": \"ContainerIscsidImage\", \"ContainerIscsidConfigImage\": \"ContainerIscsidConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"LVMFilterEnabled\": {\"get_param\": \"LVMFilterEnabled\"}, \"LVMFilterAllowlist\": {\"get_param\": \"LVMFilterAllowlist\"}, \"LVMFilterDenylist\": {\"get_param\": \"LVMFilterDenylist\"}, \"ContainerIscsidImage\": {\"get_param\": \"ContainerIscsidImage\"}, \"ContainerIscsidConfigImage\": {\"get_param\": \"ContainerIscsidConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Iscsid role.\", \"value\": {\"service_name\": \"iscsid\", \"config_settings\": {\"tripleo::profile::base::iscsid::chap_algs\": {\"get_param\": \"IscsidCHAPAlgorithms\"}}, \"service_config_settings\": {}, \"deploy_steps_tasks\": [{\"name\": \"Run lvmfilter role\", \"include_role\": {\"name\": \"tripleo_lvmfilter\"}, \"when\": [\"step|int == 1\"]}], \"ansible_group_vars\": {\"get_attr\": [\"RoleParametersValue\", \"value\"]}, \"puppet_config\": {\"config_volume\": \"iscsid\", \"puppet_tags\": \"iscsid_config\", \"step_config\": \"include tripleo::profile::base::iscsid\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerIscsidConfigImage\"]}, \"volumes\": [\"/etc/iscsi:/tmp/iscsi.host:z\"]}, \"kolla_config\": {\"/var/lib/kolla/config_files/iscsid.json\": {\"command\": \"/usr/sbin/iscsid -f\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src-iscsid/\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}]}}, \"docker_config\": {\"step_3\": {\"iscsid\": {\"start_order\": 2, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerIscsidImage\"]}, \"net\": \"host\", \"privileged\": true, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/iscsid.json:/var/lib/kolla/config_files/config.json:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/lib/modules:/lib/modules:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", \"/etc/target:/etc/target:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create fcontext entry for iscsi\", \"community.general.sefcontext\": {\"target\": \"{{ item.path }}(/.*)?\", \"setype\": \"{{ item.setype }}\", \"state\": \"present\"}, \"with_items\": [{\"path\": \"/etc/iscsi\", \"setype\": \"container_file_t\"}, {\"path\": \"/etc/target\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/lib/iscsi\", \"setype\": \"container_file_t\"}]}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\"}, \"with_items\": [{\"path\": \"/etc/iscsi\", \"setype\": \"container_file_t\"}, {\"path\": \"/etc/target\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/lib/iscsi\", \"setype\": \"container_file_t\"}]}, {\"name\": \"stat /lib/systemd/system/iscsid.socket\", \"stat\": \"path=/lib/systemd/system/iscsid.socket\", \"register\": \"stat_iscsid_socket\"}, {\"name\": \"Stop and disable iscsid.socket service\", \"service\": \"name=iscsid.socket state=stopped enabled=no\", \"when\": \"stat_iscsid_socket.stat.exists\"}, {\"name\": \"Check if iscsi.service is enabled\", \"command\": \"systemctl is-enabled --quiet iscsi.service\", \"failed_when\": false, \"register\": \"iscsi_service_enabled_result\"}, {\"name\": \"Stop iscsi.service\", \"service\": \"name=iscsi.service state=stopped enabled=no\", \"when\": [\"iscsi_service_enabled_result is changed\", \"iscsi_service_enabled_result.rc == 0\"]}], \"upgrade_tasks\": []}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(69,'2026-06-09 08:02:02',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"ControlPlaneIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}, \"EnabledServices\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"type\": \"json\"}, \"ServiceHostnameList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"NetworkHostnameMap\": {\"default\": [], \"type\": \"json\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"RoleNetworks\": {\"default\": \"ctlplane\", \"type\": \"comma_delimited_list\"}}, \"conditions\": {\"is_cell\": {\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}}, \"resources\": {\"EnabledServicesValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> $.data.extra_services.items().where($[0] in $root.data.enabled_services).select($[1]).flatten() + $root.data.enabled_services\", \"data\": {\"enabled_services\": {\"get_param\": \"EnabledServices\"}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"NetIpMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"yaql\": {\"expression\": \"let(root => $) -> dict($.data.net_ip_map.items().where($[0] in $root.data.role_networks))\", \"data\": {\"role_networks\": {\"get_param\": \"RoleNetworks\"}, \"net_ip_map\": {\"ctlplane\": {\"get_param\": \"ControlPlaneIpList\"}, \"storage\": {\"get_param\": \"StorageIpList\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtIpList\"}, \"internal_api\": {\"get_param\": \"InternalApiIpList\"}, \"tenant\": {\"get_param\": \"TenantIpList\"}, \"external\": {\"get_param\": \"ExternalIpList\"}}}}}, {\"keys\": {\"ctlplane\": \"ctlplane\", \"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"external\": {\"get_param\": \"ExternalNetName\"}}}]}}}}, \"outputs\": {\"net_ip_map\": {\"description\": \"A Hash containing a mapping of network names to assigned lists of IP addresses.\\n\", \"value\": {\"get_attr\": [\"NetIpMapValue\", \"value\"]}}, \"ctlplane_service_ips\": {\"description\": \"Map of enabled services to a list of their ctlplane IP addresses\\n\", \"value\": {\"map_merge\": {\"repeat\": {\"template\": {\"SERVICE_ctlplane_node_ips\": \"$$ groups[\'SERVICE\'] | default ([]) | map(\'extract\', hostvars, \'ctlplane_ip\') | list | to_json $$\"}, \"for_each\": {\"SERVICE\": {\"get_attr\": [\"EnabledServicesValue\", \"value\"]}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ControlPlaneIpList\": \"\", \"StorageIpList\": \"\", \"StorageMgmtIpList\": \"\", \"InternalApiIpList\": \"\", \"EnabledServices\": \"\", \"ServiceNetMap\": {\"apache_network\": \"internal_api\", \"neutron_tenant_network\": \"tenant\", \"aodh_api_network\": \"internal_api\", \"barbican_api_network\": \"internal_api\", \"gnocchi_api_network\": \"internal_api\", \"mongodb_network\": \"internal_api\", \"cinder_api_network\": \"internal_api\", \"cinder_iscsi_network\": \"storage\", \"glance_api_network\": \"internal_api\", \"glance_api_edge_network\": \"internal_api\", \"glance_api_internal_network\": \"internal_api\", \"ironic_api_network\": \"ctlplane\", \"ironic_network\": \"ctlplane\", \"ironic_inspector_network\": \"ctlplane\", \"keystone_admin_api_network\": \"ctlplane\", \"keystone_public_api_network\": \"internal_api\", \"manila_api_network\": \"internal_api\", \"neutron_api_network\": \"internal_api\", \"octavia_api_network\": \"internal_api\", \"heat_api_network\": \"internal_api\", \"heat_api_cfn_network\": \"internal_api\", \"heat_api_cloudwatch_network\": \"internal_api\", \"nova_api_network\": \"internal_api\", \"placement_network\": \"internal_api\", \"nova_metadata_network\": \"internal_api\", \"nova_libvirt_network\": \"internal_api\", \"novajoin_network\": \"internal_api\", \"swift_storage_network\": \"storage_mgmt\", \"swift_proxy_network\": \"storage\", \"horizon_network\": \"internal_api\", \"memcached_network\": \"internal_api\", \"oslo_messaging_rpc_network\": \"internal_api\", \"oslo_messaging_notify_network\": \"internal_api\", \"rabbitmq_network\": \"internal_api\", \"rabbitmq_management_network\": \"internal_api\", \"qdr_network\": \"internal_api\", \"redis_network\": \"internal_api\", \"ganesha_network\": \"external\", \"mysql_network\": \"internal_api\", \"snmpd_network\": \"ctlplane\", \"ceph_cluster_network\": \"storage_mgmt\", \"ceph_dashboard_network\": \"ctlplane\", \"ceph_grafana_network\": \"storage\", \"ceph_mon_network\": \"storage\", \"ceph_rgw_network\": \"storage\", \"public_network\": \"external\", \"internal_api_network\": \"internal_api\", \"opendaylight_api_network\": \"internal_api\", \"ovn_dbs_network\": \"internal_api\", \"docker_registry_network\": \"ctlplane\", \"pacemaker_network\": \"internal_api\", \"pacemaker_remote_network\": \"internal_api\", \"designate_api_network\": \"internal_api\", \"designate_mdns_network\": \"internal_api\", \"designate_worker_network\": \"external\", \"designate_bind_network\": \"external\", \"bindnetwork\": \"external\", \"etcd_network\": \"internal_api\", \"haproxy_network\": \"ctlplane\", \"unbound_network\": \"external\", \"controller_hostname_resolve_network\": \"internal_api\", \"controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_hostname_resolve_network\": \"internal_api\", \"cell_controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_compute_hostname_resolve_network\": \"internal_api\", \"cell_controller_compute_metrics_qdr_network\": \"internal_api\", \"compute_hostname_resolve_network\": \"internal_api\", \"compute_metrics_qdr_network\": \"internal_api\", \"block_storage_hostname_resolve_network\": \"internal_api\", \"block_storage_metrics_qdr_network\": \"internal_api\", \"object_storage_hostname_resolve_network\": \"internal_api\", \"object_storage_metrics_qdr_network\": \"internal_api\", \"ceph_storage_hostname_resolve_network\": \"storage\", \"ceph_storage_metrics_qdr_network\": \"storage\", \"networker_hostname_resolve_network\": \"internal_api\", \"networker_metrics_qdr_network\": \"internal_api\", \"nova_vnc_proxy_network\": \"internal_api\"}, \"ServiceHostnameList\": \"\", \"NetworkHostnameMap\": {}, \"RoleNetworks\": \"ctlplane,storage,storage_mgmt,internal_api\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(70,'2026-06-09 08:02:02',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Ceilometer service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"CeilometerMeteringSecret\": {\"description\": \"Secret shared by the ceilometer services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\"}, \"CeilometerPassword\": {\"description\": \"The password for the ceilometer service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"6GBzmfESOACPjM70aXaIF8M8d\"}, \"AmqpRpcAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for RPC addresses\", \"type\": \"string\"}, \"AmqpNotifyAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for Notification addresses\", \"type\": \"string\"}, \"ManagePolling\": {\"default\": false, \"description\": \"Whether to manage polling.yaml.\", \"type\": \"boolean\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"CeilometerDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Ceilometer services.\", \"type\": \"boolean\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"SnmpdReadonlyUserName\": {\"default\": \"ro_snmp_user\", \"description\": \"The user name for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\"}, \"SnmpdReadonlyUserPassword\": {\"description\": \"The user password for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\", \"hidden\": true, \"default\": \"IUqJgJKOidh20dco1DYKnuQ1\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"GnocchiArchivePolicy\": {\"default\": \"ceilometer-low-rate\", \"type\": \"string\", \"description\": \"(DEPRECATED) archive policy to use with gnocchi backend\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"MemcachedTLS\": {\"default\": true, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"GnocchiArchivePolicy\"]}], \"conditions\": {\"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer role.\", \"value\": {\"service_name\": \"ceilometer_base\", \"config_settings\": {\"map_merge\": [{\"ceilometer::logging::debug\": {\"if\": [{\"get_param\": \"CeilometerDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"ceilometer::agent::polling::manage_polling\": {\"get_param\": \"ManagePolling\"}, \"ceilometer::agent::service_credentials::password\": {\"get_param\": \"CeilometerPassword\"}, \"ceilometer::agent::service_credentials::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"ceilometer::agent::service_credentials::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"ceilometer::agent::service_credentials::project_name\": \"service\", \"ceilometer::agent::service_credentials::user_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::auth_project_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::interface\": \"internalURL\", \"ceilometer::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"ceilometer::amqp_rpc_address_prefix\": {\"get_param\": \"AmqpRpcAddressPrefix\"}, \"ceilometer::amqp_notify_address_prefix\": {\"get_param\": \"AmqpNotifyAddressPrefix\"}, \"ceilometer::telemetry_secret\": {\"get_param\": \"CeilometerMeteringSecret\"}, \"ceilometer::snmpd_readonly_username\": {\"get_param\": \"SnmpdReadonlyUserName\"}, \"ceilometer::snmpd_readonly_user_password\": {\"get_param\": \"SnmpdReadonlyUserPassword\"}, \"ceilometer::host\": \"%{hiera(\'fqdn_canonical\')}\", \"ceilometer::rabbit_heartbeat_in_pthread\": false, \"ceilometer::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"ceilometer::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}}, {\"if\": [\"tls_cache_enabled\", {\"ceilometer::cache::backend\": \"dogpile.cache.pymemcache\", \"ceilometer::cache::enable_socket_keepalive\": true}, {\"ceilometer::cache::backend\": \"dogpile.cache.memcached\"}]}]}, \"service_config_settings\": {\"keystone\": {\"tripleo::profile::base::keystone::ceilometer_notification_topics\": [\"notifications\"]}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(71,'2026-06-09 08:02:02',NULL,'{\"heat_template_version\": \"wallaby\", \"parameters\": {\"ControlPlaneIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageNetName\": {\"default\": \"storage\", \"description\": \"The name of the storage network.\", \"type\": \"string\"}, \"StorageMgmtIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"StorageMgmtNetName\": {\"default\": \"storage_mgmt\", \"description\": \"The name of the storage_mgmt network.\", \"type\": \"string\"}, \"InternalApiIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"InternalApiNetName\": {\"default\": \"internal_api\", \"description\": \"The name of the internal_api network.\", \"type\": \"string\"}, \"TenantIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"TenantNetName\": {\"default\": \"tenant\", \"description\": \"The name of the tenant network.\", \"type\": \"string\"}, \"ExternalIpList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ExternalNetName\": {\"default\": \"external\", \"description\": \"The name of the external network.\", \"type\": \"string\"}, \"EnabledServices\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"type\": \"json\"}, \"ServiceHostnameList\": {\"default\": [], \"type\": \"comma_delimited_list\"}, \"NetworkHostnameMap\": {\"default\": [], \"type\": \"json\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"RoleNetworks\": {\"default\": \"ctlplane\", \"type\": \"comma_delimited_list\"}}, \"conditions\": {\"is_cell\": {\"equals\": [{\"get_param\": \"NovaAdditionalCell\"}, true]}}, \"resources\": {\"EnabledServicesValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"comma_delimited_list\", \"value\": {\"yaql\": {\"expression\": \"let(root => $) -> $.data.extra_services.items().where($[0] in $root.data.enabled_services).select($[1]).flatten() + $root.data.enabled_services\", \"data\": {\"enabled_services\": {\"get_param\": \"EnabledServices\"}, \"extra_services\": {\"keystone\": [\"keystone_admin_api\", \"keystone_public_api\"]}}}}}}, \"NetIpMapValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"yaql\": {\"expression\": \"let(root => $) -> dict($.data.net_ip_map.items().where($[0] in $root.data.role_networks))\", \"data\": {\"role_networks\": {\"get_param\": \"RoleNetworks\"}, \"net_ip_map\": {\"ctlplane\": {\"get_param\": \"ControlPlaneIpList\"}, \"storage\": {\"get_param\": \"StorageIpList\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtIpList\"}, \"internal_api\": {\"get_param\": \"InternalApiIpList\"}, \"tenant\": {\"get_param\": \"TenantIpList\"}, \"external\": {\"get_param\": \"ExternalIpList\"}}}}}, {\"keys\": {\"ctlplane\": \"ctlplane\", \"storage\": {\"get_param\": \"StorageNetName\"}, \"storage_mgmt\": {\"get_param\": \"StorageMgmtNetName\"}, \"internal_api\": {\"get_param\": \"InternalApiNetName\"}, \"tenant\": {\"get_param\": \"TenantNetName\"}, \"external\": {\"get_param\": \"ExternalNetName\"}}}]}}}}, \"outputs\": {\"net_ip_map\": {\"description\": \"A Hash containing a mapping of network names to assigned lists of IP addresses.\\n\", \"value\": {\"get_attr\": [\"NetIpMapValue\", \"value\"]}}, \"ctlplane_service_ips\": {\"description\": \"Map of enabled services to a list of their ctlplane IP addresses\\n\", \"value\": {\"map_merge\": {\"repeat\": {\"template\": {\"SERVICE_ctlplane_node_ips\": \"$$ groups[\'SERVICE\'] | default ([]) | map(\'extract\', hostvars, \'ctlplane_ip\') | list | to_json $$\"}, \"for_each\": {\"SERVICE\": {\"get_attr\": [\"EnabledServicesValue\", \"value\"]}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ControlPlaneIpList\": \"\", \"InternalApiIpList\": \"\", \"TenantIpList\": \"\", \"EnabledServices\": \"\", \"ServiceNetMap\": {\"apache_network\": \"internal_api\", \"neutron_tenant_network\": \"tenant\", \"aodh_api_network\": \"internal_api\", \"barbican_api_network\": \"internal_api\", \"gnocchi_api_network\": \"internal_api\", \"mongodb_network\": \"internal_api\", \"cinder_api_network\": \"internal_api\", \"cinder_iscsi_network\": \"storage\", \"glance_api_network\": \"internal_api\", \"glance_api_edge_network\": \"internal_api\", \"glance_api_internal_network\": \"internal_api\", \"ironic_api_network\": \"ctlplane\", \"ironic_network\": \"ctlplane\", \"ironic_inspector_network\": \"ctlplane\", \"keystone_admin_api_network\": \"ctlplane\", \"keystone_public_api_network\": \"internal_api\", \"manila_api_network\": \"internal_api\", \"neutron_api_network\": \"internal_api\", \"octavia_api_network\": \"internal_api\", \"heat_api_network\": \"internal_api\", \"heat_api_cfn_network\": \"internal_api\", \"heat_api_cloudwatch_network\": \"internal_api\", \"nova_api_network\": \"internal_api\", \"placement_network\": \"internal_api\", \"nova_metadata_network\": \"internal_api\", \"nova_libvirt_network\": \"internal_api\", \"novajoin_network\": \"internal_api\", \"swift_storage_network\": \"storage_mgmt\", \"swift_proxy_network\": \"storage\", \"horizon_network\": \"internal_api\", \"memcached_network\": \"internal_api\", \"oslo_messaging_rpc_network\": \"internal_api\", \"oslo_messaging_notify_network\": \"internal_api\", \"rabbitmq_network\": \"internal_api\", \"rabbitmq_management_network\": \"internal_api\", \"qdr_network\": \"internal_api\", \"redis_network\": \"internal_api\", \"ganesha_network\": \"external\", \"mysql_network\": \"internal_api\", \"snmpd_network\": \"ctlplane\", \"ceph_cluster_network\": \"storage_mgmt\", \"ceph_dashboard_network\": \"ctlplane\", \"ceph_grafana_network\": \"storage\", \"ceph_mon_network\": \"storage\", \"ceph_rgw_network\": \"storage\", \"public_network\": \"external\", \"internal_api_network\": \"internal_api\", \"opendaylight_api_network\": \"internal_api\", \"ovn_dbs_network\": \"internal_api\", \"docker_registry_network\": \"ctlplane\", \"pacemaker_network\": \"internal_api\", \"pacemaker_remote_network\": \"internal_api\", \"designate_api_network\": \"internal_api\", \"designate_mdns_network\": \"internal_api\", \"designate_worker_network\": \"external\", \"designate_bind_network\": \"external\", \"bindnetwork\": \"external\", \"etcd_network\": \"internal_api\", \"haproxy_network\": \"ctlplane\", \"unbound_network\": \"external\", \"controller_hostname_resolve_network\": \"internal_api\", \"controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_hostname_resolve_network\": \"internal_api\", \"cell_controller_metrics_qdr_network\": \"internal_api\", \"cell_controller_compute_hostname_resolve_network\": \"internal_api\", \"cell_controller_compute_metrics_qdr_network\": \"internal_api\", \"compute_hostname_resolve_network\": \"internal_api\", \"compute_metrics_qdr_network\": \"internal_api\", \"block_storage_hostname_resolve_network\": \"internal_api\", \"block_storage_metrics_qdr_network\": \"internal_api\", \"object_storage_hostname_resolve_network\": \"internal_api\", \"object_storage_metrics_qdr_network\": \"internal_api\", \"ceph_storage_hostname_resolve_network\": \"storage\", \"ceph_storage_metrics_qdr_network\": \"storage\", \"networker_hostname_resolve_network\": \"internal_api\", \"networker_metrics_qdr_network\": \"internal_api\", \"nova_vnc_proxy_network\": \"internal_api\"}, \"ServiceHostnameList\": \"\", \"NetworkHostnameMap\": {}, \"RoleNetworks\": \"ctlplane,internal_api,tenant\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(72,'2026-06-09 08:02:03',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (73,'2026-06-09 08:02:03',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Nova Migration Target service\\n\", \"parameters\": {\"ContainerNovaComputeImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\"}, \"ContainerNovaLibvirtConfigImage\": {\"description\": \"The container image to use for the nova_libvirt config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"DockerNovaMigrationSshdPort\": {\"default\": 2022, \"description\": \"Port that dockerized nova migration target sshd service binds to.\", \"type\": \"number\"}, \"MigrationSshKey\": {\"type\": \"json\", \"description\": \"SSH key for migration. Expects a dictionary with keys \'public_key\' and \'private_key\'. Values should be identical to SSH public/private key files.\\n\", \"default\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}}, \"MigrationSshPort\": {\"default\": 2022, \"description\": \"Target port for migration over ssh\", \"type\": \"number\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"SshdBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-puppet.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerNovaComputeImage\": \"ContainerNovaComputeImage\", \"ContainerNovaLibvirtConfigImage\": \"ContainerNovaLibvirtConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerNovaComputeImage\": {\"get_param\": \"ContainerNovaComputeImage\"}, \"ContainerNovaLibvirtConfigImage\": {\"get_param\": \"ContainerNovaLibvirtConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Nova Migration Target service.\", \"value\": {\"service_name\": \"nova_migration_target\", \"firewall_rules\": {\"map_merge\": [{\"map_merge\": {\"repeat\": {\"for_each\": {\"<%net_cidr%>\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}]}}, \"template\": {\"113 nova_migration_target accept libvirt subnet <%net_cidr%>\": {\"source\": \"<%net_cidr%>\", \"proto\": \"tcp\", \"dport\": {\"get_param\": \"MigrationSshPort\"}}}}}}, {\"map_merge\": {\"repeat\": {\"for_each\": {\"<%net_cidr%>\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}]}}, \"template\": {\"113 nova_migration_target accept api subnet <%net_cidr%>\": {\"source\": \"<%net_cidr%>\", \"proto\": \"tcp\", \"dport\": {\"get_param\": \"MigrationSshPort\"}}}}}}]}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"SshdBase\", \"role_data\", \"config_settings\"]}, {\"tripleo::profile::base::nova::migration::target::ssh_authorized_keys\": [{\"get_param\": [\"MigrationSshKey\", \"public_key\"]}], \"tripleo::profile::base::nova::migration::target::ssh_localaddrs\": [\"%{hiera(\'cold_migration_ssh_inbound_addr\')}\", \"%{hiera(\'live_migration_ssh_inbound_addr\')}\"], \"live_migration_ssh_inbound_addr\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"cold_migration_ssh_inbound_addr\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}}}, \"tripleo::profile::base::sshd::port\": [22]}]}, \"puppet_config\": {\"config_volume\": \"nova_libvirt\", \"step_config\": {\"list_join\": [\"\\n\", [{\"get_attr\": [\"SshdBase\", \"role_data\", \"step_config\"]}, \"include tripleo::profile::base::nova::migration::target\"]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/nova-migration-target.json\": {\"command\": {\"str_replace\": {\"template\": \"dumb-init --single-child -- /usr/sbin/sshd -D -p SSHDPORT\", \"params\": {\"SSHDPORT\": {\"get_param\": \"DockerNovaMigrationSshdPort\"}}}}, \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/host-ssh/ssh_host_*_key\", \"dest\": \"/etc/ssh/\", \"owner\": \"root\", \"perm\": \"0600\"}]}}, \"host_prep_tasks\": [{\"name\": \"Create libvirt persistent data directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\"}, \"loop\": [{\"path\": \"/run/libvirt\", \"setype\": \"virt_var_run_t\"}]}, {\"name\": \"ensure /run/libvirt is present upon reboot\", \"copy\": {\"dest\": \"/etc/tmpfiles.d/run-libvirt.conf\", \"content\": \"d /run/libvirt 0755 root root - -\\n\"}}], \"docker_config\": {\"step_4\": {\"nova_migration_target\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaComputeImage\"]}, \"net\": \"host\", \"privileged\": true, \"user\": \"root\", \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/nova-migration-target.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\", \"/etc/ssh:/host-ssh:ro\", \"/run/libvirt:/run/libvirt:shared,z\", \"/var/lib/nova:/var/lib/nova:shared\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"deploy_steps_tasks\": [{\"name\": \"validate nova-migration-target container state\", \"containers.podman.podman_container_info\": {\"name\": \"nova_migration_target\"}, \"register\": \"nova_migration_target_infos\", \"failed_when\": [\"nova_migration_target_infos.containers.0.Healthcheck.Status is defined\", \"\'healthy\' not in nova_migration_target_infos.containers.0.Healthcheck.Status\"], \"retries\": 10, \"delay\": 30, \"tags\": [\"opendev-validation\", \"opendev-validation-nova\"], \"when\": [\"container_cli == \'podman\'\", \"not container_healthcheck_disabled\", \"step|int == 5\"]}], \"update_tasks\": [{\"name\": \"nova_migration_target_tmpfile_cleanup\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Remove old tmpfiles.d config\", \"file\": {\"path\": \"/etc/tmpfiles.d/var-run-libvirt.conf\", \"state\": \"absent\"}}]}], \"upgrade_tasks\": [{\"name\": \"nova_migration_target_tmpfile_cleanup\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Remove old tmpfiles.d config\", \"file\": {\"path\": \"/etc/tmpfiles.d/var-run-libvirt.conf\", \"state\": \"absent\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(74,'2026-06-09 08:02:03',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"HAproxy service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"CAMap\": {\"description\": \"Map containing the CA certs and information needed for deploying them.\\n\", \"default\": {}, \"type\": \"json\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for injecting CA certificates.\", \"value\": {\"service_name\": \"ca_certs\", \"config_settings\": {\"tripleo::trusted_cas::ca_map\": {\"get_param\": \"CAMap\"}}, \"step_config\": \"include tripleo::trusted_cas\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(75,'2026-06-09 08:02:03',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Configure sshd_config\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"BannerText\": {\"default\": \"\", \"description\": \"Configures Banner text in sshd_config\", \"type\": \"string\"}, \"MessageOfTheDay\": {\"default\": \"\", \"description\": \"Configures /etc/motd text\", \"type\": \"string\"}, \"SshServerOptions\": {\"default\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"description\": \"Mapping of sshd_config values\", \"type\": \"json\"}, \"SshServerOptionsOverrides\": {\"default\": {}, \"description\": \"Mapping of sshd_config values to override definitions in SshServerOptions\", \"type\": \"json\"}, \"PasswordAuthentication\": {\"default\": \"yes\", \"description\": \"Whether or not disable password authentication\", \"type\": \"string\"}, \"SshFirewallAllowAll\": {\"default\": true, \"description\": \"Set this to true to open up ssh access from all sources.\", \"type\": \"boolean\"}}, \"conditions\": {\"ssh_firewall_allow_all\": {\"equals\": [{\"get_param\": \"SshFirewallAllowAll\"}, true]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the ssh\", \"value\": {\"service_name\": \"sshd\", \"firewall_rules\": {\"003 accept ssh from all\": {\"proto\": \"tcp\", \"dport\": 22, \"extras\": {\"ensure\": {\"if\": [\"ssh_firewall_allow_all\", \"present\", \"absent\"]}}}}, \"config_settings\": {\"tripleo::profile::base::sshd::bannertext\": {\"get_param\": \"BannerText\"}, \"tripleo::profile::base::sshd::motd\": {\"get_param\": \"MessageOfTheDay\"}, \"tripleo::profile::base::sshd::options\": {\"map_merge\": [{\"get_param\": \"SshServerOptions\"}, {\"get_param\": \"SshServerOptionsOverrides\"}]}, \"tripleo::profile::base::sshd::password_authentication\": {\"get_param\": \"PasswordAuthentication\"}}, \"step_config\": \"include tripleo::profile::base::sshd\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(76,'2026-06-09 08:02:03',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(77,'2026-06-09 08:02:03',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Ceilometer Agent Central service\\n\", \"parameters\": {\"ContainerCeilometerCentralImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\"}, \"ContainerCeilometerConfigImage\": {\"description\": \"The container image to use for the ceilometer config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\"}, \"CeilometerAgentCentralLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.ceilometer.agent.central\", \"file\": \"/var/log/containers/ceilometer/central.log\"}}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"RedisPassword\": {\"description\": \"The password for the redis service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"Qw5poqjrA95kbXlQw5cMcjZDa\"}, \"MonitoringSubscriptionCeilometerCentral\": {\"default\": \"overcloud-ceilometer-agent-central\", \"type\": \"string\"}, \"CeilometerEnableGnocchi\": {\"default\": false, \"description\": \"Whether to enable gnocchi usage.\", \"type\": \"boolean\"}, \"CeilometerPassword\": {\"description\": \"The password for the ceilometer service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"6GBzmfESOACPjM70aXaIF8M8d\"}, \"CeilometerEnableTenantDiscovery\": {\"default\": false, \"description\": \"Identify user and project names from polled metrics.\", \"type\": \"boolean\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CeilometerServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-base-container-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCeilometerCentralImage\": \"ContainerCeilometerCentralImage\", \"ContainerCeilometerConfigImage\": \"ContainerCeilometerConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCeilometerCentralImage\": {\"get_param\": \"ContainerCeilometerCentralImage\"}, \"ContainerCeilometerConfigImage\": {\"get_param\": \"ContainerCeilometerConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer Agent Central role.\", \"value\": {\"service_name\": \"ceilometer_agent_central\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionCeilometerCentral\"}, \"keystone_resources\": {\"ceilometer\": {\"users\": {\"ceilometer\": {\"password\": {\"get_param\": \"CeilometerPassword\"}, \"roles\": [\"admin\", \"ResellerAdmin\"]}}, \"roles\": [\"ResellerAdmin\"]}}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CeilometerServiceBase\", \"role_data\", \"config_settings\"]}, {\"ceilometer_redis_password\": {\"get_param\": \"RedisPassword\"}, \"central_namespace\": true, \"ceilometer::agent::polling::tenant_name_discovery\": {\"get_param\": \"CeilometerEnableTenantDiscovery\"}}]}, \"service_config_settings\": {\"map_merge\": [{\"get_attr\": [\"CeilometerServiceBase\", \"role_data\", \"service_config_settings\"]}, {\"rsyslog\": {\"tripleo_logging_sources_ceilometer_agent_central\": [{\"get_param\": \"CeilometerAgentCentralLoggingSource\"}]}}]}, \"puppet_config\": {\"config_volume\": \"ceilometer\", \"puppet_tags\": \"ceilometer_config\", \"step_config\": \"include tripleo::profile::base::ceilometer::agent::polling\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/ceilometer_agent_central.json\": {\"command\": \"/usr/bin/ceilometer-polling --polling-namespaces central --logfile /var/log/ceilometer/central.log\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}, \"/var/lib/kolla/config_files/ceilometer_agent_gnocchi_upgrade.json\": {\"command\": \"/usr/bin/bootstrap_host_exec ceilometer_agent_central su ceilometer -s /bin/bash -c \'for n in {1..10}; do /usr/bin/ceilometer-upgrade && exit 0 || sleep 30; done; exit 1\'\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}}, \"docker_config\": {\"step_3\": {\"ceilometer_init_log\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerCentralImage\"]}, \"net\": \"none\", \"user\": \"root\", \"command\": [\"/bin/bash\", \"-c\", \"chown -R ceilometer:ceilometer /var/log/ceilometer\"], \"volumes\": [\"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]}}, \"step_4\": {\"ceilometer_agent_central\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerCentralImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/ceilometer_agent_central.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}, \"step_5\": {\"if\": [{\"get_param\": \"CeilometerEnableGnocchi\"}, {\"ceilometer_gnocchi_upgrade\": {\"start_order\": 99, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCeilometerCentralImage\"]}, \"net\": \"host\", \"detach\": false, \"privileged\": false, \"user\": \"root\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/ceilometer_agent_gnocchi_upgrade.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/ceilometer:/var/log/ceilometer:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}]}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/ceilometer\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop ceilometer agent central container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"ceilometer_agent_central\"], \"tripleo_delegate_to\": \"{{ groups[\'ceilometer_agent_central\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(78,'2026-06-09 08:02:03',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(79,'2026-06-09 08:02:03',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Ceilometer service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"CeilometerMeteringSecret\": {\"description\": \"Secret shared by the ceilometer services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\"}, \"CeilometerPassword\": {\"description\": \"The password for the ceilometer service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"6GBzmfESOACPjM70aXaIF8M8d\"}, \"AmqpRpcAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for RPC addresses\", \"type\": \"string\"}, \"AmqpNotifyAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for Notification addresses\", \"type\": \"string\"}, \"ManagePolling\": {\"default\": false, \"description\": \"Whether to manage polling.yaml.\", \"type\": \"boolean\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"CeilometerDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Ceilometer services.\", \"type\": \"boolean\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"SnmpdReadonlyUserName\": {\"default\": \"ro_snmp_user\", \"description\": \"The user name for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\"}, \"SnmpdReadonlyUserPassword\": {\"description\": \"The user password for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\", \"hidden\": true, \"default\": \"IUqJgJKOidh20dco1DYKnuQ1\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"GnocchiArchivePolicy\": {\"default\": \"ceilometer-low-rate\", \"type\": \"string\", \"description\": \"(DEPRECATED) archive policy to use with gnocchi backend\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"MemcachedTLS\": {\"default\": true, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"GnocchiArchivePolicy\"]}], \"conditions\": {\"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer role.\", \"value\": {\"service_name\": \"ceilometer_base\", \"config_settings\": {\"map_merge\": [{\"ceilometer::logging::debug\": {\"if\": [{\"get_param\": \"CeilometerDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"ceilometer::agent::polling::manage_polling\": {\"get_param\": \"ManagePolling\"}, \"ceilometer::agent::service_credentials::password\": {\"get_param\": \"CeilometerPassword\"}, \"ceilometer::agent::service_credentials::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"ceilometer::agent::service_credentials::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"ceilometer::agent::service_credentials::project_name\": \"service\", \"ceilometer::agent::service_credentials::user_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::auth_project_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::interface\": \"internalURL\", \"ceilometer::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"ceilometer::amqp_rpc_address_prefix\": {\"get_param\": \"AmqpRpcAddressPrefix\"}, \"ceilometer::amqp_notify_address_prefix\": {\"get_param\": \"AmqpNotifyAddressPrefix\"}, \"ceilometer::telemetry_secret\": {\"get_param\": \"CeilometerMeteringSecret\"}, \"ceilometer::snmpd_readonly_username\": {\"get_param\": \"SnmpdReadonlyUserName\"}, \"ceilometer::snmpd_readonly_user_password\": {\"get_param\": \"SnmpdReadonlyUserPassword\"}, \"ceilometer::host\": \"%{hiera(\'fqdn_canonical\')}\", \"ceilometer::rabbit_heartbeat_in_pthread\": false, \"ceilometer::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"ceilometer::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}}, {\"if\": [\"tls_cache_enabled\", {\"ceilometer::cache::backend\": \"dogpile.cache.pymemcache\", \"ceilometer::cache::enable_socket_keepalive\": true}, {\"ceilometer::cache::backend\": \"dogpile.cache.memcached\"}]}]}, \"service_config_settings\": {\"keystone\": {\"tripleo::profile::base::keystone::ceilometer_notification_topics\": [\"notifications\"]}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(80,'2026-06-09 08:02:04',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (81,'2026-06-09 08:02:04',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Apache service configured with Puppet. Note this is typically included automatically via other services which run via Apache.\\n\", \"parameters\": {\"ApacheMaxRequestWorkers\": {\"default\": 100, \"description\": \"Maximum number of simultaneously processed requests.\", \"type\": \"number\"}, \"ApacheServerLimit\": {\"default\": 100, \"description\": \"Maximum number of Apache processes.\", \"type\": \"number\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"ApacheCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"ApacheTimeout\": {\"type\": \"number\", \"default\": 90, \"description\": \"The timeout in seconds for Apache, which defines duration Apache waits for I/O operations\"}}, \"conditions\": {\"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"ApacheCertificateKeySize\"}, \"\"]}}}, \"resources\": {\"ApacheNetworks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"Controller\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"CellController\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"CellControllerCompute\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"Compute\": [\"ctlplane\", \"storage\", \"internal_api\"], \"BlockStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"ObjectStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"CephStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\"], \"Networker\": [\"ctlplane\", \"internal_api\"]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Apache role.\", \"value\": {\"service_name\": \"apache\", \"config_settings\": {\"map_merge\": [{\"apache::ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}}}}, \"apache::default_vhost\": false, \"apache::trace_enable\": \"Off\", \"apache::server_signature\": \"Off\", \"apache::server_tokens\": \"Prod\", \"apache::timeout\": {\"get_param\": \"ApacheTimeout\"}, \"apache::default_mods\": false, \"apache::mod::prefork::maxrequestworkers\": {\"get_param\": \"ApacheMaxRequestWorkers\"}, \"apache::mod::prefork::serverlimit\": {\"get_param\": \"ApacheServerLimit\"}, \"apache::mod::remoteip::proxy_ips\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}]}, \"apache::mod::alias::icons_options\": \"None\"}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"apache::mod::ssl::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}, \"apache::mod::ssl::ssl_protocol\": [\"all\", \"-SSLv2\", \"-SSLv3\", \"-TLSv1\"], \"apache_certificates_specs\": {\"map_merge\": {\"repeat\": {\"template\": {\"httpd-NETWORK\": {\"service_certificate\": \"/etc/pki/tls/certs/httpd/httpd-NETWORK.crt\", \"service_key\": \"/etc/pki/tls/private/httpd/httpd-NETWORK.key\"}}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}, \"metadata_settings\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"repeat\": {\"template\": [{\"service\": \"HTTP\", \"network\": \"$NETWORK\", \"type\": \"node\"}], \"for_each\": {\"$NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}]}, \"upgrade_tasks\": [], \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [\"/etc/pki/tls/certs/httpd\", \"/etc/pki/tls/private/httpd\"]}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": {\"repeat\": {\"template\": {\"name\": \"httpd-NETWORK\", \"dns\": \"{{ fqdn_NETWORK }}\", \"principal\": \"HTTP/{{ fqdn_NETWORK }}@{{ idm_realm }}\", \"run_after\": \"cp /etc/pki/tls/certs/httpd-NETWORK.crt /etc/pki/tls/certs/httpd/httpd-NETWORK.crt\\ncp /etc/pki/tls/private/httpd-NETWORK.key /etc/pki/tls/private/httpd/httpd-NETWORK.key\\npkill -USR1 httpd\\n\", \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"ApacheCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"EnableInternalTLS\": true}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(82,'2026-06-09 08:02:04',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(83,'2026-06-09 08:02:04',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Ceilometer service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"CeilometerMeteringSecret\": {\"description\": \"Secret shared by the ceilometer services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\"}, \"CeilometerPassword\": {\"description\": \"The password for the ceilometer service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"6GBzmfESOACPjM70aXaIF8M8d\"}, \"AmqpRpcAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for RPC addresses\", \"type\": \"string\"}, \"AmqpNotifyAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for Notification addresses\", \"type\": \"string\"}, \"ManagePolling\": {\"default\": false, \"description\": \"Whether to manage polling.yaml.\", \"type\": \"boolean\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"CeilometerDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Ceilometer services.\", \"type\": \"boolean\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"SnmpdReadonlyUserName\": {\"default\": \"ro_snmp_user\", \"description\": \"The user name for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\"}, \"SnmpdReadonlyUserPassword\": {\"description\": \"The user password for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\", \"hidden\": true, \"default\": \"IUqJgJKOidh20dco1DYKnuQ1\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"GnocchiArchivePolicy\": {\"default\": \"ceilometer-low-rate\", \"type\": \"string\", \"description\": \"(DEPRECATED) archive policy to use with gnocchi backend\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"MemcachedTLS\": {\"default\": true, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"GnocchiArchivePolicy\"]}], \"conditions\": {\"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer role.\", \"value\": {\"service_name\": \"ceilometer_base\", \"config_settings\": {\"map_merge\": [{\"ceilometer::logging::debug\": {\"if\": [{\"get_param\": \"CeilometerDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"ceilometer::agent::polling::manage_polling\": {\"get_param\": \"ManagePolling\"}, \"ceilometer::agent::service_credentials::password\": {\"get_param\": \"CeilometerPassword\"}, \"ceilometer::agent::service_credentials::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"ceilometer::agent::service_credentials::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"ceilometer::agent::service_credentials::project_name\": \"service\", \"ceilometer::agent::service_credentials::user_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::auth_project_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::interface\": \"internalURL\", \"ceilometer::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"ceilometer::amqp_rpc_address_prefix\": {\"get_param\": \"AmqpRpcAddressPrefix\"}, \"ceilometer::amqp_notify_address_prefix\": {\"get_param\": \"AmqpNotifyAddressPrefix\"}, \"ceilometer::telemetry_secret\": {\"get_param\": \"CeilometerMeteringSecret\"}, \"ceilometer::snmpd_readonly_username\": {\"get_param\": \"SnmpdReadonlyUserName\"}, \"ceilometer::snmpd_readonly_user_password\": {\"get_param\": \"SnmpdReadonlyUserPassword\"}, \"ceilometer::host\": \"%{hiera(\'fqdn_canonical\')}\", \"ceilometer::rabbit_heartbeat_in_pthread\": false, \"ceilometer::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"ceilometer::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}}, {\"if\": [\"tls_cache_enabled\", {\"ceilometer::cache::backend\": \"dogpile.cache.pymemcache\", \"ceilometer::cache::enable_socket_keepalive\": true}, {\"ceilometer::cache::backend\": \"dogpile.cache.memcached\"}]}]}, \"service_config_settings\": {\"keystone\": {\"tripleo::profile::base::keystone::ceilometer_notification_topics\": [\"notifications\"]}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(84,'2026-06-09 08:02:04',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Cinder Backup service\\n\", \"parameters\": {\"ContainerCinderBackupImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\"}, \"ContainerCinderConfigImage\": {\"description\": \"The container image to use for the cinder config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\"}, \"ClusterCommonTag\": {\"default\": false, \"description\": \"When set to false, a pacemaker service is configured to use a floating tag for its container image name, e.g. \'REGISTRY/NAMESPACE/IMAGENAME:pcmklatest\'. When set to true, the service uses a floating prefix as well, e.g. \'cluster.common.tag/IMAGENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"ClusterFullTag\": {\"default\": true, \"description\": \"When set to true, the pacemaker service uses a fully constant tag for its container image name, e.g. \'cluster.common.tag/SERVICENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"CinderBackupBackend\": {\"default\": \"swift\", \"description\": \"The short name of the Cinder Backup backend to use.\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"swift\", \"ceph\", \"nfs\", \"gcs\", \"s3\"]}]}, \"CinderBackupRbdPoolName\": {\"default\": \"backups\", \"type\": \"string\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ConfigDebug\": {\"default\": false, \"description\": \"Whether to run config management (e.g. Puppet) in debug mode.\", \"type\": \"boolean\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}, \"DeployIdentifier\": {\"default\": 1780992067, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"DockerCinderBackupLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.cinder.backup\", \"file\": \"/var/log/containers/cinder/cinder-backup.log\"}}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"CinderBackupBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-container-puppet.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"CinderBackupBackend\": {\"get_param\": \"CinderBackupBackend\"}, \"CinderBackupRbdPoolName\": {\"get_param\": \"CinderBackupRbdPoolName\"}, \"CephClientUserName\": {\"get_param\": \"CephClientUserName\"}}}, \"CinderCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCinderBackupImage\": \"ContainerCinderBackupImage\", \"ContainerCinderConfigImage\": \"ContainerCinderConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCinderBackupImage\": {\"get_param\": \"ContainerCinderBackupImage\"}, \"ContainerCinderConfigImage\": {\"get_param\": \"ContainerCinderConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder Backup role.\", \"value\": {\"service_name\": \"cinder_backup\", \"monitoring_subscription\": {\"get_attr\": [\"CinderBackupBase\", \"role_data\", \"monitoring_subscription\"]}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CinderBackupBase\", \"role_data\", \"config_settings\"]}, {\"tripleo::profile::pacemaker::cinder::backup_bundle::cinder_backup_docker_image\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-backup:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"tripleo::profile::pacemaker::cinder::backup_bundle::docker_volumes\": {\"get_attr\": [\"CinderCommon\", \"cinder_backup_volumes\"]}, \"tripleo::profile::pacemaker::cinder::backup_bundle::docker_environment\": {\"get_attr\": [\"CinderCommon\", \"cinder_backup_environment\"]}, \"tripleo::profile::pacemaker::cinder::backup_bundle::container_backend\": {\"get_param\": \"ContainerCli\"}, \"tripleo::profile::pacemaker::cinder::backup_bundle::ceph_conf_path\": {\"get_param\": \"CephConfigPath\"}, \"cinder::backup::manage_service\": false, \"cinder::backup::enabled\": false}]}, \"service_config_settings\": {\"get_attr\": [\"CinderBackupBase\", \"role_data\", \"service_config_settings\"]}, \"puppet_config\": {\"config_volume\": \"cinder\", \"puppet_tags\": \"cinder_config,file,concat,file_line\", \"step_config\": {\"list_join\": [\"\\n\", [{\"get_attr\": [\"CinderBackupBase\", \"role_data\", \"puppet_config\", \"step_config\"]}, \"include tripleo::profile::pacemaker::cinder::backup_bundle\"]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/cinder_backup.json\": {\"command\": \"/usr/bin/cinder-backup --config-file /usr/share/cinder/cinder-dist.conf --config-file /etc/cinder/cinder.conf\", \"config_files\": {\"get_attr\": [\"CinderCommon\", \"cinder_common_kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"CinderCommon\", \"cinder_common_kolla_permissions\"]}}}, \"container_config_scripts\": {\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, \"docker_config\": {\"step_3\": {\"cinder_backup_init_logs\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/cinder:/var/log/cinder:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R cinder:cinder /var/log/cinder\"]}}}, \"host_prep_tasks\": {\"get_attr\": [\"CinderCommon\", \"cinder_backup_host_prep_tasks\"]}, \"deploy_steps_tasks\": [{\"name\": \"Cinder Backup tag container image for pacemaker\", \"when\": \"step|int == 1\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"container_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-backup:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}}}, {\"name\": \"Cinder Backup HA Wrappers Step\", \"when\": \"step|int == 5\", \"block\": [{\"name\": \"Cinder backup puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"cinder_backup\", \"tripleo_ha_wrapper_resource_name\": \"openstack-cinder-backup\", \"tripleo_ha_wrapper_bundle_name\": \"openstack-cinder-backup\", \"tripleo_ha_wrapper_resource_state\": \"_ Started\", \"tripleo_ha_wrapper_puppet_config_volume\": \"cinder\", \"tripleo_ha_wrapper_puppet_execute\": \"include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::cinder::backup_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".cinder_backup_previous_run\"}}]}], \"external_update_tasks\": [{\"when\": \"step|int == 1\", \"tags\": \"ha_image_update\", \"block\": [{\"block\": [{\"name\": \"Get cinder_backup image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_cinder_backup_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'openstack-cinder-backup\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container cinder_backup image\", \"set_fact\": {\"cinder_backup_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"cinder_backup_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-backup:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_cinder_backup_image\": \"{{xmllint_pcmk_cinder_backup_image.stdout}}\"}}], \"delegate_to\": \"{{ (groups[\\\"cinder_backup\\\"] | difference(groups[\\\"excluded_overcloud\\\"]))[0] }}\"}, {\"name\": \"cinder-backup temporary pacemaker container tag in case of image switch\", \"become\": true, \"import_role\": {\"name\": \"tripleo_ha_image_update\"}, \"vars\": {\"tripleo_ha_image_update_node_names\": \"{{ groups[\\\"cinder_backup\\\"] | difference(groups[\\\"excluded_overcloud\\\"]) }}\", \"tripleo_ha_image_update_bundle\": \"openstack-cinder-backup\", \"tripleo_ha_image_update_new_image\": \"{{cinder_backup_image_latest}}\", \"tripleo_ha_image_update_old_image\": \"{{pcmk_cinder_backup_image}}\"}, \"when\": [\"(pcmk_cinder_backup_image != \\\"\\\")\", \"(pcmk_cinder_backup_image != cinder_backup_image_latest)\"]}]}], \"update_tasks\": [{\"block\": [{\"name\": \"Get cinder_backup image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_cinder_backup_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'openstack-cinder-backup\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container cinder_backup image\", \"set_fact\": {\"cinder_backup_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"cinder_backup_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-backup:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_cinder_backup_image\": \"{{xmllint_pcmk_cinder_backup_image.stdout}}\"}}], \"when\": \"(step|int == 0 or step|int == 2)\"}, {\"name\": \"Check for update of cinder-backup container image name\", \"when\": \"step|int == 0\", \"assert\": {\"that\": \"pcmk_cinder_backup_image == cinder_backup_image_latest\", \"fail_msg\": \"cinder-backup image change detected, run overcloud external-update --tags ha_image_update first\"}}, {\"name\": \"Tear-down non-HA cinder-backup container\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Remove non-HA cinder-backup container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"cinder_backup\"]}}]}, {\"name\": \"cinder_backup fetch and retag container image for pacemaker\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Retag pcmklatest to latest cinder_backup image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{cinder_backup_image}}\", \"container_image_latest\": \"{{cinder_backup_image_latest}}\"}}]}], \"post_update_tasks\": [{\"name\": \"Cinder backup bundle post update\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Cinder backup puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"cinder_backup\", \"tripleo_ha_wrapper_resource_name\": \"openstack-cinder-backup\", \"tripleo_ha_wrapper_bundle_name\": \"openstack-cinder-backup\", \"tripleo_ha_wrapper_resource_state\": \"_ Started\", \"tripleo_ha_wrapper_puppet_config_volume\": \"cinder\", \"tripleo_ha_wrapper_puppet_execute\": \"include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::cinder::backup_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".cinder_backup_previous_run\"}}], \"vars\": {\"tripleo_ha_wrapper_minor_update\": true}}], \"upgrade_tasks\": [{\"name\": \"Tear-down non-HA cinder_backup container\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Remove non-HA cinder-backup container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"cinder_backup\"]}}]}, {\"name\": \"Prepare switch of cinder_backup image name\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Get cinder_backup image id currently used by pacemaker\", \"shell\": \"pcs resource config openstack-cinder-backup | grep -Eo \'image=[^ ]+\' | awk -F= \'{print $2;}\'\", \"register\": \"cinder_backup_image_current_res\", \"failed_when\": false}, {\"name\": \"cinder_backup image facts\", \"set_fact\": {\"cinder_backup_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-backup:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"cinder_backup_image_current\": \"{{cinder_backup_image_current_res.stdout}}\"}}, {\"name\": \"Temporarily tag the current cinder_backup image id with the upgraded image name\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{cinder_backup_image_current}}\", \"container_image_latest\": \"{{cinder_backup_image_latest}}\", \"pull_image\": false}, \"when\": [\"cinder_backup_image_current != \'\'\", \"cinder_backup_image_current != cinder_backup_image_latest\"]}, {\"name\": \"Create cinder_backup retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/cinder_backup_needs_retag\", \"state\": \"touch\"}, \"when\": [\"cinder_backup_image_current != \'\'\", \"cinder_backup_image_current != cinder_backup_image_latest\"]}]}, {\"name\": \"Update cinder_backup pcs resource bundle for new container image - check\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"set is_cinder_backup_bootstrap_node fact\", \"tags\": \"common\", \"set_fact\": \"is_cinder_backup_bootstrap_node={{cinder_backup_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower}}\"}, {\"name\": \"Check for cinder_backup retag statefile\", \"stat\": {\"path\": \"/var/lib/tripleo/cinder_backup_needs_retag\"}, \"register\": \"cinder_backup_retag_state_file\"}]}, {\"name\": \"Update cinder_backup pcs resource bundle for new container image\", \"when\": [\"step|int == 1\", \"is_cinder_backup_bootstrap_node\", \"cinder_backup_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Disable the cinder_backup cluster resource before container upgrade step1\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-backup\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Update the cinder_backup bundle to use the new container image name\", \"command\": \"pcs resource bundle update openstack-cinder-backup container image={{cinder_backup_image_latest}}\"}, {\"name\": \"Enable the cinder_backup cluster resource\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-backup\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}]}, {\"name\": \"Check for cinder_backup retag statefile\", \"when\": [\"step|int == 3\"], \"stat\": {\"path\": \"/var/lib/tripleo/cinder_backup_needs_retag\"}, \"register\": \"cinder_backup_retag_state_file\"}, {\"name\": \"Retag the pacemaker image for cinder_backup\", \"when\": [\"step|int == 3\", \"cinder_backup_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Disable the cinder_backup cluster resource before container upgrade step3\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-backup\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Retag the pacemaker image if containerized\", \"block\": [{\"block\": [{\"name\": \"Get cinder_backup image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_cinder_backup_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'openstack-cinder-backup\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container cinder_backup image\", \"set_fact\": {\"cinder_backup_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"cinder_backup_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-backup:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_cinder_backup_image\": \"{{xmllint_pcmk_cinder_backup_image.stdout}}\"}}]}, {\"block\": [{\"name\": \"Retag pcmklatest to latest cinder_backup image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{cinder_backup_image}}\", \"container_image_latest\": \"{{cinder_backup_image_latest}}\"}}]}]}, {\"name\": \"Enable the cinder_backup cluster resource\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-backup\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Remove cinder_backup retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/cinder_backup_needs_retag\", \"state\": \"absent\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(85,'2026-06-09 08:02:04',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(86,'2026-06-09 08:02:04',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Provides the list of common container volumes and environment used by various cinder services.\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"CinderVolumeOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderBackupOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderVolumeOptEnvVars\": {\"default\": {}, \"description\": \"hash of optional environment variables\", \"type\": \"json\"}, \"CinderEnableIscsiBackend\": {\"default\": true, \"description\": \"Whether to enable or not the Iscsi backend for Cinder\", \"type\": \"boolean\"}, \"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderLVMConfigureVG\": {\"default\": true, \"description\": \"Whether to configure the \'cinder-volumes\' VG used by the LVM driver. When disabled (set to False), the LVM driver will work as long as the \'cinder-volumes\' VG has been created through some other means.\\n\", \"type\": \"boolean\"}, \"CinderLVMLoopDeviceSize\": {\"default\": 20480, \"description\": \"The size of the loopback file used by the cinder LVM driver.\", \"type\": \"number\"}, \"MultipathdEnable\": {\"default\": false, \"description\": \"Whether to enable the multipath daemon\", \"type\": \"boolean\"}, \"CinderVolumeCluster\": {\"default\": \"\", \"description\": \"The cluster name used for deploying the cinder-volume service in an active-active (A/A) configuration. This configuration requires the Cinder backend drivers support A/A, and the cinder-volume service not be managed by pacemaker. If these criteria are not met then the cluster name must be left blank.\\n\", \"type\": \"string\"}, \"CinderImageConversionNfsShare\": {\"default\": \"\", \"description\": \"When set, the NFS share to be used for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"CinderImageConversionNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options when using an NFS share for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"EnableEtcdInternalTLS\": {\"description\": \"Controls whether etcd and the cinder-volume service use TLS for cinder\'s lock manager, even when the rest of the internal API network is using TLS.\", \"type\": \"boolean\", \"default\": true}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephExternalMultiConfig\": {\"type\": \"json\", \"hidden\": true, \"description\": \"List of maps describing extra overrides which will be applied when configuring\\nextra external Ceph clusters. If this list is non-empty, ceph-ansible will run\\nan extra count(list) times using the same parameters as the first run except\\neach parameter within each map will override the defaults. If the following\\nwere used, the second run would configure the overcloud to also use the ceph2\\ncluster with all the previous parameters except /etc/ceph/ceph2.conf would have\\na mon_host entry containing the value of external_cluster_mon_ips below, and\\nnot the default CephExternalMonHost. Subsequent ceph-ansible runs are restricted\\nto just ceph clients. CephExternalMultiConfig may not be used to deploy additional\\ninternal Ceph clusters within one Heat stack. The map for each list should contain\\nnot tripleo-heat-template parameters but ceph-ansible parameters.\\n  - cluster: \'ceph2\'\\n    fsid: \'e2cba068-5f14-4b0f-b047-acf375c0004a\'\\n    external_cluster_mon_ips: \'172.18.0.5,172.18.0.6,172.18.0.7\'\\n    keys:\\n      - name: \\\"client.openstack\\\"\\n        caps:\\n          mgr: \\\"allow *\\\"\\n          mon: \\\"profile rbd\\\"\\n          osd: \\\"osd: profile rbd pool=volumes, profile rbd pool=backups, profile rbd pool=vms, profile rbd pool=images\\\"\\n        key: \\\"AQCwmeRcAAAAABAA6SQU/bGqFjlfLro5KxrB1Q==\\\"\\n        mode: \\\"0600\\\"\\n    dashboard_enabled: false\\n\", \"default\": []}}, \"conditions\": {\"cvol_active_active_tls_enabled\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderVolumeCluster\"}, \"\"]}}, {\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"EnableEtcdInternalTLS\"}]}, \"cinder_nfs_conversion_dir_enabled\": {\"not\": {\"equals\": [{\"get_param\": \"CinderImageConversionNfsShare\"}, \"\"]}}, \"cinder_configure_lvm\": {\"and\": [{\"get_param\": \"CinderLVMConfigureVG\"}, {\"or\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, {\"get_param\": \"CinderEnableNVMeOFBackend\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CinderNVMeOF\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\"}}, \"outputs\": {\"cinder_image_conversion_nfs_dir\": {\"description\": \"The directory where cinder does its image conversion when the directory is backed by an NFS share.\", \"value\": \"/var/lib/cinder_image_conversion\"}, \"cinder_common_host_prep_tasks\": {\"description\": \"Common host prep tasks for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_common_volumes\": {\"description\": \"Common volumes for all cinder services\", \"value\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}}, \"cinder_common_kolla_config_files\": {\"description\": \"Common kolla config_files for cinder-volume and cinder-backup services\", \"value\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-iscsid/*\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}]}, \"cinder_common_kolla_permissions\": {\"description\": \"Common kolla permissions for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, {\"path\": \"/etc/pki/tls/certs/etcd.crt\", \"owner\": \"cinder:cinder\"}, {\"path\": \"/etc/pki/tls/private/etcd.key\", \"owner\": \"cinder:cinder\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%cluster%>.client.*.keyring\", \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, \"for_each\": {\"<%cluster%>\": {\"yaql\": {\"expression\": \"$.data.multiconfig.select($.cluster)\", \"data\": {\"multiconfig\": {\"get_param\": \"CephExternalMultiConfig\"}}}}}}}]}}, \"cinder_volume_host_prep_and_system_upgrade_post_tasks\": {\"description\": \"Common host_prep and system_upgrade post tasks for cinder-volume\", \"value\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}, \"cinder_volume_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-volume service (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}, [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}], [{\"name\": \"cinder_configure_lvm fact\", \"set_fact\": {\"cinder_configure_lvm\": {\"if\": [\"cinder_configure_lvm\", true, false]}}}, {\"when\": \"cinder_configure_lvm|bool\", \"block\": [{\"name\": \"ensure LVM rpm dependencies are installed\", \"package\": {\"name\": \"lvm2\", \"state\": \"latest\"}}, {\"name\": \"cinder create LVM volume group dd\", \"command\": {\"list_join\": [\"\", [\"dd if=/dev/zero of=/var/lib/cinder/cinder-volumes bs=1 count=0 seek=\", {\"str_replace\": {\"template\": \"VALUE\", \"params\": {\"VALUE\": {\"get_param\": \"CinderLVMLoopDeviceSize\"}}}}, \"M\"]]}, \"args\": {\"creates\": \"/var/lib/cinder/cinder-volumes\"}}, {\"name\": \"Get or create LVM loopback device\", \"shell\": \"exit_code=0\\nexisting_device=$(losetup -j /var/lib/cinder/cinder-volumes -l -n -O NAME)\\nif [[ -z \\\"${existing_device}\\\" ]]; then\\n    losetup -f /var/lib/cinder/cinder-volumes --show\\n    exit_code=2\\nelse\\n    echo ${existing_device%$\'\\\\n\'*}\\nfi\\nexit ${exit_code}\", \"args\": {\"executable\": \"/bin/bash\"}, \"register\": \"_loopback_device\", \"changed_when\": \"_loopback_device.rc == 2\", \"failed_when\": \"_loopback_device.rc not in [0,2]\"}, {\"name\": \"Create LVM volume group\", \"community.general.lvg\": {\"vg\": \"cinder-volumes\", \"pvs\": \"{{ _loopback_device.stdout }}\", \"state\": \"present\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder create service to run losetup for LVM on startup\", \"copy\": {\"dest\": \"/etc/systemd/system/cinder-lvm-losetup.service\", \"content\": \"[Unit]\\nDescription=Cinder LVM losetup\\nDefaultDependencies=no\\nConflicts=umount.target\\nRequires=lvm2-monitor.service systemd-udev-settle.service\\nBefore=local-fs.target umount.target\\nAfter=var.mount lvm2-monitor.service systemd-udev-settle.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/sbin/losetup {{ _loopback_device.stdout }} /var/lib/cinder/cinder-volumes\\nExecStop=/sbin/losetup -d {{ _loopback_device.stdout }}\\nRemainAfterExit=yes\\n\\n[Install]\\nWantedBy=local-fs-pre.target\\n\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder enable the LVM losetup service\", \"systemd\": {\"name\": \"cinder-lvm-losetup\", \"enabled\": true, \"daemon_reload\": true}}]}]]}}, \"cinder_volume_upgrade_tasks\": {\"description\": \"Upgrade tasks for the cinder-volume service (HA or non-HA)\", \"value\": [{\"name\": \"cinder-volume pre system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Unmount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}, \"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": \"image_conversion_nfs_enabled|bool\", \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"absent\", \"fstype\": \"nfs4\"}}]}, {\"name\": \"cinder-volume post system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 5\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}]}, \"cinder_volume_config_settings\": {\"description\": \"Config settings for the cinder-volume container (HA or non-HA)\", \"value\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", {\"cinder::image_conversion_dir\": \"/var/lib/cinder_image_conversion\"}, {}]}}, \"cinder_volume_volumes\": {\"description\": \"Volumes for the cinder-volume container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderVolumeOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_volume.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/lib/modules:/lib/modules:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, [\"/etc/target:/etc/target:z\"]]}, {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}, {\"if\": [\"cinder_nfs_conversion_dir_enabled\", [{\"str_replace\": {\"template\": \"DIR:DIR:slave\", \"params\": {\"DIR\": \"/var/lib/cinder_image_conversion\"}}}]]}]}}, \"cinder_volume_environment\": {\"description\": \"Docker environment for the cinder-volume container (HA or non-HA)\", \"value\": {\"map_merge\": [{\"get_param\": \"CinderVolumeOptEnvVars\"}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}]}}, \"cinder_backup_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-backup service (HA or non-HA)\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_backup_volumes\": {\"description\": \"Volumes for the cinder-backup container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderBackupOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_backup.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/lib/modules:/lib/modules:ro\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}}, \"cinder_backup_environment\": {\"description\": \"Docker environment for the cinder-backup container (HA or non-HA)\", \"value\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(87,'2026-06-09 08:02:05',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Provides the list of common container volumes and environment used by various cinder services.\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"CinderVolumeOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderBackupOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderVolumeOptEnvVars\": {\"default\": {}, \"description\": \"hash of optional environment variables\", \"type\": \"json\"}, \"CinderEnableIscsiBackend\": {\"default\": true, \"description\": \"Whether to enable or not the Iscsi backend for Cinder\", \"type\": \"boolean\"}, \"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderLVMConfigureVG\": {\"default\": true, \"description\": \"Whether to configure the \'cinder-volumes\' VG used by the LVM driver. When disabled (set to False), the LVM driver will work as long as the \'cinder-volumes\' VG has been created through some other means.\\n\", \"type\": \"boolean\"}, \"CinderLVMLoopDeviceSize\": {\"default\": 20480, \"description\": \"The size of the loopback file used by the cinder LVM driver.\", \"type\": \"number\"}, \"MultipathdEnable\": {\"default\": false, \"description\": \"Whether to enable the multipath daemon\", \"type\": \"boolean\"}, \"CinderVolumeCluster\": {\"default\": \"\", \"description\": \"The cluster name used for deploying the cinder-volume service in an active-active (A/A) configuration. This configuration requires the Cinder backend drivers support A/A, and the cinder-volume service not be managed by pacemaker. If these criteria are not met then the cluster name must be left blank.\\n\", \"type\": \"string\"}, \"CinderImageConversionNfsShare\": {\"default\": \"\", \"description\": \"When set, the NFS share to be used for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"CinderImageConversionNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options when using an NFS share for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"EnableEtcdInternalTLS\": {\"description\": \"Controls whether etcd and the cinder-volume service use TLS for cinder\'s lock manager, even when the rest of the internal API network is using TLS.\", \"type\": \"boolean\", \"default\": true}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephExternalMultiConfig\": {\"type\": \"json\", \"hidden\": true, \"description\": \"List of maps describing extra overrides which will be applied when configuring\\nextra external Ceph clusters. If this list is non-empty, ceph-ansible will run\\nan extra count(list) times using the same parameters as the first run except\\neach parameter within each map will override the defaults. If the following\\nwere used, the second run would configure the overcloud to also use the ceph2\\ncluster with all the previous parameters except /etc/ceph/ceph2.conf would have\\na mon_host entry containing the value of external_cluster_mon_ips below, and\\nnot the default CephExternalMonHost. Subsequent ceph-ansible runs are restricted\\nto just ceph clients. CephExternalMultiConfig may not be used to deploy additional\\ninternal Ceph clusters within one Heat stack. The map for each list should contain\\nnot tripleo-heat-template parameters but ceph-ansible parameters.\\n  - cluster: \'ceph2\'\\n    fsid: \'e2cba068-5f14-4b0f-b047-acf375c0004a\'\\n    external_cluster_mon_ips: \'172.18.0.5,172.18.0.6,172.18.0.7\'\\n    keys:\\n      - name: \\\"client.openstack\\\"\\n        caps:\\n          mgr: \\\"allow *\\\"\\n          mon: \\\"profile rbd\\\"\\n          osd: \\\"osd: profile rbd pool=volumes, profile rbd pool=backups, profile rbd pool=vms, profile rbd pool=images\\\"\\n        key: \\\"AQCwmeRcAAAAABAA6SQU/bGqFjlfLro5KxrB1Q==\\\"\\n        mode: \\\"0600\\\"\\n    dashboard_enabled: false\\n\", \"default\": []}}, \"conditions\": {\"cvol_active_active_tls_enabled\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderVolumeCluster\"}, \"\"]}}, {\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"EnableEtcdInternalTLS\"}]}, \"cinder_nfs_conversion_dir_enabled\": {\"not\": {\"equals\": [{\"get_param\": \"CinderImageConversionNfsShare\"}, \"\"]}}, \"cinder_configure_lvm\": {\"and\": [{\"get_param\": \"CinderLVMConfigureVG\"}, {\"or\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, {\"get_param\": \"CinderEnableNVMeOFBackend\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CinderNVMeOF\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\"}}, \"outputs\": {\"cinder_image_conversion_nfs_dir\": {\"description\": \"The directory where cinder does its image conversion when the directory is backed by an NFS share.\", \"value\": \"/var/lib/cinder_image_conversion\"}, \"cinder_common_host_prep_tasks\": {\"description\": \"Common host prep tasks for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_common_volumes\": {\"description\": \"Common volumes for all cinder services\", \"value\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}}, \"cinder_common_kolla_config_files\": {\"description\": \"Common kolla config_files for cinder-volume and cinder-backup services\", \"value\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-iscsid/*\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}]}, \"cinder_common_kolla_permissions\": {\"description\": \"Common kolla permissions for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, {\"path\": \"/etc/pki/tls/certs/etcd.crt\", \"owner\": \"cinder:cinder\"}, {\"path\": \"/etc/pki/tls/private/etcd.key\", \"owner\": \"cinder:cinder\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%cluster%>.client.*.keyring\", \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, \"for_each\": {\"<%cluster%>\": {\"yaql\": {\"expression\": \"$.data.multiconfig.select($.cluster)\", \"data\": {\"multiconfig\": {\"get_param\": \"CephExternalMultiConfig\"}}}}}}}]}}, \"cinder_volume_host_prep_and_system_upgrade_post_tasks\": {\"description\": \"Common host_prep and system_upgrade post tasks for cinder-volume\", \"value\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}, \"cinder_volume_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-volume service (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}, [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}], [{\"name\": \"cinder_configure_lvm fact\", \"set_fact\": {\"cinder_configure_lvm\": {\"if\": [\"cinder_configure_lvm\", true, false]}}}, {\"when\": \"cinder_configure_lvm|bool\", \"block\": [{\"name\": \"ensure LVM rpm dependencies are installed\", \"package\": {\"name\": \"lvm2\", \"state\": \"latest\"}}, {\"name\": \"cinder create LVM volume group dd\", \"command\": {\"list_join\": [\"\", [\"dd if=/dev/zero of=/var/lib/cinder/cinder-volumes bs=1 count=0 seek=\", {\"str_replace\": {\"template\": \"VALUE\", \"params\": {\"VALUE\": {\"get_param\": \"CinderLVMLoopDeviceSize\"}}}}, \"M\"]]}, \"args\": {\"creates\": \"/var/lib/cinder/cinder-volumes\"}}, {\"name\": \"Get or create LVM loopback device\", \"shell\": \"exit_code=0\\nexisting_device=$(losetup -j /var/lib/cinder/cinder-volumes -l -n -O NAME)\\nif [[ -z \\\"${existing_device}\\\" ]]; then\\n    losetup -f /var/lib/cinder/cinder-volumes --show\\n    exit_code=2\\nelse\\n    echo ${existing_device%$\'\\\\n\'*}\\nfi\\nexit ${exit_code}\", \"args\": {\"executable\": \"/bin/bash\"}, \"register\": \"_loopback_device\", \"changed_when\": \"_loopback_device.rc == 2\", \"failed_when\": \"_loopback_device.rc not in [0,2]\"}, {\"name\": \"Create LVM volume group\", \"community.general.lvg\": {\"vg\": \"cinder-volumes\", \"pvs\": \"{{ _loopback_device.stdout }}\", \"state\": \"present\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder create service to run losetup for LVM on startup\", \"copy\": {\"dest\": \"/etc/systemd/system/cinder-lvm-losetup.service\", \"content\": \"[Unit]\\nDescription=Cinder LVM losetup\\nDefaultDependencies=no\\nConflicts=umount.target\\nRequires=lvm2-monitor.service systemd-udev-settle.service\\nBefore=local-fs.target umount.target\\nAfter=var.mount lvm2-monitor.service systemd-udev-settle.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/sbin/losetup {{ _loopback_device.stdout }} /var/lib/cinder/cinder-volumes\\nExecStop=/sbin/losetup -d {{ _loopback_device.stdout }}\\nRemainAfterExit=yes\\n\\n[Install]\\nWantedBy=local-fs-pre.target\\n\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder enable the LVM losetup service\", \"systemd\": {\"name\": \"cinder-lvm-losetup\", \"enabled\": true, \"daemon_reload\": true}}]}]]}}, \"cinder_volume_upgrade_tasks\": {\"description\": \"Upgrade tasks for the cinder-volume service (HA or non-HA)\", \"value\": [{\"name\": \"cinder-volume pre system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Unmount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}, \"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": \"image_conversion_nfs_enabled|bool\", \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"absent\", \"fstype\": \"nfs4\"}}]}, {\"name\": \"cinder-volume post system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 5\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}]}, \"cinder_volume_config_settings\": {\"description\": \"Config settings for the cinder-volume container (HA or non-HA)\", \"value\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", {\"cinder::image_conversion_dir\": \"/var/lib/cinder_image_conversion\"}, {}]}}, \"cinder_volume_volumes\": {\"description\": \"Volumes for the cinder-volume container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderVolumeOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_volume.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/lib/modules:/lib/modules:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, [\"/etc/target:/etc/target:z\"]]}, {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}, {\"if\": [\"cinder_nfs_conversion_dir_enabled\", [{\"str_replace\": {\"template\": \"DIR:DIR:slave\", \"params\": {\"DIR\": \"/var/lib/cinder_image_conversion\"}}}]]}]}}, \"cinder_volume_environment\": {\"description\": \"Docker environment for the cinder-volume container (HA or non-HA)\", \"value\": {\"map_merge\": [{\"get_param\": \"CinderVolumeOptEnvVars\"}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}]}}, \"cinder_backup_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-backup service (HA or non-HA)\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_backup_volumes\": {\"description\": \"Volumes for the cinder-backup container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderBackupOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_backup.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/lib/modules:/lib/modules:ro\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}}, \"cinder_backup_environment\": {\"description\": \"Docker environment for the cinder-backup container (HA or non-HA)\", \"value\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(88,'2026-06-09 08:02:05',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Cinder Volume service\\n\", \"parameters\": {\"ContainerCinderVolumeImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\"}, \"ContainerCinderConfigImage\": {\"description\": \"The container image to use for the cinder config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\"}, \"ClusterCommonTag\": {\"default\": false, \"description\": \"When set to false, a pacemaker service is configured to use a floating tag for its container image name, e.g. \'REGISTRY/NAMESPACE/IMAGENAME:pcmklatest\'. When set to true, the service uses a floating prefix as well, e.g. \'cluster.common.tag/IMAGENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"ClusterFullTag\": {\"default\": true, \"description\": \"When set to true, the pacemaker service uses a fully constant tag for its container image name, e.g. \'cluster.common.tag/SERVICENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ConfigDebug\": {\"default\": false, \"description\": \"Whether to run config management (e.g. Puppet) in debug mode.\", \"type\": \"boolean\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}, \"DeployIdentifier\": {\"default\": 1780992067, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"CinderVolumeLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.cinder.volume\", \"file\": \"/var/log/containers/cinder/cinder-volume.log\"}}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"CinderBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"CinderCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCinderVolumeImage\": \"ContainerCinderVolumeImage\", \"ContainerCinderConfigImage\": \"ContainerCinderConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCinderVolumeImage\": {\"get_param\": \"ContainerCinderVolumeImage\"}, \"ContainerCinderConfigImage\": {\"get_param\": \"ContainerCinderConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder Volume role.\", \"value\": {\"service_name\": \"cinder_volume\", \"firewall_rules\": {\"get_attr\": [\"CinderBase\", \"role_data\", \"firewall_rules\"]}, \"monitoring_subscription\": {\"get_attr\": [\"CinderBase\", \"role_data\", \"monitoring_subscription\"]}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CinderBase\", \"role_data\", \"config_settings\"]}, {\"tripleo::profile::base::lvm::enable_udev\": false, \"tripleo::profile::pacemaker::cinder::volume_bundle::cinder_volume_docker_image\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-volume:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"tripleo::profile::pacemaker::cinder::volume_bundle::docker_volumes\": {\"get_attr\": [\"CinderCommon\", \"cinder_volume_volumes\"]}, \"tripleo::profile::pacemaker::cinder::volume_bundle::docker_environment\": {\"get_attr\": [\"CinderCommon\", \"cinder_volume_environment\"]}, \"tripleo::profile::pacemaker::cinder::volume_bundle::container_backend\": {\"get_param\": \"ContainerCli\"}, \"tripleo::profile::pacemaker::cinder::volume_bundle::ceph_conf_path\": {\"get_param\": \"CephConfigPath\"}, \"cinder::volume::manage_service\": false, \"cinder::volume::enabled\": false, \"cinder::backend_host\": \"hostgroup\"}]}, \"service_config_settings\": {\"get_attr\": [\"CinderBase\", \"role_data\", \"service_config_settings\"]}, \"puppet_config\": {\"config_volume\": \"cinder\", \"puppet_tags\": \"cinder_config,file,concat,file_line\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::lvm\"], [\"include tripleo::profile::pacemaker::cinder::volume_bundle\", {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/cinder_volume.json\": {\"command\": \"/usr/bin/cinder-volume --config-file /usr/share/cinder/cinder-dist.conf --config-file /etc/cinder/cinder.conf\", \"config_files\": {\"get_attr\": [\"CinderCommon\", \"cinder_common_kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"CinderCommon\", \"cinder_common_kolla_permissions\"]}}}, \"container_config_scripts\": {\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, \"docker_config\": {\"step_3\": {\"cinder_volume_init_logs\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/cinder:/var/log/cinder\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R cinder:cinder /var/log/cinder\"]}}}, \"host_prep_tasks\": {\"get_attr\": [\"CinderCommon\", \"cinder_volume_host_prep_tasks\"]}, \"deploy_steps_tasks\": [{\"name\": \"Cinder Volume tag container image for pacemaker\", \"when\": \"step|int == 1\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"container_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-volume:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}}}, {\"name\": \"Cinder Volume HA Wrappers Step\", \"when\": \"step|int == 5\", \"block\": [{\"name\": \"Cinder volume puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"cinder_volume\", \"tripleo_ha_wrapper_resource_name\": \"openstack-cinder-volume\", \"tripleo_ha_wrapper_bundle_name\": \"openstack-cinder-volume\", \"tripleo_ha_wrapper_resource_state\": \"_ Started\", \"tripleo_ha_wrapper_puppet_config_volume\": \"cinder\", \"tripleo_ha_wrapper_puppet_execute\": \"include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::cinder::volume_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".cinder_volume_previous_run\"}}]}], \"external_update_tasks\": [{\"when\": \"step|int == 1\", \"tags\": \"ha_image_update\", \"block\": [{\"block\": [{\"name\": \"Get cinder_volume image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_cinder_volume_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'openstack-cinder-volume\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container cinder_volume image\", \"set_fact\": {\"cinder_volume_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"cinder_volume_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-volume:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_cinder_volume_image\": \"{{xmllint_pcmk_cinder_volume_image.stdout}}\"}}], \"delegate_to\": \"{{ (groups[\\\"cinder_volume\\\"] | difference(groups[\\\"excluded_overcloud\\\"]))[0] }}\"}, {\"name\": \"cinder-volume temporary pacemaker container tag in case of image switch\", \"become\": true, \"import_role\": {\"name\": \"tripleo_ha_image_update\"}, \"vars\": {\"tripleo_ha_image_update_node_names\": \"{{ groups[\\\"cinder_volume\\\"] | difference(groups[\\\"excluded_overcloud\\\"]) }}\", \"tripleo_ha_image_update_bundle\": \"openstack-cinder-volume\", \"tripleo_ha_image_update_new_image\": \"{{cinder_volume_image_latest}}\", \"tripleo_ha_image_update_old_image\": \"{{pcmk_cinder_volume_image}}\"}, \"when\": [\"(pcmk_cinder_volume_image != \\\"\\\")\", \"(pcmk_cinder_volume_image != cinder_volume_image_latest)\"]}]}], \"update_tasks\": [{\"block\": [{\"name\": \"Get cinder_volume image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_cinder_volume_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'openstack-cinder-volume\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container cinder_volume image\", \"set_fact\": {\"cinder_volume_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"cinder_volume_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-volume:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_cinder_volume_image\": \"{{xmllint_pcmk_cinder_volume_image.stdout}}\"}}], \"when\": \"(step|int == 0 or step|int == 2)\"}, {\"name\": \"Check for update of cinder-volume container image name\", \"when\": \"step|int == 0\", \"assert\": {\"that\": \"pcmk_cinder_volume_image == cinder_volume_image_latest\", \"fail_msg\": \"cinder-volume image change detected, run overcloud external-update --tags ha_image_update first\"}}, {\"name\": \"Tear-down non-HA cinder_volume container\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Remove non-HA cinder_volume container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"cinder_volume\"]}}]}, {\"name\": \"cinder_volume fetch and retag container image for pacemaker\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Retag pcmklatest to latest cinder_volume image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{cinder_volume_image}}\", \"container_image_latest\": \"{{cinder_volume_image_latest}}\"}}]}], \"post_update_tasks\": [{\"name\": \"Cinder volume bundle post update\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Cinder volume puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"cinder_volume\", \"tripleo_ha_wrapper_resource_name\": \"openstack-cinder-volume\", \"tripleo_ha_wrapper_bundle_name\": \"openstack-cinder-volume\", \"tripleo_ha_wrapper_resource_state\": \"_ Started\", \"tripleo_ha_wrapper_puppet_config_volume\": \"cinder\", \"tripleo_ha_wrapper_puppet_execute\": \"include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::cinder::volume_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".cinder_volume_previous_run\"}}], \"vars\": {\"tripleo_ha_wrapper_minor_update\": true}}], \"upgrade_tasks\": {\"list_concat\": [[{\"name\": \"Tear-down non-HA cinder_volume container\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Remove non-HA cinder_volume container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"cinder_volume\"]}}]}, {\"name\": \"Prepare switch of cinder_volume image name\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Get cinder_volume image id currently used by pacemaker\", \"shell\": \"pcs resource config openstack-cinder-volume | grep -Eo \'image=[^ ]+\' | awk -F= \'{print $2;}\'\", \"register\": \"cinder_volume_image_current_res\", \"failed_when\": false}, {\"name\": \"cinder_volume image facts\", \"set_fact\": {\"cinder_volume_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-volume:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"cinder_volume_image_current\": \"{{cinder_volume_image_current_res.stdout}}\"}}, {\"name\": \"Temporarily tag the current cinder_volume image id with the upgraded image name\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{cinder_volume_image_current}}\", \"container_image_latest\": \"{{cinder_volume_image_latest}}\", \"pull_image\": false}, \"when\": [\"cinder_volume_image_current != \'\'\", \"cinder_volume_image_current != cinder_volume_image_latest\"]}, {\"name\": \"Create cinder_volume retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/cinder_volume_needs_retag\", \"state\": \"touch\"}, \"when\": [\"cinder_volume_image_current != \'\'\", \"cinder_volume_image_current != cinder_volume_image_latest\"]}]}, {\"name\": \"Update cinder_volume pcs resource bundle for new container image\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"set is_cinder_volume_bootstrap_node fact\", \"tags\": \"common\", \"set_fact\": \"is_cinder_volume_bootstrap_node={{cinder_volume_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower}}\"}, {\"name\": \"Check for cinder_volume retag statefile\", \"stat\": {\"path\": \"/var/lib/tripleo/cinder_volume_needs_retag\"}, \"register\": \"cinder_volume_retag_state_file\"}]}, {\"name\": \"Update cinder_volume pcs resource bundle for new container image\", \"when\": [\"step|int == 1\", \"is_cinder_volume_bootstrap_node\", \"cinder_volume_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Disable the cinder_volume cluster resource before container upgrade\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-volume\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"pcs resource bundle update cinder_volume for new container image name\", \"command\": \"pcs resource bundle update openstack-cinder-volume container image={{cinder_volume_image_latest}}\"}, {\"name\": \"Enable the cinder_volume cluster resource\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-volume\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}]}, {\"name\": \"Check for cinder_volume retag statefile\", \"when\": [\"step|int == 3\"], \"stat\": {\"path\": \"/var/lib/tripleo/cinder_volume_needs_retag\"}, \"register\": \"cinder_volume_retag_state_file\"}, {\"name\": \"Retag pacemaker cinder_volume\", \"when\": [\"step|int == 3\", \"cinder_volume_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Disable the cinder_volume cluster resource before container upgrade\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-volume\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Retag the pacemaker image if containerized\", \"block\": [{\"block\": [{\"name\": \"Get cinder_volume image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_cinder_volume_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'openstack-cinder-volume\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container cinder_volume image\", \"set_fact\": {\"cinder_volume_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"cinder_volume_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/cinder-volume:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_cinder_volume_image\": \"{{xmllint_pcmk_cinder_volume_image.stdout}}\"}}]}, {\"block\": [{\"name\": \"Retag pcmklatest to latest cinder_volume image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{cinder_volume_image}}\", \"container_image_latest\": \"{{cinder_volume_image_latest}}\"}}]}]}, {\"name\": \"Enable the cinder_volume cluster resource\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-volume\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Remove cinder_volume retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/cinder_volume_needs_retag\", \"state\": \"absent\"}}]}], {\"get_attr\": [\"CinderCommon\", \"cinder_volume_upgrade_tasks\"]}]}, \"post_upgrade_tasks\": [{\"name\": \"Start cinder_volume service (pacemaker)\", \"become\": true, \"when\": \"step|int == 1\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-volume\", \"state\": \"enable\"}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (89,'2026-06-09 08:02:05',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Cinder NVMeOF backend\\n\", \"parameters\": {\"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderNVMeOFBackendName\": {\"type\": \"string\", \"default\": \"tripleo_nvmeof\"}, \"CinderNVMeOFAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NVMeOF Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNVMeOFTargetPort\": {\"type\": \"number\", \"default\": 4420}, \"CinderNVMeOFTargetHelper\": {\"type\": \"string\", \"default\": \"nvmet\"}, \"CinderNVMeOFTargetProtocol\": {\"type\": \"string\", \"default\": \"nvmet_rdma\", \"description\": \"The target protocol, supported values are nvmet_rdma and nvmet_tcp.\\n\", \"constraints\": [{\"allowed_values\": [\"nvmet_rdma\", \"nvmet_tcp\"]}]}, \"CinderNVMeOFTargetPrefix\": {\"type\": \"string\", \"default\": \"nvme-subsystem\"}, \"CinderNVMeOFTargetPortId\": {\"type\": \"number\", \"default\": 1}, \"CinderNVMeOFTargetNameSpaceId\": {\"type\": \"number\", \"default\": 10}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"type\": \"json\", \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}}, \"outputs\": {\"cinder_nvmeof_host_prep_tasks\": {\"description\": \"Host prep tasks related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [{\"name\": \"ensure /etc/nvme exists\", \"file\": {\"path\": \"/etc/nvme\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]]}}, \"cinder_nvmeof_volumes\": {\"description\": \"Volumes related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [\"/etc/nvme:/etc/nvme:z\"]]}}, \"role_data\": {\"description\": \"Role data for the Cinder NVMeOF backend.\", \"value\": {\"service_name\": \"cinder_backend_nvmeof\", \"firewall_rules\": {\"120 LVM nvmet target\": {\"dport\": {\"get_param\": \"CinderNVMeOFTargetPort\"}}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::cinder::volume::cinder_enable_nvmeof_backend\": {\"get_param\": \"CinderEnableNVMeOFBackend\"}, \"tripleo::profile::base::cinder::volume::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_port\": {\"get_param\": \"CinderNVMeOFTargetPort\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_helper\": {\"get_param\": \"CinderNVMeOFTargetHelper\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_protocol\": {\"get_param\": \"CinderNVMeOFTargetProtocol\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_prefix\": {\"get_param\": \"CinderNVMeOFTargetPrefix\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_port_id\": {\"get_param\": \"CinderNVMeOFTargetPortId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_ns_id\": {\"get_param\": \"CinderNVMeOFTargetNameSpaceId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_ip_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}, \"cinder::backend::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNVMeOFAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nvmeof::backend_availability_zone\": {\"get_param\": \"CinderNVMeOFAvailabilityZone\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(90,'2026-06-09 08:02:05',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(91,'2026-06-09 08:02:05',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(92,'2026-06-09 08:02:05',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Cinder Volume service\\n\", \"parameters\": {\"ContainerCinderVolumeImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\"}, \"ContainerCinderConfigImage\": {\"description\": \"The container image to use for the cinder config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\"}, \"DockerCinderVolumeUlimit\": {\"default\": [\"nofile=131072\"], \"description\": \"ulimit for Cinder Volume Container\", \"type\": \"comma_delimited_list\"}, \"CinderVolumeLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.cinder.volume\", \"file\": \"/var/log/containers/cinder/cinder-volume.log\"}}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CinderVolumeCluster\": {\"default\": \"\", \"description\": \"The cluster name used for deploying the cinder-volume service in an active-active (A/A) configuration. This configuration requires the Cinder backend drivers support A/A, and the cinder-volume service not be managed by pacemaker. If these criteria are not met then the cluster name must be left blank.\\n\", \"type\": \"string\"}, \"CinderEnableNfsBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NFS backend for Cinder\", \"type\": \"boolean\"}, \"CinderEnableIscsiBackend\": {\"default\": true, \"description\": \"Whether to enable or not the Iscsi backend for Cinder\", \"type\": \"boolean\"}, \"CinderEnableRbdBackend\": {\"default\": false, \"description\": \"Whether to enable or not the Rbd backend for Cinder\", \"type\": \"boolean\"}, \"CinderISCSIAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the Iscsi Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderISCSIHelper\": {\"default\": \"lioadm\", \"description\": \"The iSCSI helper to use with cinder.\", \"type\": \"string\"}, \"CinderISCSIProtocol\": {\"default\": \"iscsi\", \"description\": \"Whether to use TCP (\'iscsi\') or iSER RDMA (\'iser\') for iSCSI\", \"type\": \"string\"}, \"CinderNfsAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NFS Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNfsMountOptions\": {\"default\": \"context=system_u:object_r:container_file_t:s0\", \"description\": \"Mount options for NFS mounts used by Cinder NFS backend. Effective when CinderEnableNfsBackend is true.\\n\", \"type\": \"string\"}, \"CinderNfsServers\": {\"default\": \"\", \"description\": \"NFS servers used by Cinder NFS backend. Effective when CinderEnableNfsBackend is true.\\n\", \"type\": \"comma_delimited_list\"}, \"CinderNfsSnapshotSupport\": {\"default\": false, \"description\": \"Whether to enable support for snapshots in the NFS driver. Effective when CinderEnableNfsBackend is true.\\n\", \"type\": \"boolean\"}, \"CinderNasSecureFileOperations\": {\"default\": false, \"description\": \"Controls whether security enhanced NFS file operations are enabled. Valid values are \'auto\', \'true\' or \'false\'. Effective when CinderEnableNfsBackend is true.\\n\", \"type\": \"string\"}, \"CinderNasSecureFilePermissions\": {\"default\": false, \"description\": \"Controls whether security enhanced NFS file permissions are enabled. Valid values are \'auto\', \'true\' or \'false\'. Effective when CinderEnableNfsBackend is true.\\n\", \"type\": \"string\"}, \"CinderRbdBackendName\": {\"type\": \"comma_delimited_list\", \"default\": \"tripleo_ceph\", \"description\": \"A list of Cinder RBD backend names.\"}, \"CinderRbdAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the RBD Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderRbdPoolName\": {\"default\": \"volumes\", \"type\": \"string\"}, \"CinderRbdExtraPools\": {\"default\": [], \"description\": \"List of extra Ceph pools for use with RBD backends for Cinder. An extra Cinder RBD backend driver is created for each pool in the list. This is in addition to the standard RBD backend driver associated with the CinderRbdPoolName.\\n\", \"type\": \"comma_delimited_list\"}, \"CinderRbdFlattenVolumeFromSnapshot\": {\"default\": false, \"description\": \"Whether RBD volumes created from a snapshot should be flattened in order to remove a dependency on the snapshot.\\n\", \"type\": \"boolean\"}, \"CinderRbdMultiConfig\": {\"type\": \"json\", \"default\": {}, \"description\": \"Dictionary of settings when configuring multiple RBD backends. The\\nhash key is the backend name, and the value is a dictionary of parameter\\nvalues unique to that backend. The following parameters are required,\\nand must match the corresponding value defined in CephExternalMultiConfig.\\n  CephClusterName (must match the CephExternalMultiConfig entry\'s \'cluster\')\\n  CephClusterFSID (must match the CephExternalMultiConfig entry\'s \'fsid\')\\nThe following parameters are optional, and override the corresponding\\nparameter\'s default value.\\n  CephClientUserName\\n  CinderRbdPoolName\\n  CinderRbdExtraPools\\n  CinderRbdAvailabilityZone\\n  CinderRbdFlattenVolumeFromSnapshot\\n\"}, \"CephClusterFSID\": {\"type\": \"string\", \"description\": \"The Ceph cluster FSID. Must be a UUID.\", \"default\": \"141c0b27-2417-411f-ad72-876254cd4eac\"}, \"MonitoringSubscriptionCinderVolume\": {\"default\": \"overcloud-cinder-volume\", \"type\": \"string\"}, \"CinderEtcdLocalConnect\": {\"default\": false, \"type\": \"boolean\", \"description\": \"When running Cinder A/A, whether to connect to Etcd via the local IP for the Etcd network. If set to true, the ip on the local node will be used. If set to false, the VIP on the Etcd network will be used instead. Defaults to false.\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"EnableEtcdInternalTLS\": {\"description\": \"Controls whether etcd and the cinder-volume service use TLS for cinder\'s lock manager, even when the rest of the internal API network is using TLS.\", \"type\": \"boolean\", \"default\": true}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}}, \"conditions\": {\"cvol_active_active_tls_enabled\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderVolumeCluster\"}, \"\"]}}, {\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"EnableEtcdInternalTLS\"}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"CinderBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"CinderCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCinderVolumeImage\": \"ContainerCinderVolumeImage\", \"ContainerCinderConfigImage\": \"ContainerCinderConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCinderVolumeImage\": {\"get_param\": \"ContainerCinderVolumeImage\"}, \"ContainerCinderConfigImage\": {\"get_param\": \"ContainerCinderConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder Volume role.\", \"value\": {\"service_name\": \"cinder_volume\", \"firewall_rules\": {\"120 iscsi initiator\": {\"dport\": 3260}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionCinderVolume\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CinderBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"CinderCommon\", \"cinder_volume_config_settings\"]}, {\"tripleo::profile::base::lvm::enable_udev\": false, \"tripleo::profile::base::cinder::volume::cinder_enable_iscsi_backend\": {\"get_param\": \"CinderEnableIscsiBackend\"}, \"tripleo::profile::base::cinder::volume::cinder_enable_nfs_backend\": {\"get_param\": \"CinderEnableNfsBackend\"}, \"tripleo::profile::base::cinder::volume::cinder_enable_rbd_backend\": {\"get_param\": \"CinderEnableRbdBackend\"}, \"tripleo::profile::base::cinder::volume::cinder_volume_cluster\": {\"get_param\": \"CinderVolumeCluster\"}, \"tripleo::profile::base::cinder::volume::nfs::cinder_nfs_mount_options\": {\"get_param\": \"CinderNfsMountOptions\"}, \"tripleo::profile::base::cinder::volume::nfs::cinder_nfs_servers\": {\"get_param\": \"CinderNfsServers\"}, \"tripleo::profile::base::cinder::volume::nfs::cinder_nfs_snapshot_support\": {\"get_param\": \"CinderNfsSnapshotSupport\"}, \"tripleo::profile::base::cinder::volume::nfs::cinder_nas_secure_file_operations\": {\"get_param\": \"CinderNasSecureFileOperations\"}, \"tripleo::profile::base::cinder::volume::nfs::cinder_nas_secure_file_permissions\": {\"get_param\": \"CinderNasSecureFilePermissions\"}, \"tripleo::profile::base::cinder::volume::iscsi::cinder_iscsi_helper\": {\"get_param\": \"CinderISCSIHelper\"}, \"tripleo::profile::base::cinder::volume::iscsi::cinder_iscsi_protocol\": {\"get_param\": \"CinderISCSIProtocol\"}, \"tripleo::profile::base::cinder::volume::rbd::backend_name\": {\"get_param\": \"CinderRbdBackendName\"}, \"tripleo::profile::base::cinder::volume::rbd::cinder_rbd_ceph_conf\": {\"list_join\": [\"\", [\"/etc/ceph/\", {\"get_param\": \"CephClusterName\"}, \".conf\"]]}, \"tripleo::profile::base::cinder::volume::rbd::cinder_rbd_pool_name\": {\"get_param\": \"CinderRbdPoolName\"}, \"tripleo::profile::base::cinder::volume::rbd::cinder_rbd_extra_pools\": {\"get_param\": \"CinderRbdExtraPools\"}, \"tripleo::profile::base::cinder::volume::rbd::cinder_rbd_secret_uuid\": {\"get_param\": \"CephClusterFSID\"}, \"tripleo::profile::base::cinder::volume::rbd::cinder_rbd_user_name\": {\"get_param\": \"CephClientUserName\"}, \"tripleo::profile::base::cinder::volume::rbd::cinder_rbd_flatten_volume_from_snapshot\": {\"get_param\": \"CinderRbdFlattenVolumeFromSnapshot\"}, \"tripleo::profile::base::cinder::volume::rbd::multi_config\": {\"get_param\": \"CinderRbdMultiConfig\"}, \"tripleo::profile::base::cinder::volume::iscsi::cinder_iscsi_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderISCSIAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::iscsi::backend_availability_zone\": {\"get_param\": \"CinderISCSIAvailabilityZone\"}}]}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNfsAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nfs::backend_availability_zone\": {\"get_param\": \"CinderNfsAvailabilityZone\"}}]}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderRbdAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::rbd::backend_availability_zone\": {\"get_param\": \"CinderRbdAvailabilityZone\"}}]}, {\"if\": [{\"get_param\": \"CinderEtcdLocalConnect\"}, {\"tripleo::profile::base::cinder::volume::etcd_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"EtcdNetwork\"]}}}}}]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_cinder_volume\": [{\"get_param\": \"CinderVolumeLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"cinder\", \"puppet_tags\": \"cinder_config,file,concat,file_line\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::lvm\", \"include tripleo::profile::base::cinder::volume\", {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/cinder_volume.json\": {\"command\": \"/usr/bin/cinder-volume --config-file /usr/share/cinder/cinder-dist.conf --config-file /etc/cinder/cinder.conf\", \"config_files\": {\"get_attr\": [\"CinderCommon\", \"cinder_common_kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"CinderCommon\", \"cinder_common_kolla_permissions\"]}}}, \"docker_config\": {\"step_3\": {\"cinder_volume_init_logs\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/cinder:/var/log/cinder:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R cinder:cinder /var/log/cinder\"]}}, \"step_4\": {\"cinder_volume\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderVolumeImage\"]}, \"ulimit\": {\"get_param\": \"DockerCinderVolumeUlimit\"}, \"ipc\": \"host\", \"net\": \"host\", \"privileged\": true, \"restart\": \"always\", \"healthcheck\": {\"get_attr\": [\"ContainersCommon\", \"healthcheck_rpc_port\"]}, \"volumes\": {\"get_attr\": [\"CinderCommon\", \"cinder_volume_volumes\"]}, \"environment\": {\"get_attr\": [\"CinderCommon\", \"cinder_volume_environment\"]}}}}, \"host_prep_tasks\": {\"get_attr\": [\"CinderCommon\", \"cinder_volume_host_prep_tasks\"]}, \"upgrade_tasks\": {\"get_attr\": [\"CinderCommon\", \"cinder_volume_upgrade_tasks\"]}, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop cinder volume container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"cinder_volume\"], \"tripleo_delegate_to\": \"{{ groups[\'cinder_volume\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(93,'2026-06-09 08:02:05',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(94,'2026-06-09 08:02:05',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Nova Compute service\\n\", \"parameters\": {\"ContainerNovaComputeImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\"}, \"ContainerNovaLibvirtConfigImage\": {\"description\": \"The container image to use for the nova_libvirt config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\"}, \"DockerNovaComputeUlimit\": {\"default\": [\"nofile=131072\", \"memlock=67108864\"], \"description\": \"ulimit for Nova Compute Container\", \"type\": \"comma_delimited_list\"}, \"NovaComputeLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.nova.compute\", \"file\": \"/var/log/containers/nova/nova-compute.log\"}}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"CinderRbdMultiConfig\": {\"type\": \"json\", \"default\": {}, \"description\": \"Dictionary of settings when configuring multiple RBD backends. The\\nhash key is the backend name, and the value is a dictionary of parameter\\nvalues unique to that backend. The following parameters are required,\\nand must match the corresponding value defined in CephExternalMultiConfig.\\n  CephClusterName (must match the CephExternalMultiConfig entry\'s \'cluster\')\\n  CephClusterFSID (must match the CephExternalMultiConfig entry\'s \'fsid\')\\nThe following parameters are optional, and override the corresponding\\nparameter\'s default value.\\n  CephClientUserName\\n  CinderRbdPoolName\\n  CinderRbdExtraPools\\n  CinderRbdAvailabilityZone\\n  CinderRbdFlattenVolumeFromSnapshot\\n\"}, \"NovaComputeOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"NovaComputeOptEnvVars\": {\"default\": {}, \"description\": \"hash of optional environment variables\", \"type\": \"json\", \"tags\": [\"role_specific\"]}, \"NovaComputeStartupDelay\": {\"default\": 0, \"description\": \"Delays the startup of nova-compute service after compute node is booted. This is to give a chance to ceph to get back healthy before booting instances after and overcloud reboot.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 0, \"max\": 600}}], \"tags\": [\"role_specific\"]}, \"EnableInstanceHA\": {\"default\": false, \"description\": \"Whether to enable an Instance Ha configurarion or not. This setup requires the Compute role to have the PacemakerRemote service added to it.\", \"type\": \"boolean\"}, \"NovaRbdPoolName\": {\"default\": \"vms\", \"type\": \"string\", \"description\": \"The pool name for RBD backend ephemeral storage.\", \"tags\": [\"role_specific\"]}, \"CephClientKey\": {\"description\": \"The Ceph client key. Can be created with ceph-authtool --gen-print-key.\", \"type\": \"string\", \"hidden\": true, \"constraints\": [{\"allowed_pattern\": \"^[a-zA-Z0-9+/]{38}==$\"}], \"default\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\"}, \"CephClusterFSID\": {\"type\": \"string\", \"description\": \"The Ceph cluster FSID. Must be a UUID.\", \"default\": \"141c0b27-2417-411f-ad72-876254cd4eac\"}, \"CinderEnableNfsBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NFS backend for Cinder\", \"type\": \"boolean\"}, \"NovaMkisofsCmd\": {\"default\": \"mkisofs\", \"description\": \"Name or path of the tool used for ISO image creation.\", \"type\": \"string\", \"tags\": [\"role_specific\"]}, \"NovaNfsEnabled\": {\"default\": false, \"description\": \"Whether to enable or not the NFS backend for Nova\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaNfsShare\": {\"default\": \"\", \"description\": \"NFS share to mount for nova storage (when NovaNfsEnabled is true)\", \"type\": \"string\", \"tags\": [\"role_specific\"]}, \"NovaNfsOptions\": {\"default\": \"context=system_u:object_r:nfs_t:s0\", \"description\": \"NFS mount options for nova storage (when NovaNfsEnabled is true)\", \"type\": \"string\", \"tags\": [\"role_specific\"]}, \"NovaNfsVersion\": {\"default\": \"4.2\", \"description\": \"NFS version used for nova storage (when NovaNfsEnabled is true). Since NFSv3 does not support full locking a NFSv4 version need to be used.\\n\", \"type\": \"string\", \"constraints\": [{\"allowed_pattern\": \"^4.?[0-9]?\"}], \"tags\": [\"role_specific\"]}, \"CinderEnableRbdBackend\": {\"default\": false, \"description\": \"Whether to enable or not the Rbd backend for Cinder\", \"type\": \"boolean\"}, \"NovaEnableRbdBackend\": {\"default\": false, \"description\": \"Whether to enable the Rbd backend for Nova ephemeral storage.\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaComputeForceRawImages\": {\"default\": true, \"description\": \"Set to \\\"True\\\" to convert non-raw cached base images to raw format.\\nSet to \\\"False\\\" if you have a system with slow I/O or low available space,\\ntrading the higher CPU requirements of compression for that of minimized input\\nbandwidth.\\nNotes::\\n- The Compute service removes any compression from the base image during\\n  compression, to avoid CPU bottlenecks. Converted images cannot have backing\\n  files, which might be a security issue.\\n- The raw image format uses more space than other image formats, for example,\\n  qcow2.\\n  Raw base images are always used with libvirt_images_type=lvm.\\n\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaComputeUseCowImages\": {\"default\": true, \"description\": \"Set to \\\"True\\\" to use CoW (Copy on Write) images in cqow2 format for libvirt\\ninstance disks. With CoW, depending on the backing store and host caching,\\nthere might be better concurrency achieved by having each instance operate\\non its own copy.\\nSet to \\\"False\\\" to use the raw format. Raw format uses more space for common\\nparts of the disk image.\\n\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaComputeLibvirtPreAllocateImages\": {\"default\": \"none\", \"description\": \"Specifies the preallocation mode for libvirt instance disks.\\nSet to one of the following valid values::\\n- none - No storage is provisioned at instance start.\\n- space - Storage is fully allocated at instance start using fallocate,\\n          which can help with both space guarantees and I/O performance.\\n\\nEven when not using CoW instance disks, the copy each instance gets is sparse\\nand so the instance might fail unexpectedly at run time with ENOSPC. By\\nrunning fallocate(1) on the instance disk images, the Compute service\\nimmediately and efficiently allocates the space for them in the file system,\\nif supported. Run time performance should also be improved because the file\\nsystem does not have to dynamically allocate blocks at run time, which reduces\\nCPU overhead and file fragmentation.\\n\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"none\", \"space\"]}], \"tags\": [\"role_specific\"]}, \"NovaComputeImageCacheManagerInterval\": {\"default\": 2400, \"description\": \"Specifies the number of seconds to wait between runs of the image cache\\nmanager, which impacts base image caching on Compute nodes. This period\\nis used in the auto removal of unused cached images configured with\\nremove_unused_base_images and remove_unused_original_minimum_age_seconds.\\n\\nSet to \\\"0\\\" to run at the default interval of 60 seconds (not recommended)\\n\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": -1}}], \"tags\": [\"role_specific\"]}, \"NovaComputeImageCacheRemoveUnusedBaseImages\": {\"default\": true, \"description\": \"Set to \\\"True\\\" to automatically remove unused base images from the cache\\nat intervals configured by using image_cache_manager_interval. Images\\nare defined as unused if they have not been accessed during the time\\nspecified by using remove_unused_original_minimum_age_seconds.\\n\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaComputeImageCacheRemoveUnusedResizedMinimumAge\": {\"default\": 3600, \"description\": \"Specifies the minimum age that an unused resized base image must be to\\nbe removed from the cache, in seconds. Unused unresized base images\\nyounger than this will not be removed.\\n\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1}}], \"tags\": [\"role_specific\"]}, \"NovaComputeImageCachePrecacheConcurrency\": {\"default\": 1, \"description\": \"Maximum number of Compute nodes to trigger image precaching in parallel.\\nWhen an image precache request is made, Compute nodes are contacted {by\\nwho/which service} to initiate the download.\\n\\nHigher numbers will cause more computes to work in parallel and may result\\nin reduced time to complete the operation, but may also DDoS the image\\nservice. Lower numbers will result in more sequential operation, lower\\nimage service load, but likely longer runtime to completion.\\n\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1}}], \"tags\": [\"role_specific\"]}, \"NovaPCIPassthrough\": {\"description\": \"List of PCI Passthrough whitelist parameters. Example - NovaPCIPassthrough:\\n  - vendor_id: \\\"8086\\\"\\n    product_id: \\\"154c\\\"\\n    address: \\\"0000:05:00.0\\\"\\n    physical_network: \\\"datacentre\\\"\\nFor different formats, refer to the nova.conf documentation for pci_passthrough_whitelist configuration\\n\", \"type\": \"json\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NovaComputeCpuSharedSet\": {\"description\": \"The behavior of this option depends on the deprecated `NovaVcpuPinSet` option:\\n\\n* `NovaVcpuPinSet` is not set: `NovaComputeCpuSharedSet` is set to a\\n  comma-separated list or range of physical host CPU numbers used to:\\n\\n  - provide vCPU inventory\\n  - determine the host CPUs that unpinned instances can be scheduled to\\n  - determine the host CPUS that instance emulator threads should be\\n    offloaded to for instances configured with the share emulator thread\\n    policy, `hw:emulator_threads_policy=share`\\n\\n* `NovaVcpuPinSet` is set: `NovaComputeCpuSharedSet` is set to a list or\\n  range of host CPU cores used to determine the host CPUs that instance\\n  emulator threads should be offloaded to for instances configured with\\n  the share emulator thread policy (`hw:emulator_threads_policy=share`).\\n  In this case, `NovaVcpuPinSet` is used to provide vCPU inventory and to\\n  determine the host CPUs that both pinned and unpinned instances can be\\n  scheduled to.\\n\\nEx. NovaComputeCpuSharedSet: [4-12,^8,15] will reserve cores from 4-12\\nand 15, excluding 8.\\n\", \"type\": \"comma_delimited_list\", \"default\": [], \"tags\": [\"role_specific\"]}, \"NovaComputeCpuDedicatedSet\": {\"description\": \"A list or range of host CPU cores to which processes for pinned instance CPUs (PCPUs) can be scheduled. Ex. NovaComputeCpuDedicatedSet: [4-12,^8,15] will reserve cores from 4-12 and 15, excluding 8.\\n\", \"type\": \"comma_delimited_list\", \"default\": [], \"tags\": [\"role_specific\"]}, \"NovaReservedHostMemory\": {\"description\": \"Reserved RAM for host processes.\\n\", \"type\": \"number\", \"default\": 512, \"constraints\": [{\"range\": {\"min\": 512}}], \"tags\": [\"role_specific\"]}, \"NovaReservedHugePages\": {\"description\": \"A list of valid key=value which reflect NUMA node ID, page size (Default unit is KiB) and number of pages to be reserved. Example - NovaReservedHugePages: [\\\"node:0,size:2048,count:64\\\",\\\"node:1,size:1GB,count:1\\\"] will reserve on NUMA node 0 64 pages of 2MiB and on NUMA node 1 1 page of 1GiB\\n\", \"type\": \"comma_delimited_list\", \"default\": [], \"tags\": [\"role_specific\"]}, \"KernelArgs\": {\"default\": \"\", \"type\": \"string\", \"description\": \"Kernel Args to apply to the host\", \"tags\": [\"role_specific\"]}, \"OvsDpdkSocketMemory\": {\"default\": \"\", \"description\": \"Sets the amount of hugepage memory to assign per NUMA node. It is recommended to use the socket closest to the PCIe slot used for the desired DPDK NIC.  The format should be in \\\"<socket 0 mem>, <socket 1 mem>, <socket n mem>\\\", where the value is specified in MB.  For example: \\\"1024,0\\\".\\n\", \"type\": \"string\", \"tags\": [\"role_specific\"]}, \"MonitoringSubscriptionNovaCompute\": {\"default\": \"overcloud-nova-compute\", \"type\": \"string\"}, \"MigrationSshKey\": {\"type\": \"json\", \"description\": \"SSH key for migration. Expects a dictionary with keys \'public_key\' and \'private_key\'. Values should be identical to SSH public/private key files.\\n\", \"default\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}}, \"MigrationSshPort\": {\"default\": 2022, \"description\": \"Target port for migration over ssh\", \"type\": \"number\"}, \"VerifyGlanceSignatures\": {\"default\": false, \"description\": \"Whether to verify image signatures.\", \"type\": \"boolean\"}, \"NovaAutoDisabling\": {\"default\": \"10\", \"description\": \"Max number of consecutive build failures before the nova-compute will disable itself.\", \"type\": \"string\"}, \"NeutronPhysnetNUMANodesMapping\": {\"description\": \"Map of physnet name as key and NUMA nodes as value.\\nEx. NeutronPhysnetNUMANodesMapping: {\'foo\': [0, 1], \'bar\': [1]} where `foo` and `bar` are\\nphysnet names and corresponding values are list of associated numa_nodes.\\n\", \"type\": \"json\", \"default\": {}, \"tags\": [\"role_specific\"]}, \"NeutronTunnelNUMANodes\": {\"description\": \"Used to configure NUMA affinity for all tunneled networks.\", \"type\": \"comma_delimited_list\", \"default\": [], \"tags\": [\"role_specific\"]}, \"NovaResumeGuestsStateOnHostBoot\": {\"default\": false, \"description\": \"Whether to start running instance on compute host reboot\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaLibvirtRxQueueSize\": {\"description\": \"virtio-net RX queue size. Valid values are 256, 512, 1024\\n\", \"default\": 512, \"type\": \"number\", \"constraints\": [{\"allowed_values\": [256, 512, 1024]}], \"tags\": [\"role_specific\"]}, \"NovaLibvirtTxQueueSize\": {\"description\": \"virtio-net TX queue size. Valid values are 256, 512, 1024\\n\", \"default\": 512, \"type\": \"number\", \"constraints\": [{\"allowed_values\": [256, 512, 1024]}], \"tags\": [\"role_specific\"]}, \"NovaLibvirtFileBackedMemory\": {\"description\": \"Available capacity in MiB for file-backed memory. When configured, the ``NovaRAMAllocationRatio`` and ``NovaReservedHostMemory`` parameters must be set to 0.\\n\", \"default\": 0, \"type\": \"number\", \"tags\": [\"role_specific\"]}, \"NovaLibvirtVolumeUseMultipath\": {\"default\": false, \"description\": \"Whether to enable or not the multipath connection of the volumes.\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaHWMachineType\": {\"description\": \"To specify a default machine type per host architecture.\\n\", \"default\": \"x86_64=pc-q35-rhel9.0.0\", \"type\": \"string\", \"tags\": [\"role_specific\"]}, \"DeployIdentifier\": {\"default\": 1780992067, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"NovaComputeEnableKsm\": {\"default\": false, \"description\": \"Whether to enable KSM on compute nodes or not. Especially in NFV use case one wants to keep it disabled.\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"AdminPassword\": {\"description\": \"The password for the keystone admin account, used for monitoring, querying neutron etc.\", \"type\": \"string\", \"hidden\": true, \"default\": \"uvYUJnZlpg4RipBsqnjPENIXa\"}, \"CinderPassword\": {\"description\": \"The password for the cinder service and db account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"NovaLibvirtNumPciePorts\": {\"description\": \"Set `num_pcie_ports` to specify the number of PCIe ports an instance will get. Libvirt allows a custom number of PCIe ports (pcie-root-port controllers) a target instance will get. Some will be used by default, rest will be available for hotplug use.\\n\", \"default\": 16, \"type\": \"number\", \"tags\": [\"role_specific\"]}, \"NovaLibvirtMemStatsPeriodSeconds\": {\"description\": \"A number of seconds to memory usage statistics period, zero or negative value mean to disable memory usage statistics.\\n\", \"default\": 10, \"type\": \"number\", \"tags\": [\"role_specific\"]}, \"NovaLiveMigrationWaitForVIFPlug\": {\"description\": \"Whether to wait for `network-vif-plugged` events before starting guest transfer.\", \"default\": true, \"type\": \"boolean\"}, \"NovaLiveMigrationPermitPostCopy\": {\"description\": \"If \\\"True\\\" activates the instance on the destination node before migration is complete, and to set an upper bound on the memory that needs to be transferred. Post copy gets enabled per default if the compute roles is not a realtime role or disabled by this parameter.\\n\", \"default\": true, \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaLiveMigrationPermitAutoConverge\": {\"description\": \"Defaults to \\\"True\\\" to slow down the instance CPU until the memory copy process is faster than the instance\'s memory writes when the migration performance is slow and might not complete. Auto converge will only be used if this flag is set to True and post copy is not permitted or post copy is unavailable due to the version of libvirt and QEMU.\\n\", \"default\": true, \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"MultipathdEnable\": {\"default\": false, \"description\": \"Whether to enable the multipath daemon\", \"type\": \"boolean\"}, \"NovaCPUAllocationRatio\": {\"type\": \"number\", \"description\": \"Virtual CPU to physical CPU allocation ratio.\", \"default\": 0.0, \"tags\": [\"role_specific\"]}, \"NovaRAMAllocationRatio\": {\"type\": \"number\", \"description\": \"Virtual RAM to physical RAM allocation ratio.\", \"default\": 1.0, \"tags\": [\"role_specific\"]}, \"NovaDiskAllocationRatio\": {\"type\": \"number\", \"description\": \"Virtual disk to physical disk allocation ratio.\", \"default\": 0.0, \"tags\": [\"role_specific\"]}, \"NovaEnableVTPM\": {\"type\": \"boolean\", \"description\": \"Whether to enable support for enumlated Trusted Platform Module (TPM) devices.\\n\", \"default\": false, \"tags\": [\"role_specific\"]}, \"NovaMaxDiskDevicesToAttach\": {\"type\": \"number\", \"description\": \"Maximum number of disk devices allowed to attach to a single server. Note that the number of disks supported by an server depends on the bus used. For example, the ide disk bus is limited to 4 attached devices. The configured maximum is enforced during server create, rebuild, evacuate, unshelve, live migrate, and attach volume. Operators changing this parameter on a compute service that is hosting servers should be aware that it could cause rebuilds to fail, if the maximum is decreased lower than the number of devices already attached to servers. Operators should also be aware that during a cold migration, the configured maximum is only enforced in-place and the destination is not checked before the move. -1 means unlimited\\n\", \"default\": -1, \"tags\": [\"role_specific\"]}, \"NovaPMEMMappings\": {\"type\": \"string\", \"description\": \"PMEM namespace mappings as backend for vPMEM feature. This parameter sets Nova\'s `pmem_namespaces` configuration options. PMEM namespaces needs to be create manually or with conjunction with `NovaPMEMNamespaces` parameter. Requires format: $LABEL:$NSNAME[|$NSNAME][,$LABEL:$NSNAME[|$NSNAME]].\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NovaPMEMNamespaces\": {\"type\": \"string\", \"description\": \"Creates PMEM namespaces on the host server using `ndctl` tool through Ansible. Requires format: $SIZE:$NSNAME[,$SIZE:$NSNAME...]. $SIZE supports the suffixes \\\"k\\\" or \\\"K\\\" for KiB, \\\"m\\\" or \\\"M\\\" for MiB, \\\"g\\\" or \\\"G\\\" for GiB and \\\"t\\\" or \\\"T\\\" for TiB. NOTE: This requires properly configured NVDIMM regions and enough space for requested namespaces.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NovaImageCacheTTL\": {\"type\": \"number\", \"description\": \"Time in seconds that nova compute should continue caching an image once it is no longer used by any instances on the host\\n\", \"default\": 86400, \"tags\": [\"role_specific\"]}, \"NovaVGPUTypesDeviceAddressesMapping\": {\"type\": \"json\", \"description\": \"Map of vgpu type(s) the instances can get as key and list of corresponding device addresses as value. Ex. NovaVGPUTypesDeviceAddressesMapping: {\'nvidia-35\': [\'0000:84:00.0\', \'0000:85:00.0\'],\\n                                  \'nvidia-36\': [\'0000:86:00.0\']}\\nwhere `nvidia-35` and `nvidia-36` are vgpu types and corresponding values are list of associated device addresses.\\n\", \"default\": {}, \"tags\": [\"role_specific\"]}, \"NovaComputeDisableIrqBalance\": {\"default\": false, \"description\": \"Whether to disable irqbalance on compute nodes or not. Especially in Realtime Compute role one wants to keep it disabled.\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaLibvirtCPUMode\": {\"type\": \"string\", \"description\": \"The libvirt CPU mode to configure. Defaults to \'host-model\' if virt_type is set to kvm, otherwise defaults to \'none\'\\n\", \"default\": \"host-model\", \"constraints\": [{\"allowed_values\": [\"custom\", \"host-model\", \"none\", \"host-passthrough\"]}], \"tags\": [\"role_specific\"]}, \"NovaLibvirtCPUModels\": {\"type\": \"comma_delimited_list\", \"description\": \"The named libvirt CPU model (see names listed in /usr/share/libvirt/cpu_map.xml). Only has effect if cpu_mode=\\\"custom\\\" and virt_type=\\\"kvm|qemu\\\"\\n\", \"default\": [], \"tags\": [\"role_specific\"]}, \"NovaLibvirtCPUModelExtraFlags\": {\"type\": \"string\", \"description\": \"This allows specifying granular CPU feature flags when specifying CPU models. Only has effect if cpu_mode is not set to \'none\'.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NovaDisableImageDownloadToRbd\": {\"type\": \"boolean\", \"description\": \"Refuse to boot an instance if it would require downloading from glance and uploading to ceph instead of a COW clone.\\n\", \"default\": false, \"tags\": [\"role_specific\"]}, \"NovaDisableComputeServiceCheckForFfu\": {\"type\": \"boolean\", \"description\": \"Facilitate a Fast-Forward upgrade where new control services are being started before compute nodes have been able to update their service record.\\n\", \"default\": false}, \"NovaStatedirOwnershipSkip\": {\"type\": \"comma_delimited_list\", \"description\": \"List of paths relative to nova_statedir to ignore when recursively setting the ownership and selinux context.\\n\", \"default\": [\"triliovault-mounts\"]}, \"NovaImageTypeExcludeList\": {\"type\": \"comma_delimited_list\", \"description\": \"List of image formats that should not be advertised as supported by the compute service.\\n\", \"default\": [], \"tags\": [\"role_specific\"]}, \"NovaLibvirtMaxQueues\": {\"type\": \"number\", \"description\": \"Add parameter to configure the libvirt max_queues. The maximum number of virtio queue pairs that can be enabled when creating a multiqueue guest. The number of virtio queues allocated will be the lesser of the CPUs requested by the guest and the max value defined. Default 0 corresponds to not set\\n\", \"default\": 0, \"tags\": [\"role_specific\"]}, \"GlanceRbdPoolName\": {\"default\": \"images\", \"type\": \"string\"}, \"GlanceMultistoreConfig\": {\"type\": \"json\", \"default\": {}, \"description\": \"Dictionary of settings when configuring additional glance backends. The\\nhash key is the backend ID, and the value is a dictionary of parameter\\nvalues unique to that backend. Multiple rbd and cinder backends are allowed, but\\nfile and swift backends are limited to one each. Example:\\n  # Default glance store is rbd.\\n  GlanceBackend: rbd\\n  GlanceStoreDescription: \'Default rbd store\'\\n  # GlanceMultistoreConfig specifies a second rbd backend, plus a cinder\\n  # backend.\\n  GlanceMultistoreConfig:\\n    rbd2_store:\\n      GlanceBackend: rbd\\n      GlanceStoreDescription: \'Second rbd store\'\\n      CephClusterName: ceph2\\n      # Override CephClientUserName if this cluster uses a different\\n      # client name.\\n      CephClientUserName: client2\\n    cinder1_store:\\n      GlanceBackend: cinder\\n      GlanceCinderVolumeType: \'volume-type-1\'\\n      GlanceStoreDescription: \'First cinder store\'\\n    cinder2_store:\\n      GlanceBackend: cinder\\n      GlanceCinderVolumeType: \'volume-type-2\'\\n      GlanceStoreDescription: \'Seconde cinder store\'\\n\"}, \"NovaGlanceEnableRbdDownload\": {\"type\": \"boolean\", \"description\": \"Enable download of Glance images directly via RBD.\\n\", \"default\": false, \"tags\": [\"role_specific\"]}, \"NovaGlanceRbdDownloadMultistoreID\": {\"type\": \"string\", \"description\": \"The hash key, which is the backend ID, of the GlanceMultistoreConfig to be used for the role where NovaGlanceEnableRbdDownload is enabled and defaults should be overridden. If CephClientUserName or GlanceRbdPoolName are not set in the GlanceMultistoreConfig, the global values of those parameters will be used.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"GlanceBackendID\": {\"type\": \"string\", \"default\": \"default_backend\", \"description\": \"The default backend\'s identifier.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9_-]+\"}]}, \"NovaGlanceRbdCopyPollInterval\": {\"type\": \"number\", \"description\": \"The interval in seconds with which to poll Glance after asking for it to copy an image to the local rbd store.\\n\", \"default\": 15, \"tags\": [\"role_specific\"]}, \"NovaGlanceRbdCopyTimeout\": {\"type\": \"number\", \"description\": \"The overall maximum time we will wait for Glance to complete an image copy to our local rbd store.\\n\", \"default\": 600, \"tags\": [\"role_specific\"]}, \"CustomProviderInventories\": {\"description\": \"Array of hashes describing the custom providers for the compute role.\\nFormat:\\nname/uuid - Resource providers to target can be identified by either\\nUUID or name. In addition, the value $COMPUTE_NODE can be used in\\nthe UUID field to identify all nodes managed by the service.\\nExactly one of uuid or name is mandatory. If neither uuid or name\\nis provided, the special uuid $COMPUTE_NODE gets set in the template.\\n\\ninventories - (Optional) Hash of custom provider inventories. \'total\' is\\na mandatory property. Any other optional properties not populated will\\nbe given a default value by placement. If overriding a pre-existing\\nprovider values will not be preserved from the existing inventory.\\n\\ntraits - (Optional) Array of additional traits.\\nExample:\\nComputeParameters:\\n  CustomProviderInventories:\\n    - uuid: $COMPUTE_NODE\\n      inventories:\\n        CUSTOM_EXAMPLE_RESOURCE_CLASS:\\n          total: 100\\n          reserved: 0\\n          min_unit: 1\\n          max_unit: 10\\n          step_size: 1\\n          allocation_ratio: 1.0\\n        CUSTOM_ANOTHER_EXAMPLE_RESOURCE_CLASS:\\n          total: 100\\n      traits:\\n        - CUSTOM_P_STATE_ENABLED\\n        - CUSTOM_C_STATE_ENABLED\\n\", \"type\": \"json\", \"default\": {}, \"tags\": [\"role_specific\"]}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"UseTLSTransportForLiveMigration\": {\"type\": \"boolean\", \"default\": true, \"description\": \"If set to true and if EnableInternalTLS is enabled, it will set the libvirt URI\'s transport to tls and configure the relevant keys for libvirt.\"}, \"NovaVcpuPinSet\": {\"description\": \"A list or range of host CPU cores to which processes for unpinned instance CPUs (VCPUs) can be scheduled, if NovaCpuSharedSet is set, or to which both emulator threads and processes for unpinned instance CPUs (VCPUs) can be scheduled, if NovaCpuSharedSet is unset. Ex. NovaVcpuPinSet: [\'4-12\',\'^8\'] will reserve cores from 4-12 excluding 8\\n\", \"type\": \"comma_delimited_list\", \"default\": [], \"tags\": [\"role_specific\"]}, \"RootStackName\": {\"description\": \"The name of the stack/plan.\", \"type\": \"string\", \"default\": \"overcloud\"}, \"RbdDiskCachemodes\": {\"type\": \"comma_delimited_list\", \"default\": [\"network=writeback\"], \"description\": \"Disk cachemodes for RBD backend.\\n\"}, \"AuthCloudName\": {\"description\": \"Entry in clouds.yaml to use for authentication\", \"type\": \"string\", \"default\": \"\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenstack mailing list.\\n\", \"parameters\": [\"NovaVcpuPinSet\"]}], \"conditions\": {\"auth_cloud_name_set\": {\"not\": {\"equals\": [{\"get_param\": \"AuthCloudName\"}, \"\"]}}, \"compute_startup_delay\": {\"and\": [{\"not\": {\"get_param\": \"EnableInstanceHA\"}}, {\"not\": {\"and\": [{\"equals\": [{\"get_param\": \"NovaComputeStartupDelay\"}, 0]}, {\"or\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaComputeStartupDelay\"]}, 0]}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaComputeStartupDelay\"]}, \"\"]}]}]}}]}, \"use_tls_for_live_migration\": {\"and\": [{\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"UseTLSTransportForLiveMigration\"}]}, \"enable_live_migration_tunnelled\": {\"and\": [{\"or\": [{\"and\": [{\"get_param\": \"NovaNfsEnabled\"}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaNfsEnabled\"]}, \"\"]}]}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaNfsEnabled\"]}, true]}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaEnableRbdBackend\"]}, true]}, {\"and\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaEnableRbdBackend\"]}, \"\"]}, {\"get_param\": \"NovaEnableRbdBackend\"}]}]}, {\"not\": \"use_tls_for_live_migration\"}]}, \"libvirt_file_backed_memory_enabled\": {\"not\": {\"and\": [{\"equals\": [{\"get_param\": \"NovaLibvirtFileBackedMemory\"}, 0]}, {\"or\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaLibvirtFileBackedMemory\"]}, 0]}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaLibvirtFileBackedMemory\"]}, \"\"]}]}]}}, \"reserved_huge_pages_set\": {\"not\": {\"and\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaReservedHugePages\"]}, \"\"]}, {\"equals\": [{\"get_param\": \"NovaReservedHugePages\"}, []]}]}}, \"is_realtime\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"TunedProfileName\"]}, \"realtime-virtual-host\"]}, \"ovs_dpdk_socket_memory_not_set\": {\"and\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"OvsDpdkSocketMemory\"]}, \"\"]}, {\"equals\": [{\"get_param\": \"OvsDpdkSocketMemory\"}, \"\"]}]}, \"nova_libvirt_max_queues_set\": {\"not\": {\"and\": [{\"equals\": [{\"get_param\": \"NovaLibvirtMaxQueues\"}, 0]}, {\"or\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaLibvirtMaxQueues\"]}, \"\"]}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaLibvirtMaxQueues\"]}, 0]}]}]}}, \"glance_enable_rbd_download_set\": {\"or\": [{\"and\": [{\"get_param\": \"NovaGlanceEnableRbdDownload\"}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaGlanceEnableRbdDownload\"]}, \"\"]}]}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaGlanceEnableRbdDownload\"]}, true]}]}, \"nova_glance_rbd_download_multistore_id_set\": {\"not\": {\"and\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaGlanceRbdDownloadMultistoreID\"]}, \"\"]}, {\"equals\": [{\"get_param\": \"NovaGlanceRbdDownloadMultistoreID\"}, \"\"]}]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CinderNVMeOF\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\"}, \"NovaComputeCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-common-container-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"NovaLogging\": {\"type\": \"OS::TripleO::Services::Logging::NovaCommon\", \"properties\": {\"ContainerNovaImage\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaComputeImage\"]}, \"NovaServiceName\": \"compute\"}}, \"NovaBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"nova::compute::vcpu_pin_set\": \"NovaVcpuPinSet\", \"nova::compute::cpu_shared_set\": \"NovaComputeCpuSharedSet\", \"nova::compute::cpu_dedicated_set\": \"NovaComputeCpuDedicatedSet\", \"nova::compute::reserved_host_memory\": \"NovaReservedHostMemory\", \"nova::compute::reserved_huge_pages\": \"NovaReservedHugePages\", \"nova::compute::neutron_physnets_numa_nodes_mapping\": \"NeutronPhysnetNUMANodesMapping\", \"nova::compute::neutron_tunnel_numa_nodes\": \"NeutronTunnelNUMANodes\", \"nova::compute::resume_guests_state_on_host_boot\": \"NovaResumeGuestsStateOnHostBoot\", \"nova::compute::libvirt::rx_queue_size\": \"NovaLibvirtRxQueueSize\", \"nova::compute::libvirt::tx_queue_size\": \"NovaLibvirtTxQueueSize\", \"nova::compute::libvirt::file_backed_memory\": \"NovaLibvirtFileBackedMemory\", \"nova::compute::libvirt::volume_use_multipath\": \"NovaLibvirtVolumeUseMultipath\", \"nova::compute::libvirt::hw_machine_type\": \"NovaHWMachineType\", \"nova::compute::mkisofs_cmd\": \"NovaMkisofsCmd\", \"compute_enable_ksm\": \"NovaComputeEnableKsm\", \"nova::compute::rbd::libvirt_images_rbd_pool\": \"NovaRbdPoolName\", \"tripleo::profile::base::nova::compute::nova_nfs_enabled\": \"NovaNfsEnabled\", \"nfs_backend_enable\": \"NovaNfsEnabled\", \"nfs_share\": \"NovaNfsShare\", \"nfs_options\": \"NovaNfsOptions\", \"nfs_vers\": \"NovaNfsVersion\", \"nova::compute::libvirt::num_pcie_ports\": \"NovaLibvirtNumPciePorts\", \"nova::compute::libvirt::mem_stats_period_seconds\": \"NovaLibvirtMemStatsPeriodSeconds\", \"nova::compute::rbd::ephemeral_storage\": \"NovaEnableRbdBackend\", \"resume_guests_state_on_host_boot\": \"NovaResumeGuestsStateOnHostBoot\", \"nova::cpu_allocation_ratio\": \"NovaCPUAllocationRatio\", \"nova::ram_allocation_ratio\": \"NovaRAMAllocationRatio\", \"nova::disk_allocation_ratio\": \"NovaDiskAllocationRatio\", \"nova::compute::max_disk_devices_to_attach\": \"NovaMaxDiskDevicesToAttach\", \"nova::compute::libvirt::pmem_namespaces\": \"NovaPMEMMappings\", \"nova_pmem_namespaces\": \"NovaPMEMNamespaces\", \"nova::compute::image_cache::remove_unused_original_minimum_age_seconds\": \"NovaImageCacheTTL\", \"nova::compute::libvirt::swtpm_enabled\": \"NovaEnableVTPM\", \"nova::compute::vgpu::vgpu_types_device_addresses_mapping\": \"NovaVGPUTypesDeviceAddressesMapping\", \"compute_disable_irqbalance\": \"NovaComputeDisableIrqBalance\", \"nova::compute::libvirt::cpu_mode\": \"NovaLibvirtCPUMode\", \"nova::compute::libvirt::cpu_models\": \"NovaLibvirtCPUModels\", \"nova::compute::libvirt::cpu_model_extra_flags\": \"NovaLibvirtCPUModelExtraFlags\", \"nova_compute_opt_volumes\": \"NovaComputeOptVolumes\", \"nova_compute_startup_delay\": \"NovaComputeStartupDelay\", \"nova_compute_opt_env_vars\": \"NovaComputeOptEnvVars\", \"nova::workarounds::never_download_image_if_on_rbd\": \"NovaDisableImageDownloadToRbd\", \"nova::compute::image_type_exclude_list\": \"NovaImageTypeExcludeList\", \"nova_permit_post_copy\": \"NovaLiveMigrationPermitPostCopy\", \"nova_permit_auto_converge\": \"NovaLiveMigrationPermitAutoConverge\", \"nova_libvirt_max_queues\": \"NovaLibvirtMaxQueues\", \"nova_glance_enable_rbd_download\": \"NovaGlanceEnableRbdDownload\", \"nova_glance_rbd_download_multistore_id\": \"NovaGlanceRbdDownloadMultistoreID\", \"nova::compute::force_raw_images\": \"NovaComputeForceRawImages\", \"nova::compute::use_cow_images\": \"NovaComputeUseCowImages\", \"nova::compute::libvirt::preallocate_images\": \"NovaComputeLibvirtPreAllocateImages\", \"nova::compute::image_cache::manager_interval\": \"NovaComputeImageCacheManagerInterval\", \"nova::compute::image_cache::remove_unused_base_images\": \"NovaComputeImageCacheRemoveUnusedBaseImages\", \"nova::compute::image_cache::remove_unused_resized_minimum_age_seconds\": \"NovaComputeImageCacheRemoveUnusedResizedMinimumAge\", \"nova::compute::image_cache::precache_concurrency\": \"NovaComputeImageCachePrecacheConcurrency\", \"nova::compute::provider::custom_inventories\": \"CustomProviderInventories\", \"nova::compute::rbd::libvirt_images_rbd_glance_copy_poll_interval\": \"NovaGlanceRbdCopyPollInterval\", \"nova::compute::rbd::libvirt_images_rbd_glance_copy_timeout\": \"NovaGlanceRbdCopyTimeout\", \"ContainerNovaComputeImage\": \"ContainerNovaComputeImage\", \"ContainerNovaLibvirtConfigImage\": \"ContainerNovaLibvirtConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"NovaVcpuPinSet\": {\"get_param\": \"NovaVcpuPinSet\"}, \"NovaComputeCpuSharedSet\": {\"get_param\": \"NovaComputeCpuSharedSet\"}, \"NovaComputeCpuDedicatedSet\": {\"get_param\": \"NovaComputeCpuDedicatedSet\"}, \"NovaReservedHostMemory\": {\"get_param\": \"NovaReservedHostMemory\"}, \"NovaReservedHugePages\": {\"if\": [\"reserved_huge_pages_set\", {\"get_param\": \"NovaReservedHugePages\"}, {\"if\": [\"ovs_dpdk_socket_memory_not_set\", {\"get_param\": \"NovaReservedHugePages\"}, {\"repeat\": {\"for_each\": {\"<%node%>\": {\"yaql\": {\"expression\": \"range(0,len($.data.dpdk_p)).join(\\\",\\\").split(\\\",\\\")\", \"data\": {\"dpdk_p\": {\"if\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"OvsDpdkSocketMemory\"]}, \"\"]}, {\"str_split\": [\",\", {\"get_param\": \"OvsDpdkSocketMemory\"}]}, {\"str_split\": [\",\", {\"get_param\": [\"RoleParameters\", \"OvsDpdkSocketMemory\"]}]}]}}}}, \"<%size%>\": {\"yaql\": {\"expression\": \"let(hzx => regex(\\\"([0-9]+[K|M|G])\\\").search($.data.kern_p+$.data.kern_g)) -> let(hz =>switch($hzx = \\\"4K\\\" => \\\"4\\\", $hzx = \\\"2M\\\" => \\\"2048\\\", $hzx = \\\"1G\\\" => \\\"1048576\\\", $hzx  => \\\"2048\\\", $hzx = null => \\\"2048\\\")) -> [$hz]*len($.data.dpdk_p)\", \"data\": {\"dpdk_p\": {\"if\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"OvsDpdkSocketMemory\"]}, \"\"]}, {\"str_split\": [\",\", {\"get_param\": \"OvsDpdkSocketMemory\"}]}, {\"str_split\": [\",\", {\"get_param\": [\"RoleParameters\", \"OvsDpdkSocketMemory\"]}]}]}, \"kern_p\": {\"get_param\": [\"RoleParameters\", \"KernelArgs\"]}, \"kern_g\": {\"get_param\": \"KernelArgs\"}}}}, \"<%count%>\": {\"yaql\": {\"expression\": \"let(hzx => regex(\\\"([0-9]+[K|M|G])\\\").search($.data.kern_p+$.data.kern_g)) -> let(hz =>int(switch($hzx = \\\"4K\\\" => \\\"4\\\", $hzx = \\\"2M\\\" => \\\"2048\\\", $hzx = \\\"1G\\\" => \\\"1048576\\\", $hzx  => \\\"2048\\\", $hzx = null => \\\"2048\\\"))) -> $.data.dpdk_p.select(int($)*1024/$hz).join(\\\",\\\").split(\',\')\", \"data\": {\"dpdk_p\": {\"if\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"OvsDpdkSocketMemory\"]}, \"\"]}, {\"str_split\": [\",\", {\"get_param\": \"OvsDpdkSocketMemory\"}]}, {\"str_split\": [\",\", {\"get_param\": [\"RoleParameters\", \"OvsDpdkSocketMemory\"]}]}]}, \"kern_p\": {\"get_param\": [\"RoleParameters\", \"KernelArgs\"]}, \"kern_g\": {\"get_param\": \"KernelArgs\"}}}}}, \"template\": \"node:<%node%>,size:<%size%>,count:<%count%>\", \"permutations\": false}}]}]}, \"NeutronPhysnetNUMANodesMapping\": {\"get_param\": \"NeutronPhysnetNUMANodesMapping\"}, \"NeutronTunnelNUMANodes\": {\"get_param\": \"NeutronTunnelNUMANodes\"}, \"NovaResumeGuestsStateOnHostBoot\": {\"get_param\": \"NovaResumeGuestsStateOnHostBoot\"}, \"NovaLibvirtRxQueueSize\": {\"get_param\": \"NovaLibvirtRxQueueSize\"}, \"NovaLibvirtTxQueueSize\": {\"get_param\": \"NovaLibvirtTxQueueSize\"}, \"NovaLibvirtFileBackedMemory\": {\"get_param\": \"NovaLibvirtFileBackedMemory\"}, \"NovaLibvirtVolumeUseMultipath\": {\"get_param\": \"NovaLibvirtVolumeUseMultipath\"}, \"NovaHWMachineType\": {\"get_param\": \"NovaHWMachineType\"}, \"NovaComputeEnableKsm\": {\"get_param\": \"NovaComputeEnableKsm\"}, \"NovaRbdPoolName\": {\"get_param\": \"NovaRbdPoolName\"}, \"NovaMkisofsCmd\": {\"get_param\": \"NovaMkisofsCmd\"}, \"NovaNfsEnabled\": {\"get_param\": \"NovaNfsEnabled\"}, \"NovaNfsShare\": {\"get_param\": \"NovaNfsShare\"}, \"NovaNfsOptions\": {\"get_param\": \"NovaNfsOptions\"}, \"NovaNfsVersion\": {\"get_param\": \"NovaNfsVersion\"}, \"NovaLibvirtNumPciePorts\": {\"get_param\": \"NovaLibvirtNumPciePorts\"}, \"NovaLibvirtMemStatsPeriodSeconds\": {\"get_param\": \"NovaLibvirtMemStatsPeriodSeconds\"}, \"NovaEnableRbdBackend\": {\"get_param\": \"NovaEnableRbdBackend\"}, \"NovaCPUAllocationRatio\": {\"get_param\": \"NovaCPUAllocationRatio\"}, \"NovaRAMAllocationRatio\": {\"get_param\": \"NovaRAMAllocationRatio\"}, \"NovaDiskAllocationRatio\": {\"get_param\": \"NovaDiskAllocationRatio\"}, \"NovaEnableVTPM\": {\"get_param\": \"NovaEnableVTPM\"}, \"NovaMaxDiskDevicesToAttach\": {\"get_param\": \"NovaMaxDiskDevicesToAttach\"}, \"NovaPMEMMappings\": {\"get_param\": \"NovaPMEMMappings\"}, \"NovaPMEMNamespaces\": {\"get_param\": \"NovaPMEMNamespaces\"}, \"NovaImageCacheTTL\": {\"get_param\": \"NovaImageCacheTTL\"}, \"NovaVGPUTypesDeviceAddressesMapping\": {\"get_param\": \"NovaVGPUTypesDeviceAddressesMapping\"}, \"NovaComputeDisableIrqBalance\": {\"get_param\": \"NovaComputeDisableIrqBalance\"}, \"NovaLibvirtCPUMode\": {\"get_param\": \"NovaLibvirtCPUMode\"}, \"NovaLibvirtCPUModels\": {\"get_param\": \"NovaLibvirtCPUModels\"}, \"NovaLibvirtCPUModelExtraFlags\": {\"get_param\": \"NovaLibvirtCPUModelExtraFlags\"}, \"NovaComputeOptVolumes\": {\"get_param\": \"NovaComputeOptVolumes\"}, \"NovaComputeStartupDelay\": {\"get_param\": \"NovaComputeStartupDelay\"}, \"NovaComputeOptEnvVars\": {\"get_param\": \"NovaComputeOptEnvVars\"}, \"NovaDisableImageDownloadToRbd\": {\"get_param\": \"NovaDisableImageDownloadToRbd\"}, \"NovaImageTypeExcludeList\": {\"get_param\": \"NovaImageTypeExcludeList\"}, \"NovaLiveMigrationPermitPostCopy\": {\"get_param\": \"NovaLiveMigrationPermitPostCopy\"}, \"NovaLiveMigrationPermitAutoConverge\": {\"get_param\": \"NovaLiveMigrationPermitAutoConverge\"}, \"NovaLibvirtMaxQueues\": {\"get_param\": \"NovaLibvirtMaxQueues\"}, \"NovaGlanceEnableRbdDownload\": {\"get_param\": \"NovaGlanceEnableRbdDownload\"}, \"NovaGlanceRbdDownloadMultistoreID\": {\"get_param\": \"NovaGlanceRbdDownloadMultistoreID\"}, \"NovaComputeForceRawImages\": {\"get_param\": \"NovaComputeForceRawImages\"}, \"NovaComputeUseCowImages\": {\"get_param\": \"NovaComputeUseCowImages\"}, \"NovaComputeLibvirtPreAllocateImages\": {\"get_param\": \"NovaComputeLibvirtPreAllocateImages\"}, \"NovaComputeImageCacheManagerInterval\": {\"get_param\": \"NovaComputeImageCacheManagerInterval\"}, \"NovaComputeImageCacheRemoveUnusedBaseImages\": {\"get_param\": \"NovaComputeImageCacheRemoveUnusedBaseImages\"}, \"NovaComputeImageCacheRemoveUnusedResizedMinimumAge\": {\"get_param\": \"NovaComputeImageCacheRemoveUnusedResizedMinimumAge\"}, \"NovaComputeImageCachePrecacheConcurrency\": {\"get_param\": \"NovaComputeImageCachePrecacheConcurrency\"}, \"CustomProviderInventories\": {\"get_param\": \"CustomProviderInventories\"}, \"NovaGlanceRbdCopyPollInterval\": {\"get_param\": \"NovaGlanceRbdCopyPollInterval\"}, \"NovaGlanceRbdCopyTimeout\": {\"get_param\": \"NovaGlanceRbdCopyTimeout\"}, \"ContainerNovaComputeImage\": {\"get_param\": \"ContainerNovaComputeImage\"}, \"ContainerNovaLibvirtConfigImage\": {\"get_param\": \"ContainerNovaLibvirtConfigImage\"}}}]}}}}, \"outputs\": {\"nova_compute_host_prep_and_system_upgrade_post_tasks\": {\"description\": \"Common host_prep and system_upgrade post tasks for nova_compute\", \"value\": [{\"name\": \"Mount Nova NFS Share\", \"vars\": {\"nfs_backend_enable\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_backend_enable\"]}, \"nfs_share\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_share\"]}, \"nfs_options\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_options\"]}, \"nfs_vers\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_vers\"]}}, \"mount\": {\"name\": \"/var/lib/nova/instances\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{nfs_share}}\", \"opts\": \"_netdev,bg,{{nfs_options}},nfsvers={{nfs_vers}}\"}, \"when\": \"nfs_backend_enable|bool\"}]}, \"role_data\": {\"description\": \"Role data for the Nova Compute service.\", \"value\": {\"service_name\": \"nova_compute\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionNovaCompute\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"NovaLogging\", \"config_settings\"]}, {\"get_attr\": [\"NovaBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"RoleParametersValue\", \"value\"]}, {\"nova::compute::libvirt::manage_libvirt_services\": false, \"nova::compute::pci::passthrough\": {\"str_replace\": {\"template\": \"JSON_PARAM\", \"params\": {\"map_replace\": [{\"map_replace\": [{\"JSON_PARAM\": \"NovaPCIPassthrough\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"NovaPCIPassthrough\": {\"get_param\": \"NovaPCIPassthrough\"}}}]}}}, \"nova::compute::libvirt::migration_support\": false, \"tripleo::profile::base::nova::migration::client::nova_compute_enabled\": true, \"tripleo::profile::base::nova::migration::client::ssh_private_key\": {\"get_param\": [\"MigrationSshKey\", \"private_key\"]}, \"tripleo::profile::base::nova::migration::client::ssh_port\": {\"get_param\": \"MigrationSshPort\"}, \"nova::compute::rbd::libvirt_images_rbd_glance_store_name\": {\"get_param\": \"GlanceBackendID\"}, \"nova::compute::rbd::libvirt_images_rbd_ceph_conf\": {\"list_join\": [\"\", [\"/etc/ceph/\", {\"get_param\": \"CephClusterName\"}, \".conf\"]]}, \"nova::compute::rbd::libvirt_rbd_user\": {\"get_param\": \"CephClientUserName\"}, \"nova::compute::rbd::rbd_keyring\": {\"list_join\": [\".\", [\"client\", {\"get_param\": \"CephClientUserName\"}]]}, \"tripleo::profile::base::nova::compute::cinder_nfs_backend\": {\"get_param\": \"CinderEnableNfsBackend\"}, \"rbd_persistent_storage\": {\"get_param\": \"CinderEnableRbdBackend\"}, \"rbd_disk_cachemodes\": {\"get_param\": \"RbdDiskCachemodes\"}, \"nova::cinder::username\": \"cinder\", \"nova::cinder::auth_type\": \"v3password\", \"nova::cinder::project_name\": \"service\", \"nova::cinder::password\": {\"get_param\": \"CinderPassword\"}, \"nova::cinder::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"nova::cinder::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::compute::rbd::libvirt_rbd_secret_key\": {\"get_param\": \"CephClientKey\"}, \"nova::compute::rbd::libvirt_rbd_secret_uuid\": {\"get_param\": \"CephClusterFSID\"}, \"nova::compute::instance_usage_audit\": true, \"nova::compute::instance_usage_audit_period\": \"hour\", \"nova::compute::consecutive_build_service_disable_threshold\": {\"get_param\": \"NovaAutoDisabling\"}, \"nova::compute::live_migration_wait_for_vif_plug\": {\"get_param\": \"NovaLiveMigrationWaitForVIFPlug\"}, \"nova::migration::libvirt::live_migration_permit_post_copy\": {\"if\": [\"is_realtime\", false, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_permit_post_copy\"]}]}, \"nova::migration::libvirt::live_migration_permit_auto_converge\": {\"if\": [\"is_realtime\", false, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_permit_auto_converge\"]}]}, \"nova::migration::libvirt::live_migration_tunnelled\": false, \"nova::compute::vncserver_proxyclient_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"nova::compute::vncproxy_host\": {\"get_param\": [\"EndpointMap\", \"NovaPublic\", \"host_nobrackets\"]}, \"nova::vncproxy::common::vncproxy_protocol\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyCellPublic\", \"protocol\"]}, \"nova::vncproxy::common::vncproxy_host\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyCellPublic\", \"host_nobrackets\"]}, \"nova::vncproxy::common::vncproxy_port\": {\"get_param\": [\"EndpointMap\", \"NovaVNCProxyCellPublic\", \"port\"]}, \"nova::compute::verify_glance_signatures\": {\"get_param\": [\"VerifyGlanceSignatures\"]}, \"nova::ram_allocation_ratio\": {\"if\": [\"libvirt_file_backed_memory_enabled\", \"1.0\", {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova::ram_allocation_ratio\"]}]}, \"nova::compute::libvirt::max_queues\": {\"if\": [\"nova_libvirt_max_queues_set\", {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_libvirt_max_queues\"]}]}, \"nova::workarounds::disable_compute_service_check_for_ffu\": {\"get_param\": \"NovaDisableComputeServiceCheckForFfu\"}}, {\"if\": [\"glance_enable_rbd_download_set\", {\"nova::glance::enable_rbd_download\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_glance_enable_rbd_download\"]}, \"nova::glance::rbd_user\": {\"if\": [\"nova_glance_rbd_download_multistore_id_set\", {\"yaql\": {\"expression\": \"let(k => $.data.key, d => $.data.default_ceph_client_user_name) -> $.data.multistore.get($k).get(\\\"CephClientUserName\\\", $d)\", \"data\": {\"key\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_glance_rbd_download_multistore_id\"]}, \"multistore\": {\"get_param\": \"GlanceMultistoreConfig\"}, \"default_ceph_client_user_name\": {\"get_param\": \"CephClientUserName\"}}}}, {\"get_param\": \"CephClientUserName\"}]}, \"nova::glance::rbd_pool\": {\"if\": [\"nova_glance_rbd_download_multistore_id_set\", {\"yaql\": {\"expression\": \"let(k => $.data.key, d => $.data.default_glance_rbd_pool_name) -> $.data.multistore.get($k).get(\\\"GlanceRbdPoolName\\\", $d)\", \"data\": {\"key\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_glance_rbd_download_multistore_id\"]}, \"multistore\": {\"get_param\": \"GlanceMultistoreConfig\"}, \"default_glance_rbd_pool_name\": {\"get_param\": \"GlanceRbdPoolName\"}}}}, {\"get_param\": \"GlanceRbdPoolName\"}]}, \"nova::glance::rbd_ceph_conf\": {\"list_join\": [\"\", [\"/etc/ceph/\", {\"if\": [\"nova_glance_rbd_download_multistore_id_set\", {\"yaql\": {\"expression\": \"let(k => $.data.key) -> list(coalesce($.data.multistore, {}).get($k)).flatten().select($.get(\\\"CephClusterName\\\"))\", \"data\": {\"key\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_glance_rbd_download_multistore_id\"]}, \"multistore\": {\"get_param\": \"GlanceMultistoreConfig\"}}}}, {\"get_param\": \"CephClusterName\"}]}, \".conf\"]]}}]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_nova_compute\": [{\"get_param\": \"NovaComputeLoggingSource\"}]}, \"collectd\": {\"tripleo.collectd.plugins.nova_compute\": [\"virt\"], \"collectd::plugin::virt::connection\": \"qemu:///system\"}}, \"puppet_config\": {\"config_volume\": \"nova_libvirt\", \"puppet_tags\": \"nova_config\", \"step_config\": \"# TODO(emilien): figure how to deal with libvirt profile.\\n# We\'ll probably treat it like we do with Neutron plugins.\\n# Until then, just include it in the default nova-compute role.\\ninclude tripleo::profile::base::nova::compute::libvirt\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/nova_compute.json\": {\"command\": {\"list_join\": [\" \", [{\"if\": [\"compute_startup_delay\", {\"str_replace\": {\"template\": \"/var/lib/nova/delay-nova-compute --delay DELAY --nova-binary\", \"params\": {\"DELAY\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_compute_startup_delay\"]}}}}]}, \"/usr/bin/nova-compute\", {\"get_attr\": [\"NovaLogging\", \"cmd_extra_args\"]}]]}, \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-iscsid/*\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": {\"list_concat\": [[{\"path\": \"/var/log/nova\", \"owner\": \"nova:nova\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"nova:nova\", \"perm\": \"0600\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%keyring%>\", \"owner\": \"nova:nova\", \"perm\": \"0600\"}, \"for_each\": {\"<%keyring%>\": {\"yaql\": {\"expression\": \"let(u => $.data.user) -> $.data.multistore.values().where($.get(\\\"CephClusterName\\\")).select($.CephClusterName + \\\".client.\\\" + $.get(\\\"CephClientUserName\\\", $u) + \\\".keyring\\\")\", \"data\": {\"user\": {\"get_param\": \"CephClientUserName\"}, \"multistore\": {\"get_param\": \"GlanceMultistoreConfig\"}}}}}}}, {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%keyring%>\", \"owner\": \"nova:nova\", \"perm\": \"0600\"}, \"for_each\": {\"<%keyring%>\": {\"yaql\": {\"expression\": \"let(u => $.data.default_user) -> $.data.multiconfig.values().select($.CephClusterName + \\\".client.\\\" + $.get(\\\"CephClientUserName\\\", $u) + \\\".keyring\\\")\", \"data\": {\"default_user\": {\"get_param\": \"CephClientUserName\"}, \"multiconfig\": {\"get_param\": \"CinderRbdMultiConfig\"}}}}}}}]}}, \"/var/lib/kolla/config_files/nova_compute_wait_for_compute_service.json\": {\"command\": \"/container-config-scripts/pyshim.sh /container-config-scripts/nova_wait_for_compute_service.py\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/nova\", \"owner\": \"nova:nova\", \"recurse\": true}]}}, \"container_config_scripts\": {\"map_merge\": [{\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, {\"get_attr\": [\"NovaComputeCommon\", \"container_config_scripts\"]}]}, \"docker_config\": {\"step_2\": {\"get_attr\": [\"NovaLogging\", \"docker_config\", \"step_2\"]}, \"step_3\": {\"nova_statedir_owner\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaComputeImage\"]}, \"net\": \"none\", \"user\": \"root\", \"security_opt\": [\"label=disable\"], \"privileged\": false, \"detach\": false, \"volumes\": [\"/var/lib/nova:/var/lib/nova:shared\", \"/var/lib/_nova_secontext:/var/lib/_nova_secontext:shared,z\", \"/var/lib/container-config-scripts:/container-config-scripts:z\"], \"command\": \"/container-config-scripts/pyshim.sh /container-config-scripts/nova_statedir_ownership.py\", \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}, \"__OS_DEBUG\": {\"yaql\": {\"expression\": \"str($.data.debug)\", \"data\": {\"debug\": {\"get_attr\": [\"NovaBase\", \"role_data\", \"config_settings\", \"nova::logging::debug\"]}}}}, \"NOVA_STATEDIR_OWNERSHIP_SKIP\": {\"list_join\": [\":\", {\"get_param\": \"NovaStatedirOwnershipSkip\"}]}}}}, \"step_5\": {\"map_merge\": [{\"nova_compute\": {\"start_order\": 3, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaComputeImage\"]}, \"ulimit\": {\"get_param\": \"DockerNovaComputeUlimit\"}, \"ipc\": \"host\", \"net\": \"host\", \"privileged\": true, \"user\": \"nova\", \"restart\": \"always\", \"depends_on\": {\"list_concat\": [[\"tripleo_nova_libvirt.target\"], {\"if\": [{\"get_param\": \"NovaNfsEnabled\"}, [\"var-lib-nova-instances.mount\"]]}]}, \"healthcheck\": {\"get_attr\": [\"ContainersCommon\", \"healthcheck_rpc_port\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaLogging\", \"volumes\"]}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_compute_opt_volumes\"]}, [\"/etc/ssh/ssh_known_hosts:/etc/ssh/ssh_known_hosts:ro\", \"/var/lib/kolla/config_files/nova_compute.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/dev:/dev\", \"/lib/modules:/lib/modules:ro\", \"/run:/run\", \"/run/nova:/run/nova:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\", \"/var/lib/libvirt:/var/lib/libvirt:shared\", \"/sys/class/net:/sys/class/net\", \"/sys/bus/pci:/sys/bus/pci\", \"/boot:/boot:ro\", \"/var/lib/nova:/var/lib/nova:shared\"], {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}]}, \"environment\": {\"map_merge\": [{\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_compute_opt_env_vars\"]}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}, {\"LIBGUESTFS_BACKEND\": \"direct\"}]}}}, {\"if\": [{\"not\": {\"get_param\": \"NovaAdditionalCell\"}}, {\"nova_wait_for_compute_service\": {\"start_order\": 4, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaComputeImage\"]}, \"net\": \"host\", \"detach\": false, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/nova_compute_wait_for_compute_service.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/nova:/var/log/nova\", \"/var/lib/container-config-scripts:/container-config-scripts\"]]}, \"user\": \"nova\", \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"__OS_DEBUG\": {\"yaql\": {\"expression\": \"str($.data.debug)\", \"data\": {\"debug\": {\"get_attr\": [\"NovaBase\", \"role_data\", \"config_settings\", \"nova::logging::debug\"]}}}}}}}]}]}}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"NovaLogging\", \"host_prep_tasks\"]}, [{\"name\": \"Check for /var/lib/nova/instances directory exitance\", \"stat\": {\"path\": \"/var/lib/nova/instances\"}, \"register\": \"check_nova_instances_result\"}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype | default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/lib/nova\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/lib/_nova_secontext\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/lib/nova/instances\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/lib/libvirt\", \"setype\": \"container_file_t\"}, {\"path\": \"/etc/tmpfiles.d\"}]}, {\"name\": \"ensure /run/nova is present upon reboot\", \"copy\": {\"dest\": \"/etc/tmpfiles.d/run-nova.conf\", \"content\": \"d /run/nova 0777 root root - -\\n\"}}, {\"name\": \"create tempfiles\", \"command\": \"systemd-tmpfiles --create\"}], [{\"name\": \"Mount Nova NFS Share\", \"vars\": {\"nfs_backend_enable\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_backend_enable\"]}, \"nfs_share\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_share\"]}, \"nfs_options\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_options\"]}, \"nfs_vers\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_vers\"]}}, \"mount\": {\"name\": \"/var/lib/nova/instances\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{nfs_share}}\", \"opts\": \"_netdev,bg,{{nfs_options}},nfsvers={{nfs_vers}}\"}, \"when\": \"nfs_backend_enable|bool\"}], [{\"name\": \"delay installation of systemd-container\", \"when\": \"check_nova_instances_result.stat.exists\", \"block\": [{\"name\": \"check systemd-container package installed or not\", \"package\": {\"name\": \"systemd-container\", \"state\": \"present\"}, \"check_mode\": true, \"register\": \"is_systemd_container_package\", \"failed_when\": false}, {\"name\": \"get latest package from downloaded package versions\", \"shell\": \"ls -1t /var/tmp/systemd-container* | head -1\", \"register\": \"latest_systemd_container_package\", \"when\": [\"is_systemd_container_package is defined\", \"(\'changed\' in is_systemd_container_package)\", \"is_systemd_container_package.changed\"], \"failed_when\": false}, {\"name\": \"Install systemd-container package on boot\", \"copy\": {\"dest\": \"/etc/systemd/system/install-systemd-container.service\", \"content\": \"[Unit]\\nDescription=Install systemd container package on system boot\\nBefore=tripleo_nova_virtqemud.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/usr/bin/rpm -ivh {{ latest_systemd_container_package.stdout }}\\nExecStartPost=rm -f /var/tmp/systemd-container*\\n\\n[Install]\\nWantedBy=multi-user.target\\n\"}, \"when\": [\"latest_systemd_container_package is defined\", \"(\'stdout\' in latest_systemd_container_package)\", \"is_systemd_container_package is defined\", \"(\'changed\' in is_systemd_container_package)\", \"is_systemd_container_package.changed\"]}, {\"name\": \"enable install-systemd-container on compute boot\", \"systemd\": {\"name\": \"install-systemd-container\", \"state\": \"stopped\", \"enabled\": true, \"daemon_reload\": true}, \"when\": [\"is_systemd_container_package is defined\", \"(\'changed\' in is_systemd_container_package)\", \"is_systemd_container_package.changed\"]}, {\"name\": \"check if install-systemd-container service exists\", \"stat\": {\"path\": \"/etc/systemd/system/install-systemd-container.service\"}, \"register\": \"install_systemd_container_result\"}, {\"name\": \"disable and mask install-systemd-container on compute boot\", \"systemd\": {\"name\": \"install-systemd-container\", \"enabled\": false, \"masked\": true, \"daemon_reload\": true}, \"when\": [\"is_systemd_container_package is defined\", \"(\'changed\' in is_systemd_container_package)\", \"not is_systemd_container_package.changed\", \"install_systemd_container_result.stat.exists\"]}]}, {\"name\": \"is Nova Resume Guests State On Host Boot enabled\", \"set_fact\": {\"resume_guests_state_on_host_boot_enabled\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"resume_guests_state_on_host_boot\"]}}}, {\"name\": \"install libvirt-guests systemd unit file (docker)\", \"when\": [\"resume_guests_state_on_host_boot_enabled|bool\", \"container_cli == \'docker\'\"], \"block\": [{\"name\": \"libvirt-guests unit to stop nova_compute container before shutdown VMs\", \"copy\": {\"dest\": \"/etc/systemd/system/libvirt-guests.service\", \"content\": \"[Unit]\\nDescription=Suspend/Resume Running libvirt Guests\\nAfter=network.target\\nAfter=time-sync.target\\nAfter=virt-guest-shutdown.target\\nAfter=docker.service\\nAfter=tripleo-container-shutdown.service\\nAfter=rhel-push-plugin.service\\nDocumentation=man:libvirtd(8)\\nDocumentation=https://libvirt.org\\n\\n[Service]\\nEnvironmentFile=-/var/lib/config-data/puppet-generated/nova_libvirt/etc/sysconfig/libvirt-guests\\n# Hack just call traditional service until we factor\\n# out the code\\nExecStart=/bin/{{container_cli}} exec nova_libvirt /bin/sh -x /usr/libexec/libvirt-guests.sh start\\nExecStop=/bin/{{container_cli}} stop nova_compute\\nExecStop=/bin/{{container_cli}}  exec nova_libvirt /bin/sh -x /usr/libexec/libvirt-guests.sh stop\\nType=oneshot\\nRemainAfterExit=yes\\nStandardOutput=journal+console\\nTimeoutStopSec=0\\n\\n[Install]\\nWantedBy=multi-user.target\\n\"}}, {\"name\": \"Making sure virt-guest-shutdown.target is present\", \"copy\": {\"dest\": \"/etc/systemd/system/virt-guest-shutdown.target\", \"content\": \"[Unit]\\nDescription=Libvirt guests shutdown\\nDocumentation=https://libvirt.org\\nAfter=systemd-machined.service\\nAfter=network-online.target\\nAfter=tripleo_nova_libvirt.target\\nBefore=tripleo_nova_compute.service\\n\"}}, {\"name\": \"libvirt-guests enable VM shutdown on compute reboot/shutdown\", \"systemd\": {\"name\": \"libvirt-guests\", \"enabled\": true, \"daemon_reload\": true}}]}, {\"name\": \"install tripleo_nova_libvirt_guests systemd unit file (podman)\", \"when\": [\"resume_guests_state_on_host_boot_enabled|bool\", \"container_cli == \'podman\'\"], \"block\": [{\"name\": \"libvirt-guests unit to stop nova_compute container before shutdown VMs (monolithic libvirt)\", \"copy\": {\"dest\": \"/etc/systemd/system/tripleo_nova_libvirt_guests.service\", \"content\": \"[Unit]\\nDescription=Suspend libvirt Guests in tripleo\\nRequires=virt-guest-shutdown.target\\nAfter=systemd-machined.service\\nAfter=network-online.target\\nAfter=tripleo_nova_libvirt.target\\nBefore=tripleo_nova_compute.service\\nDocumentation=man:libvirtd(8)\\nDocumentation=https://libvirt.org\\n\\n[Service]\\nEnvironmentFile=-/etc/sysconfig/libvirt-guests\\nExecStart=/bin/podman exec nova_libvirt /bin/rm -f /var/lib/libvirt/libvirt-guests\\nExecStop=/bin/podman exec nova_libvirt /bin/sh -x /usr/libexec/libvirt-guests.sh shutdown\\nType=oneshot\\nRemainAfterExit=yes\\nStandardOutput=journal+console\\nTimeoutStopSec=0\\n\\n[Install]\\nWantedBy=multi-user.target\\n\"}, \"when\": \"tripleo_nova_libvirt_virsh_container | default(\'nova_libvirt\') == \'nova_libvirt\'\"}, {\"name\": \"libvirt-guests unit to stop nova_compute container before shutdown VMs (modular libvirt)\", \"copy\": {\"dest\": \"/etc/systemd/system/tripleo_nova_libvirt_guests.service\", \"content\": \"[Unit]\\nDescription=Suspend libvirt Guests in tripleo\\nRequires=virt-guest-shutdown.target\\nAfter=systemd-machined.service\\nAfter=network-online.target\\nAfter=tripleo_nova_libvirt.target\\nBefore=tripleo_nova_compute.service\\nDocumentation=man:libvirtd(8)\\nDocumentation=https://libvirt.org\\n\\n[Service]\\nEnvironmentFile=-/etc/sysconfig/libvirt-guests\\nExecStart=/bin/podman exec nova_virtproxyd /bin/rm -f /var/lib/libvirt/libvirt-guests\\nExecStop=/bin/podman exec nova_virtproxyd /bin/sh -x /usr/libexec/libvirt-guests.sh shutdown\\nType=oneshot\\nRemainAfterExit=yes\\nStandardOutput=journal+console\\nTimeoutStopSec=0\\n\\n[Install]\\nWantedBy=multi-user.target\\n\"}, \"when\": \"tripleo_nova_libvirt_virsh_container | default(\'nova_libvirt\') != \'nova_libvirt\'\"}, {\"name\": \"Making sure virt-guest-shutdown.target is present\", \"copy\": {\"dest\": \"/etc/systemd/system/virt-guest-shutdown.target\", \"content\": \"[Unit]\\nDescription=Libvirt guests shutdown\\nDocumentation=https://libvirt.org\\nAfter=systemd-machined.service\\nAfter=network-online.target\\nAfter=tripleo_nova_libvirt.target\\nBefore=tripleo_nova_compute.service\\n\"}}, {\"name\": \"tripleo_nova_libvirt_guests enable VM shutdown on compute reboot/shutdown\", \"systemd\": {\"name\": \"tripleo_nova_libvirt_guests\", \"enabled\": true, \"daemon_reload\": true}}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}, {\"name\": \"enable virt_sandbox_use_netlink for healthcheck\", \"seboolean\": {\"name\": \"virt_sandbox_use_netlink\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}, {\"name\": \"Do we prepend nova startup with a delay\", \"set_fact\": {\"nova_compute_delay\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_compute_startup_delay\"]}}}, {\"name\": \"install nova-compute delay wrapper script\", \"copy\": {\"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/scripts/delay-nova-compute\"}, \"dest\": \"/var/lib/nova/delay-nova-compute\", \"mode\": 493}, \"when\": \"nova_compute_delay|int > 0\"}, {\"name\": \"Is irqbalance enabled\", \"set_fact\": {\"compute_irqbalance_disabled\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"compute_disable_irqbalance\"]}}}, {\"name\": \"disable irqbalance service on compute\", \"when\": \"compute_irqbalance_disabled|bool\", \"service\": {\"name\": \"irqbalance.service\", \"state\": \"stopped\", \"enabled\": false}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}, \"deploy_steps_tasks\": [{\"name\": \"install systemd-container for a greenfield\", \"when\": [\"step|int == 1\", \"not check_nova_instances_result.stat.exists\"], \"package\": {\"name\": \"systemd-container\", \"state\": \"present\"}}, {\"name\": \"validate nova-compute container state\", \"containers.podman.podman_container_info\": {\"name\": \"nova_compute\"}, \"register\": \"nova_compute_infos\", \"failed_when\": [\"nova_compute_infos.containers.0.Healthcheck.Status is defined\", \"\'healthy\' not in nova_compute_infos.containers.0.Healthcheck.Status\"], \"retries\": 10, \"delay\": 30, \"tags\": [\"opendev-validation\", \"opendev-validation-nova\"], \"when\": [\"container_cli == \'podman\'\", \"not container_healthcheck_disabled\", \"step|int == 6\"]}, {\"name\": \"manage PMEM namespaces for vPMEM\", \"include_role\": {\"name\": \"tripleo_nvdimm\"}, \"vars\": {\"tripleo_nvdimm_pmem_namespaces\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_pmem_namespaces\"]}}, \"when\": [\"step|int == 1\", \"tripleo_nvdimm_pmem_namespaces != \'\'\"]}, {\"name\": \"manage OS version 9 specific sysctls\", \"when\": [\"step|int == 1\", \"ansible_facts[\'os_family\'] == \'RedHat\'\", \"ansible_facts[\'distribution_major_version\'] is version(\'9\', \'==\')\"], \"block\": [{\"name\": \"Enable post-copy by setting unprivileged_userfaultfd\", \"sysctl\": {\"name\": \"vm.unprivileged_userfaultfd\", \"value\": 1, \"sysctl_set\": true, \"sysctl_file\": \"/etc/sysctl.d/99-tripleo-postcopy.conf\", \"state\": \"present\", \"reload\": true}}]}, {\"name\": \"enable/disable ksm\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"is KSM enabled\", \"set_fact\": {\"compute_ksm_enabled\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"compute_enable_ksm\"]}}}, {\"name\": \"disable KSM on compute\", \"when\": \"not compute_ksm_enabled|bool\", \"block\": [{\"name\": \"Check for ksm\", \"shell\": \"systemctl is-active ksm.service || systemctl is-enabled ksm.service\", \"become\": true, \"failed_when\": false, \"register\": \"ksm_service_check\"}, {\"name\": \"disable KSM services\", \"service\": {\"name\": \"{{ item }}\", \"state\": \"stopped\", \"enabled\": false}, \"with_items\": [\"ksm.service\", \"ksmtuned.service\"], \"when\": [\"ksm_service_check.rc is defined\", \"ksm_service_check.rc == 0\"], \"register\": \"ksmdisabled\"}, {\"name\": \"delete PageKSM after disable ksm on compute\", \"command\": \"echo 2 >/sys/kernel/mm/ksm/run\", \"when\": [\"ksm_service_check.rc is defined\", \"ksm_service_check.rc == 0\", \"ksmdisabled is changed\"]}]}, {\"name\": \"enable KSM on compute\", \"when\": \"compute_ksm_enabled|bool\", \"block\": [{\"name\": \"make sure package providing ksmtuned is installed (RHEL8 or CentOS8)\", \"package\": {\"name\": \"qemu-kvm-common\", \"state\": \"present\"}, \"when\": [\"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\"]}, {\"name\": \"make sure package providing ksmtuned is installed (RHEL9 or CentOS9)\", \"package\": {\"name\": \"ksmtuned\", \"state\": \"present\"}, \"when\": [\"ansible_facts[\'distribution_major_version\'] is version(\'9\', \'==\')\"]}, {\"name\": \"enable ksmtunded\", \"service\": {\"name\": \"{{ item }}\", \"state\": \"started\", \"enabled\": true}, \"with_items\": [\"ksm.service\", \"ksmtuned.service\"]}]}]}], \"external_post_deploy_tasks\": {\"get_attr\": [\"NovaComputeCommon\", \"nova_compute_common_deploy_steps_tasks\"]}, \"upgrade_tasks\": [{\"name\": \"Remove openstack-nova-compute and python-nova package during upgrade\", \"package\": {\"name\": [\"openstack-nova-compute\", \"python-nova\"], \"state\": \"removed\"}, \"failed_when\": false, \"when\": \"step|int == 2\"}, {\"name\": \"nova_compute pre system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Unmount Nova NFS Share\", \"vars\": {\"nfs_backend_enable\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_backend_enable\"]}}, \"mount\": {\"name\": \"/var/lib/nova/instances\", \"state\": \"absent\", \"fstype\": \"nfs4\"}, \"when\": \"nfs_backend_enable|bool\"}]}, {\"name\": \"nova_compute post system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 5\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Mount Nova NFS Share\", \"vars\": {\"nfs_backend_enable\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_backend_enable\"]}, \"nfs_share\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_share\"]}, \"nfs_options\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_options\"]}, \"nfs_vers\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nfs_vers\"]}}, \"mount\": {\"name\": \"/var/lib/nova/instances\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{nfs_share}}\", \"opts\": \"_netdev,bg,{{nfs_options}},nfsvers={{nfs_vers}}\"}, \"when\": \"nfs_backend_enable|bool\"}]}], \"update_tasks\": [{\"name\": \"Remove openstack-nova-compute and python-nova package during upgrade\", \"package\": {\"name\": [\"openstack-nova-compute\", \"python-nova\"], \"state\": \"removed\"}, \"failed_when\": false, \"when\": \"step|int == 2\"}], \"post_update_tasks\": [{\"name\": \"Ensure instanceha directory is purged\", \"when\": \"step|int == 1\", \"become\": true, \"file\": {\"path\": \"/var/lib/nova/instanceha\", \"state\": \"absent\"}}], \"post_upgrade_tasks\": [{\"name\": \"Ensure instanceha directory is purged\", \"when\": \"step|int == 1\", \"become\": true, \"file\": {\"path\": \"/var/lib/nova/instanceha\", \"state\": \"absent\"}}], \"scale_tasks\": [{\"when\": [\"step|int == 1\", \"container_cli == \'podman\'\"], \"tags\": \"down\", \"become\": true, \"environment\": {\"OS_CLOUD\": {\"if\": [\"auth_cloud_name_set\", {\"get_param\": \"AuthCloudName\"}, {\"get_param\": \"RootStackName\"}]}}, \"block\": [{\"name\": \"Get nova-compute service ID\", \"command\": \"openstack compute service list --service nova-compute --column ID --column Host --format yaml\", \"register\": \"nova_compute_service_result\", \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"check_mode\": false, \"changed_when\": false}, {\"name\": \"is additional Cell?\", \"set_fact\": {\"is_additional_cell\": {\"get_param\": \"NovaAdditionalCell\"}}}, {\"name\": \"Set fact for nova_compute services\", \"set_fact\": {\"nova_compute_service\": \"{{ nova_compute_service_result.stdout | from_yaml | selectattr(\'Host\', \'match\', ansible_facts[\'fqdn\'] ~ \'.*\') | list }}\"}, \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"check_mode\": false}, {\"name\": \"Check search output\", \"fail\": {\"msg\": \"Found multiple `{{ ansible_facts[\'fqdn\'] }}`, which is unexpected. This means that the FQDN of the selected device to disable is either wrong or is sharing a name with another host, which is also wrong. Please correct this issue before continuing. Nova service list return data can be found here -> {{ nova_compute_service }}.\"}, \"when\": [\"(nova_compute_service | length) > 1\"]}, {\"name\": \"Disable nova services\", \"when\": [\"(nova_compute_service | length) == 1\"], \"block\": [{\"name\": \"Disable nova-compute service\", \"command\": \"openstack compute service set {{ nova_compute_service[0].Host }} nova-compute --disable\", \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"check_mode\": false, \"when\": [\"not is_additional_cell|bool\"]}, {\"name\": \"Stop nova-compute container\", \"service\": {\"name\": \"tripleo_nova_compute\", \"state\": \"stopped\", \"enabled\": false}, \"become\": true, \"register\": \"stop_nova_compute\", \"failed_when\": \"(\'msg\' in stop_nova_compute and \'Could not find the requested service tripleo_nova_compute\' not in stop_nova_compute.msg) or (\'rc\' in stop_nova_compute and stop_nova_compute.rc != 0)\"}, {\"name\": \"Delete nova-compute service\", \"command\": \"openstack compute service delete {{ nova_compute_service[0].ID }}\", \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"check_mode\": false}]}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(95,'2026-06-09 08:02:06',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Ceilometer service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"CeilometerMeteringSecret\": {\"description\": \"Secret shared by the ceilometer services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\"}, \"CeilometerPassword\": {\"description\": \"The password for the ceilometer service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"6GBzmfESOACPjM70aXaIF8M8d\"}, \"AmqpRpcAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for RPC addresses\", \"type\": \"string\"}, \"AmqpNotifyAddressPrefix\": {\"default\": \"\", \"description\": \"Address prefix for Notification addresses\", \"type\": \"string\"}, \"ManagePolling\": {\"default\": false, \"description\": \"Whether to manage polling.yaml.\", \"type\": \"boolean\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"CeilometerDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Ceilometer services.\", \"type\": \"boolean\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"SnmpdReadonlyUserName\": {\"default\": \"ro_snmp_user\", \"description\": \"The user name for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\"}, \"SnmpdReadonlyUserPassword\": {\"description\": \"The user password for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\", \"hidden\": true, \"default\": \"IUqJgJKOidh20dco1DYKnuQ1\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"GnocchiArchivePolicy\": {\"default\": \"ceilometer-low-rate\", \"type\": \"string\", \"description\": \"(DEPRECATED) archive policy to use with gnocchi backend\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"MemcachedTLS\": {\"default\": true, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"GnocchiArchivePolicy\"]}], \"conditions\": {\"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ceilometer role.\", \"value\": {\"service_name\": \"ceilometer_base\", \"config_settings\": {\"map_merge\": [{\"ceilometer::logging::debug\": {\"if\": [{\"get_param\": \"CeilometerDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"ceilometer::agent::polling::manage_polling\": {\"get_param\": \"ManagePolling\"}, \"ceilometer::agent::service_credentials::password\": {\"get_param\": \"CeilometerPassword\"}, \"ceilometer::agent::service_credentials::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"ceilometer::agent::service_credentials::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"ceilometer::agent::service_credentials::project_name\": \"service\", \"ceilometer::agent::service_credentials::user_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::auth_project_domain_name\": \"Default\", \"ceilometer::agent::service_credentials::interface\": \"internalURL\", \"ceilometer::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"ceilometer::amqp_rpc_address_prefix\": {\"get_param\": \"AmqpRpcAddressPrefix\"}, \"ceilometer::amqp_notify_address_prefix\": {\"get_param\": \"AmqpNotifyAddressPrefix\"}, \"ceilometer::telemetry_secret\": {\"get_param\": \"CeilometerMeteringSecret\"}, \"ceilometer::snmpd_readonly_username\": {\"get_param\": \"SnmpdReadonlyUserName\"}, \"ceilometer::snmpd_readonly_user_password\": {\"get_param\": \"SnmpdReadonlyUserPassword\"}, \"ceilometer::host\": \"%{hiera(\'fqdn_canonical\')}\", \"ceilometer::rabbit_heartbeat_in_pthread\": false, \"ceilometer::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"ceilometer::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}}, {\"if\": [\"tls_cache_enabled\", {\"ceilometer::cache::backend\": \"dogpile.cache.pymemcache\", \"ceilometer::cache::enable_socket_keepalive\": true}, {\"ceilometer::cache::backend\": \"dogpile.cache.memcached\"}]}]}, \"service_config_settings\": {\"keystone\": {\"tripleo::profile::base::keystone::ceilometer_notification_topics\": [\"notifications\"]}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(96,'2026-06-09 08:02:06',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (97,'2026-06-09 08:02:06',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(98,'2026-06-09 08:02:06',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Cinder NVMeOF backend\\n\", \"parameters\": {\"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderNVMeOFBackendName\": {\"type\": \"string\", \"default\": \"tripleo_nvmeof\"}, \"CinderNVMeOFAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NVMeOF Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNVMeOFTargetPort\": {\"type\": \"number\", \"default\": 4420}, \"CinderNVMeOFTargetHelper\": {\"type\": \"string\", \"default\": \"nvmet\"}, \"CinderNVMeOFTargetProtocol\": {\"type\": \"string\", \"default\": \"nvmet_rdma\", \"description\": \"The target protocol, supported values are nvmet_rdma and nvmet_tcp.\\n\", \"constraints\": [{\"allowed_values\": [\"nvmet_rdma\", \"nvmet_tcp\"]}]}, \"CinderNVMeOFTargetPrefix\": {\"type\": \"string\", \"default\": \"nvme-subsystem\"}, \"CinderNVMeOFTargetPortId\": {\"type\": \"number\", \"default\": 1}, \"CinderNVMeOFTargetNameSpaceId\": {\"type\": \"number\", \"default\": 10}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"type\": \"json\", \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}}, \"outputs\": {\"cinder_nvmeof_host_prep_tasks\": {\"description\": \"Host prep tasks related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [{\"name\": \"ensure /etc/nvme exists\", \"file\": {\"path\": \"/etc/nvme\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]]}}, \"cinder_nvmeof_volumes\": {\"description\": \"Volumes related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [\"/etc/nvme:/etc/nvme:z\"]]}}, \"role_data\": {\"description\": \"Role data for the Cinder NVMeOF backend.\", \"value\": {\"service_name\": \"cinder_backend_nvmeof\", \"firewall_rules\": {\"120 LVM nvmet target\": {\"dport\": {\"get_param\": \"CinderNVMeOFTargetPort\"}}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::cinder::volume::cinder_enable_nvmeof_backend\": {\"get_param\": \"CinderEnableNVMeOFBackend\"}, \"tripleo::profile::base::cinder::volume::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_port\": {\"get_param\": \"CinderNVMeOFTargetPort\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_helper\": {\"get_param\": \"CinderNVMeOFTargetHelper\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_protocol\": {\"get_param\": \"CinderNVMeOFTargetProtocol\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_prefix\": {\"get_param\": \"CinderNVMeOFTargetPrefix\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_port_id\": {\"get_param\": \"CinderNVMeOFTargetPortId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_ns_id\": {\"get_param\": \"CinderNVMeOFTargetNameSpaceId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_ip_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}, \"cinder::backend::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNVMeOFAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nvmeof::backend_availability_zone\": {\"get_param\": \"CinderNVMeOFAvailabilityZone\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(99,'2026-06-09 08:02:06',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(100,'2026-06-09 08:02:06',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Load kernel modules with kmod and configure kernel options with sysctl.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KernelPidMax\": {\"default\": 1048576, \"description\": \"Configures sysctl kernel.pid_max key\", \"type\": \"number\"}, \"KernelDisableIPv6\": {\"default\": 0, \"description\": \"Configures sysctl net.ipv6.{default/all}.disable_ipv6 keys\", \"type\": \"number\"}, \"KernelIpForward\": {\"default\": 1, \"description\": \"Configures net.ipv4.ip_forward key\", \"type\": \"number\"}, \"KernelIpv6ConfAllForwarding\": {\"default\": 0, \"description\": \"Configures the net.ipv6.conf.all.forwarding key\", \"type\": \"number\"}, \"KernelIpv4ConfAllRpFilter\": {\"default\": 1, \"description\": \"Configures the net.ipv4.conf.all.rp_filter key\", \"type\": \"number\"}, \"KernelIpNonLocalBind\": {\"default\": 1, \"description\": \"Configures net.ipv{4,6}.ip_nonlocal_bind key\", \"type\": \"number\"}, \"NeighbourGcThreshold1\": {\"default\": 1024, \"description\": \"Configures sysctl net.ipv4.neigh.default.gc_thresh1 value. This is the minimum number of entries to keep in the ARP cache. The garbage collector will not run if there are fewer than this number of entries in the cache.\", \"type\": \"number\"}, \"NeighbourGcThreshold2\": {\"default\": 2048, \"description\": \"Configures sysctl net.ipv4.neigh.default.gc_thresh2 value. This is the soft maximum number of entries to keep in the ARP cache. The garbage collector will  allow the number of entries to exceed this for 5 seconds before collection will be performed.\", \"type\": \"number\"}, \"NeighbourGcThreshold3\": {\"default\": 4096, \"description\": \"Configures sysctl net.ipv4.neigh.default.gc_thresh3 value. This is the hard maximum number of entries to keep in the ARP cache. The garbage collector will always run if there are more than this number of entries in the cache.\", \"type\": \"number\"}, \"InotifyInstancesMax\": {\"default\": 1024, \"description\": \"Configures sysctl fs.inotify.max_user_instances key\", \"type\": \"number\"}, \"BridgeNfCallArpTables\": {\"default\": 1, \"description\": \"Configures sysctl net.bridge.bridge-nf-call-arptables key\", \"type\": \"number\"}, \"BridgeNfCallIpTables\": {\"default\": 1, \"description\": \"Configures sysctl net.bridge.bridge-nf-call-iptables key\", \"type\": \"number\"}, \"BridgeNfCallIp6Tables\": {\"default\": 1, \"description\": \"Configures sysctl net.bridge.bridge-nf-call-ip6tables key\", \"type\": \"number\"}, \"ExtraKernelModules\": {\"default\": {}, \"description\": \"Hash of extra Kernel modules to load.\", \"type\": \"json\", \"tags\": [\"role_specific\"]}, \"ExtraKernelPackages\": {\"default\": {}, \"description\": \"List of extra kernel related packages to install.\", \"type\": \"json\", \"tags\": [\"role_specific\"]}, \"ExtraSysctlSettings\": {\"default\": {}, \"description\": \"Hash of extra sysctl settings to apply.\", \"type\": \"json\", \"tags\": [\"role_specific\"]}, \"FsAioMaxNumber\": {\"default\": 0, \"description\": \"The kernel allocates aio memory on demand, and this number limits the number of parallel aio requests; the only drawback of a larger limit is that a malicious guest could issue parallel requests to cause the kernel to set aside memory.  Set this number at least as large as\\n  128 * (number of virtual disks on the host)\\nLibvirt uses a default of 1M requests to allow 8k disks, with at most 64M of kernel memory if all disks hit an aio request at the same time.\\n\", \"type\": \"number\", \"tags\": [\"role_specific\"]}, \"InotifyIntancesMax\": {\"default\": 1024, \"description\": \"Configures sysctl fs.inotify.max_user_instances key\", \"type\": \"number\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"Do not use deprecated params, they will be removed.\", \"parameters\": [\"InotifyIntancesMax\"]}], \"conditions\": {\"ipv6_disabled\": {\"equals\": [{\"get_param\": \"KernelDisableIPv6\"}, 1]}, \"is_inotify_intances_max_default\": {\"equals\": [{\"get_param\": \"InotifyIntancesMax\"}, 1024]}, \"fs_aio_max_number_set\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"FsAioMaxNumber\"]}, 0]}}, {\"not\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"FsAioMaxNumber\"]}, \"\"]}}]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"extra_kernel_modules\": \"ExtraKernelModules\", \"extra_kernel_packages\": \"ExtraKernelPackages\", \"extra_sysctl_settings\": \"ExtraSysctlSettings\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ExtraKernelModules\": {\"get_param\": \"ExtraKernelModules\"}, \"ExtraKernelPackages\": {\"get_param\": \"ExtraKernelPackages\"}, \"ExtraSysctlSettings\": {\"get_param\": \"ExtraSysctlSettings\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Kernel modules\", \"value\": {\"service_name\": \"kernel\", \"host_prep_tasks\": [{\"include_role\": {\"name\": \"tripleo_kernel\"}}], \"ansible_group_vars\": {\"hieradata_localhost_address\": {\"if\": [\"ipv6_disabled\", \"127.0.0.1\", \"localhost\"]}, \"tripleo_kernel_extra_modules\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"extra_kernel_modules\"]}, \"tripleo_kernel_extra_packages\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"extra_kernel_packages\"]}, \"tripleo_kernel_sysctl_extra_settings\": {\"map_merge\": [{\"net.ipv6.conf.default.disable_ipv6\": {\"value\": {\"get_param\": \"KernelDisableIPv6\"}}, \"net.ipv4.ip_local_reserved_ports\": {\"value\": \"35357,49000-49001\"}, \"net.ipv6.conf.all.disable_ipv6\": {\"value\": {\"get_param\": \"KernelDisableIPv6\"}}, \"net.ipv6.conf.lo.disable_ipv6\": {\"value\": 0}, \"net.ipv4.ip_forward\": {\"value\": {\"get_param\": \"KernelIpForward\"}}, \"net.ipv4.conf.all.rp_filter\": {\"value\": {\"get_param\": \"KernelIpv4ConfAllRpFilter\"}}, \"net.ipv6.conf.all.forwarding\": {\"value\": {\"get_param\": \"KernelIpv6ConfAllForwarding\"}}, \"net.ipv4.ip_nonlocal_bind\": {\"value\": {\"get_param\": \"KernelIpNonLocalBind\"}}, \"net.ipv6.ip_nonlocal_bind\": {\"value\": {\"get_param\": \"KernelIpNonLocalBind\"}}, \"kernel.pid_max\": {\"value\": {\"get_param\": \"KernelPidMax\"}}, \"net.ipv4.neigh.default.gc_thresh1\": {\"value\": {\"get_param\": \"NeighbourGcThreshold1\"}}, \"net.ipv4.neigh.default.gc_thresh2\": {\"value\": {\"get_param\": \"NeighbourGcThreshold2\"}}, \"net.ipv4.neigh.default.gc_thresh3\": {\"value\": {\"get_param\": \"NeighbourGcThreshold3\"}}, \"net.bridge.bridge-nf-call-arptables\": {\"value\": {\"get_param\": \"BridgeNfCallArpTables\"}}, \"net.bridge.bridge-nf-call-iptables\": {\"value\": {\"get_param\": \"BridgeNfCallIpTables\"}}, \"net.bridge.bridge-nf-call-ip6tables\": {\"value\": {\"get_param\": \"BridgeNfCallIp6Tables\"}}, \"fs.inotify.max_user_instances\": {\"value\": {\"if\": [\"is_inotify_intances_max_default\", {\"get_param\": \"InotifyInstancesMax\"}, {\"get_param\": \"InotifyIntancesMax\"}]}}}, {\"if\": [\"fs_aio_max_number_set\", {\"fs.aio-max-nr\": {\"value\": {\"get_param\": [\"RoleParameters\", \"FsAioMaxNumber\"]}}}]}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"extra_sysctl_settings\"]}]}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(101,'2026-06-09 08:02:06',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(102,'2026-06-09 08:02:06',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Cinder Scheduler service\\n\", \"parameters\": {\"ContainerCinderSchedulerImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\"}, \"ContainerCinderConfigImage\": {\"description\": \"The container image to use for the cinder config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\"}, \"CinderSchedulerLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.cinder.scheduler\", \"file\": \"/var/log/containers/cinder/cinder-scheduler.log\"}}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"MonitoringSubscriptionCinderScheduler\": {\"default\": \"overcloud-cinder-scheduler\", \"type\": \"string\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"CinderBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"CinderCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCinderSchedulerImage\": \"ContainerCinderSchedulerImage\", \"ContainerCinderConfigImage\": \"ContainerCinderConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCinderSchedulerImage\": {\"get_param\": \"ContainerCinderSchedulerImage\"}, \"ContainerCinderConfigImage\": {\"get_param\": \"ContainerCinderConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder Scheduler role.\", \"value\": {\"service_name\": \"cinder_scheduler\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionCinderScheduler\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CinderBase\", \"role_data\", \"config_settings\"]}, {\"cinder::scheduler::scheduler_driver\": \"cinder.scheduler.filter_scheduler.FilterScheduler\"}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_cinder_scheduler\": [{\"get_param\": \"CinderSchedulerLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"cinder\", \"puppet_tags\": \"cinder_config,file,concat,file_line\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::cinder::scheduler\"], [{\"get_attr\": [\"CinderBase\", \"role_data\", \"step_config\"]}, {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/cinder_scheduler.json\": {\"command\": \"/usr/bin/cinder-scheduler --config-file /usr/share/cinder/cinder-dist.conf --config-file /etc/cinder/cinder.conf\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}], \"permissions\": [{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/etcd.crt\", \"owner\": \"cinder:cinder\"}, {\"path\": \"/etc/pki/tls/private/etcd.key\", \"owner\": \"cinder:cinder\"}]}}, \"docker_config\": {\"step_2\": {\"cinder_scheduler_init_logs\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderSchedulerImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/cinder:/var/log/cinder:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R cinder:cinder /var/log/cinder\"]}}, \"step_4\": {\"cinder_scheduler\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderSchedulerImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"get_attr\": [\"ContainersCommon\", \"healthcheck_rpc_port\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"CinderCommon\", \"cinder_common_volumes\"]}, [\"/var/lib/kolla/config_files/cinder_scheduler.json:/var/lib/kolla/config_files/config.json:ro\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}, {\"name\": \"enable virt_sandbox_use_netlink for healthcheck\", \"seboolean\": {\"name\": \"virt_sandbox_use_netlink\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop cinder scheduler container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"cinder_scheduler\"], \"tripleo_delegate_to\": \"{{ groups[\'cinder_scheduler\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(103,'2026-06-09 08:02:07',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Cinder base service. Shared by all Cinder services.\\n\", \"parameters\": {\"CinderStorageAvailabilityZone\": {\"default\": \"nova\", \"description\": \"The Cinder service\'s storage availability zone.\", \"type\": \"string\"}, \"CinderPassword\": {\"description\": \"The password for the cinder service and db account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"CinderDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging on Cinder services.\", \"type\": \"boolean\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"CinderCronDbPurgeMinute\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Minute\\n\", \"default\": \"1\"}, \"CinderCronDbPurgeHour\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Hour\\n\", \"default\": \"0\"}, \"CinderCronDbPurgeMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month Day\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeMonth\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Week Day\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeUser\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - User\\n\", \"default\": \"cinder\"}, \"CinderCronDbPurgeAge\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age\\n\", \"default\": \"30\"}, \"CinderCronDbPurgeDestination\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Log destination\\n\", \"default\": \"/var/log/cinder/cinder-rowsflush.log\"}, \"CinderCronDbPurgeMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Delay\\n\", \"default\": \"3600\"}, \"CinderRpcResponseTimeout\": {\"default\": 60, \"description\": \"Cinder\'s RPC response timeout, in seconds.\", \"type\": \"number\"}, \"NovaPassword\": {\"type\": \"string\", \"description\": \"The password for the nova service and db account\", \"hidden\": true, \"default\": \"E43sBALvNAsJYgcBpWfsAoz9C\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder base service.\", \"value\": {\"service_name\": \"cinder_base\", \"config_settings\": {\"cinder::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"cinder\", \"password\": {\"get_param\": \"CinderPassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/cinder\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"cinder\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"cinder::logging::debug\": {\"if\": [{\"get_param\": \"CinderDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"cinder::storage_availability_zone\": {\"get_param\": \"CinderStorageAvailabilityZone\"}, \"cinder::rabbit_heartbeat_timeout_threshold\": 60, \"cinder::rpc_response_timeout\": {\"get_param\": \"CinderRpcResponseTimeout\"}, \"cinder::rabbit_heartbeat_in_pthread\": false, \"cinder::db::database_db_max_retries\": -1, \"cinder::db::database_max_retries\": -1, \"cinder::cron::db_purge::minute\": {\"get_param\": \"CinderCronDbPurgeMinute\"}, \"cinder::cron::db_purge::hour\": {\"get_param\": \"CinderCronDbPurgeHour\"}, \"cinder::cron::db_purge::monthday\": {\"get_param\": \"CinderCronDbPurgeMonthday\"}, \"cinder::cron::db_purge::month\": {\"get_param\": \"CinderCronDbPurgeMonth\"}, \"cinder::cron::db_purge::weekday\": {\"get_param\": \"CinderCronDbPurgeWeekday\"}, \"cinder::cron::db_purge::user\": {\"get_param\": \"CinderCronDbPurgeUser\"}, \"cinder::cron::db_purge::age\": {\"get_param\": \"CinderCronDbPurgeAge\"}, \"cinder::cron::db_purge::destination\": {\"get_param\": \"CinderCronDbPurgeDestination\"}, \"cinder::cron::db_purge::maxdelay\": {\"get_param\": \"CinderCronDbPurgeMaxDelay\"}, \"cinder::glance::glance_api_servers\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"uri\"]}, \"cinder::keystone::service_user::send_service_user_token\": true, \"cinder::keystone::service_user::project_name\": \"service\", \"cinder::keystone::service_user::auth_type\": \"password\", \"cinder::keystone::service_user::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri\"]}, \"cinder::keystone::service_user::password\": {\"get_param\": \"CinderPassword\"}, \"cinder::keystone::service_user::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"cinder::nova::interface\": \"admin\", \"cinder::nova::project_name\": \"service\", \"cinder::nova::auth_type\": \"password\", \"cinder::nova::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri\"]}, \"cinder::nova::password\": {\"get_param\": \"NovaPassword\"}, \"cinder::nova::region_name\": {\"get_param\": \"KeystoneRegion\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(104,'2026-06-09 08:02:07',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (105,'2026-06-09 08:02:07',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Nova base service. Shared for all Nova services.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"NovaPassword\": {\"description\": \"The password for the nova service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"E43sBALvNAsJYgcBpWfsAoz9C\"}, \"NeutronPassword\": {\"description\": \"The password for the neutron service and db account, used by neutron agents.\", \"type\": \"string\", \"hidden\": true, \"default\": \"qzvItA1K3MLllVvkiCWVVbIpy\"}, \"PlacementPassword\": {\"description\": \"The password for the Placement service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"qMFVkTRvhZKx21tsfFHzUpJTe\"}, \"PlacementAPIInterface\": {\"type\": \"string\", \"description\": \"Endpoint interface to be used for the placement API.\\n\", \"default\": \"internal\"}, \"NovaOVSBridge\": {\"default\": \"br-int\", \"description\": \"Name of integration bridge used by Open vSwitch\", \"type\": \"string\"}, \"Debug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debugging on all services.\"}, \"NovaDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Nova services.\", \"type\": \"boolean\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"EnableConfigPurge\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Remove configuration that is not generated by TripleO. Used to avoid configuration remnants after upgrades.\\n\"}, \"UpgradeLevelNovaCompute\": {\"type\": \"string\", \"description\": \"Nova Compute upgrade level\", \"default\": \"\"}, \"NovaOVSDBConnection\": {\"type\": \"string\", \"description\": \"OVS DB connection string to used by Nova\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NovaSyncPowerStateInterval\": {\"type\": \"number\", \"description\": \"Interval to sync power states between the database and the hypervisor. Set to -1 to disable. Setting this to 0 will run at the default rate(60) defined in oslo.service.\", \"default\": 600}, \"RpcUseSSL\": {\"default\": true, \"description\": \"Messaging client subscriber parameter to specify an SSL connection to the messaging host.\\n\", \"type\": \"string\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"NovaCrossAZAttach\": {\"default\": true, \"description\": \"Whether instances can attach cinder volumes from a different availability zone.\", \"type\": \"boolean\"}, \"MemcachedTLS\": {\"default\": true, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}}, \"conditions\": {\"compute_upgrade_level_set\": {\"not\": {\"equals\": [{\"get_param\": \"UpgradeLevelNovaCompute\"}, \"\"]}}, \"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"nova::ovsdb_connection\": \"NovaOVSDBConnection\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"NovaOVSDBConnection\": {\"get_param\": \"NovaOVSDBConnection\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Nova base service.\", \"value\": {\"service_name\": \"nova_base\", \"config_settings\": {\"map_merge\": [{\"nova::my_ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}}}, \"nova::rabbit_use_ssl\": {\"get_param\": \"RpcUseSSL\"}, \"nova::keystone::service_user::send_service_user_token\": true, \"nova::keystone::service_user::project_name\": \"service\", \"nova::keystone::service_user::password\": {\"get_param\": \"NovaPassword\"}, \"nova::keystone::service_user::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"nova::keystone::service_user::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::placement::project_name\": \"service\", \"nova::placement::password\": {\"get_param\": \"PlacementPassword\"}, \"nova::placement::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"nova::placement::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::placement::valid_interfaces\": {\"get_param\": \"PlacementAPIInterface\"}, \"nova::os_region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::logging::debug\": {\"if\": [{\"get_param\": \"NovaDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"nova::purge_config\": {\"get_param\": \"EnableConfigPurge\"}, \"nova::network::neutron::project_name\": \"service\", \"nova::network::neutron::username\": \"neutron\", \"nova::network::neutron::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::dhcp_domain\": \"\", \"nova::network::neutron::password\": {\"get_param\": \"NeutronPassword\"}, \"nova::network::neutron::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"nova::network::neutron::valid_interfaces\": \"internal\", \"nova::glance::valid_interfaces\": \"internal\", \"nova::rabbit_heartbeat_timeout_threshold\": 60, \"nova::cinder_catalog_info\": \"volumev3:cinderv3:internalURL\", \"nova::host\": \"%{hiera(\'fqdn_canonical\')}\", \"nova::notify_on_state_change\": \"vm_and_task_state\", \"nova::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"nova::notification_format\": \"unversioned\", \"nova::network::neutron::auth_type\": \"v3password\", \"nova::db::database_db_max_retries\": -1, \"nova::db::database_max_retries\": -1, \"nova::network::neutron::ovs_bridge\": {\"get_param\": \"NovaOVSBridge\"}, \"nova::compute::sync_power_state_interval\": {\"get_param\": \"NovaSyncPowerStateInterval\"}, \"nova_is_additional_cell\": {\"get_param\": \"NovaAdditionalCell\"}, \"nova::cross_az_attach\": {\"get_param\": \"NovaCrossAZAttach\"}, \"nova::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"nova::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}, \"nova::cache::backend\": {\"if\": [\"tls_cache_enabled\", \"dogpile.cache.pymemcache\", \"dogpile.cache.memcached\"]}, \"nova::rabbit_heartbeat_in_pthread\": false, \"nova::upgrade_level_compute\": {\"if\": [\"compute_upgrade_level_set\", {\"get_param\": \"UpgradeLevelNovaCompute\"}]}}, {\"get_attr\": [\"RoleParametersValue\", \"value\"]}]}, \"service_config_settings\": {\"rabbitmq\": {\"nova::rabbit_use_ssl\": {\"get_param\": \"RpcUseSSL\"}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(106,'2026-06-09 08:02:07',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(107,'2026-06-09 08:02:07',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(108,'2026-06-09 08:02:07',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"SNMP client configured with Puppet, to facilitate Ceilometer Hardware monitoring in the undercloud. This service is required to enable hardware monitoring.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"SnmpdReadonlyUserName\": {\"default\": \"ro_snmp_user\", \"description\": \"The user name for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\"}, \"SnmpdReadonlyUserPassword\": {\"description\": \"The user password for SNMPd with readonly rights running on all Overcloud nodes\", \"type\": \"string\", \"hidden\": true, \"default\": \"IUqJgJKOidh20dco1DYKnuQ1\"}, \"SnmpdBindHost\": {\"description\": \"An array of bind host addresses on which SNMP daemon will listen.\", \"type\": \"comma_delimited_list\", \"default\": [\"udp:161\", \"udp6:[::1]:161\"]}, \"SnmpdOptions\": {\"description\": \"A string containing the commandline options passed to snmpd\", \"type\": \"string\", \"default\": \"-LS0-5d\"}, \"SnmpdIpSubnet\": {\"default\": \"\", \"description\": \"IP address/subnet on the snmpd network. If empty (default), SnmpdNetwork will be taken.\", \"type\": \"string\"}}, \"conditions\": {\"snmpd_network_unset\": {\"equals\": [{\"get_param\": \"SnmpdIpSubnet\"}, \"\"]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the SNMP services\", \"value\": {\"service_name\": \"snmp\", \"firewall_rules\": {\"if\": [\"snmpd_network_unset\", {\"map_merge\": {\"repeat\": {\"for_each\": {\"<%net_cidr%>\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"SnmpdNetwork\"]}]}}, \"template\": {\"124 snmp <%net_cidr%>\": {\"dport\": 161, \"proto\": \"udp\", \"source\": \"<%net_cidr%>\"}}}}}, {\"124 snmp\": {\"dport\": 161, \"proto\": \"udp\", \"source\": {\"get_param\": \"SnmpdIpSubnet\"}}}]}, \"config_settings\": {\"tripleo::profile::base::snmp::snmpd_user\": {\"get_param\": \"SnmpdReadonlyUserName\"}, \"tripleo::profile::base::snmp::snmpd_password\": {\"get_param\": \"SnmpdReadonlyUserPassword\"}, \"snmp::agentaddress\": {\"get_param\": \"SnmpdBindHost\"}, \"snmp::snmpd_options\": {\"get_param\": \"SnmpdOptions\"}}, \"step_config\": \"include tripleo::profile::base::snmp\\n\", \"upgrade_tasks\": [{\"when\": \"step|int == 0\", \"block\": [{\"name\": \"Check if snmpd is enabled\", \"command\": \"systemctl is-enabled --quiet snmpd\", \"failed_when\": false, \"register\": \"snmpd_enabled_result\"}, {\"name\": \"Set fact snmpd_enabled\", \"set_fact\": {\"snmpd_enabled\": \"{{ snmpd_enabled_result.rc == 0 }}\"}}]}, {\"name\": \"Stop snmp service\", \"when\": [\"step|int == 1\", \"snmpd_enabled|bool\"], \"service\": \"name=snmpd state=stopped\"}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(109,'2026-06-09 08:02:07',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Cinder base service. Shared by all Cinder services.\\n\", \"parameters\": {\"CinderStorageAvailabilityZone\": {\"default\": \"nova\", \"description\": \"The Cinder service\'s storage availability zone.\", \"type\": \"string\"}, \"CinderPassword\": {\"description\": \"The password for the cinder service and db account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"CinderDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging on Cinder services.\", \"type\": \"boolean\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"CinderCronDbPurgeMinute\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Minute\\n\", \"default\": \"1\"}, \"CinderCronDbPurgeHour\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Hour\\n\", \"default\": \"0\"}, \"CinderCronDbPurgeMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month Day\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeMonth\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Week Day\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeUser\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - User\\n\", \"default\": \"cinder\"}, \"CinderCronDbPurgeAge\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age\\n\", \"default\": \"30\"}, \"CinderCronDbPurgeDestination\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Log destination\\n\", \"default\": \"/var/log/cinder/cinder-rowsflush.log\"}, \"CinderCronDbPurgeMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Delay\\n\", \"default\": \"3600\"}, \"CinderRpcResponseTimeout\": {\"default\": 60, \"description\": \"Cinder\'s RPC response timeout, in seconds.\", \"type\": \"number\"}, \"NovaPassword\": {\"type\": \"string\", \"description\": \"The password for the nova service and db account\", \"hidden\": true, \"default\": \"E43sBALvNAsJYgcBpWfsAoz9C\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder base service.\", \"value\": {\"service_name\": \"cinder_base\", \"config_settings\": {\"cinder::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"cinder\", \"password\": {\"get_param\": \"CinderPassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/cinder\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"cinder\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"cinder::logging::debug\": {\"if\": [{\"get_param\": \"CinderDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"cinder::storage_availability_zone\": {\"get_param\": \"CinderStorageAvailabilityZone\"}, \"cinder::rabbit_heartbeat_timeout_threshold\": 60, \"cinder::rpc_response_timeout\": {\"get_param\": \"CinderRpcResponseTimeout\"}, \"cinder::rabbit_heartbeat_in_pthread\": false, \"cinder::db::database_db_max_retries\": -1, \"cinder::db::database_max_retries\": -1, \"cinder::cron::db_purge::minute\": {\"get_param\": \"CinderCronDbPurgeMinute\"}, \"cinder::cron::db_purge::hour\": {\"get_param\": \"CinderCronDbPurgeHour\"}, \"cinder::cron::db_purge::monthday\": {\"get_param\": \"CinderCronDbPurgeMonthday\"}, \"cinder::cron::db_purge::month\": {\"get_param\": \"CinderCronDbPurgeMonth\"}, \"cinder::cron::db_purge::weekday\": {\"get_param\": \"CinderCronDbPurgeWeekday\"}, \"cinder::cron::db_purge::user\": {\"get_param\": \"CinderCronDbPurgeUser\"}, \"cinder::cron::db_purge::age\": {\"get_param\": \"CinderCronDbPurgeAge\"}, \"cinder::cron::db_purge::destination\": {\"get_param\": \"CinderCronDbPurgeDestination\"}, \"cinder::cron::db_purge::maxdelay\": {\"get_param\": \"CinderCronDbPurgeMaxDelay\"}, \"cinder::glance::glance_api_servers\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"uri\"]}, \"cinder::keystone::service_user::send_service_user_token\": true, \"cinder::keystone::service_user::project_name\": \"service\", \"cinder::keystone::service_user::auth_type\": \"password\", \"cinder::keystone::service_user::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri\"]}, \"cinder::keystone::service_user::password\": {\"get_param\": \"CinderPassword\"}, \"cinder::keystone::service_user::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"cinder::nova::interface\": \"admin\", \"cinder::nova::project_name\": \"service\", \"cinder::nova::auth_type\": \"password\", \"cinder::nova::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri\"]}, \"cinder::nova::password\": {\"get_param\": \"NovaPassword\"}, \"cinder::nova::region_name\": {\"get_param\": \"KeystoneRegion\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(110,'2026-06-09 08:02:08',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(111,'2026-06-09 08:02:08',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(112,'2026-06-09 08:02:08',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Modular Libvirt Service\\n\", \"parameters\": {\"ContainerNovaLibvirtImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\"}, \"ContainerNovaLibvirtConfigImage\": {\"description\": \"The container image to use for the nova_libvirt config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\"}, \"ContainerNovaLibvirtUlimit\": {\"default\": [\"nofile=131072\", \"nproc=126960\"], \"description\": \"ulimit for Nova Libvirt Container\", \"type\": \"comma_delimited_list\"}, \"ContainerNovaLibvirtPidsLimit\": {\"default\": 65536, \"description\": \"Tune nova_libvirt container PID limit (set to 0 for unlimited) (defaults to 65536)\", \"type\": \"number\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"UseCustomGnuTlsQemuCryptoPolicy\": {\"type\": \"boolean\", \"default\": false, \"description\": \"If set to true, will use CustomGnuTlsQemuCryptoPolicy in crypto policy.\"}, \"CustomGnuTlsQemuCryptoPolicy\": {\"default\": \"QEMU=NONE:+ECDHE-RSA:+ECDHE-ECDSA:+RSA:+DHE-RSA:+GROUP-X25519:+GROUP-X448:+GROUP-SECP256R1:+GROUP-SECP384R1:+GROUP-SECP521R1:+GROUP-FFDHE2048:+GROUP-FFDHE3072:+GROUP-FFDHE4096:+GROUP-FFDHE6144:+GROUP-FFDHE8192:+CHACHA20-POLY1305:+AEAD:+SHA1:+SHA512:+SIGN-ECDSA-SHA256:+SIGN-ECDSA-SECP256R1-SHA256:+SIGN-ECDSA-SHA384:+SIGN-ECDSA-SECP384R1-SHA384:+SIGN-ECDSA-SHA512:+SIGN-ECDSA-SECP521R1-SHA512:+SIGN-EdDSA-Ed25519:+SIGN-EdDSA-Ed448:+SIGN-RSA-PSS-SHA256:+SIGN-RSA-PSS-SHA384:+SIGN-RSA-PSS-SHA512:+SIGN-RSA-PSS-RSAE-SHA256:+SIGN-RSA-PSS-RSAE-SHA384:+SIGN-RSA-PSS-RSAE-SHA512:+SIGN-RSA-SHA256:+SIGN-RSA-SHA384:+SIGN-RSA-SHA512:+VERS-TLS1.3:+VERS-TLS1.2:+VERS-DTLS1.2\", \"description\": \"Custom GnuTls Crypto Policy for QEMU\", \"type\": \"string\"}, \"UseTLSTransportForLiveMigration\": {\"type\": \"boolean\", \"default\": true, \"description\": \"If set to true and if EnableInternalTLS is enabled, it will set the libvirt URI\'s transport to tls and configure the relevant keys for libvirt.\"}, \"NovaEnableRbdBackend\": {\"default\": false, \"description\": \"Whether to enable the Rbd backend for Nova ephemeral storage.\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"CinderEnableRbdBackend\": {\"default\": false, \"description\": \"Whether to enable or not the Rbd backend for Cinder\", \"type\": \"boolean\"}, \"CephClientKey\": {\"description\": \"The Ceph client key. Can be created with ceph-authtool --gen-print-key.\", \"type\": \"string\", \"hidden\": true, \"constraints\": [{\"allowed_pattern\": \"^[a-zA-Z0-9+/]{38}==$\"}], \"default\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\"}, \"CephClusterFSID\": {\"type\": \"string\", \"description\": \"The Ceph cluster FSID. Must be a UUID.\", \"default\": \"141c0b27-2417-411f-ad72-876254cd4eac\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"CinderRbdMultiConfig\": {\"type\": \"json\", \"default\": {}, \"description\": \"Dictionary of settings when configuring multiple RBD backends. The\\nhash key is the backend name, and the value is a dictionary of parameter\\nvalues unique to that backend. The following parameters are required,\\nand must match the corresponding value defined in CephExternalMultiConfig.\\n  CephClusterName (must match the CephExternalMultiConfig entry\'s \'cluster\')\\n  CephClusterFSID (must match the CephExternalMultiConfig entry\'s \'fsid\')\\nThe following parameters are optional, and override the corresponding\\nparameter\'s default value.\\n  CephClientUserName\\n  CinderRbdPoolName\\n  CinderRbdExtraPools\\n  CinderRbdAvailabilityZone\\n  CinderRbdFlattenVolumeFromSnapshot\\n\"}, \"UseTLSTransportForVnc\": {\"type\": \"boolean\", \"default\": true, \"description\": \"If set to true and if EnableInternalTLS is enabled, it will enable TLS transaport for libvirt VNC and configure the relevant keys for libvirt.\"}, \"UseTLSTransportForNbd\": {\"type\": \"boolean\", \"default\": true, \"description\": \"If set to true and if EnableInternalTLS is enabled, it will enable TLS transaport for libvirt NBD and configure the relevant keys for libvirt.\"}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"LibvirtCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"QemuServerCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"QemuClientCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"LibvirtCACert\": {\"type\": \"string\", \"default\": \"\", \"description\": \"This specifies the CA certificate to use for TLS in libvirt. This file will be symlinked to the default CA path in libvirt, which is /etc/pki/CA/cacert.pem. Note that due to limitations GNU TLS, which is the TLS backend for libvirt, the file must be less than 65K (so we can\'t use the system\'s CA bundle). This parameter should be used if the default (which comes from the InternalTLSCAFile parameter) is not desired. The current default reflects TripleO\'s default CA, which is FreeIPA. It will only be used if internal TLS is enabled.\"}, \"QemuCACert\": {\"type\": \"string\", \"default\": \"\", \"description\": \"This specifies the CA certificate to use for qemu. This file will be symlinked to the default CA path, which is /etc/pki/qemu/ca-cert.pem. This parameter should be used if the default (which comes from the InternalTLSCAFile parameter) is not desired. The current default reflects TripleO\'s default CA, which is FreeIPA. It will only be used if internal TLS is enabled.\"}, \"VhostuserSocketGroup\": {\"default\": \"qemu\", \"description\": \"The vhost-user socket directory group name. Defaults to \'qemu\'. When vhostuser mode is \'dpdkvhostuserclient\' (which is the default mode), the vhost socket is created by qemu.\\n\", \"type\": \"string\", \"tags\": [\"role_specific\"]}, \"QemuMemoryBackingDir\": {\"type\": \"string\", \"description\": \"Directory used for memoryBacking source if configured as file. NOTE: big files will be stored here\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NovaComputeLibvirtType\": {\"type\": \"string\", \"default\": \"qemu\"}, \"LibvirtEnabledPerfEvents\": {\"type\": \"comma_delimited_list\", \"default\": [], \"description\": \"This is a performance event list which could be used as monitor. For example - ``enabled_perf_events = cmt, mbml, mbmt`` The supported events list can be found in https://libvirt.org/html/libvirt-libvirt-domain.html , which you may need to search key words ``VIR_PERF_PARAM_*``\"}, \"MonitoringSubscriptionNovaLibvirt\": {\"default\": \"overcloud-nova-libvirt\", \"type\": \"string\"}, \"MigrationSshKey\": {\"type\": \"json\", \"description\": \"SSH key for migration. Expects a dictionary with keys \'public_key\' and \'private_key\'. Values should be identical to SSH public/private key files.\\n\", \"default\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}}, \"MigrationSshPort\": {\"default\": 2022, \"description\": \"Target port for migration over ssh\", \"type\": \"number\"}, \"LibvirtTLSPassword\": {\"description\": \"The password for the libvirt service when TLS is enabled\", \"type\": \"string\", \"hidden\": true, \"default\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\"}, \"QemuDefaultTLSVerify\": {\"description\": \"Whether to enable or disable TLS client certificate verification. Enabling this option will reject any client who does not have a certificate signed by the CA in /etc/pki/qemu/ca-cert.pem\\n\", \"default\": true, \"type\": \"boolean\"}, \"LibvirtLogFilters\": {\"description\": \"Defines a filter in libvirt daemon to select a different logging level for a given category log outputs, as specified in https://libvirt.org/logging.html .\", \"type\": \"string\", \"default\": \"1:libvirt 1:qemu 1:conf 1:security 3:event 3:json 3:file 3:object 1:util\"}, \"LibvirtVirtlogdLogFilters\": {\"description\": \"Defines a filter in virtlogd to select a different logging level for a given category log outputs, as specified in https://libvirt.org/logging.html .\", \"type\": \"string\", \"default\": \"1:logging 4:object 4:json 4:event 1:util\"}, \"LibvirtVirtsecretdLogFilters\": {\"description\": \"Defines a filter in virtsecretd to select a different logging level for a given category log outputs, as specified in https://libvirt.org/logging.html .\", \"type\": \"string\", \"default\": \"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\"}, \"LibvirtVirtnodedevdLogFilters\": {\"description\": \"Defines a filter in virtnodedevd to select a different logging level for a given category log outputs, as specified in https://libvirt.org/logging.html .\", \"type\": \"string\", \"default\": \"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\"}, \"LibvirtVirtstoragedLogFilters\": {\"description\": \"Defines a filter in virtstoraged to select a different logging level for a given category log outputs, as specified in https://libvirt.org/logging.html .\", \"type\": \"string\", \"default\": \"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\"}, \"LibvirtVirtqemudLogFilters\": {\"description\": \"Defines a filter in virtqemud to select a different logging level for a given category log outputs, as specified in https://libvirt.org/logging.html .\", \"type\": \"string\", \"default\": \"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\"}, \"LibvirtVirtproxydLogFilters\": {\"description\": \"Defines a filter in virtproxyd to select a different logging level for a given category log outputs, as specified in https://libvirt.org/logging.html .\", \"type\": \"string\", \"default\": \"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\"}, \"LibvirtTLSPriority\": {\"description\": \"Override the compile time default TLS priority string.\\n\", \"type\": \"string\", \"default\": \"NORMAL:-VERS-SSL3.0:-VERS-TLS-ALL:+VERS-TLS1.2\"}, \"NovaLibvirtOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"NovaEnableVirtlogdContainerWrapper\": {\"description\": \"Generate a virtlogd wrapper script so that virtlogd launches in a separate container and won\'t get restarted e.g. on minor updates.\", \"type\": \"boolean\", \"default\": true}, \"VirtlogdWrapperDebug\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Controls debugging for the wrapper scripts.\"}, \"DeployIdentifier\": {\"default\": 1780992067, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"RbdDiskCachemodes\": {\"type\": \"comma_delimited_list\", \"default\": [\"network=writeback\"], \"description\": \"Disk cachemodes for RBD backend.\\n\"}}, \"conditions\": {\"use_tls_for_live_migration\": {\"and\": [{\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"UseTLSTransportForLiveMigration\"}]}, \"libvirt_specific_ca_set\": {\"not\": {\"equals\": [{\"get_param\": \"LibvirtCACert\"}, \"\"]}}, \"need_libvirt_secret\": {\"or\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaEnableRbdBackend\"]}, true]}, {\"and\": [{\"equals\": [{\"get_param\": [\"RoleParameters\", \"NovaEnableRbdBackend\"]}, \"\"]}, {\"equals\": [{\"get_param\": \"NovaEnableRbdBackend\"}, true]}]}, {\"get_param\": \"CinderEnableRbdBackend\"}]}, \"use_tls_for_vnc\": {\"and\": [{\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"UseTLSTransportForVnc\"}]}, \"libvirt_vnc_specific_ca_set\": {\"not\": {\"equals\": [{\"get_param\": \"LibvirtVncCACert\"}, \"\"]}}, \"use_tls_for_nbd\": {\"and\": [{\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"UseTLSTransportForNbd\"}]}, \"qemu_specific_ca_set\": {\"not\": {\"equals\": [{\"get_param\": \"QemuCACert\"}, \"\"]}}, \"key_size_libvirt_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"LibvirtCertificateKeySize\"}, \"\"]}}, \"key_size_qemu_client_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"QemuClientCertificateKeySize\"}, \"\"]}}, \"key_size_qemu_server_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"QemuServerCertificateKeySize\"}, \"\"]}}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"vhostuser_socket_group\": \"VhostuserSocketGroup\", \"nova_libvirt_opt_volumes\": \"NovaLibvirtOptVolumes\", \"ContainerNovaLibvirtImage\": \"ContainerNovaLibvirtImage\", \"ContainerNovaLibvirtConfigImage\": \"ContainerNovaLibvirtConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"VhostuserSocketGroup\": {\"get_param\": \"VhostuserSocketGroup\"}, \"NovaLibvirtOptVolumes\": {\"get_param\": \"NovaLibvirtOptVolumes\"}, \"ContainerNovaLibvirtImage\": {\"get_param\": \"ContainerNovaLibvirtImage\"}, \"ContainerNovaLibvirtConfigImage\": {\"get_param\": \"ContainerNovaLibvirtConfigImage\"}}}]}}}, \"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"NovaLibvirtLogging\": {\"type\": \"OS::TripleO::Services::Logging::NovaLibvirt\"}, \"NovaBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-base-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"NovaLibvirtCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-common.yaml\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Libvirt service.\", \"value\": {\"service_name\": \"nova_libvirt\", \"firewall_rules\": {\"200 nova_libvirt\": {\"dport\": [16514, \"61152-61215\", \"5900-6923\"]}}, \"ansible_group_vars\": {\"tripleo_nova_libvirt_virsh_container\": \"nova_virtproxyd\"}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionNovaLibvirt\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"NovaBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"RoleParametersValue\", \"value\"]}, {\"get_attr\": [\"NovaLibvirtLogging\", \"config_settings\"]}, {\"get_attr\": [\"NovaLibvirtCommon\", \"config_settings\"]}, {\"nova::compute::libvirt::manage_libvirt_services\": false, \"tripleo::profile::base::nova::virtlogd_wrapper::enable_wrapper\": {\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, \"tripleo::profile::base::nova::virtlogd_wrapper::virtlogd_process_wrapper\": \"/var/lib/container-config-scripts/virtlogd_wrapper\", \"tripleo::profile::base::nova::virtlogd_wrapper::virtlogd_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"tripleo::profile::base::nova::virtlogd_wrapper::debug\": {\"if\": [{\"get_param\": \"VirtlogdWrapperDebug\"}, true, {\"get_attr\": [\"NovaBase\", \"role_data\", \"config_settings\", \"nova::logging::debug\"]}]}, \"nova::compute::libvirt::migration_support\": false, \"nova::compute::rbd::libvirt_images_rbd_ceph_conf\": {\"list_join\": [\"\", [\"/etc/ceph/\", {\"get_param\": \"CephClusterName\"}, \".conf\"]]}, \"nova::compute::rbd::libvirt_rbd_user\": {\"get_param\": \"CephClientUserName\"}, \"tripleo::profile::base::nova::compute_libvirt_shared::nova_rbd_ceph_conf_path\": {\"get_param\": \"CephConfigPath\"}, \"nova::compute::rbd::rbd_keyring\": {\"list_join\": [\".\", [\"client\", {\"get_param\": \"CephClientUserName\"}]]}, \"nova::compute::rbd::libvirt_rbd_secret_key\": {\"get_param\": \"CephClientKey\"}, \"nova::compute::rbd::libvirt_rbd_secret_uuid\": {\"get_param\": \"CephClusterFSID\"}, \"tripleo::profile::base::nova::migration::client::libvirt_enabled\": true, \"tripleo::profile::base::nova::migration::client::ssh_private_key\": {\"get_param\": [\"MigrationSshKey\", \"private_key\"]}, \"tripleo::profile::base::nova::migration::client::ssh_port\": {\"get_param\": \"MigrationSshPort\"}, \"nova::compute::libvirt::services::libvirt_virt_type\": {\"get_param\": \"NovaComputeLibvirtType\"}, \"nova::compute::libvirt::virt_type\": {\"get_param\": \"NovaComputeLibvirtType\"}, \"nova::compute::libvirt::enabled_perf_events\": {\"get_param\": \"LibvirtEnabledPerfEvents\"}, \"nova::compute::libvirt::qemu::configure_qemu\": true, \"nova::compute::libvirt::qemu::max_files\": 32768, \"nova::compute::libvirt::qemu::max_processes\": 131072, \"nova::migration::qemu::configure_qemu\": true, \"nova::migration::qemu::migration_port_min\": 61152, \"nova::migration::qemu::migration_port_max\": 61215, \"nova::compute::libvirt::vncserver_listen\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"nova::compute::libvirt::log_filters\": {\"get_param\": \"LibvirtLogFilters\"}, \"nova::compute::libvirt::virtlogd::log_filters\": {\"get_param\": \"LibvirtVirtlogdLogFilters\"}, \"rbd_persistent_storage\": {\"get_param\": \"CinderEnableRbdBackend\"}, \"rbd_disk_cachemodes\": {\"get_param\": \"RbdDiskCachemodes\"}, \"nova::compute::libvirt::virtsecretd::log_filters\": {\"get_param\": \"LibvirtVirtsecretdLogFilters\"}, \"nova::compute::libvirt::virtnodedevd::log_filters\": {\"get_param\": \"LibvirtVirtnodedevdLogFilters\"}, \"nova::compute::libvirt::virtstoraged::log_filters\": {\"get_param\": \"LibvirtVirtstoragedLogFilters\"}, \"nova::compute::libvirt::virtqemud::log_filters\": {\"get_param\": \"LibvirtVirtqemudLogFilters\"}, \"nova::compute::libvirt::virtproxyd::log_filters\": {\"get_param\": \"LibvirtVirtproxydLogFilters\"}, \"tripleo::profile::base::nova::libvirt::modular_libvirt\": true, \"nova::compute::libvirt::services::modular_libvirt\": true, \"nova::compute::libvirt::modular_libvirt\": true, \"nova::migration::libvirt::modular_libvirt\": true}, {\"if\": [\"use_tls_for_live_migration\", {\"tripleo::profile::base::nova::migration::client::libvirt_tls\": true, \"tripleo::profile::base::nova::libvirt::tls_password\": {\"get_param\": [\"LibvirtTLSPassword\"]}, \"nova::compute::libvirt::qemu::default_tls_verify\": {\"get_param\": \"QemuDefaultTLSVerify\"}, \"nova::compute::libvirt::tls_priority\": {\"get_param\": \"LibvirtTLSPriority\"}, \"nova::migration::libvirt::listen_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"nova::migration::libvirt::live_migration_inbound_addr\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}}, {\"nova::migration::libvirt::live_migration_inbound_addr\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}}]}, {\"if\": [\"use_tls_for_vnc\", {\"nova::compute::libvirt::qemu::vnc_tls\": true, \"nova::compute::libvirt::qemu::vnc_tls_verify\": true}]}, {\"if\": [\"use_tls_for_nbd\", {\"nova::compute::libvirt::qemu::nbd_tls\": true, \"nova::migration::libvirt::live_migration_with_native_tls\": true}]}]}, \"puppet_config\": {\"config_volume\": \"nova_libvirt\", \"puppet_tags\": \"libvirtd_config,virtlogd_config,virtproxyd_config,virtqemud_config,virtnodedevd_config,virtsecretd_config,virtstoraged_config,nova_config,file,libvirt_tls_password\", \"step_config\": \"include tripleo::profile::base::nova::libvirt\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/nova_virtlogd.json\": {\"command\": {\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, \"/usr/local/bin/virtlogd_wrapper\", \"/usr/sbin/virtlogd --config /etc/libvirt/virtlogd.conf\"]}, \"config_files\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_permissions\"]}}, \"/var/lib/kolla/config_files/nova_virtsecretd.json\": {\"command\": \"/usr/sbin/virtsecretd --config /etc/libvirt/virtsecretd.conf\", \"config_files\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_permissions\"]}}, \"/var/lib/kolla/config_files/nova_virtnodedevd.json\": {\"command\": \"/usr/sbin/virtnodedevd --config /etc/libvirt/virtnodedevd.conf\", \"config_files\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_permissions\"]}}, \"/var/lib/kolla/config_files/nova_virtstoraged.json\": {\"command\": \"/usr/sbin/virtstoraged --config /etc/libvirt/virtstoraged.conf\", \"config_files\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_permissions\"]}}, \"/var/lib/kolla/config_files/nova_virtqemud.json\": {\"command\": \"/usr/sbin/virtqemud --config /etc/libvirt/virtqemud.conf\", \"config_files\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_permissions\"]}}, \"/var/lib/kolla/config_files/nova_virtproxyd.json\": {\"command\": \"/usr/sbin/virtproxyd --config /etc/libvirt/virtproxyd.conf\", \"config_files\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"NovaLibvirtCommon\", \"kolla_permissions\"]}}}, \"container_config_scripts\": {\"nova_libvirt_init_secret.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/nova_libvirt_init_secret.sh\"}}}, \"docker_config\": {\"step_2\": {\"nova_virtqemud_init_logs\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"net\": \"none\", \"privileged\": true, \"security_opt\": [\"label=level:s0\", \"label=type:spc_t\", \"label=filetype:container_file_t\"], \"user\": \"root\", \"volumes\": [\"/var/log/containers/libvirt/swtpm:/var/log/swtpm:shared,z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R tss:tss /var/log/swtpm\"], \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}, \"create_virtlogd_wrapper\": {\"start_order\": 1, \"detach\": false, \"cgroupns\": \"host\", \"net\": \"host\", \"pid\": \"host\", \"user\": \"root\", \"command\": {\"list_concat\": [[\"/container_puppet_apply.sh\", \"4\", \"file\", \"include ::tripleo::profile::base::nova::virtlogd_wrapper\"]]}, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"container_puppet_apply_volumes\"]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:shared,z\"]]}, \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}}, \"step_3\": {\"map_merge\": [{\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, {\"nova_virtlogd_wrapper\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"ulimit\": {\"get_param\": \"ContainerNovaLibvirtUlimit\"}, \"cgroupns\": \"host\", \"net\": \"host\", \"pid\": \"host\", \"privileged\": true, \"security_opt\": [\"label=level:s0\", \"label=type:spc_t\", \"label=filetype:container_file_t\"], \"restart\": \"always\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtLogging\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/nova_virtlogd.json:/var/lib/kolla/config_files/config.json:ro\"], {\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, [\"/var/lib/container-config-scripts/virtlogd_wrapper:/usr/local/bin/virtlogd_wrapper:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}, {\"nova_virtlogd\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"ulimit\": {\"get_param\": \"ContainerNovaLibvirtUlimit\"}, \"cgroupns\": \"host\", \"net\": \"host\", \"pid\": \"host\", \"privileged\": true, \"security_opt\": [\"label=level:s0\", \"label=type:spc_t\", \"label=filetype:container_file_t\"], \"restart\": \"always\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtLogging\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/nova_virtlogd.json:/var/lib/kolla/config_files/config.json:ro\"], {\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, [\"/var/lib/container-config-scripts/virtlogd_wrapper:/usr/local/bin/virtlogd_wrapper:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}]}, {\"nova_virtsecretd\": {\"start_order\": 1, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"ulimit\": {\"get_param\": \"ContainerNovaLibvirtUlimit\"}, \"cgroupns\": \"host\", \"net\": \"host\", \"pid\": \"host\", \"pids_limit\": {\"get_param\": \"ContainerNovaLibvirtPidsLimit\"}, \"privileged\": true, \"security_opt\": [\"label=level:s0\", \"label=type:spc_t\", \"label=filetype:container_file_t\"], \"restart\": \"always\", \"depends_on\": [{\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, \"tripleo_nova_virtlogd_wrapper.service\", \"tripleo_nova_virtlogd.service\"]}], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtLogging\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtCommon\", \"volumes\"]}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_libvirt_opt_volumes\"]}, [\"/var/lib/kolla/config_files/nova_virtsecretd.json:/var/lib/kolla/config_files/config.json:ro\"]]}}}, {\"nova_virtnodedevd\": {\"start_order\": 2, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"ulimit\": {\"get_param\": \"ContainerNovaLibvirtUlimit\"}, \"cgroupns\": \"host\", \"net\": \"host\", \"pid\": \"host\", \"pids_limit\": {\"get_param\": \"ContainerNovaLibvirtPidsLimit\"}, \"privileged\": true, \"security_opt\": [\"label=level:s0\", \"label=type:spc_t\", \"label=filetype:container_file_t\"], \"restart\": \"always\", \"depends_on\": [{\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, \"tripleo_nova_virtlogd_wrapper.service\", \"tripleo_nova_virtlogd.service\"]}], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtLogging\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtCommon\", \"volumes\"]}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_libvirt_opt_volumes\"]}, [\"/var/lib/kolla/config_files/nova_virtnodedevd.json:/var/lib/kolla/config_files/config.json:ro\"]]}}}, {\"nova_virtstoraged\": {\"start_order\": 3, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"ulimit\": {\"get_param\": \"ContainerNovaLibvirtUlimit\"}, \"cgroupns\": \"host\", \"net\": \"host\", \"pid\": \"host\", \"pids_limit\": {\"get_param\": \"ContainerNovaLibvirtPidsLimit\"}, \"privileged\": true, \"security_opt\": [\"label=level:s0\", \"label=type:spc_t\", \"label=filetype:container_file_t\"], \"restart\": \"always\", \"depends_on\": [{\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, \"tripleo_nova_virtlogd_wrapper.service\", \"tripleo_nova_virtlogd.service\"]}], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtLogging\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtCommon\", \"volumes\"]}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_libvirt_opt_volumes\"]}, [\"/var/lib/kolla/config_files/nova_virtstoraged.json:/var/lib/kolla/config_files/config.json:ro\"]]}}}, {\"nova_virtqemud\": {\"start_order\": 4, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"ulimit\": {\"get_param\": \"ContainerNovaLibvirtUlimit\"}, \"cgroupns\": \"host\", \"net\": \"host\", \"pid\": \"host\", \"pids_limit\": {\"get_param\": \"ContainerNovaLibvirtPidsLimit\"}, \"privileged\": true, \"security_opt\": [\"label=level:s0\", \"label=type:spc_t\", \"label=filetype:container_file_t\"], \"restart\": \"always\", \"depends_on\": [{\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, \"tripleo_nova_virtlogd_wrapper.service\", \"tripleo_nova_virtlogd.service\"]}], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtLogging\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtCommon\", \"volumes\"]}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_libvirt_opt_volumes\"]}, [\"/var/lib/kolla/config_files/nova_virtqemud.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/log/containers/libvirt/swtpm:/var/log/swtpm:z\", {\"if\": [{\"get_param\": \"UseCustomGnuTlsQemuCryptoPolicy\"}, \"/etc/crypto-policies:/etc/crypto-policies:ro\"]}]]}}}, {\"nova_virtproxyd\": {\"start_order\": 5, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"ulimit\": {\"get_param\": \"ContainerNovaLibvirtUlimit\"}, \"cgroupns\": \"host\", \"net\": \"host\", \"pid\": \"host\", \"pids_limit\": {\"get_param\": \"ContainerNovaLibvirtPidsLimit\"}, \"privileged\": true, \"security_opt\": [\"label=level:s0\", \"label=type:spc_t\", \"label=filetype:container_file_t\"], \"restart\": \"always\", \"depends_on\": [{\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, \"tripleo_nova_virtlogd_wrapper.service\", \"tripleo_nova_virtlogd.service\"]}], \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtLogging\", \"volumes\"]}, {\"get_attr\": [\"NovaLibvirtCommon\", \"volumes\"]}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova_libvirt_opt_volumes\"]}, [\"/var/lib/kolla/config_files/nova_virtproxyd.json:/var/lib/kolla/config_files/config.json:ro\"]]}}}]}, \"step_4\": {\"if\": [\"need_libvirt_secret\", {\"nova_libvirt_init_secret\": {\"detach\": false, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}, \"security_opt\": [\"label=disable\"], \"privileged\": false, \"user\": \"root\", \"cgroupns\": \"host\", \"net\": \"host\", \"environment\": {\"LIBVIRT_DEFAULT_URI\": \"qemu:///system\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/nova_libvirt/etc/nova:/etc/nova\", \"/etc/libvirt:/etc/libvirt\", \"/run/libvirt:/run/libvirt:shared,z\", \"/var/lib/libvirt:/var/lib/libvirt:shared\", \"/var/lib/container-config-scripts/nova_libvirt_init_secret.sh:/nova_libvirt_init_secret.sh:ro\", {\"str_replace\": {\"template\": \"HOST_CEPH:/etc/ceph:ro\", \"params\": {\"HOST_CEPH\": {\"get_param\": \"CephConfigPath\"}}}}]]}, \"command\": {\"list_join\": [\" \", [{\"str_replace\": {\"template\": \"/nova_libvirt_init_secret.sh CLUSTER:USER\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}], {\"repeat\": {\"template\": \"<%ceph_info%>\", \"for_each\": {\"<%ceph_info%>\": {\"yaql\": {\"expression\": \"let(u => $.data.default_user) -> $.data.multiconfig.values().select($.CephClusterName + \\\":\\\" + $.get(\\\"CephClientUserName\\\", $u))\", \"data\": {\"default_user\": {\"get_param\": \"CephClientUserName\"}, \"multiconfig\": {\"get_param\": \"CinderRbdMultiConfig\"}}}}}}}]}}}]}}, \"deploy_steps_tasks\": {\"list_concat\": [[{\"name\": \"Ensure recovery of containerized virtqemud\", \"when\": \"step|int == 4\", \"become\": true, \"block\": [{\"name\": \"Create virtqemud recovery script\", \"copy\": {\"dest\": \"/usr/libexec/recover_tripleo_nova_virtqemud.sh\", \"mode\": \"0755\", \"content\": \"#!/bin/bash\\npgrep -f /sbin/virtqemud\\n[ $? -eq 0 ] && exit 0\\nkill -9 $(cat /run/nova_virtqemud.pid)\\n\"}}, {\"name\": \"Create virtqemud recovery trigger service\", \"copy\": {\"dest\": \"/etc/systemd/system/tripleo_nova_virtqemud_recover.service\", \"mode\": \"0644\", \"content\": \"[Unit]\\nDescription=Check and recover tripleo_nova_virtqemud\\nAfter=tripleo_nova_virtqemud.service\\nRequisite=tripleo_nova_virtqemud.service\\n[Service]\\nType=oneshot\\nExecStart=bash /usr/libexec/recover_tripleo_nova_virtqemud.sh\\nSyslogIdentifier=recover_tripleo_nova_virtqemud\\n[Install]\\nWantedBy=multi-user.target\\n\"}}, {\"name\": \"Create virtqemud recovery trigger timer\", \"copy\": {\"dest\": \"/etc/systemd/system/tripleo_nova_virtqemud_recover.timer\", \"mode\": \"0644\", \"content\": \"[Unit]\\nDescription=Check and recover tripleo_nova_virtqemud every 10m\\nPartOf=tripleo_nova_virtqemud.service\\n[Timer]\\nOnCalendar=*:5/10\\nOnActiveSec=120\\nOnUnitActiveSec=60\\nRandomizedDelaySec=1m\\n[Install]\\nWantedBy=timers.target\\n\"}}, {\"name\": \"Enable virtqemud recovery trigger service\", \"systemd\": {\"name\": \"tripleo_nova_virtqemud_recover.service\", \"enabled\": true, \"daemon_reload\": true}}, {\"name\": \"Enable virtqemud recovery trigger timer\", \"systemd\": {\"name\": \"tripleo_nova_virtqemud_recover.timer\", \"enabled\": true, \"state\": \"restarted\", \"daemon_reload\": true}, \"register\": \"virtqemud_recover_timer_result\"}, {\"name\": \"Really enable virtqemud recovery trigger timer\", \"shell\": {\"cmd\": \"systemctl enable --now tripleo_nova_virtqemud_recover.timer\"}, \"when\": \"virtqemud_recover_timer_result.status.UnitFileState != \\\"enabled\\\"\"}]}], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [{\"name\": \"Certificate generation\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [\"/etc/pki/libvirt\", \"/etc/pki/libvirt/private\", \"/etc/pki/qemu\"]}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"libvirt-server-cert\", \"dns\": {\"str_replace\": {\"template\": \"{{fqdn_$NETWORK}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"principal\": {\"str_replace\": {\"template\": \"libvirt/{{fqdn_$NETWORK}}@{{idm_realm}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"run_after\": {\"str_replace\": {\"template\": \"# Copy cert and key to libvirt dirs\\ncp CACERT /etc/pki/CA/cacert.pem\\nchown root:root /etc/pki/CA/cacert.pem\\nchmod 644 /etc/pki/CA/cacert.pem\\ncp /etc/pki/tls/certs/libvirt-server-cert.crt /etc/pki/libvirt/servercert.pem\\ncp /etc/pki/tls/private/libvirt-server-cert.key /etc/pki/libvirt/private/serverkey.pem\\npodman exec nova_virtproxyd virt-admin server-update-tls virtproxyd || systemctl reload tripleo_nova_virtproxyd\\n\", \"params\": {\"CACERT\": {\"if\": [\"libvirt_specific_ca_set\", {\"get_param\": \"LibvirtCACert\"}, {\"get_param\": \"InternalTLSCAFile\"}]}}}}, \"key_size\": {\"if\": [\"key_size_libvirt_override_set\", {\"get_param\": \"LibvirtCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, {\"name\": \"libvirt-client-cert\", \"dns\": {\"str_replace\": {\"template\": \"{{fqdn_$NETWORK}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"principal\": {\"str_replace\": {\"template\": \"libvirt/{{fqdn_$NETWORK}}@{{idm_realm}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"run_after\": \"# Copy cert and key to libvirt dirs\\ncp /etc/pki/tls/certs/libvirt-client-cert.crt /etc/pki/libvirt/clientcert.pem\\ncp /etc/pki/tls/private/libvirt-client-cert.key /etc/pki/libvirt/private/clientkey.pem\\npodman exec nova_virtproxyd virt-admin server-update-tls virtproxyd || systemctl reload tripleo_nova_virtproxyd\\n\", \"key_size\": {\"if\": [\"key_size_libvirt_override_set\", {\"get_param\": \"LibvirtCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, {\"name\": \"qemu-server-cert\", \"owner\": \"root\", \"group\": \"qemu\", \"dns\": {\"str_replace\": {\"template\": \"{{fqdn_$NETWORK}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"principal\": {\"str_replace\": {\"template\": \"qemu/{{fqdn_$NETWORK}}@{{idm_realm}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"run_after\": {\"str_replace\": {\"template\": \"# Copy cert and key to qemu dir\\ncp CACERT /etc/pki/qemu/ca-cert.pem\\nchown root:root /etc/pki/qemu/ca-cert.pem\\nchmod 644 /etc/pki/qemu/ca-cert.pem\\ncp -a /etc/pki/tls/certs/qemu-server-cert.crt /etc/pki/qemu/server-cert.pem\\ncp -a /etc/pki/tls/private/qemu-server-cert.key /etc/pki/qemu/server-key.pem\\nchgrp qemu /etc/pki/qemu/server-*\\nchmod 0640 /etc/pki/qemu/server-cert.pem\\nchmod 0640 /etc/pki/qemu/server-key.pem\\n\", \"params\": {\"CACERT\": {\"if\": [\"qemu_specific_ca_set\", {\"get_param\": \"QemuCACert\"}, {\"get_param\": \"InternalTLSCAFile\"}]}}}}, \"key_size\": {\"if\": [\"key_size_qemu_server_override_set\", {\"get_param\": \"QemuServerCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, {\"name\": \"qemu-client-cert\", \"owner\": \"root\", \"group\": \"qemu\", \"dns\": {\"str_replace\": {\"template\": \"{{fqdn_$NETWORK}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"principal\": {\"str_replace\": {\"template\": \"qemu/{{fqdn_$NETWORK}}@{{idm_realm}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}}}}, \"run_after\": \"# Copy cert and key to qemu dir\\ncp -a /etc/pki/tls/certs/qemu-client-cert.crt /etc/pki/qemu/client-cert.pem\\ncp -a /etc/pki/tls/private/qemu-client-cert.key /etc/pki/qemu/client-key.pem\\nchgrp qemu /etc/pki/qemu/client-*\\nchmod 0640 /etc/pki/qemu/client-cert.pem\\nchmod 0640 /etc/pki/qemu/client-key.pem\\n\", \"key_size\": {\"if\": [\"key_size_qemu_client_override_set\", {\"get_param\": \"QemuClientCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}]}}]}]]}, [{\"name\": \"Set up systemd target for libvirt services\", \"when\": \"step|int == 4\", \"block\": [{\"name\": \"Create systemd file\", \"copy\": {\"dest\": \"/etc/systemd/system/tripleo_nova_libvirt.target\", \"mode\": \"0644\", \"owner\": \"root\", \"group\": \"root\", \"content\": \"[Unit]\\nWants=tripleo_nova_virtsecretd.service\\nWants=tripleo_nova_virtnodedevd.service\\nWants=tripleo_nova_virtstoraged.service\\nWants=tripleo_nova_virtproxyd.service\\nWants=tripleo_nova_virtqemud.service\\nAfter=tripleo_nova_virtsecretd.service\\nAfter=tripleo_nova_virtnodedevd.service\\nAfter=tripleo_nova_virtstoraged.service\\nAfter=tripleo_nova_virtproxyd.service\\nAfter=tripleo_nova_virtqemud.service\\n\"}, \"become\": true, \"register\": \"libvirt_target_result\"}, {\"name\": \"Reload systemd\", \"systemd\": {\"name\": \"tripleo_nova_libvirt.target\", \"enabled\": true, \"state\": \"restarted\", \"daemon_reload\": true}, \"become\": true, \"when\": \"libvirt_target_result.changed\"}]}]]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"NovaLibvirtLogging\", \"host_prep_tasks\"]}, [{\"name\": \"create libvirt persistent data directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype | default(omit) }}\", \"mode\": \"{{ item.mode | default(omit) }}\"}, \"with_items\": [{\"path\": \"/etc/libvirt\", \"setype\": \"container_file_t\"}, {\"path\": \"/etc/libvirt/secrets\", \"setype\": \"container_file_t\"}, {\"path\": \"/etc/libvirt/qemu\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/lib/libvirt\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/cache/libvirt\"}, {\"path\": \"/var/lib/nova\", \"setype\": \"container_file_t\"}, {\"path\": \"/run/libvirt\"}, {\"path\": \"/var/log/containers/libvirt/swtpm\", \"setype\": \"container_file_t\", \"mode\": \"0770\"}]}, {\"name\": \"ensure qemu group is present on the host\", \"group\": {\"name\": \"qemu\", \"gid\": 107, \"state\": \"present\"}}, {\"name\": \"ensure qemu user is present on the host\", \"user\": {\"name\": \"qemu\", \"uid\": 107, \"group\": \"qemu\", \"state\": \"present\", \"shell\": \"/sbin/nologin\", \"comment\": \"qemu user\"}}, {\"name\": \"create directory for vhost-user sockets with qemu ownership\", \"file\": {\"path\": \"/var/lib/vhost_sockets\", \"state\": \"directory\", \"owner\": \"qemu\", \"group\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"vhostuser_socket_group\"]}, \"setype\": \"virt_cache_t\", \"seuser\": \"system_u\"}}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}, {\"name\": \"check if libvirt is installed\", \"command\": \"/usr/bin/rpm -q libvirt-daemon\", \"failed_when\": false, \"register\": \"libvirt_installed\", \"check_mode\": false}, {\"name\": \"make sure libvirt services are disabled and masked\", \"service\": {\"name\": \"{{ item }}\", \"state\": \"stopped\", \"enabled\": false, \"masked\": true, \"daemon_reload\": true}, \"with_items\": [\"libvirtd.service\", \"virtlogd.socket\"], \"when\": \"libvirt_installed.rc == 0\"}, {\"name\": \"ensure /run/libvirt is present upon reboot\", \"copy\": {\"dest\": \"/etc/tmpfiles.d/run-libvirt.conf\", \"content\": \"d /run/libvirt 0755 root root - -\\n\"}}, {\"name\": \"Enable os_enable_vtpm SELinux boolean for vTPM\", \"seboolean\": {\"name\": \"os_enable_vtpm\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}, {\"if\": [{\"get_param\": \"UseCustomGnuTlsQemuCryptoPolicy\"}, [{\"name\": \"set gnutls_qemu_config_crypto_policy fact\", \"set_fact\": {\"gnutls_qemu_config_crypto_policy\": {\"get_param\": \"CustomGnuTlsQemuCryptoPolicy\"}}}, {\"name\": \"create gnutls-qemu.config\", \"copy\": {\"dest\": \"/etc/crypto-policies/local.d/gnutls-qemu.config\", \"mode\": \"0644\", \"owner\": \"root\", \"group\": \"root\", \"content\": \"{{ gnutls_qemu_config_crypto_policy }}\\n\"}, \"register\": \"update_gnutls_config\"}], [{\"name\": \"remove gnutls-qemu.config\", \"file\": {\"path\": \"/etc/crypto-policies/local.d/gnutls-qemu.config\", \"state\": \"absent\"}, \"register\": \"update_gnutls_config\"}]]}, {\"name\": \"update crypto policies\", \"command\": \"update-crypto-policies\", \"when\": \"update_gnutls_config.changed\"}]]}, \"metadata_settings\": {\"list_concat\": [{\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [{\"service\": \"libvirt\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}, \"type\": \"node\"}, {\"service\": \"qemu\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}, \"type\": \"node\"}, {\"service\": \"libvirt-vnc\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"NovaLibvirtNetwork\"]}, \"type\": \"node\"}]]}]}, \"upgrade_tasks\": {\"list_concat\": [[{\"name\": \"Fail if we are on RHEL8 as this is monolithic libvirt deployment\", \"when\": [\"step|int == 0\", \"\'system_upgrade\' not in ansible_run_tags\", \"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\"], \"fail\": {\"msg\": \"Use of the Modular Libvirt deployment on RHEL8 results in loss of workloads. Use NovaLibvirtLegacy in roles data.\"}}, {\"name\": \"nova_libvirt_container_tmpfile_cleanup\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Remove old tmpfiles.d config\", \"file\": {\"path\": \"/etc/tmpfiles.d/var-run-libvirt.conf\", \"state\": \"absent\"}}]}, {\"name\": \"Get container virtlogd image\", \"when\": \"step|int == 1\", \"tags\": \"always\", \"set_fact\": {\"virtlogd_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtImage\"]}}}, {\"name\": \"Force pull image novalibvirt\", \"when\": [\"step|int == 1\"], \"containers.podman.podman_image\": {\"name\": \"{{ virtlogd_image }}\", \"force\": true}}, {\"name\": \"Diff OS release in container image and baremetal\", \"when\": \"step|int == 1\", \"shell\": \"diff /etc/redhat-release <(podman run {{ virtlogd_image }} cat /etc/redhat-release)\\n\", \"args\": {\"executable\": \"/bin/bash\"}, \"failed_when\": false, \"register\": \"libvirt_ubi_diff\"}, {\"name\": \"Fail if UBI of the container does not match RHEL of running host\", \"when\": [\"\'system_upgrade\' not in ansible_run_tags\", \"step|int == 1\", \"libvirt_ubi_diff.rc == 1\"], \"fail\": {\"msg\": \"The host operating system versus container UBI does not match.\\n{{ libvirt_ubi_diff.stdout }}\\nMost likely container passed to NovaLibvirt was EL8 one.\\nYou have to pass the correct container for container-image-prepare.\\nIf you would continue all running workloads would get destroyed.\\n\"}}], {\"if\": [{\"get_param\": \"NovaEnableVirtlogdContainerWrapper\"}, [{\"name\": \"Switch virtlogd image before system upgrade\", \"when\": \"step|int == 1\", \"tags\": [\"never\", \"system_upgrade\"], \"block\": [{\"name\": \"Get running image version\", \"shell\": \"podman ps --filter name=^nova_virtlogd$ --format \\\"{% raw %}{{ .Image }}{% endraw %}\\\"\\n\", \"register\": \"old_virtlogd_image\"}, {\"name\": \"Switch running image to new image in wrapper script\", \"shell\": \"set -o pipefail\\nsed -i -e \'s|{{ old_virtlogd_image.stdout }}|{{ virtlogd_image }}|\' /var/lib/container-config-scripts/virtlogd_wrapper\\n\", \"when\": [\"old_virtlogd_image.stdout != virtlogd_image\", \"old_virtlogd_image.stdout != \'\'\"]}]}]]}]}, \"update_tasks\": {\"list_concat\": [{\"get_attr\": [\"NovaLibvirtCommon\", \"update_tasks\"]}, [{\"name\": \"nova_libvirt_container_tmpfile_cleanup\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Remove old tmpfiles.d config\", \"file\": {\"path\": \"/etc/tmpfiles.d/var-run-libvirt.conf\", \"state\": \"absent\"}}]}]]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (113,'2026-06-09 08:02:08',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(114,'2026-06-09 08:02:08',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Template for nova\'s logging to files\\n\", \"parameters\": {\"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerNovaImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"]}, \"NovaServiceName\": {\"description\": \"service name\", \"type\": \"string\"}, \"DeployIdentifier\": {\"default\": 1780992067, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}}, \"resources\": {\"InitLogContainerName\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"string\", \"value\": {\"str_replace\": {\"template\": \"nova_SERVICE_init_log\", \"params\": {\"SERVICE\": {\"get_param\": \"NovaServiceName\"}}}}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerNovaImage\": \"ContainerNovaImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerNovaImage\": {\"get_param\": \"ContainerNovaImage\"}}}]}}}}, \"outputs\": {\"cmd_extra_args\": {\"description\": \"Extra command line arguments for running the service in the container.\", \"value\": \"\"}, \"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/nova:/var/log/nova\"]}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_2\": {\"map_replace\": [{\"CONTAINERNAME\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/nova:/var/log/nova:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R nova:nova /var/log/nova\"], \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}}, {\"keys\": {\"CONTAINERNAME\": {\"get_attr\": [\"InitLogContainerName\", \"value\"]}}}]}}}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"setype\": \"{{ item.setype }}\", \"state\": \"directory\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/nova\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ContainerNovaImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"NovaServiceName\": \"compute\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(115,'2026-06-09 08:02:08',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Nova libvirt service\\n\", \"parameters\": {\"Debug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debugging on all services.\"}, \"LibvirtDebug\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Set to True to enable debugging libvirt services.\"}, \"LibvirtLogLevel\": {\"default\": 3, \"description\": \"Defines log level in libvirt to filter log output. See https://libvirt.org/logging.html to find its detail.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1, \"max\": 4}}]}, \"LibvirtVirtlogdLogLevel\": {\"default\": 3, \"description\": \"Defines log level in virtlogd to filter log output. See https://libvirt.org/logging.html to find its detail.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1, \"max\": 4}}]}, \"LibvirtVirtsecretdLogLevel\": {\"default\": 3, \"description\": \"Defines log level in virtsecretd to filter log output. See https://libvirt.org/logging.html to find its detail.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1, \"max\": 4}}]}, \"LibvirtVirtnodedevdLogLevel\": {\"default\": 3, \"description\": \"Defines log level in virtnodedevd to filter log output. See https://libvirt.org/logging.html to find its detail.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1, \"max\": 4}}]}, \"LibvirtVirtqemudLogLevel\": {\"default\": 3, \"description\": \"Defines log level in virtqemud to filter log output. See https://libvirt.org/logging.html to find its detail.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1, \"max\": 4}}]}, \"LibvirtVirtproxydLogLevel\": {\"default\": 3, \"description\": \"Defines log level in virtproxyd to filter log output. See https://libvirt.org/logging.html to find its detail.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1, \"max\": 4}}]}, \"LibvirtVirtstoragedLogLevel\": {\"default\": 3, \"description\": \"Defines log level in virtstoraged to filter log output. See https://libvirt.org/logging.html to find its detail.\", \"type\": \"number\", \"constraints\": [{\"range\": {\"min\": 1, \"max\": 4}}]}}, \"outputs\": {\"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": {\"nova::compute::libvirt::log_outputs\": {\"str_replace\": {\"template\": \"LEVEL:file:/var/log/libvirt/libvirtd.log\", \"params\": {\"LEVEL\": {\"if\": [{\"or\": [{\"get_param\": \"Debug\"}, {\"get_param\": \"LibvirtDebug\"}]}, 1, {\"get_param\": \"LibvirtLogLevel\"}]}}}}, \"nova::compute::libvirt::virtlogd::log_outputs\": {\"str_replace\": {\"template\": \"LEVEL:file:/var/log/libvirt/virtlogd.log\", \"params\": {\"LEVEL\": {\"if\": [{\"or\": [{\"get_param\": \"Debug\"}, {\"get_param\": \"LibvirtDebug\"}]}, 1, {\"get_param\": \"LibvirtVirtlogdLogLevel\"}]}}}}, \"nova::compute::libvirt::virtsecretd::log_outputs\": {\"str_replace\": {\"template\": \"LEVEL:file:/var/log/libvirt/virtsecretd.log\", \"params\": {\"LEVEL\": {\"if\": [{\"or\": [{\"get_param\": \"Debug\"}, {\"get_param\": \"LibvirtDebug\"}]}, 1, {\"get_param\": \"LibvirtVirtsecretdLogLevel\"}]}}}}, \"nova::compute::libvirt::virtnodedevd::log_outputs\": {\"str_replace\": {\"template\": \"LEVEL:file:/var/log/libvirt/virtnodedevd.log\", \"params\": {\"LEVEL\": {\"if\": [{\"or\": [{\"get_param\": \"Debug\"}, {\"get_param\": \"LibvirtDebug\"}]}, 1, {\"get_param\": \"LibvirtVirtnodedevdLogLevel\"}]}}}}, \"nova::compute::libvirt::virtqemud::log_outputs\": {\"str_replace\": {\"template\": \"LEVEL:file:/var/log/libvirt/virtqemud.log\", \"params\": {\"LEVEL\": {\"if\": [{\"or\": [{\"get_param\": \"Debug\"}, {\"get_param\": \"LibvirtDebug\"}]}, 1, {\"get_param\": \"LibvirtVirtqemudLogLevel\"}]}}}}, \"nova::compute::libvirt::virtproxyd::log_outputs\": {\"str_replace\": {\"template\": \"LEVEL:file:/var/log/libvirt/virtproxyd.log\", \"params\": {\"LEVEL\": {\"if\": [{\"or\": [{\"get_param\": \"Debug\"}, {\"get_param\": \"LibvirtDebug\"}]}, 1, {\"get_param\": \"LibvirtVirtproxydLogLevel\"}]}}}}, \"nova::compute::libvirt::virtstoraged::log_outputs\": {\"str_replace\": {\"template\": \"LEVEL:file:/var/log/libvirt/virtstoraged.log\", \"params\": {\"LEVEL\": {\"if\": [{\"or\": [{\"get_param\": \"Debug\"}, {\"get_param\": \"LibvirtDebug\"}]}, 1, {\"get_param\": \"LibvirtVirtstoragedLogLevel\"}]}}}}}}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/libvirt:/var/log/libvirt:shared,z\"]}, \"docker_config\": {\"description\": \"Extra containers needed for logging to file in the host.\", \"value\": null}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"setype\": \"{{ item.setype }}\", \"state\": \"directory\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/libvirt\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(116,'2026-06-09 08:02:08',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"TripleO Firewall settings\\n\", \"parameters\": {\"Debug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debugging on all services.\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ExtraFirewallRules\": {\"default\": {}, \"description\": \"Mapping of firewall rules.\", \"type\": \"json\", \"tags\": [\"role_specific\"]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"extra_firewall_rules\": \"ExtraFirewallRules\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ExtraFirewallRules\": {\"get_param\": \"ExtraFirewallRules\"}}}]}}}}, \"conditions\": {\"no_ctlplane\": {\"equals\": [{\"get_params\": [\"ServiceData\", \"net_cidr_map\", \"ctlplane\"]}, null]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the TripleO firewall settings\", \"value\": {\"service_name\": \"tripleo_firewall\", \"config_settings\": {\"tripleo::firewall::manage_firewall\": false, \"tripleo::firewall::purge_firewall_rules\": false}, \"ansible_group_vars\": {\"tripleo_nftables_debug\": {\"get_param\": \"Debug\"}}, \"firewall_rules\": {\"map_merge\": [{\"map_merge\": {\"repeat\": {\"for_each\": {\"<%net_cidr%>\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", \"ctlplane\"]}}, \"template\": {\"003 accept ssh from ctlplane subnet <%net_cidr%>\": {\"source\": \"<%net_cidr%>\", \"proto\": \"tcp\", \"dport\": 22}}}}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"extra_firewall_rules\"]}]}, \"host_prep_tasks\": [{\"if\": [\"no_ctlplane\", {\"name\": \"Failure - ctlplane subnet is unset\", \"fail\": {\"msg\": \"No CIDRs found in the ctlplane network tags.\\nPlease refer to the documentation in order to\\nset the correct network tags in DeployedServerPortMap.\\n\"}}, {\"name\": \"Notice - ctlplane subnet is set\", \"debug\": {\"msg\": \"CIDRs found in the ctlplane network tags.\\n\"}}]}], \"host_firewall_tasks\": [{\"name\": \"Run firewall role\", \"include_role\": {\"name\": \"tripleo_firewall\"}}], \"update_tasks\": [{\"name\": \"Cleanup tripleo-iptables services\", \"when\": [\"(step | int) == 1\"], \"block\": [{\"name\": \"Disable tripleo-iptables.service\", \"systemd\": {\"name\": \"tripleo-iptables.service\", \"state\": \"stopped\", \"enabled\": false}, \"register\": \"systemd_tripleo_iptables\", \"failed_when\": false}, {\"name\": \"Cleanup tripleo-iptables.services\", \"file\": {\"path\": \"/etc/systemd/system/tripleo-iptables.service\", \"state\": \"absent\"}}, {\"name\": \"Disable tripleo-ip6tables.service\", \"systemd\": {\"name\": \"tripleo-ip6tables.service\", \"state\": \"stopped\", \"enabled\": false}, \"register\": \"systemd_tripleo_ip6tables\", \"failed_when\": false}, {\"name\": \"Cleanup tripleo-ip6tables.services\", \"file\": {\"path\": \"/etc/systemd/system/tripleo-ip6tables.service\", \"state\": \"absent\"}}, {\"name\": \"Reload systemd\", \"systemd\": {\"daemon_reload\": true}, \"when\": [\"(systemd_tripleo_iptables is changed or systemd_tripleo_ip6tables is changed)\"]}]}], \"upgrade_tasks\": [{\"name\": \"Cleanup tripleo-iptables services\", \"when\": [\"(step | int) == 1\"], \"block\": [{\"name\": \"Disable tripleo-iptables.service\", \"systemd\": {\"name\": \"tripleo-iptables.service\", \"state\": \"stopped\", \"enabled\": false}, \"register\": \"systemd_tripleo_iptables\", \"failed_when\": false}, {\"name\": \"Cleanup tripleo-iptables.services\", \"file\": {\"path\": \"/etc/systemd/system/tripleo-iptables.service\", \"state\": \"absent\"}}, {\"name\": \"Disable tripleo-ip6tables.service\", \"systemd\": {\"name\": \"tripleo-ip6tables.service\", \"state\": \"stopped\", \"enabled\": false}, \"register\": \"systemd_tripleo_ip6tables\", \"failed_when\": false}, {\"name\": \"Cleanup tripleo-ip6tables.services\", \"file\": {\"path\": \"/etc/systemd/system/tripleo-ip6tables.service\", \"state\": \"absent\"}}, {\"name\": \"Reload systemd\", \"systemd\": {\"daemon_reload\": true}, \"when\": [\"(systemd_tripleo_iptables is changed or systemd_tripleo_ip6tables is changed)\"]}]}, {\"when\": [\"(step | int) == 3\"], \"block\": [{\"name\": \"blank ipv6 rule before activating ipv6 firewall.\", \"shell\": \"cat /etc/sysconfig/ip6tables > /etc/sysconfig/ip6tables.n-o-upgrade; cat</dev/null>/etc/sysconfig/ip6tables\", \"args\": {\"creates\": \"/etc/sysconfig/ip6tables.n-o-upgrade\"}}, {\"name\": \"cleanup unmanaged rules pushed by iptables-services\", \"shell\": \"iptables -C INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT &>/dev/null && \\\\\\n  iptables -D INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT\\niptables -C INPUT -p icmp -j ACCEPT &>/dev/null && \\\\\\n  iptables -D INPUT -p icmp -j ACCEPT\\niptables -C INPUT -i lo -j ACCEPT &>/dev/null && \\\\\\n  iptables -D INPUT -i lo -j ACCEPT\\niptables -C INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT &>/dev/null && \\\\\\n  iptables -D INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT\\niptables -C INPUT -j REJECT --reject-with icmp-host-prohibited &>/dev/null && \\\\\\n  iptables -D INPUT -j REJECT --reject-with icmp-host-prohibited\\niptables -C FORWARD -j REJECT --reject-with icmp-host-prohibited &>/dev/null && \\\\\\n  iptables -D FORWARD -j REJECT --reject-with icmp-host-prohibited\\n\\nsed -i \'/^-A INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT$/d\' /etc/sysconfig/iptables\\nsed -i \'/^-A INPUT -p icmp -j ACCEPT$/d\' /etc/sysconfig/iptables\\nsed -i \'/^-A INPUT -i lo -j ACCEPT$/d\' /etc/sysconfig/iptables\\nsed -i \'/^-A INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT$/d\' /etc/sysconfig/iptables\\nsed -i \'/^-A INPUT -j REJECT --reject-with icmp-host-prohibited$/d\' /etc/sysconfig/iptables\\nsed -i \'/^-A FORWARD -j REJECT --reject-with icmp-host-prohibited$/d\' /etc/sysconfig/iptables\\n\\nip6tables -C INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT &>/dev/null && \\\\\\n  ip6tables -D INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT\\nip6tables -C INPUT -p ipv6-icmp -j ACCEPT &>/dev/null && \\\\\\n  ip6tables -D INPUT -p ipv6-icmp -j ACCEPT\\nip6tables -C INPUT -i lo -j ACCEPT &>/dev/null && \\\\\\n  ip6tables -D INPUT -i lo -j ACCEPT\\nip6tables -C INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT &>/dev/null && \\\\\\n  ip6tables -D INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT\\nip6tables -C INPUT -d fe80::/64 -p udp -m udp --dport 546 -m state --state NEW -j ACCEPT &>/dev/null && \\\\\\n  ip6tables -D INPUT -d fe80::/64 -p udp -m udp --dport 546 -m state --state NEW -j ACCEPT\\nip6tables -C INPUT -j REJECT --reject-with icmp6-adm-prohibited &>/dev/null && \\\\\\n  ip6tables -D INPUT -j REJECT --reject-with icmp6-adm-prohibited\\nip6tables -C FORWARD -j REJECT --reject-with icmp6-adm-prohibited &>/dev/null && \\\\\\n  ip6tables -D FORWARD -j REJECT --reject-with icmp6-adm-prohibited\\n\\nsed -i \'/^-A INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A INPUT -p ipv6-icmp -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A INPUT -i lo -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A INPUT -d fe80::\\\\/64 -p udp -m udp --dport 546 -m state --state NEW -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A INPUT -j REJECT --reject-with icmp6-adm-prohibited$/d\' /etc/sysconfig/ip6tables\\nsed -i \'/^-A FORWARD -j REJECT --reject-with icmp6-adm-prohibited$/d\' /etc/sysconfig/ip6tables\"}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(117,'2026-06-09 08:02:09',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Cinder Backup service\\n\", \"parameters\": {\"ContainerCinderBackupImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\"}, \"ContainerCinderConfigImage\": {\"description\": \"The container image to use for the cinder config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"DockerCinderBackupLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.cinder.backup\", \"file\": \"/var/log/containers/cinder/cinder-backup.log\"}}, \"CinderBackupBackend\": {\"default\": \"swift\", \"description\": \"The short name of the Cinder Backup backend to use.\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"swift\", \"ceph\", \"nfs\", \"gcs\", \"s3\"]}]}, \"CinderBackupWorkers\": {\"type\": \"number\", \"default\": 1, \"description\": \"The number of cinder-backup processes to launch.\"}, \"CinderBackupMaxOperations\": {\"type\": \"number\", \"default\": 15, \"description\": \"The maximum number of concurrent cinder backup/restore operations (0 means unlimited).\"}, \"CinderBackupCompressionAlgorithm\": {\"default\": \"zlib\", \"description\": \"The compression algorithm used by Cinder Backup backends that are based on Cinder\'s \\\"chunked\\\" backup driver. This includes the swift, nfs, gcs and s3 backends. The ceph backend does not support the feature.\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"none\", \"zlib\", \"bzip2\", \"zstd\"]}]}, \"CinderBackupRbdClusterName\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The Ceph cluster where backups are to be stored. If no value is specified then the CephClusterName value is used.\"}, \"CinderBackupRbdClientUserName\": {\"default\": \"\", \"type\": \"string\", \"description\": \"The Ceph client name used by the backup service. If no value is specified then the CephClientUserName value is used.\"}, \"CinderBackupRbdPoolName\": {\"default\": \"backups\", \"type\": \"string\"}, \"CinderBackupNfsShare\": {\"default\": \"\", \"description\": \"NFS share to be mounted\", \"type\": \"string\"}, \"CinderBackupNfsMountOptions\": {\"default\": \"context=system_u:object_r:container_file_t:s0\", \"description\": \"Mount options passed to the NFS client. See NFS man page for details.\", \"type\": \"string\"}, \"CinderBackupGcsCredentials\": {\"default\": {}, \"description\": \"The GCS service account credentials, in JSON format.\", \"type\": \"json\"}, \"CinderBackupGcsProjectId\": {\"default\": \"\", \"description\": \"The GCS project ID.\", \"type\": \"string\"}, \"CinderBackupGcsBucket\": {\"default\": \"volumebackups\", \"description\": \"The GCS bucket where backups are to be stored.\", \"type\": \"string\"}, \"CinderBackupGcsBucketLocation\": {\"default\": \"\", \"description\": \"If set, it specifies the location where the GCS bucket should be created.\", \"type\": \"string\"}, \"CinderBackupS3EndpointUrl\": {\"default\": \"\", \"description\": \"The URL where the S3 server is listening.\", \"type\": \"string\"}, \"CinderBackupS3AccessKey\": {\"default\": \"\", \"description\": \"The S3 query token access key.\", \"type\": \"string\"}, \"CinderBackupS3SecretKey\": {\"default\": \"\", \"description\": \"The S3 query token secret key.\", \"type\": \"string\"}, \"CinderBackupS3Bucket\": {\"default\": \"volumebackups\", \"description\": \"The S3 bucket where backups are to be stored.\", \"type\": \"string\"}, \"MonitoringSubscriptionCinderBackup\": {\"default\": \"overcloud-cinder-backup\", \"type\": \"string\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"CinderBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-base.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"CinderCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-common-container-puppet.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCinderBackupImage\": \"ContainerCinderBackupImage\", \"ContainerCinderConfigImage\": \"ContainerCinderConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCinderBackupImage\": {\"get_param\": \"ContainerCinderBackupImage\"}, \"ContainerCinderConfigImage\": {\"get_param\": \"ContainerCinderConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder Backup role.\", \"value\": {\"service_name\": \"cinder_backup\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionCinderBackup\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"CinderBase\", \"role_data\", \"config_settings\"]}, {\"cinder::backup::backup_workers\": {\"get_param\": \"CinderBackupWorkers\"}, \"cinder::backup::backup_max_operations\": {\"get_param\": \"CinderBackupMaxOperations\"}}, {\"if\": [{\"equals\": [{\"get_param\": \"CinderBackupBackend\"}, \"ceph\"]}, {\"cinder::backup::ceph::backup_ceph_user\": {\"str_replace\": {\"template\": \"USERNAME\", \"params\": {\"USERNAME\": {\"if\": [{\"equals\": [{\"get_param\": \"CinderBackupRbdClientUserName\"}, \"\"]}, {\"get_param\": \"CephClientUserName\"}, {\"get_param\": \"CinderBackupRbdClientUserName\"}]}}}}, \"cinder::backup::ceph::backup_ceph_pool\": {\"get_param\": \"CinderBackupRbdPoolName\"}, \"cinder::backup::ceph::backup_ceph_conf\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.conf\", \"params\": {\"CLUSTER\": {\"if\": [{\"equals\": [{\"get_param\": \"CinderBackupRbdClusterName\"}, \"\"]}, {\"get_param\": \"CephClusterName\"}, {\"get_param\": \"CinderBackupRbdClusterName\"}]}}}}}]}, {\"if\": [{\"equals\": [{\"get_param\": \"CinderBackupBackend\"}, \"swift\"]}, {\"cinder::backup::swift::backup_swift_container\": \"volumebackups\", \"cinder::backup::swift::backup_compression_algorithm\": {\"get_param\": \"CinderBackupCompressionAlgorithm\"}, \"cinder::backup::swift::swift_catalog_info\": \"object-store:swift:internalURL\"}]}, {\"if\": [{\"equals\": [{\"get_param\": \"CinderBackupBackend\"}, \"nfs\"]}, {\"cinder::backup::nfs::backup_share\": {\"get_param\": \"CinderBackupNfsShare\"}, \"cinder::backup::nfs::backup_mount_options\": {\"get_param\": \"CinderBackupNfsMountOptions\"}, \"cinder::backup::nfs::backup_compression_algorithm\": {\"get_param\": \"CinderBackupCompressionAlgorithm\"}}]}, {\"if\": [{\"equals\": [{\"get_param\": \"CinderBackupBackend\"}, \"gcs\"]}, {\"tripleo::profile::base::cinder::backup::gcs::credentials\": {\"get_param\": \"CinderBackupGcsCredentials\"}, \"cinder::backup::google::backup_gcs_project_id\": {\"get_param\": \"CinderBackupGcsProjectId\"}, \"cinder::backup::google::backup_gcs_bucket\": {\"get_param\": \"CinderBackupGcsBucket\"}, \"cinder::backup::google::backup_gcs_bucket_location\": {\"get_param\": \"CinderBackupGcsBucketLocation\"}, \"cinder::config::cinder_config\": {\"DEFAULT/backup_compression_algorithm\": {\"value\": {\"get_param\": \"CinderBackupCompressionAlgorithm\"}}}}]}, {\"if\": [{\"equals\": [{\"get_param\": \"CinderBackupBackend\"}, \"s3\"]}, {\"cinder::backup::s3::backup_s3_endpoint_url\": {\"get_param\": \"CinderBackupS3EndpointUrl\"}, \"cinder::backup::s3::backup_s3_store_access_key\": {\"get_param\": \"CinderBackupS3AccessKey\"}, \"cinder::backup::s3::backup_s3_store_secret_key\": {\"get_param\": \"CinderBackupS3SecretKey\"}, \"cinder::backup::s3::backup_s3_store_bucket\": {\"get_param\": \"CinderBackupS3Bucket\"}, \"cinder::backup::s3::backup_compression_algorithm\": {\"get_param\": \"CinderBackupCompressionAlgorithm\"}}]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_cinder_backup\": [{\"get_param\": \"DockerCinderBackupLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"cinder\", \"puppet_tags\": \"cinder_config,file,concat,file_line\", \"step_config\": {\"list_join\": [\"\\n\", [{\"get_attr\": [\"CinderBase\", \"role_data\", \"step_config\"]}, {\"str_replace\": {\"template\": \"include tripleo::profile::base::cinder::backup::DRIVER\", \"params\": {\"DRIVER\": {\"get_param\": \"CinderBackupBackend\"}}}}, {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/cinder_backup.json\": {\"command\": \"/usr/bin/cinder-backup --config-file /usr/share/cinder/cinder-dist.conf --config-file /etc/cinder/cinder.conf\", \"config_files\": {\"get_attr\": [\"CinderCommon\", \"cinder_common_kolla_config_files\"]}, \"permissions\": {\"get_attr\": [\"CinderCommon\", \"cinder_common_kolla_permissions\"]}}}, \"docker_config\": {\"step_3\": {\"cinder_backup_init_logs\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/cinder:/var/log/cinder:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R cinder:cinder /var/log/cinder\"]}}, \"step_4\": {\"cinder_backup\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCinderBackupImage\"]}, \"ipc\": \"host\", \"net\": \"host\", \"privileged\": true, \"user\": \"root\", \"restart\": \"always\", \"healthcheck\": {\"get_attr\": [\"ContainersCommon\", \"healthcheck_rpc_port\"]}, \"volumes\": {\"get_attr\": [\"CinderCommon\", \"cinder_backup_volumes\"]}, \"environment\": {\"get_attr\": [\"CinderCommon\", \"cinder_backup_environment\"]}}}}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"CinderCommon\", \"cinder_backup_host_prep_tasks\"]}, [{\"name\": \"enable virt_sandbox_use_netlink for healthcheck\", \"seboolean\": {\"name\": \"virt_sandbox_use_netlink\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}]]}, \"deploy_steps_tasks\": [{\"name\": \"Clean up when switching cinder-backup from pcmk to active-active\", \"when\": [\"step|int == 1\"], \"become\": true, \"block\": [{\"name\": \"Check if cinder-backup is running under pacemaker\", \"command\": \"pcs status\", \"register\": \"cinder_backup_pcs_status\", \"check_mode\": false, \"failed_when\": false, \"changed_when\": false}, {\"when\": [\"\\\"cinder-backup\\\" in cinder_backup_pcs_status.stdout\"], \"block\": [{\"name\": \"Remove the openstack-cinder-backup pcs resource\", \"pacemaker_resource\": {\"resource\": \"openstack-cinder-backup\", \"state\": \"delete\"}, \"run_once\": true}, {\"name\": \"Identify the cinder-backup pcmklatest container image\", \"shell\": \"{{container_cli}} images | awk \'$1 ~ \\\"cinder-backup\\\" && $2 == \\\"pcmklatest\\\" {print $1\\\":\\\"$2}\'\", \"register\": \"cinder_backup_pcmklatest_image\", \"check_mode\": false, \"changed_when\": false}, {\"name\": \"Remove the cinder-backup pcmklatest container image\", \"command\": \"{{container_cli}} rmi {{cinder_backup_pcmklatest_image.stdout}}\", \"when\": [\"cinder_backup_pcmklatest_image.stdout|length > 0\"]}]}]}], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop cinder backup container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"cinder_backup\"], \"tripleo_delegate_to\": \"{{ groups[\'cinder_backup\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"CephClientUserName\": \"openstack\", \"CinderBackupBackend\": \"swift\", \"CinderBackupRbdPoolName\": \"backups\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(118,'2026-06-09 08:02:09',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Provides the list of common container volumes and environment used by various cinder services.\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"CinderVolumeOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderBackupOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderVolumeOptEnvVars\": {\"default\": {}, \"description\": \"hash of optional environment variables\", \"type\": \"json\"}, \"CinderEnableIscsiBackend\": {\"default\": true, \"description\": \"Whether to enable or not the Iscsi backend for Cinder\", \"type\": \"boolean\"}, \"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderLVMConfigureVG\": {\"default\": true, \"description\": \"Whether to configure the \'cinder-volumes\' VG used by the LVM driver. When disabled (set to False), the LVM driver will work as long as the \'cinder-volumes\' VG has been created through some other means.\\n\", \"type\": \"boolean\"}, \"CinderLVMLoopDeviceSize\": {\"default\": 20480, \"description\": \"The size of the loopback file used by the cinder LVM driver.\", \"type\": \"number\"}, \"MultipathdEnable\": {\"default\": false, \"description\": \"Whether to enable the multipath daemon\", \"type\": \"boolean\"}, \"CinderVolumeCluster\": {\"default\": \"\", \"description\": \"The cluster name used for deploying the cinder-volume service in an active-active (A/A) configuration. This configuration requires the Cinder backend drivers support A/A, and the cinder-volume service not be managed by pacemaker. If these criteria are not met then the cluster name must be left blank.\\n\", \"type\": \"string\"}, \"CinderImageConversionNfsShare\": {\"default\": \"\", \"description\": \"When set, the NFS share to be used for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"CinderImageConversionNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options when using an NFS share for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"EnableEtcdInternalTLS\": {\"description\": \"Controls whether etcd and the cinder-volume service use TLS for cinder\'s lock manager, even when the rest of the internal API network is using TLS.\", \"type\": \"boolean\", \"default\": true}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephExternalMultiConfig\": {\"type\": \"json\", \"hidden\": true, \"description\": \"List of maps describing extra overrides which will be applied when configuring\\nextra external Ceph clusters. If this list is non-empty, ceph-ansible will run\\nan extra count(list) times using the same parameters as the first run except\\neach parameter within each map will override the defaults. If the following\\nwere used, the second run would configure the overcloud to also use the ceph2\\ncluster with all the previous parameters except /etc/ceph/ceph2.conf would have\\na mon_host entry containing the value of external_cluster_mon_ips below, and\\nnot the default CephExternalMonHost. Subsequent ceph-ansible runs are restricted\\nto just ceph clients. CephExternalMultiConfig may not be used to deploy additional\\ninternal Ceph clusters within one Heat stack. The map for each list should contain\\nnot tripleo-heat-template parameters but ceph-ansible parameters.\\n  - cluster: \'ceph2\'\\n    fsid: \'e2cba068-5f14-4b0f-b047-acf375c0004a\'\\n    external_cluster_mon_ips: \'172.18.0.5,172.18.0.6,172.18.0.7\'\\n    keys:\\n      - name: \\\"client.openstack\\\"\\n        caps:\\n          mgr: \\\"allow *\\\"\\n          mon: \\\"profile rbd\\\"\\n          osd: \\\"osd: profile rbd pool=volumes, profile rbd pool=backups, profile rbd pool=vms, profile rbd pool=images\\\"\\n        key: \\\"AQCwmeRcAAAAABAA6SQU/bGqFjlfLro5KxrB1Q==\\\"\\n        mode: \\\"0600\\\"\\n    dashboard_enabled: false\\n\", \"default\": []}}, \"conditions\": {\"cvol_active_active_tls_enabled\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderVolumeCluster\"}, \"\"]}}, {\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"EnableEtcdInternalTLS\"}]}, \"cinder_nfs_conversion_dir_enabled\": {\"not\": {\"equals\": [{\"get_param\": \"CinderImageConversionNfsShare\"}, \"\"]}}, \"cinder_configure_lvm\": {\"and\": [{\"get_param\": \"CinderLVMConfigureVG\"}, {\"or\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, {\"get_param\": \"CinderEnableNVMeOFBackend\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CinderNVMeOF\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\"}}, \"outputs\": {\"cinder_image_conversion_nfs_dir\": {\"description\": \"The directory where cinder does its image conversion when the directory is backed by an NFS share.\", \"value\": \"/var/lib/cinder_image_conversion\"}, \"cinder_common_host_prep_tasks\": {\"description\": \"Common host prep tasks for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_common_volumes\": {\"description\": \"Common volumes for all cinder services\", \"value\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}}, \"cinder_common_kolla_config_files\": {\"description\": \"Common kolla config_files for cinder-volume and cinder-backup services\", \"value\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-iscsid/*\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}]}, \"cinder_common_kolla_permissions\": {\"description\": \"Common kolla permissions for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, {\"path\": \"/etc/pki/tls/certs/etcd.crt\", \"owner\": \"cinder:cinder\"}, {\"path\": \"/etc/pki/tls/private/etcd.key\", \"owner\": \"cinder:cinder\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%cluster%>.client.*.keyring\", \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, \"for_each\": {\"<%cluster%>\": {\"yaql\": {\"expression\": \"$.data.multiconfig.select($.cluster)\", \"data\": {\"multiconfig\": {\"get_param\": \"CephExternalMultiConfig\"}}}}}}}]}}, \"cinder_volume_host_prep_and_system_upgrade_post_tasks\": {\"description\": \"Common host_prep and system_upgrade post tasks for cinder-volume\", \"value\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}, \"cinder_volume_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-volume service (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}, [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}], [{\"name\": \"cinder_configure_lvm fact\", \"set_fact\": {\"cinder_configure_lvm\": {\"if\": [\"cinder_configure_lvm\", true, false]}}}, {\"when\": \"cinder_configure_lvm|bool\", \"block\": [{\"name\": \"ensure LVM rpm dependencies are installed\", \"package\": {\"name\": \"lvm2\", \"state\": \"latest\"}}, {\"name\": \"cinder create LVM volume group dd\", \"command\": {\"list_join\": [\"\", [\"dd if=/dev/zero of=/var/lib/cinder/cinder-volumes bs=1 count=0 seek=\", {\"str_replace\": {\"template\": \"VALUE\", \"params\": {\"VALUE\": {\"get_param\": \"CinderLVMLoopDeviceSize\"}}}}, \"M\"]]}, \"args\": {\"creates\": \"/var/lib/cinder/cinder-volumes\"}}, {\"name\": \"Get or create LVM loopback device\", \"shell\": \"exit_code=0\\nexisting_device=$(losetup -j /var/lib/cinder/cinder-volumes -l -n -O NAME)\\nif [[ -z \\\"${existing_device}\\\" ]]; then\\n    losetup -f /var/lib/cinder/cinder-volumes --show\\n    exit_code=2\\nelse\\n    echo ${existing_device%$\'\\\\n\'*}\\nfi\\nexit ${exit_code}\", \"args\": {\"executable\": \"/bin/bash\"}, \"register\": \"_loopback_device\", \"changed_when\": \"_loopback_device.rc == 2\", \"failed_when\": \"_loopback_device.rc not in [0,2]\"}, {\"name\": \"Create LVM volume group\", \"community.general.lvg\": {\"vg\": \"cinder-volumes\", \"pvs\": \"{{ _loopback_device.stdout }}\", \"state\": \"present\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder create service to run losetup for LVM on startup\", \"copy\": {\"dest\": \"/etc/systemd/system/cinder-lvm-losetup.service\", \"content\": \"[Unit]\\nDescription=Cinder LVM losetup\\nDefaultDependencies=no\\nConflicts=umount.target\\nRequires=lvm2-monitor.service systemd-udev-settle.service\\nBefore=local-fs.target umount.target\\nAfter=var.mount lvm2-monitor.service systemd-udev-settle.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/sbin/losetup {{ _loopback_device.stdout }} /var/lib/cinder/cinder-volumes\\nExecStop=/sbin/losetup -d {{ _loopback_device.stdout }}\\nRemainAfterExit=yes\\n\\n[Install]\\nWantedBy=local-fs-pre.target\\n\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder enable the LVM losetup service\", \"systemd\": {\"name\": \"cinder-lvm-losetup\", \"enabled\": true, \"daemon_reload\": true}}]}]]}}, \"cinder_volume_upgrade_tasks\": {\"description\": \"Upgrade tasks for the cinder-volume service (HA or non-HA)\", \"value\": [{\"name\": \"cinder-volume pre system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Unmount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}, \"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": \"image_conversion_nfs_enabled|bool\", \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"absent\", \"fstype\": \"nfs4\"}}]}, {\"name\": \"cinder-volume post system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 5\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}]}, \"cinder_volume_config_settings\": {\"description\": \"Config settings for the cinder-volume container (HA or non-HA)\", \"value\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", {\"cinder::image_conversion_dir\": \"/var/lib/cinder_image_conversion\"}, {}]}}, \"cinder_volume_volumes\": {\"description\": \"Volumes for the cinder-volume container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderVolumeOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_volume.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/lib/modules:/lib/modules:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, [\"/etc/target:/etc/target:z\"]]}, {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}, {\"if\": [\"cinder_nfs_conversion_dir_enabled\", [{\"str_replace\": {\"template\": \"DIR:DIR:slave\", \"params\": {\"DIR\": \"/var/lib/cinder_image_conversion\"}}}]]}]}}, \"cinder_volume_environment\": {\"description\": \"Docker environment for the cinder-volume container (HA or non-HA)\", \"value\": {\"map_merge\": [{\"get_param\": \"CinderVolumeOptEnvVars\"}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}]}}, \"cinder_backup_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-backup service (HA or non-HA)\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_backup_volumes\": {\"description\": \"Volumes for the cinder-backup container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderBackupOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_backup.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/lib/modules:/lib/modules:ro\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}}, \"cinder_backup_environment\": {\"description\": \"Docker environment for the cinder-backup container (HA or non-HA)\", \"value\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(119,'2026-06-09 08:02:09',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Qpid dispatch router service for metrics and monitoring purposes\\n\", \"parameters\": {\"ContainerMetricsQdrImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\"}, \"ContainerMetricsQdrConfigImage\": {\"description\": \"The container image to use for the qdrouterd config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"MonitoringSubscriptionQdr\": {\"default\": \"overcloud-qdr\", \"type\": \"string\"}, \"MetricsQdrLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.nova.consoleauth\", \"file\": \"/var/log/containers/metrics_qdr/metrics_qdr.log\", \"startmsg.regex\": \"^[0-9]{4}-[0-9]{2}-[0-9]{2} [0-9]{2}:[0-9]{2}:[0-9]{2}(.[0-9]+ \\\\\\\\+[0-9]+)? [A-Z]+ \\\\\\\\([a-z]+\\\\\\\\) \"}}, \"MetricsQdrPort\": {\"default\": 5666, \"description\": \"Service name or port number on which the qdrouterd will accept connections.\", \"type\": \"number\"}, \"MetricsQdrUsername\": {\"default\": \"guest\", \"description\": \"Username which should be used to authenticate to the deployed qdrouterd.\", \"type\": \"string\"}, \"MetricsQdrPassword\": {\"default\": \"guest\", \"description\": \"Password which should be used to authenticate to the deployed qdrouterd.\", \"type\": \"string\", \"hidden\": true}, \"MetricsQdrConnectors\": {\"default\": [], \"description\": \"Connectors configuration (array of hashes).\", \"type\": \"json\"}, \"MetricsQdrSSLProfiles\": {\"default\": [{\"name\": \"sslProfile\"}], \"description\": \"SSL Profiles for the connectors (array of hashes).\", \"type\": \"json\"}, \"MetricsQdrAddresses\": {\"default\": [{\"prefix\": \"collectd\", \"distribution\": \"multicast\"}, {\"prefix\": \"ceilometer/metering.sample\", \"distribution\": \"multicast\"}, {\"prefix\": \"ceilometer/event.sample\", \"distribution\": \"multicast\"}], \"description\": \"Addresses configuration (array of hashes).\", \"type\": \"json\"}, \"MetricsQdrAutoLinks\": {\"default\": [], \"description\": \"AutoLinks for the Configured Addresses\", \"type\": \"json\"}, \"MetricsQdrUseSSL\": {\"default\": false, \"description\": \"Set to true if it is required to use SSL or TLS on the connection for the local listener. !WARNING! Currently breaks connections from collectd and ceilometer.\", \"type\": \"boolean\"}, \"MetricsQdrUseEncryption\": {\"default\": false, \"description\": \"Set to true if it is required to encrypt connection to the peer for listener. Not currently implemented, use EnableInternalTLS instead. This option can be ignored.\", \"type\": \"boolean\"}, \"MetricsQdrSaslMechanisms\": {\"default\": \"ANONYMOUS\", \"description\": \"List of accepted SASL auth mechanisms for listener in format of comma separated list.\", \"type\": \"string\"}, \"MetricsQdrSslCertDb\": {\"default\": \"/etc/ipa/ca.crt\", \"description\": \"Path to SSL certificate db for listener.\", \"type\": \"string\"}, \"MetricsQdrSslCertFile\": {\"default\": \"/etc/pki/tls/certs/metrics_qdr.crt\", \"description\": \"Path to SSL certificate file for listener.\", \"type\": \"string\"}, \"MetricsQdrSslKeyFile\": {\"default\": \"/etc/pki/tls/private/metrics_qdr.key\", \"description\": \"Path to SSL private key file for listener.\", \"type\": \"string\"}, \"MetricsQdrSslPwFile\": {\"default\": \"\", \"description\": \"Path to SSL password file for certificate key for listener.\", \"type\": \"string\"}, \"MetricsQdrSslPassword\": {\"default\": \"\", \"description\": \"SSL password to be supplied for listener.\", \"type\": \"string\"}, \"MetricsQdrTrustedCerts\": {\"default\": \"\", \"description\": \"Path to file containing trusted certificates for listener.\", \"type\": \"string\"}, \"MetricsQdrAuthenticateClient\": {\"default\": false, \"description\": \"Authenticate the client using SSL/TLS\", \"type\": \"boolean\"}, \"MetricsQdrExternalEndpoint\": {\"default\": false, \"description\": \"Whether QDR should listen on external network interface. To enable listening on external network one must deploy QDRs in mesh mode.\", \"type\": \"boolean\"}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"EnableSTF\": {\"default\": false, \"description\": \"Set to true to enable configuration for STF client.\", \"type\": \"boolean\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"QdrCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"listener_ssl_enabled\": {\"equals\": [{\"get_param\": \"MetricsQdrUseSSL\"}, true]}, \"enable_stf\": {\"equals\": [{\"get_param\": \"EnableSTF\"}, true]}, \"key_size_override_unset\": {\"equals\": [{\"get_param\": \"QdrCertificateKeySize\"}, \"\"]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerMetricsQdrImage\": \"ContainerMetricsQdrImage\", \"ContainerMetricsQdrConfigImage\": \"ContainerMetricsQdrConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerMetricsQdrImage\": {\"get_param\": \"ContainerMetricsQdrImage\"}, \"ContainerMetricsQdrConfigImage\": {\"get_param\": \"ContainerMetricsQdrConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the metrics Qdr role.\", \"value\": {\"service_name\": \"metrics_qdr\", \"firewall_rules\": {\"map_merge\": [{\"109 metrics qdr\": {\"dport\": [{\"get_param\": \"MetricsQdrPort\"}]}}, {\"map_merge\": {\"repeat\": {\"for_each\": {\"<%net_cidr%>\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", \"ctlplane\"]}}, \"template\": {\"109 accept internal metrics qdr ctlplane subnet <%net_cidr%>\": {\"dport\": [5667, 5668]}}}}}]}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionQdr\"}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_metrics_qdr\": [{\"get_param\": \"MetricsQdrLoggingSource\"}]}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::metrics::qdr::listener_addr\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"tripleo::haproxy::metrics_qdr\": {\"get_param\": \"MetricsQdrExternalEndpoint\"}, \"tripleo::profile::base::metrics::qdr::listener_port\": {\"get_param\": \"MetricsQdrPort\"}, \"tripleo::profile::base::metrics::qdr::username\": {\"get_param\": \"MetricsQdrUsername\"}, \"tripleo::profile::base::metrics::qdr::password\": {\"get_param\": \"MetricsQdrPassword\"}, \"tripleo::profile::base::metrics::qdr::connectors\": {\"get_param\": \"MetricsQdrConnectors\"}, \"tripleo::profile::base::metrics::qdr::addresses\": {\"get_param\": \"MetricsQdrAddresses\"}, \"tripleo::profile::base::metrics::qdr::autolink_addresses\": {\"get_param\": \"MetricsQdrAutoLinks\"}, \"tripleo::profile::base::metrics::qdr::listener_require_ssl\": {\"if\": [\"listener_ssl_enabled\", true, false]}, \"tripleo::profile::base::metrics::qdr::listener_require_encrypt\": {\"get_param\": \"MetricsQdrUseEncryption\"}, \"tripleo::profile::base::metrics::qdr::listener_sasl_mech\": {\"get_param\": \"MetricsQdrSaslMechanisms\"}, \"tripleo::profile::base::metrics::qdr::listener_ssl_cert_db\": {\"get_param\": \"MetricsQdrSslCertDb\"}, \"tripleo::profile::base::metrics::qdr::listener_ssl_cert_file\": {\"get_param\": \"MetricsQdrSslCertFile\"}, \"tripleo::profile::base::metrics::qdr::listener_ssl_key_file\": {\"get_param\": \"MetricsQdrSslKeyFile\"}, \"tripleo::profile::base::metrics::qdr::listener_ssl_pw_file\": {\"get_param\": \"MetricsQdrSslPwFile\"}, \"tripleo::profile::base::metrics::qdr::listener_ssl_password\": {\"get_param\": \"MetricsQdrSslPassword\"}, \"tripleo::profile::base::metrics::qdr::listener_trusted_certs\": {\"get_param\": \"MetricsQdrTrustedCerts\"}, \"qdr::log_enable\": \"info+\", \"qdr::log_output\": \"/var/log/qdrouterd/metrics_qdr.log\", \"qdr::listener_auth_peer\": {\"get_param\": \"MetricsQdrAuthenticateClient\"}}, {\"if\": [\"internal_tls_enabled\", {\"tripleo::profile::base::metrics::qdr::ssl_profiles\": {\"list_concat\": [{\"get_param\": \"MetricsQdrSSLProfiles\"}, [{\"name\": \"tlsProfile\", \"certFile\": \"/etc/pki/tls/certs/metrics_qdr.crt\", \"keyFile\": \"/etc/pki/tls/private/metrics_qdr.key\", \"caCertFile\": {\"get_param\": \"InternalTLSCAFile\"}}]]}}, {\"tripleo::profile::base::metrics::qdr::ssl_profiles\": {\"get_param\": \"MetricsQdrSSLProfiles\"}}]}, {\"if\": [\"enable_stf\", {\"tripleo::profile::base::metrics::qdr::interior_mesh_nodes\": \"\", \"tripleo::profile::base::metrics::qdr::router_mode\": \"edge\"}, null]}]}, \"metadata_settings\": {\"if\": [\"internal_tls_enabled\", [{\"service\": \"metrics_qdr\", \"network\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}, \"type\": \"node\"}], null]}, \"puppet_config\": {\"config_volume\": \"metrics_qdr\", \"step_config\": \"include tripleo::profile::base::metrics::qdr\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMetricsQdrConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/metrics_qdr.json\": {\"command\": \"/usr/sbin/qdrouterd -c /etc/qpid-dispatch/qdrouterd.conf\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}], \"permissions\": [{\"path\": \"/var/lib/qdrouterd\", \"owner\": \"qdrouterd:qdrouterd\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/metrics_qdr.crt\", \"owner\": \"qdrouterd:qdrouterd\", \"optional\": true}, {\"path\": \"/etc/pki/tls/private/metrics_qdr.key\", \"owner\": \"qdrouterd:qdrouterd\", \"optional\": true}]}}, \"docker_config\": {\"step_1\": {\"metrics_qdr_init_logs\": {\"start_order\": 0, \"detach\": false, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMetricsQdrImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/metrics_qdr:/var/log/qdrouterd:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R qdrouterd:qdrouterd /var/log/qdrouterd\"]}, \"metrics_qdr\": {\"start_order\": 1, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMetricsQdrImage\"]}, \"net\": \"host\", \"user\": \"qdrouterd\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/metrics_qdr.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/metrics_qdr:/var/lib/kolla/config_files/src:ro\", \"/var/lib/metrics_qdr:/var/lib/qdrouterd:z\", \"/var/log/containers/metrics_qdr:/var/log/qdrouterd:z\"], {\"if\": [\"internal_tls_enabled\", [\"/etc/pki/tls/certs/metrics_qdr.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/metrics_qdr.crt:ro\", \"/etc/pki/tls/private/metrics_qdr.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/metrics_qdr.key:ro\"], null]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"metrics_qdr\", \"dns\": {\"str_replace\": {\"template\": \"{{fqdn_NETWORK}}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"principal\": {\"str_replace\": {\"template\": \"metrics_qdr/{{fqdn_NETWORK}}@{{idm_realm}}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"run_after\": \"container_name=$({{container_cli}} ps --format=\\\\{\\\\{.Names\\\\}\\\\} | grep metrics_qdr)\\nservice_crt=\\\"/etc/pki/tls/certs/metrics_qdr.crt\\\"\\nservice_key=\\\"/etc/pki/tls/private/metrics_qdr.key\\n# Copy the new cert from the mount-point to the real path\\n{{container_cli}} exec \\\"$container_name\\\" cp \\\"/var/lib/kolla/config_files/src-tls$service_crt\\\" \\\"$service_crt\\\"\\n# Copy the new key from the mount-point to the real path\\n{{container_cli}} exec \\\"$container_name\\\" cp \\\"/var/lib/kolla/config_files/src-tls$service_key\\\" \\\"$service_key\\\"\\n# Set appropriate permissions\\n{{container_cli}} exec \\\"$container_name\\\" chown qdrouterd:qdrouterd \\\"$service_crt\\\"\\n{{container_cli}} exec \\\"$container_name\\\" chown qdrouterd:qdrouterd \\\"$service_key\\\"\\n# Trigger a container restart to read the new certificate\\n{{container_cli}} restart \\\"$container_name\\\"\\n\", \"key_size\": {\"if\": [\"key_size_override_unset\", {\"get_param\": \"CertificateKeySize\"}, {\"get_param\": \"QdrCertificateKeySize\"}]}, \"ca\": \"ipa\"}]}}]}], \"host_prep_tasks\": [{\"name\": \"create persistent logs directory\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/metrics_qdr\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/metrics_qdr\", \"setype\": \"container_file_t\"}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(120,'2026-06-09 08:02:09',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Cinder NVMeOF backend\\n\", \"parameters\": {\"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderNVMeOFBackendName\": {\"type\": \"string\", \"default\": \"tripleo_nvmeof\"}, \"CinderNVMeOFAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NVMeOF Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNVMeOFTargetPort\": {\"type\": \"number\", \"default\": 4420}, \"CinderNVMeOFTargetHelper\": {\"type\": \"string\", \"default\": \"nvmet\"}, \"CinderNVMeOFTargetProtocol\": {\"type\": \"string\", \"default\": \"nvmet_rdma\", \"description\": \"The target protocol, supported values are nvmet_rdma and nvmet_tcp.\\n\", \"constraints\": [{\"allowed_values\": [\"nvmet_rdma\", \"nvmet_tcp\"]}]}, \"CinderNVMeOFTargetPrefix\": {\"type\": \"string\", \"default\": \"nvme-subsystem\"}, \"CinderNVMeOFTargetPortId\": {\"type\": \"number\", \"default\": 1}, \"CinderNVMeOFTargetNameSpaceId\": {\"type\": \"number\", \"default\": 10}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"type\": \"json\", \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}}, \"outputs\": {\"cinder_nvmeof_host_prep_tasks\": {\"description\": \"Host prep tasks related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [{\"name\": \"ensure /etc/nvme exists\", \"file\": {\"path\": \"/etc/nvme\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]]}}, \"cinder_nvmeof_volumes\": {\"description\": \"Volumes related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [\"/etc/nvme:/etc/nvme:z\"]]}}, \"role_data\": {\"description\": \"Role data for the Cinder NVMeOF backend.\", \"value\": {\"service_name\": \"cinder_backend_nvmeof\", \"firewall_rules\": {\"120 LVM nvmet target\": {\"dport\": {\"get_param\": \"CinderNVMeOFTargetPort\"}}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::cinder::volume::cinder_enable_nvmeof_backend\": {\"get_param\": \"CinderEnableNVMeOFBackend\"}, \"tripleo::profile::base::cinder::volume::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_port\": {\"get_param\": \"CinderNVMeOFTargetPort\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_helper\": {\"get_param\": \"CinderNVMeOFTargetHelper\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_protocol\": {\"get_param\": \"CinderNVMeOFTargetProtocol\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_prefix\": {\"get_param\": \"CinderNVMeOFTargetPrefix\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_port_id\": {\"get_param\": \"CinderNVMeOFTargetPortId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_ns_id\": {\"get_param\": \"CinderNVMeOFTargetNameSpaceId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_ip_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}, \"cinder::backend::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNVMeOFAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nvmeof::backend_availability_zone\": {\"get_param\": \"CinderNVMeOFAvailabilityZone\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (121,'2026-06-09 08:02:09',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Cinder base service. Shared by all Cinder services.\\n\", \"parameters\": {\"CinderStorageAvailabilityZone\": {\"default\": \"nova\", \"description\": \"The Cinder service\'s storage availability zone.\", \"type\": \"string\"}, \"CinderPassword\": {\"description\": \"The password for the cinder service and db account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"CinderDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging on Cinder services.\", \"type\": \"boolean\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"CinderCronDbPurgeMinute\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Minute\\n\", \"default\": \"1\"}, \"CinderCronDbPurgeHour\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Hour\\n\", \"default\": \"0\"}, \"CinderCronDbPurgeMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month Day\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeMonth\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Week Day\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeUser\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - User\\n\", \"default\": \"cinder\"}, \"CinderCronDbPurgeAge\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age\\n\", \"default\": \"30\"}, \"CinderCronDbPurgeDestination\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Log destination\\n\", \"default\": \"/var/log/cinder/cinder-rowsflush.log\"}, \"CinderCronDbPurgeMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Delay\\n\", \"default\": \"3600\"}, \"CinderRpcResponseTimeout\": {\"default\": 60, \"description\": \"Cinder\'s RPC response timeout, in seconds.\", \"type\": \"number\"}, \"NovaPassword\": {\"type\": \"string\", \"description\": \"The password for the nova service and db account\", \"hidden\": true, \"default\": \"E43sBALvNAsJYgcBpWfsAoz9C\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder base service.\", \"value\": {\"service_name\": \"cinder_base\", \"config_settings\": {\"cinder::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"cinder\", \"password\": {\"get_param\": \"CinderPassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/cinder\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"cinder\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"cinder::logging::debug\": {\"if\": [{\"get_param\": \"CinderDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"cinder::storage_availability_zone\": {\"get_param\": \"CinderStorageAvailabilityZone\"}, \"cinder::rabbit_heartbeat_timeout_threshold\": 60, \"cinder::rpc_response_timeout\": {\"get_param\": \"CinderRpcResponseTimeout\"}, \"cinder::rabbit_heartbeat_in_pthread\": false, \"cinder::db::database_db_max_retries\": -1, \"cinder::db::database_max_retries\": -1, \"cinder::cron::db_purge::minute\": {\"get_param\": \"CinderCronDbPurgeMinute\"}, \"cinder::cron::db_purge::hour\": {\"get_param\": \"CinderCronDbPurgeHour\"}, \"cinder::cron::db_purge::monthday\": {\"get_param\": \"CinderCronDbPurgeMonthday\"}, \"cinder::cron::db_purge::month\": {\"get_param\": \"CinderCronDbPurgeMonth\"}, \"cinder::cron::db_purge::weekday\": {\"get_param\": \"CinderCronDbPurgeWeekday\"}, \"cinder::cron::db_purge::user\": {\"get_param\": \"CinderCronDbPurgeUser\"}, \"cinder::cron::db_purge::age\": {\"get_param\": \"CinderCronDbPurgeAge\"}, \"cinder::cron::db_purge::destination\": {\"get_param\": \"CinderCronDbPurgeDestination\"}, \"cinder::cron::db_purge::maxdelay\": {\"get_param\": \"CinderCronDbPurgeMaxDelay\"}, \"cinder::glance::glance_api_servers\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"uri\"]}, \"cinder::keystone::service_user::send_service_user_token\": true, \"cinder::keystone::service_user::project_name\": \"service\", \"cinder::keystone::service_user::auth_type\": \"password\", \"cinder::keystone::service_user::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri\"]}, \"cinder::keystone::service_user::password\": {\"get_param\": \"CinderPassword\"}, \"cinder::keystone::service_user::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"cinder::nova::interface\": \"admin\", \"cinder::nova::project_name\": \"service\", \"cinder::nova::auth_type\": \"password\", \"cinder::nova::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri\"]}, \"cinder::nova::password\": {\"get_param\": \"NovaPassword\"}, \"cinder::nova::region_name\": {\"get_param\": \"KeystoneRegion\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(122,'2026-06-09 08:02:09',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Provides the list of common container volumes and environment used by various cinder services.\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"CinderVolumeOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderBackupOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderVolumeOptEnvVars\": {\"default\": {}, \"description\": \"hash of optional environment variables\", \"type\": \"json\"}, \"CinderEnableIscsiBackend\": {\"default\": true, \"description\": \"Whether to enable or not the Iscsi backend for Cinder\", \"type\": \"boolean\"}, \"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderLVMConfigureVG\": {\"default\": true, \"description\": \"Whether to configure the \'cinder-volumes\' VG used by the LVM driver. When disabled (set to False), the LVM driver will work as long as the \'cinder-volumes\' VG has been created through some other means.\\n\", \"type\": \"boolean\"}, \"CinderLVMLoopDeviceSize\": {\"default\": 20480, \"description\": \"The size of the loopback file used by the cinder LVM driver.\", \"type\": \"number\"}, \"MultipathdEnable\": {\"default\": false, \"description\": \"Whether to enable the multipath daemon\", \"type\": \"boolean\"}, \"CinderVolumeCluster\": {\"default\": \"\", \"description\": \"The cluster name used for deploying the cinder-volume service in an active-active (A/A) configuration. This configuration requires the Cinder backend drivers support A/A, and the cinder-volume service not be managed by pacemaker. If these criteria are not met then the cluster name must be left blank.\\n\", \"type\": \"string\"}, \"CinderImageConversionNfsShare\": {\"default\": \"\", \"description\": \"When set, the NFS share to be used for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"CinderImageConversionNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options when using an NFS share for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"EnableEtcdInternalTLS\": {\"description\": \"Controls whether etcd and the cinder-volume service use TLS for cinder\'s lock manager, even when the rest of the internal API network is using TLS.\", \"type\": \"boolean\", \"default\": true}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephExternalMultiConfig\": {\"type\": \"json\", \"hidden\": true, \"description\": \"List of maps describing extra overrides which will be applied when configuring\\nextra external Ceph clusters. If this list is non-empty, ceph-ansible will run\\nan extra count(list) times using the same parameters as the first run except\\neach parameter within each map will override the defaults. If the following\\nwere used, the second run would configure the overcloud to also use the ceph2\\ncluster with all the previous parameters except /etc/ceph/ceph2.conf would have\\na mon_host entry containing the value of external_cluster_mon_ips below, and\\nnot the default CephExternalMonHost. Subsequent ceph-ansible runs are restricted\\nto just ceph clients. CephExternalMultiConfig may not be used to deploy additional\\ninternal Ceph clusters within one Heat stack. The map for each list should contain\\nnot tripleo-heat-template parameters but ceph-ansible parameters.\\n  - cluster: \'ceph2\'\\n    fsid: \'e2cba068-5f14-4b0f-b047-acf375c0004a\'\\n    external_cluster_mon_ips: \'172.18.0.5,172.18.0.6,172.18.0.7\'\\n    keys:\\n      - name: \\\"client.openstack\\\"\\n        caps:\\n          mgr: \\\"allow *\\\"\\n          mon: \\\"profile rbd\\\"\\n          osd: \\\"osd: profile rbd pool=volumes, profile rbd pool=backups, profile rbd pool=vms, profile rbd pool=images\\\"\\n        key: \\\"AQCwmeRcAAAAABAA6SQU/bGqFjlfLro5KxrB1Q==\\\"\\n        mode: \\\"0600\\\"\\n    dashboard_enabled: false\\n\", \"default\": []}}, \"conditions\": {\"cvol_active_active_tls_enabled\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderVolumeCluster\"}, \"\"]}}, {\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"EnableEtcdInternalTLS\"}]}, \"cinder_nfs_conversion_dir_enabled\": {\"not\": {\"equals\": [{\"get_param\": \"CinderImageConversionNfsShare\"}, \"\"]}}, \"cinder_configure_lvm\": {\"and\": [{\"get_param\": \"CinderLVMConfigureVG\"}, {\"or\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, {\"get_param\": \"CinderEnableNVMeOFBackend\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CinderNVMeOF\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\"}}, \"outputs\": {\"cinder_image_conversion_nfs_dir\": {\"description\": \"The directory where cinder does its image conversion when the directory is backed by an NFS share.\", \"value\": \"/var/lib/cinder_image_conversion\"}, \"cinder_common_host_prep_tasks\": {\"description\": \"Common host prep tasks for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_common_volumes\": {\"description\": \"Common volumes for all cinder services\", \"value\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}}, \"cinder_common_kolla_config_files\": {\"description\": \"Common kolla config_files for cinder-volume and cinder-backup services\", \"value\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-iscsid/*\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}]}, \"cinder_common_kolla_permissions\": {\"description\": \"Common kolla permissions for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, {\"path\": \"/etc/pki/tls/certs/etcd.crt\", \"owner\": \"cinder:cinder\"}, {\"path\": \"/etc/pki/tls/private/etcd.key\", \"owner\": \"cinder:cinder\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%cluster%>.client.*.keyring\", \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, \"for_each\": {\"<%cluster%>\": {\"yaql\": {\"expression\": \"$.data.multiconfig.select($.cluster)\", \"data\": {\"multiconfig\": {\"get_param\": \"CephExternalMultiConfig\"}}}}}}}]}}, \"cinder_volume_host_prep_and_system_upgrade_post_tasks\": {\"description\": \"Common host_prep and system_upgrade post tasks for cinder-volume\", \"value\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}, \"cinder_volume_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-volume service (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}, [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}], [{\"name\": \"cinder_configure_lvm fact\", \"set_fact\": {\"cinder_configure_lvm\": {\"if\": [\"cinder_configure_lvm\", true, false]}}}, {\"when\": \"cinder_configure_lvm|bool\", \"block\": [{\"name\": \"ensure LVM rpm dependencies are installed\", \"package\": {\"name\": \"lvm2\", \"state\": \"latest\"}}, {\"name\": \"cinder create LVM volume group dd\", \"command\": {\"list_join\": [\"\", [\"dd if=/dev/zero of=/var/lib/cinder/cinder-volumes bs=1 count=0 seek=\", {\"str_replace\": {\"template\": \"VALUE\", \"params\": {\"VALUE\": {\"get_param\": \"CinderLVMLoopDeviceSize\"}}}}, \"M\"]]}, \"args\": {\"creates\": \"/var/lib/cinder/cinder-volumes\"}}, {\"name\": \"Get or create LVM loopback device\", \"shell\": \"exit_code=0\\nexisting_device=$(losetup -j /var/lib/cinder/cinder-volumes -l -n -O NAME)\\nif [[ -z \\\"${existing_device}\\\" ]]; then\\n    losetup -f /var/lib/cinder/cinder-volumes --show\\n    exit_code=2\\nelse\\n    echo ${existing_device%$\'\\\\n\'*}\\nfi\\nexit ${exit_code}\", \"args\": {\"executable\": \"/bin/bash\"}, \"register\": \"_loopback_device\", \"changed_when\": \"_loopback_device.rc == 2\", \"failed_when\": \"_loopback_device.rc not in [0,2]\"}, {\"name\": \"Create LVM volume group\", \"community.general.lvg\": {\"vg\": \"cinder-volumes\", \"pvs\": \"{{ _loopback_device.stdout }}\", \"state\": \"present\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder create service to run losetup for LVM on startup\", \"copy\": {\"dest\": \"/etc/systemd/system/cinder-lvm-losetup.service\", \"content\": \"[Unit]\\nDescription=Cinder LVM losetup\\nDefaultDependencies=no\\nConflicts=umount.target\\nRequires=lvm2-monitor.service systemd-udev-settle.service\\nBefore=local-fs.target umount.target\\nAfter=var.mount lvm2-monitor.service systemd-udev-settle.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/sbin/losetup {{ _loopback_device.stdout }} /var/lib/cinder/cinder-volumes\\nExecStop=/sbin/losetup -d {{ _loopback_device.stdout }}\\nRemainAfterExit=yes\\n\\n[Install]\\nWantedBy=local-fs-pre.target\\n\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder enable the LVM losetup service\", \"systemd\": {\"name\": \"cinder-lvm-losetup\", \"enabled\": true, \"daemon_reload\": true}}]}]]}}, \"cinder_volume_upgrade_tasks\": {\"description\": \"Upgrade tasks for the cinder-volume service (HA or non-HA)\", \"value\": [{\"name\": \"cinder-volume pre system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Unmount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}, \"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": \"image_conversion_nfs_enabled|bool\", \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"absent\", \"fstype\": \"nfs4\"}}]}, {\"name\": \"cinder-volume post system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 5\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}]}, \"cinder_volume_config_settings\": {\"description\": \"Config settings for the cinder-volume container (HA or non-HA)\", \"value\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", {\"cinder::image_conversion_dir\": \"/var/lib/cinder_image_conversion\"}, {}]}}, \"cinder_volume_volumes\": {\"description\": \"Volumes for the cinder-volume container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderVolumeOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_volume.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/lib/modules:/lib/modules:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, [\"/etc/target:/etc/target:z\"]]}, {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}, {\"if\": [\"cinder_nfs_conversion_dir_enabled\", [{\"str_replace\": {\"template\": \"DIR:DIR:slave\", \"params\": {\"DIR\": \"/var/lib/cinder_image_conversion\"}}}]]}]}}, \"cinder_volume_environment\": {\"description\": \"Docker environment for the cinder-volume container (HA or non-HA)\", \"value\": {\"map_merge\": [{\"get_param\": \"CinderVolumeOptEnvVars\"}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}]}}, \"cinder_backup_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-backup service (HA or non-HA)\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_backup_volumes\": {\"description\": \"Volumes for the cinder-backup container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderBackupOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_backup.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/lib/modules:/lib/modules:ro\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}}, \"cinder_backup_environment\": {\"description\": \"Docker environment for the cinder-backup container (HA or non-HA)\", \"value\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(123,'2026-06-09 08:02:09',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(124,'2026-06-09 08:02:09',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Cinder NVMeOF backend\\n\", \"parameters\": {\"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderNVMeOFBackendName\": {\"type\": \"string\", \"default\": \"tripleo_nvmeof\"}, \"CinderNVMeOFAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NVMeOF Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNVMeOFTargetPort\": {\"type\": \"number\", \"default\": 4420}, \"CinderNVMeOFTargetHelper\": {\"type\": \"string\", \"default\": \"nvmet\"}, \"CinderNVMeOFTargetProtocol\": {\"type\": \"string\", \"default\": \"nvmet_rdma\", \"description\": \"The target protocol, supported values are nvmet_rdma and nvmet_tcp.\\n\", \"constraints\": [{\"allowed_values\": [\"nvmet_rdma\", \"nvmet_tcp\"]}]}, \"CinderNVMeOFTargetPrefix\": {\"type\": \"string\", \"default\": \"nvme-subsystem\"}, \"CinderNVMeOFTargetPortId\": {\"type\": \"number\", \"default\": 1}, \"CinderNVMeOFTargetNameSpaceId\": {\"type\": \"number\", \"default\": 10}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"type\": \"json\", \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}}, \"outputs\": {\"cinder_nvmeof_host_prep_tasks\": {\"description\": \"Host prep tasks related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [{\"name\": \"ensure /etc/nvme exists\", \"file\": {\"path\": \"/etc/nvme\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]]}}, \"cinder_nvmeof_volumes\": {\"description\": \"Volumes related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [\"/etc/nvme:/etc/nvme:z\"]]}}, \"role_data\": {\"description\": \"Role data for the Cinder NVMeOF backend.\", \"value\": {\"service_name\": \"cinder_backend_nvmeof\", \"firewall_rules\": {\"120 LVM nvmet target\": {\"dport\": {\"get_param\": \"CinderNVMeOFTargetPort\"}}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::cinder::volume::cinder_enable_nvmeof_backend\": {\"get_param\": \"CinderEnableNVMeOFBackend\"}, \"tripleo::profile::base::cinder::volume::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_port\": {\"get_param\": \"CinderNVMeOFTargetPort\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_helper\": {\"get_param\": \"CinderNVMeOFTargetHelper\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_protocol\": {\"get_param\": \"CinderNVMeOFTargetProtocol\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_prefix\": {\"get_param\": \"CinderNVMeOFTargetPrefix\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_port_id\": {\"get_param\": \"CinderNVMeOFTargetPortId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_ns_id\": {\"get_param\": \"CinderNVMeOFTargetNameSpaceId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_ip_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}, \"cinder::backend::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNVMeOFAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nvmeof::backend_availability_zone\": {\"get_param\": \"CinderNVMeOFAvailabilityZone\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(125,'2026-06-09 08:02:09',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Provides the list of common container volumes and environment used by various cinder services.\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"CinderVolumeOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderBackupOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderVolumeOptEnvVars\": {\"default\": {}, \"description\": \"hash of optional environment variables\", \"type\": \"json\"}, \"CinderEnableIscsiBackend\": {\"default\": true, \"description\": \"Whether to enable or not the Iscsi backend for Cinder\", \"type\": \"boolean\"}, \"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderLVMConfigureVG\": {\"default\": true, \"description\": \"Whether to configure the \'cinder-volumes\' VG used by the LVM driver. When disabled (set to False), the LVM driver will work as long as the \'cinder-volumes\' VG has been created through some other means.\\n\", \"type\": \"boolean\"}, \"CinderLVMLoopDeviceSize\": {\"default\": 20480, \"description\": \"The size of the loopback file used by the cinder LVM driver.\", \"type\": \"number\"}, \"MultipathdEnable\": {\"default\": false, \"description\": \"Whether to enable the multipath daemon\", \"type\": \"boolean\"}, \"CinderVolumeCluster\": {\"default\": \"\", \"description\": \"The cluster name used for deploying the cinder-volume service in an active-active (A/A) configuration. This configuration requires the Cinder backend drivers support A/A, and the cinder-volume service not be managed by pacemaker. If these criteria are not met then the cluster name must be left blank.\\n\", \"type\": \"string\"}, \"CinderImageConversionNfsShare\": {\"default\": \"\", \"description\": \"When set, the NFS share to be used for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"CinderImageConversionNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options when using an NFS share for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"EnableEtcdInternalTLS\": {\"description\": \"Controls whether etcd and the cinder-volume service use TLS for cinder\'s lock manager, even when the rest of the internal API network is using TLS.\", \"type\": \"boolean\", \"default\": true}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephExternalMultiConfig\": {\"type\": \"json\", \"hidden\": true, \"description\": \"List of maps describing extra overrides which will be applied when configuring\\nextra external Ceph clusters. If this list is non-empty, ceph-ansible will run\\nan extra count(list) times using the same parameters as the first run except\\neach parameter within each map will override the defaults. If the following\\nwere used, the second run would configure the overcloud to also use the ceph2\\ncluster with all the previous parameters except /etc/ceph/ceph2.conf would have\\na mon_host entry containing the value of external_cluster_mon_ips below, and\\nnot the default CephExternalMonHost. Subsequent ceph-ansible runs are restricted\\nto just ceph clients. CephExternalMultiConfig may not be used to deploy additional\\ninternal Ceph clusters within one Heat stack. The map for each list should contain\\nnot tripleo-heat-template parameters but ceph-ansible parameters.\\n  - cluster: \'ceph2\'\\n    fsid: \'e2cba068-5f14-4b0f-b047-acf375c0004a\'\\n    external_cluster_mon_ips: \'172.18.0.5,172.18.0.6,172.18.0.7\'\\n    keys:\\n      - name: \\\"client.openstack\\\"\\n        caps:\\n          mgr: \\\"allow *\\\"\\n          mon: \\\"profile rbd\\\"\\n          osd: \\\"osd: profile rbd pool=volumes, profile rbd pool=backups, profile rbd pool=vms, profile rbd pool=images\\\"\\n        key: \\\"AQCwmeRcAAAAABAA6SQU/bGqFjlfLro5KxrB1Q==\\\"\\n        mode: \\\"0600\\\"\\n    dashboard_enabled: false\\n\", \"default\": []}}, \"conditions\": {\"cvol_active_active_tls_enabled\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderVolumeCluster\"}, \"\"]}}, {\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"EnableEtcdInternalTLS\"}]}, \"cinder_nfs_conversion_dir_enabled\": {\"not\": {\"equals\": [{\"get_param\": \"CinderImageConversionNfsShare\"}, \"\"]}}, \"cinder_configure_lvm\": {\"and\": [{\"get_param\": \"CinderLVMConfigureVG\"}, {\"or\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, {\"get_param\": \"CinderEnableNVMeOFBackend\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CinderNVMeOF\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\"}}, \"outputs\": {\"cinder_image_conversion_nfs_dir\": {\"description\": \"The directory where cinder does its image conversion when the directory is backed by an NFS share.\", \"value\": \"/var/lib/cinder_image_conversion\"}, \"cinder_common_host_prep_tasks\": {\"description\": \"Common host prep tasks for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_common_volumes\": {\"description\": \"Common volumes for all cinder services\", \"value\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}}, \"cinder_common_kolla_config_files\": {\"description\": \"Common kolla config_files for cinder-volume and cinder-backup services\", \"value\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-iscsid/*\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}]}, \"cinder_common_kolla_permissions\": {\"description\": \"Common kolla permissions for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, {\"path\": \"/etc/pki/tls/certs/etcd.crt\", \"owner\": \"cinder:cinder\"}, {\"path\": \"/etc/pki/tls/private/etcd.key\", \"owner\": \"cinder:cinder\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%cluster%>.client.*.keyring\", \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, \"for_each\": {\"<%cluster%>\": {\"yaql\": {\"expression\": \"$.data.multiconfig.select($.cluster)\", \"data\": {\"multiconfig\": {\"get_param\": \"CephExternalMultiConfig\"}}}}}}}]}}, \"cinder_volume_host_prep_and_system_upgrade_post_tasks\": {\"description\": \"Common host_prep and system_upgrade post tasks for cinder-volume\", \"value\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}, \"cinder_volume_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-volume service (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}, [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}], [{\"name\": \"cinder_configure_lvm fact\", \"set_fact\": {\"cinder_configure_lvm\": {\"if\": [\"cinder_configure_lvm\", true, false]}}}, {\"when\": \"cinder_configure_lvm|bool\", \"block\": [{\"name\": \"ensure LVM rpm dependencies are installed\", \"package\": {\"name\": \"lvm2\", \"state\": \"latest\"}}, {\"name\": \"cinder create LVM volume group dd\", \"command\": {\"list_join\": [\"\", [\"dd if=/dev/zero of=/var/lib/cinder/cinder-volumes bs=1 count=0 seek=\", {\"str_replace\": {\"template\": \"VALUE\", \"params\": {\"VALUE\": {\"get_param\": \"CinderLVMLoopDeviceSize\"}}}}, \"M\"]]}, \"args\": {\"creates\": \"/var/lib/cinder/cinder-volumes\"}}, {\"name\": \"Get or create LVM loopback device\", \"shell\": \"exit_code=0\\nexisting_device=$(losetup -j /var/lib/cinder/cinder-volumes -l -n -O NAME)\\nif [[ -z \\\"${existing_device}\\\" ]]; then\\n    losetup -f /var/lib/cinder/cinder-volumes --show\\n    exit_code=2\\nelse\\n    echo ${existing_device%$\'\\\\n\'*}\\nfi\\nexit ${exit_code}\", \"args\": {\"executable\": \"/bin/bash\"}, \"register\": \"_loopback_device\", \"changed_when\": \"_loopback_device.rc == 2\", \"failed_when\": \"_loopback_device.rc not in [0,2]\"}, {\"name\": \"Create LVM volume group\", \"community.general.lvg\": {\"vg\": \"cinder-volumes\", \"pvs\": \"{{ _loopback_device.stdout }}\", \"state\": \"present\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder create service to run losetup for LVM on startup\", \"copy\": {\"dest\": \"/etc/systemd/system/cinder-lvm-losetup.service\", \"content\": \"[Unit]\\nDescription=Cinder LVM losetup\\nDefaultDependencies=no\\nConflicts=umount.target\\nRequires=lvm2-monitor.service systemd-udev-settle.service\\nBefore=local-fs.target umount.target\\nAfter=var.mount lvm2-monitor.service systemd-udev-settle.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/sbin/losetup {{ _loopback_device.stdout }} /var/lib/cinder/cinder-volumes\\nExecStop=/sbin/losetup -d {{ _loopback_device.stdout }}\\nRemainAfterExit=yes\\n\\n[Install]\\nWantedBy=local-fs-pre.target\\n\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder enable the LVM losetup service\", \"systemd\": {\"name\": \"cinder-lvm-losetup\", \"enabled\": true, \"daemon_reload\": true}}]}]]}}, \"cinder_volume_upgrade_tasks\": {\"description\": \"Upgrade tasks for the cinder-volume service (HA or non-HA)\", \"value\": [{\"name\": \"cinder-volume pre system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Unmount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}, \"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": \"image_conversion_nfs_enabled|bool\", \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"absent\", \"fstype\": \"nfs4\"}}]}, {\"name\": \"cinder-volume post system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 5\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}]}, \"cinder_volume_config_settings\": {\"description\": \"Config settings for the cinder-volume container (HA or non-HA)\", \"value\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", {\"cinder::image_conversion_dir\": \"/var/lib/cinder_image_conversion\"}, {}]}}, \"cinder_volume_volumes\": {\"description\": \"Volumes for the cinder-volume container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderVolumeOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_volume.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/lib/modules:/lib/modules:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, [\"/etc/target:/etc/target:z\"]]}, {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}, {\"if\": [\"cinder_nfs_conversion_dir_enabled\", [{\"str_replace\": {\"template\": \"DIR:DIR:slave\", \"params\": {\"DIR\": \"/var/lib/cinder_image_conversion\"}}}]]}]}}, \"cinder_volume_environment\": {\"description\": \"Docker environment for the cinder-volume container (HA or non-HA)\", \"value\": {\"map_merge\": [{\"get_param\": \"CinderVolumeOptEnvVars\"}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}]}}, \"cinder_backup_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-backup service (HA or non-HA)\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_backup_volumes\": {\"description\": \"Volumes for the cinder-backup container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderBackupOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_backup.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/lib/modules:/lib/modules:ro\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}}, \"cinder_backup_environment\": {\"description\": \"Docker environment for the cinder-backup container (HA or non-HA)\", \"value\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(126,'2026-06-09 08:02:10',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Cinder NVMeOF backend\\n\", \"parameters\": {\"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderNVMeOFBackendName\": {\"type\": \"string\", \"default\": \"tripleo_nvmeof\"}, \"CinderNVMeOFAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NVMeOF Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNVMeOFTargetPort\": {\"type\": \"number\", \"default\": 4420}, \"CinderNVMeOFTargetHelper\": {\"type\": \"string\", \"default\": \"nvmet\"}, \"CinderNVMeOFTargetProtocol\": {\"type\": \"string\", \"default\": \"nvmet_rdma\", \"description\": \"The target protocol, supported values are nvmet_rdma and nvmet_tcp.\\n\", \"constraints\": [{\"allowed_values\": [\"nvmet_rdma\", \"nvmet_tcp\"]}]}, \"CinderNVMeOFTargetPrefix\": {\"type\": \"string\", \"default\": \"nvme-subsystem\"}, \"CinderNVMeOFTargetPortId\": {\"type\": \"number\", \"default\": 1}, \"CinderNVMeOFTargetNameSpaceId\": {\"type\": \"number\", \"default\": 10}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"type\": \"json\", \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}}, \"outputs\": {\"cinder_nvmeof_host_prep_tasks\": {\"description\": \"Host prep tasks related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [{\"name\": \"ensure /etc/nvme exists\", \"file\": {\"path\": \"/etc/nvme\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]]}}, \"cinder_nvmeof_volumes\": {\"description\": \"Volumes related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [\"/etc/nvme:/etc/nvme:z\"]]}}, \"role_data\": {\"description\": \"Role data for the Cinder NVMeOF backend.\", \"value\": {\"service_name\": \"cinder_backend_nvmeof\", \"firewall_rules\": {\"120 LVM nvmet target\": {\"dport\": {\"get_param\": \"CinderNVMeOFTargetPort\"}}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::cinder::volume::cinder_enable_nvmeof_backend\": {\"get_param\": \"CinderEnableNVMeOFBackend\"}, \"tripleo::profile::base::cinder::volume::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_port\": {\"get_param\": \"CinderNVMeOFTargetPort\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_helper\": {\"get_param\": \"CinderNVMeOFTargetHelper\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_protocol\": {\"get_param\": \"CinderNVMeOFTargetProtocol\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_prefix\": {\"get_param\": \"CinderNVMeOFTargetPrefix\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_port_id\": {\"get_param\": \"CinderNVMeOFTargetPortId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_ns_id\": {\"get_param\": \"CinderNVMeOFTargetNameSpaceId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_ip_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}, \"cinder::backend::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNVMeOFAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nvmeof::backend_availability_zone\": {\"get_param\": \"CinderNVMeOFAvailabilityZone\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(127,'2026-06-09 08:02:10',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"MySQL HA clustercheck service deployment using puppet This service is used by HAProxy in a HA scenario to report whether the local galera node is synced\\n\", \"parameters\": {\"ContainerClustercheckImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\"}, \"ContainerClustercheckConfigImage\": {\"description\": \"The container image to use for the clustercheck config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ClustercheckListener\": {\"default\": \"socat\", \"description\": \"How to expose the clustercheck service over TCP\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"socat\", \"xinetd\"]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MysqlPuppetBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerClustercheckImage\": \"ContainerClustercheckImage\", \"ContainerClustercheckConfigImage\": \"ContainerClustercheckConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerClustercheckImage\": {\"get_param\": \"ContainerClustercheckImage\"}, \"ContainerClustercheckConfigImage\": {\"get_param\": \"ContainerClustercheckConfigImage\"}}}]}}}}, \"conditions\": {\"socat_listener\": {\"equals\": [{\"get_param\": \"ClustercheckListener\"}, \"socat\"]}}, \"outputs\": {\"role_data\": {\"description\": \"Containerized service clustercheck using composable services.\", \"value\": {\"service_name\": \"clustercheck\", \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"MysqlPuppetBase\", \"role_data\", \"config_settings\"]}, {\"tripleo::profile::pacemaker::clustercheck::bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$FQDN$NETWORK\')}\", \"params\": {\"$FQDN\": {\"if\": [\"socat_listener\", \"\", \"fqdn_\"]}, \"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}}]}, \"puppet_config\": {\"config_volume\": \"clustercheck\", \"puppet_tags\": \"file\", \"step_config\": \"include tripleo::profile::pacemaker::clustercheck\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerClustercheckConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/clustercheck.json\": {\"command\": {\"if\": [\"socat_listener\", \"bash -c $* -- eval source /etc/sysconfig/clustercheck; exec socat -T\\\"${TRIPLEO_HEALTHCHECK_TIMEOUT:-2}\\\" \\\"$TRIPLEO_SOCAT_BIND\\\" system:\\\"grep -qPe \\\\\\\"^\\\\\\\\r\\\\$\\\\\\\" && /usr/bin/clustercheck\\\"\", \"/usr/sbin/xinetd -dontfork\"]}, \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}}, \"docker_config\": {\"step_2\": {\"clustercheck\": {\"start_order\": 1, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerClustercheckImage\"]}, \"restart\": \"always\", \"net\": \"host\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/clustercheck.json:/var/lib/kolla/config_files/config.json\", \"/var/lib/config-data/puppet-generated/clustercheck:/var/lib/kolla/config_files/src:ro\", \"/var/lib/mysql:/var/lib/mysql\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": null, \"upgrade_tasks\": null, \"update_tasks\": null, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop clustercheck container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"clustercheck\"], \"tripleo_delegate_to\": \"{{ groups[\'clustercheck\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(128,'2026-06-09 08:02:10',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized OVN Metadata agent\\n\", \"parameters\": {\"ContainerOvnMetadataImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\"}, \"ContainerNeutronConfigImage\": {\"description\": \"The container image to use for the neutron config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\"}, \"OvnMetadataAgentLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.neutron.agent.ovn-metadata\", \"file\": \"/var/log/containers/neutron/networking-ovn-metadata-agent.log\"}}, \"OVNEnableHaproxyDockerWrapper\": {\"description\": \"Generate a wrapper script so that haproxy is launched in a separate container.\", \"type\": \"boolean\", \"default\": true}, \"Debug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debugging on all services.\"}, \"OVNWrapperDebug\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Controls debugging for the wrapper scripts.\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"DeployIdentifier\": {\"default\": 1780992067, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"NeutronMetadataProxySharedSecret\": {\"description\": \"Shared secret to prevent spoofing\", \"type\": \"string\", \"hidden\": true, \"default\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\"}, \"NeutronMetadataWorkers\": {\"default\": 1, \"description\": \"Sets the number of worker processes for the neutron OVN metadata agent.\\nThe default value results in the configuration being left unset and a\\nsystem-dependent default will be chosen (usually the number of\\nprocessors). Please note that this can result in a large number of\\nprocesses and memory consumption on systems with a large core count. On\\nsuch systems it is recommended that a non-default value be selected that\\nmatches the load requirements.\\n\", \"type\": \"string\"}, \"NeutronPassword\": {\"description\": \"The password for the neutron service and db account, used by neutron agents.\", \"type\": \"string\", \"hidden\": true, \"default\": \"qzvItA1K3MLllVvkiCWVVbIpy\"}, \"OVNNorthboundServerPort\": {\"description\": \"Port of the OVN Northbound DB server\", \"type\": \"number\", \"default\": 6641}, \"OVNSouthboundServerPort\": {\"description\": \"Port of the OVN Southbound DB server\", \"type\": \"number\", \"default\": 6642}, \"OVNDbConnectionTimeout\": {\"description\": \"Timeout in seconds for the OVSDB connection transaction\", \"type\": \"number\", \"default\": 180}, \"OVNOvsdbProbeInterval\": {\"description\": \"Probe interval in ms for the OVSDB session\", \"type\": \"number\", \"default\": 60000}, \"MonitoringSubscriptionOvnMetadata\": {\"default\": \"overcloud-ovn-metadata\", \"type\": \"string\"}, \"OvnMetadataAgentDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging for OVN Metadata agent.\", \"type\": \"boolean\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"DockerAdditionalSockets\": {\"default\": [\"/var/lib/openstack/docker.sock\"], \"description\": \"Additional domain sockets for the docker daemon to bind to (useful for mounting into containers that launch other containers)\", \"type\": \"comma_delimited_list\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"OvnMetadataCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"OvnHardwareOffloadedQos\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Enable the QoS support for hardware offloaded ports\"}, \"OVNMetadataImageUpdateTimeout\": {\"description\": \"During update, how long we wait for the container image to be updated, in seconds.\\n\", \"type\": \"number\", \"default\": 600}, \"OVNMetadataUpdateTimeout\": {\"description\": \"During update, how long we wait for the container to be updated, in seconds.\\n\", \"type\": \"number\", \"default\": 600}}, \"conditions\": {\"haproxy_wrapper_enabled\": {\"equals\": [{\"get_param\": \"OVNEnableHaproxyDockerWrapper\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}, \"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"neutron_metadata_workers_unset\": {\"equals\": [{\"get_param\": \"NeutronMetadataWorkers\"}, \"\"]}, \"key_size_override_unset\": {\"equals\": [{\"get_param\": \"OvnMetadataCertificateKeySize\"}, \"\"]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"NeutronBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-base.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"NeutronLogging\": {\"type\": \"OS::TripleO::Services::Logging::NeutronCommon\", \"properties\": {\"NeutronServiceName\": \"ovn-metadata-agent\"}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerOvnMetadataImage\": \"ContainerOvnMetadataImage\", \"ContainerNeutronConfigImage\": \"ContainerNeutronConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerOvnMetadataImage\": {\"get_param\": \"ContainerOvnMetadataImage\"}, \"ContainerNeutronConfigImage\": {\"get_param\": \"ContainerNeutronConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for OVNMetadata agent\", \"value\": {\"service_name\": \"ovn_metadata\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionOvnMetadata\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"NeutronBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"NeutronLogging\", \"config_settings\"]}, {\"tripleo::profile::base::neutron::ovn_metadata_agent_wrappers::enable_haproxy_wrapper\": {\"get_param\": \"OVNEnableHaproxyDockerWrapper\"}, \"tripleo::profile::base::neutron::ovn_metadata_agent_wrappers::haproxy_process_wrapper\": \"/var/lib/neutron/ovn_metadata_haproxy_wrapper\", \"tripleo::profile::base::neutron::ovn_metadata_agent_wrappers::haproxy_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerOvnMetadataImage\"]}, \"tripleo::profile::base::neutron::ovn_metadata_agent_wrappers::debug\": {\"if\": [{\"get_param\": \"OVNWrapperDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"tripleo::profile::base::neutron::container_cli\": {\"get_param\": \"ContainerCli\"}, \"neutron::agents::ovn_metadata::shared_secret\": {\"get_param\": \"NeutronMetadataProxySharedSecret\"}, \"neutron::agents::ovn_metadata::auth_password\": {\"get_param\": \"NeutronPassword\"}, \"neutron::agents::ovn_metadata::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"neutron::agents::ovn_metadata::auth_tenant\": \"service\", \"neutron::agents::ovn_metadata::metadata_host\": {\"get_param\": [\"EndpointMap\", \"NovaMetadataCellInternal\", \"host_nobrackets\"]}, \"neutron::agents::ovn_metadata::ovsdb_connection_timeout\": {\"get_param\": \"OVNDbConnectionTimeout\"}, \"neutron::agents::ovn_metadata::ovsdb_probe_interval\": {\"get_param\": \"OVNOvsdbProbeInterval\"}, \"neutron::agents::ovn_metadata::hwol_qos_enabled\": {\"get_param\": \"OvnHardwareOffloadedQos\"}, \"ovn::northbound::port\": {\"get_param\": \"OVNNorthboundServerPort\"}, \"ovn::southbound::port\": {\"get_param\": \"OVNSouthboundServerPort\"}, \"neutron::agents::ovn_metadata::debug\": {\"if\": [{\"get_param\": \"OvnMetadataAgentDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"neutron::agents::ovn_metadata::metadata_protocol\": {\"if\": [\"internal_tls_enabled\", \"https\", \"http\"]}}, {\"if\": [\"neutron_metadata_workers_unset\", {}, {\"neutron::agents::ovn_metadata::metadata_workers\": {\"get_param\": \"NeutronMetadataWorkers\"}}]}, {\"if\": [\"internal_tls_enabled\", {\"tripleo::profile::base::neutron::ovn_metadata::ovn_nb_ca_cert\": {\"get_param\": \"InternalTLSCAFile\"}, \"tripleo::profile::base::neutron::ovn_metadata::ovn_sb_ca_cert\": {\"get_param\": \"InternalTLSCAFile\"}, \"tripleo::profile::base::neutron::ovn_metadata::protocol\": \"ssl\", \"tripleo::profile::base::neutron::ovn_metadata::ovn_nb_certificate\": \"/etc/pki/tls/certs/ovn_metadata.crt\", \"tripleo::profile::base::neutron::ovn_metadata::ovn_nb_private_key\": \"/etc/pki/tls/private/ovn_metadata.key\", \"tripleo::profile::base::neutron::ovn_metadata::ovn_sb_certificate\": \"/etc/pki/tls/certs/ovn_metadata.crt\", \"tripleo::profile::base::neutron::ovn_metadata::ovn_sb_private_key\": \"/etc/pki/tls/private/ovn_metadata.key\"}, {}]}]}, \"puppet_config\": {\"puppet_tags\": \"neutron_config,ovn_metadata_agent_config\", \"config_volume\": \"neutron\", \"step_config\": \"include tripleo::profile::base::neutron::ovn_metadata\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNeutronConfigImage\"]}, \"volumes\": [\"/lib/modules:/lib/modules:ro\", \"/run/openvswitch:/run/openvswitch:shared,z\"]}, \"kolla_config\": {\"/var/lib/kolla/config_files/ovn_metadata_agent.json\": {\"command\": {\"list_join\": [\" \", [\"/usr/bin/networking-ovn-metadata-agent --config-file /etc/neutron/neutron.conf --config-file /etc/neutron/plugins/networking-ovn/networking-ovn-metadata-agent.ini\", {\"get_attr\": [\"NeutronLogging\", \"cmd_extra_args\"]}]]}, \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/neutron\", \"owner\": \"neutron:neutron\", \"recurse\": true}, {\"path\": \"/var/lib/neutron\", \"owner\": \"neutron:neutron\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/ovn_metadata.crt\", \"owner\": \"neutron:neutron\", \"optional\": true, \"perm\": \"0644\"}, {\"path\": \"/etc/pki/tls/private/ovn_metadata.key\", \"owner\": \"neutron:neutron\", \"optional\": true, \"perm\": \"0644\"}]}}, \"container_config_scripts\": {\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, \"docker_config\": {\"step_2\": {\"create_haproxy_wrapper\": {\"start_order\": 1, \"detach\": false, \"net\": \"host\", \"pid\": \"host\", \"user\": \"root\", \"command\": {\"list_concat\": [[\"/container_puppet_apply.sh\", \"4\", \"file\", \"include ::tripleo::profile::base::neutron::ovn_metadata_agent_wrappers\"]]}, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerOvnMetadataImage\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"container_puppet_apply_volumes\"]}, [\"/run/openvswitch:/run/openvswitch:shared,z\", \"/var/lib/neutron:/var/lib/neutron:shared,z\"]]}}}, \"step_4\": {\"setup_ovs_manager\": {\"start_order\": 0, \"detach\": false, \"net\": \"host\", \"privileged\": true, \"user\": \"root\", \"command\": {\"list_concat\": [[\"/container_puppet_apply.sh\", \"4\", \"exec\", \"include tripleo::profile::base::neutron::ovn_metadata\"]]}, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerOvnMetadataImage\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"container_puppet_apply_volumes\"]}, [\"/lib/modules:/lib/modules:ro\", \"/run/openvswitch:/run/openvswitch:shared,z\"]]}, \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}, \"ovn_metadata_agent\": {\"start_order\": 1, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerOvnMetadataImage\"]}, \"net\": \"host\", \"pid\": \"host\", \"cgroupns\": \"host\", \"privileged\": true, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"NeutronLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/ovn_metadata_agent.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/neutron:/var/lib/kolla/config_files/src:ro\", \"/lib/modules:/lib/modules:ro\", \"/run/openvswitch:/run/openvswitch:shared,z\", \"/var/lib/neutron:/var/lib/neutron:shared,z\", \"/run/netns:/run/netns:shared\", \"/var/lib/neutron/kill_scripts:/etc/neutron/kill_scripts:shared,z\"], {\"if\": [\"docker_enabled\", [\"/var/lib/openstack:/var/lib/openstack\"], null]}, {\"if\": [\"haproxy_wrapper_enabled\", [\"/var/lib/neutron/ovn_metadata_haproxy_wrapper:/usr/local/bin/haproxy:ro\"], null]}, {\"if\": [\"internal_tls_enabled\", [\"/etc/pki/tls/certs/ovn_metadata.crt:/etc/pki/tls/certs/ovn_metadata.crt\", \"/etc/pki/tls/private/ovn_metadata.key:/etc/pki/tls/private/ovn_metadata.key\"], null]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"metadata_settings\": {\"list_concat\": [{\"get_attr\": [\"NeutronBase\", \"role_data\", \"metadata_settings\"]}, {\"if\": [\"internal_tls_enabled\", [{\"service\": \"ovn_metadata\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"OvnDbsNetwork\"]}, \"type\": \"node\"}], null]}]}, \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"ovn_metadata\", \"dns\": {\"str_replace\": {\"template\": \"{{fqdn_$NETWORK}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OvnDbsNetwork\"]}}}}, \"principal\": {\"str_replace\": {\"template\": \"ovn_metadata/{{fqdn_$NETWORK}}@{{idm_realm}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OvnDbsNetwork\"]}}}}, \"run_after\": \"systemctl restart tripleo_ovn_metadata_agent\\n\", \"key_size\": {\"if\": [\"key_size_override_unset\", {\"get_param\": \"CertificateKeySize\"}, {\"get_param\": \"OvnMetadataCertificateKeySize\"}]}, \"ca\": \"ipa\"}]}}]}], \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"NeutronLogging\", \"host_prep_tasks\"]}, [{\"name\": \"create /run/netns with temp namespace\", \"command\": \"ip netns add ns_temp\", \"register\": \"ipnetns_add_result\", \"failed_when\": false}, {\"name\": \"remove temp namespace\", \"command\": \"ip netns delete ns_temp\", \"failed_when\": false, \"when\": [\"ipnetns_add_result.rc is defined\", \"ipnetns_add_result.rc == 0\"]}, {\"name\": \"create /var/lib/neutron\", \"file\": {\"path\": \"/var/lib/neutron\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}, {\"name\": \"set conditions\", \"set_fact\": {\"haproxy_wrapper_enabled\": {\"get_param\": \"OVNEnableHaproxyDockerWrapper\"}, \"debug_enabled\": {\"if\": [{\"get_param\": \"OVNWrapperDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"docker_additional_sockets\": {\"get_param\": \"DockerAdditionalSockets\"}}}, {\"name\": \"create kill_scripts directory within /var/lib/neutron\", \"file\": {\"state\": \"directory\", \"path\": \"/var/lib/neutron/kill_scripts\"}}, {\"name\": \"create haproxy kill script\", \"when\": \"haproxy_wrapper_enabled|bool\", \"copy\": {\"dest\": \"/var/lib/neutron/kill_scripts/haproxy-kill\", \"mode\": 493, \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/kill-script\"}}}]]}, \"upgrade_tasks\": [], \"external_update_tasks\": [{\"name\": \"Check if python3-openvswitch3.1 workaround is needed\", \"delegate_to\": \"{{ item }}\", \"become\": true, \"tags\": [\"ovn\", \"ovn_image\"], \"when\": \"step|int == 1\", \"shell\": \"if podman exec ovn_metadata_agent rpm -q python3-openvswitch3.1 > /dev/null ; then echo REQUIRED; else echo OK ; fi\\n\", \"register\": \"metadata_python_ovs_3_1\", \"failed_when\": false, \"loop\": \"{{ groups[\'ovn_metadata\'] | difference(groups[\'excluded_overcloud\']) }}\"}, {\"name\": \"Update ovn_metadata_agents\", \"vars\": {\"hosts_to_update_metadata\": \"{{ metadata_python_ovs_3_1.results | selectattr(\'stdout\', \'eq\', \'REQUIRED\') | map(attribute=\'item\') | list }}\"}, \"tags\": [\"ovn\", \"ovn_image\"], \"when\": [\"step|int == 1\", \"hosts_to_update_metadata | length > 0\"], \"block\": [{\"name\": \"Force pull image in case image name doesn\'t change.\", \"become\": true, \"loop\": \"{{ hosts_to_update_metadata }}\", \"delegate_to\": \"{{ item }}\", \"async\": {\"get_param\": \"OVNMetadataImageUpdateTimeout\"}, \"poll\": 0, \"register\": \"ovn_metadata_image_update\", \"containers.podman.podman_image\": {\"name\": {\"get_param\": \"ContainerOvnMetadataImage\"}, \"validate_certs\": false, \"force\": true}}, {\"name\": \"Was the ovn_metadata_agent image pull successful.\", \"when\": [\"\'results\' in ovn_metadata_image_update\"], \"become\": true, \"delegate_to\": \"{{ async_result_item.item }}\", \"async_status\": {\"jid\": \"{{ async_result_item.ansible_job_id }}\"}, \"loop\": \"{{ovn_metadata_image_update.results }}\", \"loop_control\": {\"loop_var\": \"async_result_item\"}, \"register\": \"async_poll_results\", \"until\": \"async_poll_results.finished\", \"retries\": {\"get_param\": \"OVNMetadataImageUpdateTimeout\"}, \"delay\": 1}, {\"name\": \"Now rotate all ovn_metadata_agents\", \"tags\": [\"ovn_metadata_parallel\"], \"delegate_to\": \"{{ item }}\", \"become\": true, \"tripleo_container_manage\": {\"config_dir\": \"/var/lib/tripleo-config/container-startup-config/step_4\", \"config_id\": [\"ovn_metadata_agent\"], \"config_patterns\": \"*ovn_metadata_agent.json\", \"config_overrides\": {\".*ovn_metadata_agent\": {\"image\": {\"get_param\": \"ContainerOvnMetadataImage\"}, \"name\": \"ovn_metadata_agent\"}}}, \"loop\": \"{{ hosts_to_update_metadata }}\", \"async\": {\"get_param\": \"OVNMetadataImageUpdateTimeout\"}, \"poll\": 0}]}, {\"name\": \"Now rotate all ovn_metadata_agents\", \"vars\": {\"hosts_to_update_metadata\": \"{{ metadata_python_ovs_3_1.results | selectattr(\'stdout\', \'eq\', \'REQUIRED\') | map(attribute=\'item\') | list }}\"}, \"tags\": [\"never\", \"ovn_metadata_serial\"], \"when\": [\"step|int == 1\", \"hosts_to_update_metadata | length > 0\"], \"delegate_to\": \"{{ item }}\", \"become\": true, \"tripleo_container_manage\": {\"config_dir\": \"/var/lib/tripleo-config/container-startup-config/step_4\", \"config_id\": [\"ovn_metadata_agent\"], \"config_patterns\": \"*ovn_metadata_agent.json\", \"config_overrides\": {\".*ovn_metadata_agent\": {\"image\": {\"get_param\": \"ContainerOvnMetadataImage\"}, \"name\": \"ovn_metadata_agent\"}}}, \"loop\": \"{{ hosts_to_update_metadata }}\", \"loop_control\": {\"pause\": 1}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (129,'2026-06-09 08:02:10',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(130,'2026-06-09 08:02:10',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for nova-compute containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared docker config scripts\", \"value\": {\"nova_statedir_ownership.py\": {\"mode\": \"0700\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/nova_statedir_ownership.py\"}}, \"nova_wait_for_compute_service.py\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/nova_wait_for_compute_service.py\"}}}}, \"nova_compute_common_deploy_steps_tasks\": {\"description\": \"Common host prep tasks for nova-compute services (compute + ironic)\", \"value\": [{\"block\": [{\"name\": \"is additonal Cell?\", \"set_fact\": {\"nova_additional_cell\": {\"get_param\": \"NovaAdditionalCell\"}}}, {\"name\": \"check if discover hosts is required\", \"when\": [\"not nova_additional_cell|bool\", \"nova_cellv2_discovery_done is not defined\"], \"block\": [{\"name\": \"discover via nova_manager?\", \"set_fact\": {\"nova_cellv2_discovery_delegate_host\": \"{{ groups[\'nova_manager\'][0] }}\", \"nova_cellv2_discovery_container\": \"nova_manager\"}, \"when\": [\"groups[\'nova_manager\'] is defined and (groups[\'nova_manager\']|length>0)\"]}, {\"name\": \"discover via nova_api?\", \"set_fact\": {\"nova_cellv2_discovery_delegate_host\": \"{{ groups[\'nova_api\'][0] }}\", \"nova_cellv2_discovery_container\": \"nova_api\"}, \"when\": [\"nova_cellv2_discovery_delegate_host is not defined\", \"groups[\'nova_api\'] is defined and (groups[\'nova_api\']|length>0)\"]}, {\"name\": \"Warn if no discovery host available\", \"fail\": {\"msg\": \"No hosts available to run nova cell_v2 host discovery.\"}, \"ignore_errors\": true, \"when\": [\"nova_cellv2_discovery_delegate_host is not defined\"]}, {\"name\": \"Discovering nova hosts\", \"command\": \"{{ container_cli }} exec {{ nova_cellv2_discovery_container }} nova-manage cell_v2 discover_hosts --by-service\", \"become\": true, \"changed_when\": false, \"delegate_to\": \"{{ nova_cellv2_discovery_delegate_host }}\", \"when\": [\"nova_cellv2_discovery_delegate_host is defined\"]}, {\"set_fact\": {\"nova_cellv2_discovery_done\": true}}]}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(131,'2026-06-09 08:02:10',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(132,'2026-06-09 08:02:10',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(133,'2026-06-09 08:02:10',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(134,'2026-06-09 08:02:10',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Cinder NVMeOF backend\\n\", \"parameters\": {\"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderNVMeOFBackendName\": {\"type\": \"string\", \"default\": \"tripleo_nvmeof\"}, \"CinderNVMeOFAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NVMeOF Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNVMeOFTargetPort\": {\"type\": \"number\", \"default\": 4420}, \"CinderNVMeOFTargetHelper\": {\"type\": \"string\", \"default\": \"nvmet\"}, \"CinderNVMeOFTargetProtocol\": {\"type\": \"string\", \"default\": \"nvmet_rdma\", \"description\": \"The target protocol, supported values are nvmet_rdma and nvmet_tcp.\\n\", \"constraints\": [{\"allowed_values\": [\"nvmet_rdma\", \"nvmet_tcp\"]}]}, \"CinderNVMeOFTargetPrefix\": {\"type\": \"string\", \"default\": \"nvme-subsystem\"}, \"CinderNVMeOFTargetPortId\": {\"type\": \"number\", \"default\": 1}, \"CinderNVMeOFTargetNameSpaceId\": {\"type\": \"number\", \"default\": 10}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"type\": \"json\", \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}}, \"outputs\": {\"cinder_nvmeof_host_prep_tasks\": {\"description\": \"Host prep tasks related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [{\"name\": \"ensure /etc/nvme exists\", \"file\": {\"path\": \"/etc/nvme\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]]}}, \"cinder_nvmeof_volumes\": {\"description\": \"Volumes related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [\"/etc/nvme:/etc/nvme:z\"]]}}, \"role_data\": {\"description\": \"Role data for the Cinder NVMeOF backend.\", \"value\": {\"service_name\": \"cinder_backend_nvmeof\", \"firewall_rules\": {\"120 LVM nvmet target\": {\"dport\": {\"get_param\": \"CinderNVMeOFTargetPort\"}}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::cinder::volume::cinder_enable_nvmeof_backend\": {\"get_param\": \"CinderEnableNVMeOFBackend\"}, \"tripleo::profile::base::cinder::volume::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_port\": {\"get_param\": \"CinderNVMeOFTargetPort\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_helper\": {\"get_param\": \"CinderNVMeOFTargetHelper\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_protocol\": {\"get_param\": \"CinderNVMeOFTargetProtocol\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_prefix\": {\"get_param\": \"CinderNVMeOFTargetPrefix\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_port_id\": {\"get_param\": \"CinderNVMeOFTargetPortId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_ns_id\": {\"get_param\": \"CinderNVMeOFTargetNameSpaceId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_ip_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}, \"cinder::backend::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNVMeOFAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nvmeof::backend_availability_zone\": {\"get_param\": \"CinderNVMeOFAvailabilityZone\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(135,'2026-06-09 08:02:10',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(136,'2026-06-09 08:02:10',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Nova base service. Shared for all Nova services.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"NovaPassword\": {\"description\": \"The password for the nova service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"E43sBALvNAsJYgcBpWfsAoz9C\"}, \"NeutronPassword\": {\"description\": \"The password for the neutron service and db account, used by neutron agents.\", \"type\": \"string\", \"hidden\": true, \"default\": \"qzvItA1K3MLllVvkiCWVVbIpy\"}, \"PlacementPassword\": {\"description\": \"The password for the Placement service and db account\", \"type\": \"string\", \"hidden\": true, \"default\": \"qMFVkTRvhZKx21tsfFHzUpJTe\"}, \"PlacementAPIInterface\": {\"type\": \"string\", \"description\": \"Endpoint interface to be used for the placement API.\\n\", \"default\": \"internal\"}, \"NovaOVSBridge\": {\"default\": \"br-int\", \"description\": \"Name of integration bridge used by Open vSwitch\", \"type\": \"string\"}, \"Debug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debugging on all services.\"}, \"NovaDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Nova services.\", \"type\": \"boolean\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"EnableConfigPurge\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Remove configuration that is not generated by TripleO. Used to avoid configuration remnants after upgrades.\\n\"}, \"UpgradeLevelNovaCompute\": {\"type\": \"string\", \"description\": \"Nova Compute upgrade level\", \"default\": \"\"}, \"NovaOVSDBConnection\": {\"type\": \"string\", \"description\": \"OVS DB connection string to used by Nova\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NovaSyncPowerStateInterval\": {\"type\": \"number\", \"description\": \"Interval to sync power states between the database and the hypervisor. Set to -1 to disable. Setting this to 0 will run at the default rate(60) defined in oslo.service.\", \"default\": 600}, \"RpcUseSSL\": {\"default\": true, \"description\": \"Messaging client subscriber parameter to specify an SSL connection to the messaging host.\\n\", \"type\": \"string\"}, \"NovaAdditionalCell\": {\"default\": false, \"description\": \"Whether this is an cell additional to the default cell.\", \"type\": \"boolean\"}, \"NovaCrossAZAttach\": {\"default\": true, \"description\": \"Whether instances can attach cinder volumes from a different availability zone.\", \"type\": \"boolean\"}, \"MemcachedTLS\": {\"default\": true, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}}, \"conditions\": {\"compute_upgrade_level_set\": {\"not\": {\"equals\": [{\"get_param\": \"UpgradeLevelNovaCompute\"}, \"\"]}}, \"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"nova::ovsdb_connection\": \"NovaOVSDBConnection\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"NovaOVSDBConnection\": {\"get_param\": \"NovaOVSDBConnection\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Nova base service.\", \"value\": {\"service_name\": \"nova_base\", \"config_settings\": {\"map_merge\": [{\"nova::my_ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NovaApiNetwork\"]}}}}, \"nova::rabbit_use_ssl\": {\"get_param\": \"RpcUseSSL\"}, \"nova::keystone::service_user::send_service_user_token\": true, \"nova::keystone::service_user::project_name\": \"service\", \"nova::keystone::service_user::password\": {\"get_param\": \"NovaPassword\"}, \"nova::keystone::service_user::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"nova::keystone::service_user::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::placement::project_name\": \"service\", \"nova::placement::password\": {\"get_param\": \"PlacementPassword\"}, \"nova::placement::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"nova::placement::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::placement::valid_interfaces\": {\"get_param\": \"PlacementAPIInterface\"}, \"nova::os_region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::logging::debug\": {\"if\": [{\"get_param\": \"NovaDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"nova::purge_config\": {\"get_param\": \"EnableConfigPurge\"}, \"nova::network::neutron::project_name\": \"service\", \"nova::network::neutron::username\": \"neutron\", \"nova::network::neutron::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"nova::dhcp_domain\": \"\", \"nova::network::neutron::password\": {\"get_param\": \"NeutronPassword\"}, \"nova::network::neutron::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"nova::network::neutron::valid_interfaces\": \"internal\", \"nova::glance::valid_interfaces\": \"internal\", \"nova::rabbit_heartbeat_timeout_threshold\": 60, \"nova::cinder_catalog_info\": \"volumev3:cinderv3:internalURL\", \"nova::host\": \"%{hiera(\'fqdn_canonical\')}\", \"nova::notify_on_state_change\": \"vm_and_task_state\", \"nova::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"nova::notification_format\": \"unversioned\", \"nova::network::neutron::auth_type\": \"v3password\", \"nova::db::database_db_max_retries\": -1, \"nova::db::database_max_retries\": -1, \"nova::network::neutron::ovs_bridge\": {\"get_param\": \"NovaOVSBridge\"}, \"nova::compute::sync_power_state_interval\": {\"get_param\": \"NovaSyncPowerStateInterval\"}, \"nova_is_additional_cell\": {\"get_param\": \"NovaAdditionalCell\"}, \"nova::cross_az_attach\": {\"get_param\": \"NovaCrossAZAttach\"}, \"nova::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"nova::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}, \"nova::cache::backend\": {\"if\": [\"tls_cache_enabled\", \"dogpile.cache.pymemcache\", \"dogpile.cache.memcached\"]}, \"nova::rabbit_heartbeat_in_pthread\": false, \"nova::upgrade_level_compute\": {\"if\": [\"compute_upgrade_level_set\", {\"get_param\": \"UpgradeLevelNovaCompute\"}]}}, {\"get_attr\": [\"RoleParametersValue\", \"value\"]}]}, \"service_config_settings\": {\"rabbitmq\": {\"nova::rabbit_use_ssl\": {\"get_param\": \"RpcUseSSL\"}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(137,'2026-06-09 08:02:11',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (138,'2026-06-09 08:02:11',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Provides the list of common container volumes and environment used by various cinder services.\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"CinderVolumeOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderBackupOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"CinderVolumeOptEnvVars\": {\"default\": {}, \"description\": \"hash of optional environment variables\", \"type\": \"json\"}, \"CinderEnableIscsiBackend\": {\"default\": true, \"description\": \"Whether to enable or not the Iscsi backend for Cinder\", \"type\": \"boolean\"}, \"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderLVMConfigureVG\": {\"default\": true, \"description\": \"Whether to configure the \'cinder-volumes\' VG used by the LVM driver. When disabled (set to False), the LVM driver will work as long as the \'cinder-volumes\' VG has been created through some other means.\\n\", \"type\": \"boolean\"}, \"CinderLVMLoopDeviceSize\": {\"default\": 20480, \"description\": \"The size of the loopback file used by the cinder LVM driver.\", \"type\": \"number\"}, \"MultipathdEnable\": {\"default\": false, \"description\": \"Whether to enable the multipath daemon\", \"type\": \"boolean\"}, \"CinderVolumeCluster\": {\"default\": \"\", \"description\": \"The cluster name used for deploying the cinder-volume service in an active-active (A/A) configuration. This configuration requires the Cinder backend drivers support A/A, and the cinder-volume service not be managed by pacemaker. If these criteria are not met then the cluster name must be left blank.\\n\", \"type\": \"string\"}, \"CinderImageConversionNfsShare\": {\"default\": \"\", \"description\": \"When set, the NFS share to be used for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"CinderImageConversionNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options when using an NFS share for Cinder\'s image conversion directory.\", \"type\": \"string\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"EnableEtcdInternalTLS\": {\"description\": \"Controls whether etcd and the cinder-volume service use TLS for cinder\'s lock manager, even when the rest of the internal API network is using TLS.\", \"type\": \"boolean\", \"default\": true}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephExternalMultiConfig\": {\"type\": \"json\", \"hidden\": true, \"description\": \"List of maps describing extra overrides which will be applied when configuring\\nextra external Ceph clusters. If this list is non-empty, ceph-ansible will run\\nan extra count(list) times using the same parameters as the first run except\\neach parameter within each map will override the defaults. If the following\\nwere used, the second run would configure the overcloud to also use the ceph2\\ncluster with all the previous parameters except /etc/ceph/ceph2.conf would have\\na mon_host entry containing the value of external_cluster_mon_ips below, and\\nnot the default CephExternalMonHost. Subsequent ceph-ansible runs are restricted\\nto just ceph clients. CephExternalMultiConfig may not be used to deploy additional\\ninternal Ceph clusters within one Heat stack. The map for each list should contain\\nnot tripleo-heat-template parameters but ceph-ansible parameters.\\n  - cluster: \'ceph2\'\\n    fsid: \'e2cba068-5f14-4b0f-b047-acf375c0004a\'\\n    external_cluster_mon_ips: \'172.18.0.5,172.18.0.6,172.18.0.7\'\\n    keys:\\n      - name: \\\"client.openstack\\\"\\n        caps:\\n          mgr: \\\"allow *\\\"\\n          mon: \\\"profile rbd\\\"\\n          osd: \\\"osd: profile rbd pool=volumes, profile rbd pool=backups, profile rbd pool=vms, profile rbd pool=images\\\"\\n        key: \\\"AQCwmeRcAAAAABAA6SQU/bGqFjlfLro5KxrB1Q==\\\"\\n        mode: \\\"0600\\\"\\n    dashboard_enabled: false\\n\", \"default\": []}}, \"conditions\": {\"cvol_active_active_tls_enabled\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderVolumeCluster\"}, \"\"]}}, {\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"EnableEtcdInternalTLS\"}]}, \"cinder_nfs_conversion_dir_enabled\": {\"not\": {\"equals\": [{\"get_param\": \"CinderImageConversionNfsShare\"}, \"\"]}}, \"cinder_configure_lvm\": {\"and\": [{\"get_param\": \"CinderLVMConfigureVG\"}, {\"or\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, {\"get_param\": \"CinderEnableNVMeOFBackend\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"CinderNVMeOF\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\"}}, \"outputs\": {\"cinder_image_conversion_nfs_dir\": {\"description\": \"The directory where cinder does its image conversion when the directory is backed by an NFS share.\", \"value\": \"/var/lib/cinder_image_conversion\"}, \"cinder_common_host_prep_tasks\": {\"description\": \"Common host prep tasks for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_common_volumes\": {\"description\": \"Common volumes for all cinder services\", \"value\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}}, \"cinder_common_kolla_config_files\": {\"description\": \"Common kolla config_files for cinder-volume and cinder-backup services\", \"value\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-iscsid/*\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}]}, \"cinder_common_kolla_permissions\": {\"description\": \"Common kolla permissions for cinder-volume and cinder-backup services\", \"value\": {\"list_concat\": [[{\"path\": \"/var/log/cinder\", \"owner\": \"cinder:cinder\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, {\"path\": \"/etc/pki/tls/certs/etcd.crt\", \"owner\": \"cinder:cinder\"}, {\"path\": \"/etc/pki/tls/private/etcd.key\", \"owner\": \"cinder:cinder\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%cluster%>.client.*.keyring\", \"owner\": \"cinder:cinder\", \"perm\": \"0600\"}, \"for_each\": {\"<%cluster%>\": {\"yaql\": {\"expression\": \"$.data.multiconfig.select($.cluster)\", \"data\": {\"multiconfig\": {\"get_param\": \"CephExternalMultiConfig\"}}}}}}}]}}, \"cinder_volume_host_prep_and_system_upgrade_post_tasks\": {\"description\": \"Common host_prep and system_upgrade post tasks for cinder-volume\", \"value\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}, \"cinder_volume_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-volume service (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}, [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}], [{\"name\": \"cinder_configure_lvm fact\", \"set_fact\": {\"cinder_configure_lvm\": {\"if\": [\"cinder_configure_lvm\", true, false]}}}, {\"when\": \"cinder_configure_lvm|bool\", \"block\": [{\"name\": \"ensure LVM rpm dependencies are installed\", \"package\": {\"name\": \"lvm2\", \"state\": \"latest\"}}, {\"name\": \"cinder create LVM volume group dd\", \"command\": {\"list_join\": [\"\", [\"dd if=/dev/zero of=/var/lib/cinder/cinder-volumes bs=1 count=0 seek=\", {\"str_replace\": {\"template\": \"VALUE\", \"params\": {\"VALUE\": {\"get_param\": \"CinderLVMLoopDeviceSize\"}}}}, \"M\"]]}, \"args\": {\"creates\": \"/var/lib/cinder/cinder-volumes\"}}, {\"name\": \"Get or create LVM loopback device\", \"shell\": \"exit_code=0\\nexisting_device=$(losetup -j /var/lib/cinder/cinder-volumes -l -n -O NAME)\\nif [[ -z \\\"${existing_device}\\\" ]]; then\\n    losetup -f /var/lib/cinder/cinder-volumes --show\\n    exit_code=2\\nelse\\n    echo ${existing_device%$\'\\\\n\'*}\\nfi\\nexit ${exit_code}\", \"args\": {\"executable\": \"/bin/bash\"}, \"register\": \"_loopback_device\", \"changed_when\": \"_loopback_device.rc == 2\", \"failed_when\": \"_loopback_device.rc not in [0,2]\"}, {\"name\": \"Create LVM volume group\", \"community.general.lvg\": {\"vg\": \"cinder-volumes\", \"pvs\": \"{{ _loopback_device.stdout }}\", \"state\": \"present\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder create service to run losetup for LVM on startup\", \"copy\": {\"dest\": \"/etc/systemd/system/cinder-lvm-losetup.service\", \"content\": \"[Unit]\\nDescription=Cinder LVM losetup\\nDefaultDependencies=no\\nConflicts=umount.target\\nRequires=lvm2-monitor.service systemd-udev-settle.service\\nBefore=local-fs.target umount.target\\nAfter=var.mount lvm2-monitor.service systemd-udev-settle.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/sbin/losetup {{ _loopback_device.stdout }} /var/lib/cinder/cinder-volumes\\nExecStop=/sbin/losetup -d {{ _loopback_device.stdout }}\\nRemainAfterExit=yes\\n\\n[Install]\\nWantedBy=local-fs-pre.target\\n\"}, \"when\": [\"not (ansible_check_mode | bool)\"]}, {\"name\": \"cinder enable the LVM losetup service\", \"systemd\": {\"name\": \"cinder-lvm-losetup\", \"enabled\": true, \"daemon_reload\": true}}]}]]}}, \"cinder_volume_upgrade_tasks\": {\"description\": \"Upgrade tasks for the cinder-volume service (HA or non-HA)\", \"value\": [{\"name\": \"cinder-volume pre system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Unmount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}, \"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": \"image_conversion_nfs_enabled|bool\", \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"absent\", \"fstype\": \"nfs4\"}}]}, {\"name\": \"cinder-volume post system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 5\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Support using an NFS share for cinder image conversion\", \"vars\": {\"image_conversion_nfs_enabled\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", true, false]}}, \"when\": [\"image_conversion_nfs_enabled|bool\"], \"block\": [{\"name\": \"Create cinder image conversion directory\", \"file\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"directory\"}}, {\"name\": \"Mount cinder\'s image conversion NFS share\", \"vars\": {\"image_conversion_nfs_share\": {\"get_param\": \"CinderImageConversionNfsShare\"}, \"image_conversion_nfs_options\": {\"get_param\": \"CinderImageConversionNfsOptions\"}}, \"mount\": {\"path\": \"/var/lib/cinder_image_conversion\", \"state\": \"mounted\", \"fstype\": \"nfs4\", \"src\": \"{{ image_conversion_nfs_share }}\", \"opts\": \"{{ image_conversion_nfs_options }}\"}}]}]}]}, \"cinder_volume_config_settings\": {\"description\": \"Config settings for the cinder-volume container (HA or non-HA)\", \"value\": {\"if\": [\"cinder_nfs_conversion_dir_enabled\", {\"cinder::image_conversion_dir\": \"/var/lib/cinder_image_conversion\"}, {}]}}, \"cinder_volume_volumes\": {\"description\": \"Volumes for the cinder-volume container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderVolumeOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_volume.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/lib/modules:/lib/modules:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"CinderEnableIscsiBackend\"}, [\"/etc/target:/etc/target:z\"]]}, {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}, {\"if\": [\"cinder_nfs_conversion_dir_enabled\", [{\"str_replace\": {\"template\": \"DIR:DIR:slave\", \"params\": {\"DIR\": \"/var/lib/cinder_image_conversion\"}}}]]}]}}, \"cinder_volume_environment\": {\"description\": \"Docker environment for the cinder-volume container (HA or non-HA)\", \"value\": {\"map_merge\": [{\"get_param\": \"CinderVolumeOptEnvVars\"}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}]}}, \"cinder_backup_host_prep_tasks\": {\"description\": \"Host prep tasks for the cinder-backup service (HA or non-HA)\", \"value\": {\"list_concat\": [[{\"name\": \"create fcontext entry for cinder data\", \"community.general.sefcontext\": {\"target\": \"/var/lib/cinder(/.*)?\", \"setype\": \"container_file_t\", \"state\": \"present\"}}, {\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/cinder\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/cinder\", \"setype\": \"container_file_t\"}]}, {\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}}, \"cinder_backup_volumes\": {\"description\": \"Volumes for the cinder-backup container (HA or non-HA)\", \"value\": {\"list_concat\": [{\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/config-data/puppet-generated/cinder:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/cinder:/var/log/cinder:z\"], {\"if\": [\"cvol_active_active_tls_enabled\", [\"/etc/pki/tls/certs/etcd.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/etcd.crt:ro\", \"/etc/pki/tls/private/etcd.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/etcd.key:ro\"]]}]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}, {\"get_param\": \"CinderBackupOptVolumes\"}, [\"/var/lib/kolla/config_files/cinder_backup.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/dev:/dev\", \"/run:/run\", \"/sys:/sys\", \"/lib/modules:/lib/modules:ro\", \"/var/lib/cinder:/var/lib/cinder:z\", \"/var/lib/iscsi:/var/lib/iscsi:z\"], {\"if\": [{\"get_param\": \"MultipathdEnable\"}, [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}}, \"cinder_backup_environment\": {\"description\": \"Docker environment for the cinder-backup container (HA or non-HA)\", \"value\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(139,'2026-06-09 08:02:11',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Cinder base service. Shared by all Cinder services.\\n\", \"parameters\": {\"CinderStorageAvailabilityZone\": {\"default\": \"nova\", \"description\": \"The Cinder service\'s storage availability zone.\", \"type\": \"string\"}, \"CinderPassword\": {\"description\": \"The password for the cinder service and db account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"CinderDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging on Cinder services.\", \"type\": \"boolean\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"CinderCronDbPurgeMinute\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Minute\\n\", \"default\": \"1\"}, \"CinderCronDbPurgeHour\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Hour\\n\", \"default\": \"0\"}, \"CinderCronDbPurgeMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month Day\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeMonth\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Week Day\\n\", \"default\": \"*\"}, \"CinderCronDbPurgeUser\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - User\\n\", \"default\": \"cinder\"}, \"CinderCronDbPurgeAge\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age\\n\", \"default\": \"30\"}, \"CinderCronDbPurgeDestination\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Log destination\\n\", \"default\": \"/var/log/cinder/cinder-rowsflush.log\"}, \"CinderCronDbPurgeMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Delay\\n\", \"default\": \"3600\"}, \"CinderRpcResponseTimeout\": {\"default\": 60, \"description\": \"Cinder\'s RPC response timeout, in seconds.\", \"type\": \"number\"}, \"NovaPassword\": {\"type\": \"string\", \"description\": \"The password for the nova service and db account\", \"hidden\": true, \"default\": \"E43sBALvNAsJYgcBpWfsAoz9C\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Cinder base service.\", \"value\": {\"service_name\": \"cinder_base\", \"config_settings\": {\"cinder::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"cinder\", \"password\": {\"get_param\": \"CinderPassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/cinder\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"cinder\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"cinder::logging::debug\": {\"if\": [{\"get_param\": \"CinderDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"cinder::storage_availability_zone\": {\"get_param\": \"CinderStorageAvailabilityZone\"}, \"cinder::rabbit_heartbeat_timeout_threshold\": 60, \"cinder::rpc_response_timeout\": {\"get_param\": \"CinderRpcResponseTimeout\"}, \"cinder::rabbit_heartbeat_in_pthread\": false, \"cinder::db::database_db_max_retries\": -1, \"cinder::db::database_max_retries\": -1, \"cinder::cron::db_purge::minute\": {\"get_param\": \"CinderCronDbPurgeMinute\"}, \"cinder::cron::db_purge::hour\": {\"get_param\": \"CinderCronDbPurgeHour\"}, \"cinder::cron::db_purge::monthday\": {\"get_param\": \"CinderCronDbPurgeMonthday\"}, \"cinder::cron::db_purge::month\": {\"get_param\": \"CinderCronDbPurgeMonth\"}, \"cinder::cron::db_purge::weekday\": {\"get_param\": \"CinderCronDbPurgeWeekday\"}, \"cinder::cron::db_purge::user\": {\"get_param\": \"CinderCronDbPurgeUser\"}, \"cinder::cron::db_purge::age\": {\"get_param\": \"CinderCronDbPurgeAge\"}, \"cinder::cron::db_purge::destination\": {\"get_param\": \"CinderCronDbPurgeDestination\"}, \"cinder::cron::db_purge::maxdelay\": {\"get_param\": \"CinderCronDbPurgeMaxDelay\"}, \"cinder::glance::glance_api_servers\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"uri\"]}, \"cinder::keystone::service_user::send_service_user_token\": true, \"cinder::keystone::service_user::project_name\": \"service\", \"cinder::keystone::service_user::auth_type\": \"password\", \"cinder::keystone::service_user::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri\"]}, \"cinder::keystone::service_user::password\": {\"get_param\": \"CinderPassword\"}, \"cinder::keystone::service_user::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"cinder::nova::interface\": \"admin\", \"cinder::nova::project_name\": \"service\", \"cinder::nova::auth_type\": \"password\", \"cinder::nova::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri\"]}, \"cinder::nova::password\": {\"get_param\": \"NovaPassword\"}, \"cinder::nova::region_name\": {\"get_param\": \"KeystoneRegion\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(140,'2026-06-09 08:02:11',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(141,'2026-06-09 08:02:11',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Neutron base service. Shared for all Neutron agents.\\n\", \"parameters\": {\"DatabaseSyncTimeout\": {\"default\": 900, \"description\": \"DB Sync Timeout default\", \"type\": \"number\"}, \"NeutronDhcpAgentsPerNetwork\": {\"type\": \"number\", \"default\": 0, \"description\": \"The number of neutron dhcp agents to schedule per network\"}, \"DhcpAgentNotification\": {\"default\": false, \"description\": \"Whether or not to enable DHCP agent notifications.\", \"type\": \"boolean\"}, \"NeutronDnsDomain\": {\"type\": \"string\", \"default\": \"ooo.test\", \"description\": \"Domain to use for building the hostnames.\"}, \"NeutronCorePlugin\": {\"default\": \"ml2\", \"description\": \"The core plugin for Neutron. The value should be the entrypoint to be loaded\\nfrom neutron.core_plugins namespace.\\n\", \"type\": \"string\"}, \"NeutronServicePlugins\": {\"default\": \"qos,ovn-router,trunk,segments,port_forwarding,log\", \"description\": \"Comma-separated list of service plugin entrypoints to be loaded from the\\nneutron.service_plugins namespace.\\n\", \"type\": \"comma_delimited_list\"}, \"Debug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debugging on all services.\"}, \"NeutronDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Neutron services.\", \"type\": \"boolean\"}, \"EnableConfigPurge\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Remove configuration that is not generated by TripleO. Used to avoid configuration remnants after upgrades.\\n\"}, \"NeutronGlobalPhysnetMtu\": {\"type\": \"number\", \"default\": 1350, \"description\": \"MTU of the underlying physical network. Neutron uses this value to\\ncalculate MTU for all virtual network components. For flat and VLAN\\nnetworks, neutron uses this value without modification. For overlay\\nnetworks such as VXLAN, neutron automatically subtracts the overlay\\nprotocol overhead from this value.\\n(If this is not changed TenantNetPhysnetMtu will be used.)\\n\"}, \"TenantNetPhysnetMtu\": {\"type\": \"number\", \"default\": 1500, \"description\": \"MTU of the underlying physical network. Neutron uses this value to\\ncalculate MTU for all virtual network components. For flat and VLAN\\nnetworks, neutron uses this value without modification. For overlay\\nnetworks such as VXLAN, neutron automatically subtracts the overlay\\nprotocol overhead from this value.\\n(The mtu setting of the Tenant network in network_data.yaml\\ncontrol\'s this parameter.)\\n\"}, \"NeutronDBSyncExtraParams\": {\"default\": \"\", \"description\": \"String of extra command line parameters to append to the neutron-db-manage\\nupgrade head command.\\n\", \"type\": \"string\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"EnableVLANTransparency\": {\"default\": false, \"description\": \"If True, then allow plugins that support it to create VLAN transparent networks.\\n\", \"type\": \"boolean\"}, \"NeutronGlobalReportInterval\": {\"default\": 300, \"description\": \"Seconds between nodes reporting state to server; should be less than NeutronAgentDownTime, best if it is half or less than NeutronAgentDownTime.\\n\", \"type\": \"number\"}}, \"conditions\": {\"dhcp_agents_zero\": {\"equals\": [{\"get_param\": \"NeutronDhcpAgentsPerNetwork\"}, 0]}, \"global_physnet_mtu_unset\": {\"equals\": [{\"get_param\": \"NeutronGlobalPhysnetMtu\"}, 0]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Neutron base service.\", \"value\": {\"service_name\": \"neutron_base\", \"config_settings\": {\"map_merge\": [{\"neutron::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"neutron::core_plugin\": {\"get_param\": \"NeutronCorePlugin\"}, \"neutron::service_plugins\": {\"get_param\": \"NeutronServicePlugins\"}, \"neutron::report_interval\": {\"get_param\": \"NeutronGlobalReportInterval\"}, \"neutron::logging::debug\": {\"if\": [{\"get_param\": \"NeutronDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"neutron::purge_config\": {\"get_param\": \"EnableConfigPurge\"}, \"neutron::allow_overlapping_ips\": true, \"neutron::dhcp_agent_notification\": {\"get_param\": \"DhcpAgentNotification\"}, \"neutron::dns_domain\": {\"get_param\": \"NeutronDnsDomain\"}, \"neutron::rabbit_heartbeat_timeout_threshold\": 60, \"neutron::host\": \"%{hiera(\'fqdn_canonical\')}\", \"neutron::db::database_db_max_retries\": -1, \"neutron::db::database_max_retries\": -1, \"neutron::db::sync::db_sync_timeout\": {\"get_param\": \"DatabaseSyncTimeout\"}, \"neutron::global_physnet_mtu\": {\"if\": [\"global_physnet_mtu_unset\", {\"get_param\": \"TenantNetPhysnetMtu\"}, {\"get_param\": \"NeutronGlobalPhysnetMtu\"}]}, \"neutron::db::sync::extra_params\": {\"get_param\": \"NeutronDBSyncExtraParams\"}, \"neutron::vlan_transparent\": {\"get_param\": \"EnableVLANTransparency\"}, \"neutron::rabbit_heartbeat_in_pthread\": false}, {\"if\": [\"dhcp_agents_zero\", {}, {\"tripleo::profile::base::neutron::dhcp_agents_per_network\": {\"get_param\": \"NeutronDhcpAgentsPerNetwork\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(142,'2026-06-09 08:02:11',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry.  This mapping overrides those in ServiceNetMapDefaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CinderRbdMultiConfig\": {\"type\": \"json\", \"default\": {}, \"description\": \"Dictionary of settings when configuring multiple RBD backends. The\\nhash key is the backend name, and the value is a dictionary of parameter\\nvalues unique to that backend. The following parameters are required,\\nand must match the corresponding value defined in CephExternalMultiConfig.\\n  CephClusterName (must match the CephExternalMultiConfig entry\'s \'cluster\')\\n  CephClusterFSID (must match the CephExternalMultiConfig entry\'s \'fsid\')\\nThe following parameters are optional, and override the corresponding\\nparameter\'s default value.\\n  CephClientUserName\\n  CinderRbdPoolName\\n  CinderRbdExtraPools\\n  CinderRbdAvailabilityZone\\n  CinderRbdFlattenVolumeFromSnapshot\\n\"}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"QemuMemoryBackingDir\": {\"type\": \"string\", \"description\": \"Directory used for memoryBacking source if configured as file. NOTE: big files will be stored here\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}}, \"conditions\": {\"memory_backing_dir_set\": {\"not\": {\"and\": [{\"equals\": [{\"get_param\": \"QemuMemoryBackingDir\"}, \"\"]}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"QemuMemoryBackingDir\"]}, \"\"]}]}}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"nova::compute::libvirt::qemu::memory_backing_dir\": \"QemuMemoryBackingDir\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"QemuMemoryBackingDir\": {\"get_param\": \"QemuMemoryBackingDir\"}}}]}}}}, \"outputs\": {\"kolla_config_files\": {\"description\": \"Common kolla config_files.\", \"value\": {\"list_concat\": [[{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}]]}}, \"kolla_permissions\": {\"description\": \"Common kolla permissions.\", \"value\": {\"list_concat\": [[{\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"nova:nova\", \"perm\": \"0600\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%keyring%>\", \"owner\": \"nova:nova\", \"perm\": \"0600\"}, \"for_each\": {\"<%keyring%>\": {\"yaql\": {\"expression\": \"let(u => $.data.default_user) -> $.data.multiconfig.values().select($.CephClusterName + \\\".client.\\\" + $.get(\\\"CephClientUserName\\\", $u) + \\\".keyring\\\")\", \"data\": {\"default_user\": {\"get_param\": \"CephClientUserName\"}, \"multiconfig\": {\"get_param\": \"CinderRbdMultiConfig\"}}}}}}}]}}, \"config_settings\": {\"description\": \"Extra hieradata for all modular virt daemons.\", \"value\": {\"get_attr\": [\"RoleParametersValue\", \"value\"]}}, \"volumes\": {\"description\": \"Common volumes for all modular virt daemons.\", \"value\": {\"list_concat\": [[\"/lib/modules:/lib/modules:ro\", \"/dev:/dev\", \"/run:/run\", \"/sys/fs/cgroup:/sys/fs/cgroup\", \"/sys/fs/selinux:/sys/fs/selinux\", \"/etc/selinux/config:/etc/selinux/config:ro\", \"/etc/libvirt:/etc/libvirt:shared\", \"/etc/ssh/ssh_known_hosts:/etc/ssh/ssh_known_hosts:ro\", \"/run/libvirt:/run/libvirt:shared,z\", \"/var/lib/nova:/var/lib/nova:shared\", \"/var/lib/libvirt:/var/lib/libvirt:shared\", \"/var/cache/libvirt:/var/cache/libvirt:shared\", \"/var/lib/vhost_sockets:/var/lib/vhost_sockets\", \"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/CA/cacert.pem:/etc/pki/CA/cacert.pem:ro\", \"/etc/pki/libvirt:/etc/pki/libvirt:ro\", \"/etc/pki/qemu:/etc/pki/qemu:ro\"]]}, {\"if\": [\"memory_backing_dir_set\", [{\"str_replace\": {\"template\": \"MEMORY_BACKING_DIR:MEMORY_BACKING_DIR\", \"params\": {\"MEMORY_BACKING_DIR\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nova::compute::libvirt::qemu::memory_backing_dir\"]}}}}]]}]}}, \"update_tasks\": {\"description\": \"Common update tasks for modular virt daemons\", \"value\": [{\"name\": \"check systemd-container package present or not\", \"package\": {\"name\": \"systemd-container\", \"state\": \"present\"}, \"check_mode\": true, \"register\": \"is_systemd_container_package\"}, {\"name\": \"download systemd-container package if not present\", \"yum\": {\"name\": \"systemd-container\", \"state\": \"present\", \"download_only\": true, \"download_dir\": \"/var/tmp/\"}, \"when\": \"is_systemd_container_package.changed\"}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(143,'2026-06-09 08:02:12',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Cinder NVMeOF backend\\n\", \"parameters\": {\"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderNVMeOFBackendName\": {\"type\": \"string\", \"default\": \"tripleo_nvmeof\"}, \"CinderNVMeOFAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NVMeOF Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNVMeOFTargetPort\": {\"type\": \"number\", \"default\": 4420}, \"CinderNVMeOFTargetHelper\": {\"type\": \"string\", \"default\": \"nvmet\"}, \"CinderNVMeOFTargetProtocol\": {\"type\": \"string\", \"default\": \"nvmet_rdma\", \"description\": \"The target protocol, supported values are nvmet_rdma and nvmet_tcp.\\n\", \"constraints\": [{\"allowed_values\": [\"nvmet_rdma\", \"nvmet_tcp\"]}]}, \"CinderNVMeOFTargetPrefix\": {\"type\": \"string\", \"default\": \"nvme-subsystem\"}, \"CinderNVMeOFTargetPortId\": {\"type\": \"number\", \"default\": 1}, \"CinderNVMeOFTargetNameSpaceId\": {\"type\": \"number\", \"default\": 10}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"type\": \"json\", \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}}, \"outputs\": {\"cinder_nvmeof_host_prep_tasks\": {\"description\": \"Host prep tasks related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [{\"name\": \"ensure /etc/nvme exists\", \"file\": {\"path\": \"/etc/nvme\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]]}}, \"cinder_nvmeof_volumes\": {\"description\": \"Volumes related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [\"/etc/nvme:/etc/nvme:z\"]]}}, \"role_data\": {\"description\": \"Role data for the Cinder NVMeOF backend.\", \"value\": {\"service_name\": \"cinder_backend_nvmeof\", \"firewall_rules\": {\"120 LVM nvmet target\": {\"dport\": {\"get_param\": \"CinderNVMeOFTargetPort\"}}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::cinder::volume::cinder_enable_nvmeof_backend\": {\"get_param\": \"CinderEnableNVMeOFBackend\"}, \"tripleo::profile::base::cinder::volume::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_port\": {\"get_param\": \"CinderNVMeOFTargetPort\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_helper\": {\"get_param\": \"CinderNVMeOFTargetHelper\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_protocol\": {\"get_param\": \"CinderNVMeOFTargetProtocol\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_prefix\": {\"get_param\": \"CinderNVMeOFTargetPrefix\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_port_id\": {\"get_param\": \"CinderNVMeOFTargetPortId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_ns_id\": {\"get_param\": \"CinderNVMeOFTargetNameSpaceId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_ip_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}, \"cinder::backend::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNVMeOFAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nvmeof::backend_availability_zone\": {\"get_param\": \"CinderNVMeOFAvailabilityZone\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(144,'2026-06-09 08:02:12',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"MySQL service deployment with pacemaker bundle\\n\", \"parameters\": {\"ContainerMysqlImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\"}, \"ContainerMysqlConfigImage\": {\"description\": \"The container image to use for the mysql config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\"}, \"ClusterCommonTag\": {\"default\": false, \"description\": \"When set to false, a pacemaker service is configured to use a floating tag for its container image name, e.g. \'REGISTRY/NAMESPACE/IMAGENAME:pcmklatest\'. When set to true, the service uses a floating prefix as well, e.g. \'cluster.common.tag/IMAGENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"ClusterFullTag\": {\"default\": true, \"description\": \"When set to true, the pacemaker service uses a fully constant tag for its container image name, e.g. \'cluster.common.tag/SERVICENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"MysqlRootPassword\": {\"type\": \"string\", \"hidden\": true, \"default\": \"CEwojbg8cQ\"}, \"MysqlClustercheckPassword\": {\"type\": \"string\", \"hidden\": true, \"default\": \"aNliMndyyYkYXXmrEs48JOHfH\"}, \"MysqlUpgradePersist\": {\"type\": \"boolean\", \"default\": false}, \"MysqlUpgradeTransfer\": {\"type\": \"boolean\", \"default\": true}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"ConfigDebug\": {\"default\": false, \"description\": \"Whether to run config management (e.g. Puppet) in debug mode.\", \"type\": \"boolean\"}, \"DeployIdentifier\": {\"default\": 1780992067, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}, \"MysqlGaleraSSTMethod\": {\"type\": \"string\", \"default\": \"rsync\", \"description\": \"Method used by galera to perform State Snapshot Transfers\", \"constraints\": [{\"allowed_values\": [\"rsync\", \"mariabackup\"]}]}, \"MysqlMariabackupUser\": {\"type\": \"string\", \"default\": \"mariabackup\", \"description\": \"When MysqlGaleraSSTMethod is set to mariabackup, the name of the database user that executes the SST.\"}, \"MysqlMariabackupPassword\": {\"type\": \"string\", \"hidden\": true, \"description\": \"When MysqlGaleraSSTMethod is set to mariabackup, the password of the database user that executes the SST.\", \"default\": \"v37DXivQZPH0c9WJEo2d76ZZ3\"}, \"MysqlGaleraSSLCipher\": {\"type\": \"string\", \"default\": \"AES128-SHA256\", \"description\": \"Symmetric cipher to use.\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MysqlBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-base.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerMysqlImage\": \"ContainerMysqlImage\", \"ContainerMysqlConfigImage\": \"ContainerMysqlConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerMysqlImage\": {\"get_param\": \"ContainerMysqlImage\"}, \"ContainerMysqlConfigImage\": {\"get_param\": \"ContainerMysqlConfigImage\"}}}]}}}}, \"conditions\": {\"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"role_data\": {\"description\": \"Containerized service MySQL using composable services.\", \"value\": {\"service_name\": {\"get_attr\": [\"MysqlBase\", \"role_data\", \"service_name\"]}, \"firewall_rules\": {\"104 mysql galera-bundle\": {\"dport\": [873, 3123, 3306, 4444, 4567, 4568, 9200]}}, \"firewall_frontend_rules\": {\"100 mysql_haproxy\": {\"dport\": [3306]}}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"MysqlBase\", \"role_data\", \"config_settings\"]}, {\"tripleo::profile::pacemaker::database::mysql::bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::pacemaker::database::mysql::gmcast_listen_addr\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::pacemaker::database::mysql::ca_file\": {\"get_param\": \"InternalTLSCAFile\"}, \"tripleo::profile::pacemaker::database::mysql_bundle::mysql_docker_image\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"tripleo::profile::pacemaker::database::mysql_bundle::control_port\": 3123, \"tripleo::profile::pacemaker::database::mysql_bundle::container_backend\": {\"get_param\": \"ContainerCli\"}, \"tripleo::profile::pacemaker::database::mysql_bundle::bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::pacemaker::database::mysql_bundle::ca_file\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"InternalTLSCAFile\"}]}, \"tripleo::profile::pacemaker::database::mysql_bundle::sst_method\": {\"get_param\": \"MysqlGaleraSSTMethod\"}, \"tripleo::profile::pacemaker::database::mysql_bundle::mariabackup_user\": {\"get_param\": \"MysqlMariabackupUser\"}, \"tripleo::profile::pacemaker::database::mysql_bundle::mariabackup_password\": {\"get_param\": \"MysqlMariabackupPassword\"}, \"tripleo::profile::pacemaker::database::mysql_bundle::force_ocf\": true, \"tripleo::profile::pacemaker::database::mysql_bundle::gcomm_cipher\": {\"get_param\": \"MysqlGaleraSSLCipher\"}}]}, \"puppet_config\": {\"config_volume\": \"mysql\", \"puppet_tags\": \"file\", \"step_config\": {\"list_join\": [\"\\n\", [\"[\'Mysql_datadir\', \'Mysql_user\', \'Mysql_database\', \'Mysql_grant\', \'Mysql_plugin\'].each |String $val| { noop_resource($val) }\", \"exec {\'wait-for-settle\': command => \'/bin/true\' }\", \"include tripleo::profile::pacemaker::database::mysql_bundle\"]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/mysql.json\": {\"command\": \"/usr/sbin/pacemaker_remoted\", \"config_files\": [{\"dest\": \"/etc/libqb/force-filesystem-sockets\", \"source\": \"/dev/null\", \"owner\": \"root\", \"perm\": \"0644\"}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"optional\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/mysql\", \"owner\": \"mysql:mysql\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/mysql.crt\", \"owner\": \"mysql:mysql\", \"perm\": \"0600\", \"optional\": true}, {\"path\": \"/etc/pki/tls/private/mysql.key\", \"owner\": \"mysql:mysql\", \"perm\": \"0600\", \"optional\": true}]}}, \"container_config_scripts\": {\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, \"docker_config\": {\"step_1\": {\"mysql_data_ownership\": {\"start_order\": 0, \"detach\": false, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"net\": \"host\", \"user\": \"root\", \"command\": [\"chown\", \"-R\", \"mysql:\", \"/var/lib/mysql\"], \"volumes\": [\"/var/lib/mysql:/var/lib/mysql:z\"]}, \"mysql_bootstrap\": {\"start_order\": 1, \"detach\": false, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"net\": \"host\", \"user\": \"root\", \"command\": [\"bash\", \"-ec\", {\"list_join\": [\"\\n\", [\"if [ -e /var/lib/mysql/mysql ]; then exit 0; fi\", \"echo -e \\\"\\\\n[mysqld]\\\\nwsrep_provider=none\\\" >> /etc/my.cnf\", \"export DB_ROOT_PASSWORD=$(hiera \'mysql::server::root_password\')\", \"kolla_set_configs\", \"sudo -u mysql -E kolla_extend_start\", \"timeout ${DB_MAX_TIMEOUT} /bin/bash -c \'while pgrep -af /usr/bin/mysqld_safe | grep -q -v grep; do sleep 1; done\'\", \"mysqld_safe --skip-networking --wsrep-on=OFF &\", \"timeout ${DB_MAX_TIMEOUT} /bin/bash -c \'until mysqladmin -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" ping 2>/dev/null; do sleep 1; done\'\"], {\"if\": [{\"equals\": [{\"get_param\": \"MysqlGaleraSSTMethod\"}, \"mariabackup\"]}, [\"mysql -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" -e \\\"CREATE USER \'${DB_MARIABACKUP_USER}\'@\'localhost\' IDENTIFIED BY \'${DB_MARIABACKUP_PASSWORD}\';\\\"\", \"mysql -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" -e \\\"GRANT RELOAD, PROCESS, LOCK TABLES, REPLICATION CLIENT ON *.* TO \'${DB_MARIABACKUP_USER}\'@\'localhost\';\\\"\"]]}, [\"mysql -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" -e \\\"CREATE USER \'clustercheck\'@\'localhost\' IDENTIFIED BY \'$(hiera mysql_clustercheck_password)\';\\\"\", \"mysql -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" -e \\\"GRANT PROCESS ON *.* TO \'clustercheck\'@\'localhost\' WITH GRANT OPTION;\\\"\", \"mysql -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" -e \\\"DELETE FROM mysql.user WHERE user = \'root\' AND host NOT IN (\'%\',\'localhost\');\\\"\", \"timeout ${DB_MAX_TIMEOUT} mysqladmin -uroot -p\\\"$(hiera \'mysql::server::root_password\')\\\" shutdown\"]]}], \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/mysql.json:/var/lib/kolla/config_files/config.json:rw,z\", \"/var/lib/config-data/puppet-generated/mysql:/var/lib/kolla/config_files/src:ro,z\", \"/var/lib/mysql:/var/lib/mysql:rw,z\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/mysql.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/mysql.crt:ro\", \"/etc/pki/tls/private/mysql.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/mysql.key:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"KOLLA_BOOTSTRAP\": true, \"DB_MAX_TIMEOUT\": 60, \"DB_MARIABACKUP_USER\": {\"get_param\": \"MysqlMariabackupUser\"}, \"DB_MARIABACKUP_PASSWORD\": {\"get_param\": \"MysqlMariabackupPassword\"}}}}, \"step_2\": {\"mysql_wait_bundle\": {\"start_order\": 0, \"detach\": false, \"net\": \"host\", \"ipc\": \"host\", \"user\": \"root\", \"command\": {\"list_concat\": [[\"/container_puppet_apply.sh\", \"2\", \"file,file_line,concat,augeas,galera_ready,mysql_database,mysql_grant,mysql_user\", \"include tripleo::profile::pacemaker::database::mysql_bundle\"], {\"if\": [{\"get_param\": \"ConfigDebug\"}, [\"--debug\"]]}]}, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"container_puppet_apply_volumes\"]}, [\"/var/lib/mysql:/var/lib/mysql:rw,z\", \"/var/lib/config-data/puppet-generated/mysql/root:/root:rw\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"]]}]}, \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/mysql\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/mysql\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/log/mariadb\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}], \"metadata_settings\": {\"get_attr\": [\"MysqlBase\", \"role_data\", \"metadata_settings\"]}, \"deploy_steps_tasks\": {\"list_concat\": [{\"get_attr\": [\"MysqlBase\", \"role_data\", \"deploy_steps_tasks\"]}, [{\"name\": \"MySQL tag container image for pacemaker\", \"when\": \"step|int == 1\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"container_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}}}, {\"name\": \"MySQL HA Wrappers Step\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Mysql puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"mysql\", \"tripleo_ha_wrapper_resource_name\": \"galera\", \"tripleo_ha_wrapper_bundle_name\": \"galera-bundle\", \"tripleo_ha_wrapper_resource_state\": \"Master\", \"tripleo_ha_wrapper_puppet_config_volume\": \"mysql\", \"tripleo_ha_wrapper_puppet_execute\": \"[\\\"Mysql_datadir\\\", \\\"Mysql_user\\\", \\\"Mysql_database\\\", \\\"Mysql_grant\\\", \\\"Mysql_plugin\\\"].each |String $val| { noop_resource($val) }; include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::database::mysql_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".previous_run\"}}]}]]}, \"external_update_tasks\": [{\"when\": \"step|int == 1\", \"tags\": \"ha_image_update\", \"block\": [{\"block\": [{\"name\": \"Get galera image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_galera_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'galera-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container galera image\", \"set_fact\": {\"galera_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"galera_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_galera_image\": \"{{xmllint_pcmk_galera_image.stdout}}\"}}], \"delegate_to\": \"{{ (groups[\\\"mysql\\\"] | difference(groups[\\\"excluded_overcloud\\\"]))[0] }}\"}, {\"name\": \"MySQL temporary pacemaker container tag in case of image switch\", \"become\": true, \"import_role\": {\"name\": \"tripleo_ha_image_update\"}, \"vars\": {\"tripleo_ha_image_update_node_names\": \"{{ groups[\\\"mysql\\\"] | difference(groups[\\\"excluded_overcloud\\\"]) }}\", \"tripleo_ha_image_update_bundle\": \"galera-bundle\", \"tripleo_ha_image_update_new_image\": \"{{galera_image_latest}}\", \"tripleo_ha_image_update_old_image\": \"{{pcmk_galera_image}}\"}, \"when\": [\"(pcmk_galera_image != \\\"\\\")\", \"(pcmk_galera_image != galera_image_latest)\"]}]}], \"update_tasks\": [{\"block\": [{\"name\": \"Get galera image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_galera_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'galera-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container galera image\", \"set_fact\": {\"galera_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"galera_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_galera_image\": \"{{xmllint_pcmk_galera_image.stdout}}\"}}], \"when\": \"(step|int == 0 or step|int == 2)\"}, {\"name\": \"Check for update of galera container image name\", \"when\": \"step|int == 0\", \"assert\": {\"that\": \"pcmk_galera_image == galera_image_latest\", \"fail_msg\": \"galera image change detected, run overcloud external-update --tags ha_image_update first\"}}, {\"name\": \"Tear-down non-HA mysql container\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"stat mysql container\", \"command\": \"podman container exists mysql\", \"failed_when\": false, \"changed_when\": false, \"register\": \"stat_mysql_container\"}, {\"name\": \"Create clustercheck user and permissions\", \"command\": {\"argv\": \"{{ mysql_exec_data | container_exec_cmd }}\"}, \"changed_when\": true, \"when\": [\"stat_mysql_container.rc == 0\"], \"vars\": {\"mysql_exec_data\": {\"environment\": {\"CLUSTERCHECK_PASSWORD\": {\"get_param\": \"MysqlClustercheckPassword\"}}, \"command\": [\"mysql\", \"/bin/sh\", \"-c\", \"mysql -e \\\"CREATE USER IF NOT EXISTS \'clustercheck\'@\'localhost\' IDENTIFIED BY \'${CLUSTERCHECK_PASSWORD}\'; GRANT PROCESS ON *.* TO \'clustercheck\'@\'localhost\' WITH GRANT OPTION;\\\"\"]}}}, {\"name\": \"Remove non-HA mysql container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"mysql\"]}}]}, {\"name\": \"Mariadb fetch and retag container image for pacemaker\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Retag pcmklatest to latest galera image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{galera_image}}\", \"container_image_latest\": \"{{galera_image_latest}}\"}}]}, {\"name\": \"Ensure mariadb-server is not installed on the host\", \"when\": \"step|int == 2\", \"yum\": {\"name\": \"mariadb-server*\", \"state\": \"absent\"}}], \"post_update_tasks\": [{\"name\": \"Mysql bundle post update\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Mysql puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"mysql\", \"tripleo_ha_wrapper_resource_name\": \"galera\", \"tripleo_ha_wrapper_bundle_name\": \"galera-bundle\", \"tripleo_ha_wrapper_resource_state\": \"Master\", \"tripleo_ha_wrapper_puppet_config_volume\": \"mysql\", \"tripleo_ha_wrapper_puppet_execute\": \"[\\\"Mysql_datadir\\\", \\\"Mysql_user\\\", \\\"Mysql_database\\\", \\\"Mysql_grant\\\", \\\"Mysql_plugin\\\"].each |String $val| { noop_resource($val) }; include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::database::mysql_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".previous_run\"}}], \"vars\": {\"tripleo_ha_wrapper_minor_update\": true}}], \"upgrade_tasks\": {\"list_concat\": [[{\"name\": \"Tear-down non-HA mysql container\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"stat mysql container\", \"command\": \"podman container exists mysql\", \"failed_when\": false, \"changed_when\": false, \"register\": \"stat_mysql_container\"}, {\"name\": \"Create clustercheck user and permissions\", \"command\": {\"argv\": \"{{ mysql_exec_data | container_exec_cmd }}\"}, \"changed_when\": true, \"when\": [\"stat_mysql_container.rc == 0\"], \"vars\": {\"mysql_exec_data\": {\"environment\": {\"CLUSTERCHECK_PASSWORD\": {\"get_param\": \"MysqlClustercheckPassword\"}}, \"command\": [\"mysql\", \"/bin/sh\", \"-c\", \"mysql -e \\\"CREATE USER IF NOT EXISTS \'clustercheck\'@\'localhost\' IDENTIFIED BY \'${CLUSTERCHECK_PASSWORD}\'; GRANT PROCESS ON *.* TO \'clustercheck\'@\'localhost\' WITH GRANT OPTION;\\\"\"]}}}, {\"name\": \"Remove non-HA mysql container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"mysql\"]}}]}], [{\"name\": \"set mysql container name fact\", \"when\": [\"step|int == 1\"], \"set_fact\": {\"mysql_container_name\": \"galera-bundle\"}}], {\"get_attr\": [\"MysqlBase\", \"mysql_drop_unused_users\"]}, [{\"vars\": {\"mysql_upgrade_persist\": {\"get_param\": \"MysqlUpgradePersist\"}}, \"when\": [\"step|int == 3\", \"mysql_upgrade_persist\"], \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_prepare\"], \"block\": [{\"name\": \"Persist mysql data\", \"include_role\": {\"name\": \"tripleo_persist\", \"tasks_from\": \"persist.yml\"}, \"vars\": {\"tripleo_persist_dir\": \"/var/lib/mysql\"}}]}, {\"vars\": {\"mysql_upgrade_persist\": {\"get_param\": \"MysqlUpgradePersist\"}}, \"when\": [\"step|int == 5\", \"mysql_upgrade_persist\"], \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\"], \"block\": [{\"name\": \"Restore mysql data\", \"include_role\": {\"name\": \"tripleo_persist\", \"tasks_from\": \"restore.yml\"}, \"vars\": {\"tripleo_persist_dir\": \"/var/lib/mysql\"}}]}, {\"name\": \"Prepare switch of galera image name\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Get galera image id currently used by pacemaker\", \"shell\": \"pcs resource config galera-bundle | grep -Eo \'image=[^ ]+\' | awk -F= \'{print $2;}\'\", \"register\": \"galera_image_current_res\", \"failed_when\": false}, {\"name\": \"Image facts for galera\", \"set_fact\": {\"galera_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"galera_image_current\": \"{{galera_image_current_res.stdout}}\"}}, {\"name\": \"Temporarily tag the current galera image id with the upgraded image name\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{galera_image_current}}\", \"container_image_latest\": \"{{galera_image_latest}}\", \"pull_image\": false}, \"when\": [\"galera_image_current != \'\'\", \"galera_image_current != galera_image_latest\"]}, {\"name\": \"Create galera retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/galera_needs_retag\", \"state\": \"touch\"}, \"when\": [\"galera_image_current != \'\'\", \"galera_image_current != galera_image_latest\"]}]}, {\"name\": \"Update galera pcs resource bundle for new container image - check\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"set is_mysql_bootstrap_node fact\", \"tags\": \"common\", \"set_fact\": \"is_mysql_bootstrap_node={{mysql_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower}}\"}, {\"name\": \"Check for galera retag statefile\", \"stat\": {\"path\": \"/var/lib/tripleo/galera_needs_retag\"}, \"register\": \"galera_retag_state_file\"}]}, {\"name\": \"Update galera pcs resource bundle for new container image\", \"when\": [\"step|int == 1\", \"is_mysql_bootstrap_node|bool\", \"galera_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Disable the galera cluster resource before container upgrade\", \"pacemaker_resource\": {\"resource\": \"galera-bundle\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Move Mysql logging to /var/log/containers\", \"block\": [{\"name\": \"Check Mysql logging configuration in pacemaker\", \"command\": \"cibadmin --query --xpath \\\"//storage-mapping[@id=\'mysql-log\']\\\"\", \"failed_when\": false, \"register\": \"mysql_logs_moved\"}, {\"name\": \"Change Mysql logging configuration in pacemaker\", \"when\": \"mysql_logs_moved.rc == 6\", \"block\": [{\"name\": \"Add a bind mount for logging in the galera bundle\", \"command\": \"pcs resource bundle update galera-bundle storage-map add id=mysql-log source-dir=/var/log/containers/mysql target-dir=/var/log/mysql options=rw\"}, {\"name\": \"Reconfigure Mysql log file in the galera resource agent\", \"command\": \"pcs resource update galera log=/var/log/mysql/mysqld.log\"}]}]}, {\"name\": \"Update the galera bundle to use the new container image name\", \"command\": \"pcs resource bundle update galera-bundle container image={{galera_image_latest}}\"}, {\"name\": \"Enable the galera cluster resource\", \"pacemaker_resource\": {\"resource\": \"galera-bundle\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}]}, {\"name\": \"Upgrade galera in step3\", \"when\": [\"step|int == 3\"], \"block\": [{\"name\": \"Bind mounts for temporary container\", \"set_fact\": {\"mysql_upgrade_db_bind_mounts\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/mysql.json:/var/lib/kolla/config_files/config.json:rw,z\", \"/var/lib/config-data/puppet-generated/mysql:/var/lib/kolla/config_files/src:ro,z\", \"/var/lib/mysql:/var/lib/mysql:rw,z\"], [\"/var/log/containers/mysql:/var/log/mysql:rw,z\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/mysql.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/mysql.crt:ro\", \"/etc/pki/tls/private/mysql.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/mysql.key:ro\"]]}]}}}, {\"name\": \"Check if Galera needs upgrade\", \"shell\": {\"str_replace\": {\"template\": \"CONTAINER_CLI run --rm --log-driver=k8s-file --log-opt path=LOG_DIR/db-upgrade.log \\\\ -u root --net=host UPGRADE_ENV UPGRADE_VOLUMES \\\"UPGRADE_IMAGE\\\" /bin/bash -ecx \\\"$UPGRADE_SCRIPT\\\"\", \"params\": {\"UPGRADE_ENV\": \"-e \\\"KOLLA_CONFIG_STRATEGY=COPY_ALWAYS\\\"\", \"UPGRADE_IMAGE\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"UPGRADE_VOLUMES\": \"-v {{ mysql_upgrade_db_bind_mounts | join(\' -v \')}}\", \"CONTAINER_CLI\": \"{{ container_cli }}\", \"LOG_DIR\": \"/var/log/containers/mysql\"}}}, \"environment\": {\"UPGRADE_SCRIPT\": \"kolla_set_configs\\nupgraded_ver=$(cat /var/lib/mysql/mysql_upgrade_info 2>/dev/null || true)\\nmysql_ver=$(mysql --version | awk -F\'[ ,]*\' \'{print $5}\')\\nif [ \\\"${upgraded_ver}\\\" = \\\"${mysql_ver}\\\" ]; then\\n    echo \\\"mysql already upgraded\\\"\\nelse\\n    echo \\\"${upgraded_ver} VS ${mysql_ver}\\\"\\nfi\\n\"}, \"register\": \"mysql_upgrade_needed\"}, {\"name\": \"Set fact upgrade_mysql\", \"set_fact\": {\"upgrade_mysql\": \"{{ (mysql_upgrade_needed.stdout != \\\"mysql already upgraded\\\") | bool }}\"}}, {\"debug\": {\"msg\": \"MYSQL check - {{ mysql_upgrade_needed.stdout }} - Upgrade needed: {{ upgrade_mysql }}\"}}, {\"name\": \"Disable the galera cluster resource before container upgrade\", \"when\": [\"upgrade_mysql|bool\"], \"pacemaker_resource\": {\"resource\": \"galera-bundle\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"block\": [{\"name\": \"Get galera image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_galera_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'galera-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container galera image\", \"set_fact\": {\"galera_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"galera_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_galera_image\": \"{{xmllint_pcmk_galera_image.stdout}}\"}}]}, {\"name\": \"Check for galera retag statefile\", \"stat\": {\"path\": \"/var/lib/tripleo/galera_needs_retag\"}, \"register\": \"galera_retag_state_file\"}, {\"name\": \"Retag the pacemaker image if containerized\", \"when\": [\"galera_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Retag pcmklatest to latest galera image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{galera_image}}\", \"container_image_latest\": \"{{galera_image_latest}}\"}}]}, {\"name\": \"Remove galera retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/galera_needs_retag\", \"state\": \"absent\"}}, {\"name\": \"Mysql upgrade script\", \"when\": [\"upgrade_mysql|bool\"], \"set_fact\": {\"mysql_upgrade_script\": {\"list_join\": [\"\\n\", [\"kolla_set_configs\\nif mysqladmin ping --silent; then exit 0; fi\\nupgraded_ver=$(cat /var/lib/mysql/mysql_upgrade_info 2>/dev/null || true)\\nmysql_ver=$(mysql --version | awk -F\'[ ,]*\' \'{print $5}\')\\nif [ \\\"${upgraded_ver}\\\" = \\\"${mysql_ver}\\\" ]; then\\n    echo \\\"mysql already upgraded\\\"\\n    exit 0\\nfi\\nchown -R mysql:mysql /var/lib/mysql\\nchown -R mysql:mysql /var/log/mysql\\nmysqld_safe --user=mysql --wsrep-provider=none --skip-networking --wsrep-on=off --log-error=/var/log/mysql/mysqld-upgrade.log &\\n\", {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/mysql_upgrade_db.sh\"}, \"mysqladmin shutdown\"]]}}}, {\"name\": \"Upgrade Mysql database from a temporary container\", \"when\": [\"upgrade_mysql|bool\"], \"shell\": {\"str_replace\": {\"template\": \"CONTAINER_CLI run --rm --log-driver=k8s-file --log-opt path=LOG_DIR/db-upgrade.log \\\\ -u root --net=host UPGRADE_ENV UPGRADE_VOLUMES \\\"UPGRADE_IMAGE\\\" /bin/bash -ecx \\\"$UPGRADE_SCRIPT\\\"\", \"params\": {\"UPGRADE_ENV\": \"-e \\\"KOLLA_CONFIG_STRATEGY=COPY_ALWAYS\\\"\", \"UPGRADE_IMAGE\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/mariadb:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMysqlImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"UPGRADE_VOLUMES\": \"-v {{ mysql_upgrade_db_bind_mounts | join(\' -v \')}}\", \"CONTAINER_CLI\": \"{{ container_cli }}\", \"LOG_DIR\": \"/var/log/containers/mysql\"}}}, \"environment\": {\"UPGRADE_SCRIPT\": \"{{ mysql_upgrade_script }}\"}}, {\"name\": \"Enable the galera cluster resource\", \"when\": [\"upgrade_mysql|bool\"], \"pacemaker_resource\": {\"resource\": \"galera-bundle\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}]}]]}, \"external_upgrade_tasks\": [{\"vars\": {\"mysql_upgrade_transfer\": {\"get_param\": \"MysqlUpgradeTransfer\"}}, \"when\": [\"step|int == 2\", \"mysql_upgrade_transfer\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\"], \"block\": [{\"name\": \"Transfer mysql data\", \"include_role\": {\"name\": \"tripleo_transfer\"}, \"vars\": {\"tripleo_transfer_src_dir\": \"/var/lib/mysql\", \"tripleo_transfer_src_host\": \"{{hostvars[groups[\'overcloud\'][0]][\'mysql_short_node_names\'][1]}}\", \"tripleo_transfer_dest_dir\": \"/var/lib/mysql\", \"tripleo_transfer_dest_host\": \"{{hostvars[groups[\'overcloud\'][0]][\'mysql_short_bootstrap_node_name\']}}\", \"tripleo_transfer_flag_file\": \"/var/lib/tripleo/transfer-flags/var-lib-mysql\", \"tripleo_transfer_sync_options\": \"--whole-file --ignore-times --inplace --archive --delete\", \"tripleo_transfer_include\": [\"/ibdata*\", \"/ib_lru_dump\", \"/ib_logfile[0-9]*\", \"/undo*\", \"/*/\"], \"tripleo_transfer_exclude\": \"/*\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(145,'2026-06-09 08:02:12',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"MySQL service deployment using puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"MysqlMaxConnections\": {\"description\": \"Configures MySQL max_connections config setting\", \"type\": \"number\", \"default\": 4096}, \"MysqlIncreaseFileLimit\": {\"description\": \"Flag to increase MySQL open-files-limit to 16384\", \"type\": \"boolean\", \"default\": true}, \"MysqlRootPassword\": {\"type\": \"string\", \"hidden\": true, \"default\": \"CEwojbg8cQ\"}, \"MysqlClustercheckPassword\": {\"type\": \"string\", \"hidden\": true, \"default\": \"aNliMndyyYkYXXmrEs48JOHfH\"}, \"EnableGalera\": {\"default\": true, \"description\": \"Whether to use Galera instead of regular MariaDB.\", \"type\": \"boolean\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"EnableMysqlAuthEd25519\": {\"type\": \"boolean\", \"description\": \"Whether to configure MySQL users to connect to the server using the Ed25519-based client authentication.\", \"default\": false}, \"MysqlIPv6\": {\"default\": false, \"description\": \"Enable IPv6 in MySQL\", \"type\": \"boolean\"}, \"MysqlInnodbBufferPoolSize\": {\"type\": \"string\", \"description\": \"Buffer pool size for MySQL database; this needs to be larger for at-scale deployments\", \"default\": \"128M\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"MysqlCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"MysqlIPv6\"]}], \"conditions\": {\"is_ipv6\": {\"equals\": [{\"get_param\": [\"ServiceData\", \"net_ip_version_map\", {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}]}, 6]}, \"innodb_buffer_pool_set\": {\"not\": {\"equals\": [{\"get_param\": \"MysqlInnodbBufferPoolSize\"}, \"\"]}}, \"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"MysqlCertificateKeySize\"}, \"\"]}}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared docker config scripts\", \"value\": {\"mysql_upgrade_db.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/mysql_upgrade_db.sh\"}}}}, \"mysql_drop_unused_users\": {\"description\": \"Ansible block to clean up unusued Openstack DB users\", \"value\": [{\"name\": \"Drop unused OpenStack DB users\", \"when\": [\"step|int == 1\", \"mysql_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower\"], \"block\": [{\"name\": \"mysql container id\", \"command\": \"podman ps -q --filter name={{ mysql_container_name }} --filter status=running\", \"register\": \"mysql_container_id\"}, {\"name\": \"set mysql container id fact\", \"set_fact\": {\"mysql_container\": \"{{ mysql_container_id.stdout }}\"}}, {\"name\": \"Mysql script to drop unused DB users\", \"when\": \"( mysql_container | length ) > 0\", \"block\": [{\"name\": \"Get the list of all OpenStack DB users\", \"shell\": \"jq -r \'to_entries[] | select(.key|endswith(\\\"::db::mysql::user\\\")) | .value\' /etc/puppet/hieradata/service_configs.json\", \"register\": \"openstack_db_users\"}, {\"name\": \"List all DB users that match the DB users to be dropped\", \"shell\": \"for u in {{ openstack_db_users.stdout_lines | join(\' \') }}; do podman exec -u root -it \\\"{{ mysql_container }}\\\" mysql -sNe \\\"select concat(\'\\\\`\',user,\'\\\\`@\\\\`\',host,\'\\\\`\') from mysql.user where user = \'$u\' and host != \'%\';\\\"; done\", \"register\": \"mysql_db_users\"}, {\"name\": \"resulting DB users to be dropped\", \"debug\": {\"msg\": \"{{ mysql_db_users.stdout_lines }}\"}}, {\"name\": \"Drop all unneeded Openstack DB users\", \"shell\": \"podman exec -u root -it \\\"{{ mysql_container }}\\\" mysql -sNe \'drop user {{ item }};\'\", \"loop\": \"{{ mysql_db_users.stdout_lines }}\"}]}]}]}, \"role_data\": {\"description\": \"Service MySQL using composable services.\", \"value\": {\"service_name\": \"mysql\", \"config_settings\": {\"mysql::server::package_name\": \"mariadb-galera-server\", \"mysql::server::manage_config_file\": true, \"mysql_ipv6\": {\"if\": [\"is_ipv6\", true, false]}, \"mysql_max_connections\": {\"get_param\": \"MysqlMaxConnections\"}, \"mysql::server::root_password\": {\"get_param\": \"MysqlRootPassword\"}, \"mysql_clustercheck_password\": {\"get_param\": \"MysqlClustercheckPassword\"}, \"enable_galera\": {\"get_param\": \"EnableGalera\"}, \"mysql_auth_ed25519\": {\"get_param\": \"EnableMysqlAuthEd25519\"}, \"mysql_bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::generate_dropin_file_limit\": {\"get_param\": \"MysqlIncreaseFileLimit\"}, \"tripleo::profile::base::database::mysql::certificate_specs\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"service_certificate\": \"/etc/pki/tls/certs/mysql.crt\", \"service_key\": \"/etc/pki/tls/private/mysql.key\"}]}, \"innodb_buffer_pool_size\": {\"if\": [\"innodb_buffer_pool_set\", {\"get_param\": \"MysqlInnodbBufferPoolSize\"}]}}, \"step_config\": \"include tripleo::profile::base::database::mysql\\n\", \"metadata_settings\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [{\"service\": \"mysql\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}, \"type\": \"vip\"}, {\"service\": \"mysql\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}, \"type\": \"node\"}]]}, \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"mysql\", \"dns\": [{\"str_replace\": {\"template\": \"{{fqdn_$NETWORK}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, {\"str_replace\": {\"template\": \"{{cloud_names.cloud_name_NETWORK}}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}], \"principal\": {\"str_replace\": {\"template\": \"mysql/{{fqdn_$NETWORK}}@{{idm_realm}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"MysqlCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}]}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (146,'2026-06-09 08:02:12',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Containerized logrotate with crond for containerized service logs rotation\\n\", \"parameters\": {\"ContainerCrondImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\"}, \"ContainerCrondConfigImage\": {\"description\": \"The container image to use for the crond config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"LogrotateMaxsize\": {\"description\": \"Configures the maxsize param for containerized logrotate.\", \"type\": \"string\", \"default\": \"10M\"}, \"LogrotateRotationInterval\": {\"description\": \"Configures rotation interval for containerized logrotate.\", \"type\": \"string\", \"default\": \"daily\", \"constraints\": [{\"allowed_values\": [\"hourly\", \"daily\", \"weekly\", \"monthly\"]}]}, \"LogrotateRotate\": {\"description\": \"Configures the rotate param for containerized logrotate.\", \"type\": \"string\", \"default\": \"14\"}, \"LogrotatePurgeAfterDays\": {\"description\": \"Enforces life time (days) of rotated and compressed files.\", \"type\": \"string\", \"default\": \"14\"}, \"LogrotateDateExt\": {\"description\": \"Enable/disable dateext parameter.\", \"type\": \"boolean\", \"default\": false}, \"LogrotateDateFormat\": {\"description\": \"Configures dateformat strings for containerized logrotate. This is valid when LogrotateDateExt is true. The allowed specifiers are only %Y %m %d %H %M %S %V and %s.\", \"type\": \"string\", \"default\": \"-%Y%m%d\", \"constraints\": [{\"allowed_pattern\": \"-(%[YmdHMSVs])+$\"}]}, \"LogrotateDateYesterday\": {\"description\": \"Configures dateyesterday paramter for containerized logrotate. This is valid when LogrotateDateExt is true.\", \"type\": \"boolean\", \"default\": false}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCrondImage\": \"ContainerCrondImage\", \"ContainerCrondConfigImage\": \"ContainerCrondConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCrondImage\": {\"get_param\": \"ContainerCrondImage\"}, \"ContainerCrondConfigImage\": {\"get_param\": \"ContainerCrondConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the crond role.\", \"value\": {\"service_name\": \"logrotate_crond\", \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::logging::logrotate::maxsize\": {\"get_param\": \"LogrotateMaxsize\"}, \"tripleo::profile::base::logging::logrotate::rotation\": {\"get_param\": \"LogrotateRotationInterval\"}, \"tripleo::profile::base::logging::logrotate::rotate\": {\"get_param\": \"LogrotateRotate\"}, \"tripleo::profile::base::logging::logrotate::purge_after_days\": {\"get_param\": \"LogrotatePurgeAfterDays\"}, \"tripleo::profile::base::logging::logrotate::dateext\": {\"get_param\": \"LogrotateDateExt\"}}, {\"if\": [{\"get_param\": \"LogrotateDateExt\"}, {\"tripleo::profile::base::logging::logrotate::dateformat\": {\"get_param\": \"LogrotateDateFormat\"}, \"tripleo::profile::base::logging::logrotate::dateyesterday\": {\"get_param\": \"LogrotateDateYesterday\"}}]}]}, \"host_prep_tasks\": [{\"name\": \"allow logrotate to read inside containers\", \"seboolean\": {\"name\": \"logrotate_read_inside_containers\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}], \"deploy_steps_tasks\": [{\"name\": \"configure tmpwatch on the host\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Push script\", \"copy\": {\"dest\": \"/usr/local/sbin/containers-tmpwatch\", \"owner\": \"root\", \"group\": \"root\", \"mode\": 493, \"content\": \"#!/bin/sh\\ntmpwatch --nodirs \\\\\\n  -X \\\"/var/log/containers/*/*log\\\" \\\\\\n  -X \\\"/var/log/containers/*/*/*log\\\" \\\\\\n  -X \\\"/var/log/containers/*/*err\\\" \\\\\\n  {{ LogrotatePurgeAfterDays|int +1 }}d \\\\\\n  /var/log/containers/ 2>&1 | logger -t container-tmpwatch\\n\"}, \"vars\": {\"LogrotatePurgeAfterDays\": {\"get_param\": \"LogrotatePurgeAfterDays\"}}}, {\"name\": \"Insert cronjob in root crontab\", \"cron\": {\"name\": \"Remove old logs\", \"special_time\": \"daily\", \"user\": \"root\", \"job\": \"/usr/local/sbin/containers-tmpwatch\"}}]}], \"update_tasks\": [{\"name\": \"Ensure old cron.daily is absent\", \"when\": \"step|int == 1\", \"file\": {\"path\": \"/etc/cron.daily/containers-tmpwatch\", \"state\": \"absent\"}}], \"upgrade_tasks\": [{\"name\": \"Ensure old cron.daily is absent\", \"when\": \"step|int == 1\", \"file\": {\"path\": \"/etc/cron.daily/containers-tmpwatch\", \"state\": \"absent\"}}], \"puppet_config\": {\"config_volume\": \"crond\", \"step_config\": \"include tripleo::profile::base::logging::logrotate\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCrondConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/logrotate-crond.json\": {\"command\": \"/usr/sbin/crond -s -n\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}}, \"docker_config\": {\"step_4\": {\"logrotate_crond\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCrondImage\"]}, \"net\": \"none\", \"pid\": \"host\", \"privileged\": true, \"user\": \"root\", \"restart\": \"always\", \"healthcheck\": {\"test\": \"/usr/share/openstack-tripleo-common/healthcheck/cron\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/logrotate-crond.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/crond:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers:/var/log/containers:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop logrotate container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"logrotate_crond\"], \"tripleo_delegate_to\": \"{{ groups[\'logrotate_crond\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(147,'2026-06-09 08:02:12',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(148,'2026-06-09 08:02:12',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Configure libvirt-guests\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerNovaLibvirtConfigImage\": {\"description\": \"The container image to use for the nova_libvirt config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\"}, \"NovaResumeGuestsStateOnHostBoot\": {\"default\": false, \"description\": \"Whether to start running instance on compute host reboot\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"NovaResumeGuestsShutdownTimeout\": {\"default\": 300, \"description\": \"Number of seconds we\'re willing to wait for a guest to shut down. If this is 0, then there is no time out (use with caution, as guests might not respond to a shutdown request). The default value is 300 seconds (5 minutes).\", \"type\": \"string\", \"tags\": [\"role_specific\"]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"tripleo::profile::base::nova::compute::libvirt_guests::enabled\": \"NovaResumeGuestsStateOnHostBoot\", \"nova::compute::libvirt_guests::shutdown_timeout\": \"NovaResumeGuestsShutdownTimeout\", \"ContainerNovaLibvirtConfigImage\": \"ContainerNovaLibvirtConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"NovaResumeGuestsStateOnHostBoot\": {\"get_param\": \"NovaResumeGuestsStateOnHostBoot\"}, \"NovaResumeGuestsShutdownTimeout\": {\"get_param\": \"NovaResumeGuestsShutdownTimeout\"}, \"ContainerNovaLibvirtConfigImage\": {\"get_param\": \"ContainerNovaLibvirtConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for libvirt-guests\", \"value\": {\"service_name\": \"nova_libvirt_guests\", \"config_settings\": {\"get_attr\": [\"RoleParametersValue\", \"value\"]}, \"puppet_config\": {\"config_volume\": \"nova_libvirt\", \"puppet_tags\": \"libvirtd_config,nova_config,file,libvirt_tls_password\", \"step_config\": \"include tripleo::profile::base::nova::compute::libvirt_guests\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerNovaLibvirtConfigImage\"]}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(149,'2026-06-09 08:02:13',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(150,'2026-06-09 08:02:13',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(151,'2026-06-09 08:02:13',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Neutron service\\n\", \"parameters\": {\"NeutronServiceName\": {\"description\": \"service name\", \"type\": \"string\"}}, \"outputs\": {\"cmd_extra_args\": {\"description\": \"Extra command line arguments for running the service in the container.\", \"value\": {\"str_replace\": {\"template\": \"--log-file=/var/log/neutron/SERVICE.log\", \"params\": {\"SERVICE\": {\"get_param\": \"NeutronServiceName\"}}}}}, \"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_2\": {}}}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/neutron:/var/log/neutron:z\"]}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/neutron\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"NeutronServiceName\": \"ovn-metadata-agent\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(152,'2026-06-09 08:02:14',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Containerized rsyslogd service for purposes of centralized log collection of OpenStack services\' logs.\\n\", \"parameters\": {\"ContainerRsyslogImage\": {\"description\": \"The container image to use for container\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\"}, \"ContainerRsyslogConfigImage\": {\"description\": \"The container image to use for the rsyslog config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"RsyslogReopenOnTruncate\": {\"default\": true, \"description\": \"Rsyslog imfile reopenOnTruncate parameter\", \"type\": \"boolean\"}, \"RsyslogElasticsearchSetting\": {\"default\": {}, \"description\": \"Configuration for rsyslog-elasticsearch plugin\", \"type\": \"json\"}, \"RsyslogElasticsearchTlsCACert\": {\"default\": \"\", \"description\": \"Contains content of the CA cert for the CA that issued Elasticsearch server cert.\", \"type\": \"string\"}, \"RsyslogElasticsearchTlsClientCert\": {\"default\": \"\", \"description\": \"Contains content of the client cert for doing client cert auth against Elasticsearch.\", \"type\": \"string\"}, \"RsyslogElasticsearchTlsClientKey\": {\"default\": \"\", \"description\": \"Contains content of the private key corresponding to the cert RsyslogElasticsearchTlsClientCert.\", \"type\": \"string\"}, \"CloudName\": {\"default\": \"overcloud.ooo.test\", \"description\": \"The DNS name of this cloud. E.g. ci-overcloud.tripleo.org\", \"type\": \"string\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"RsyslogAmqp1Setting\": {\"default\": {}, \"description\": \"Configuration for rsyslog-omamqp1 plugin\", \"type\": \"json\"}, \"RsyslogAmqp1Local\": {\"default\": true, \"description\": \"Set to false to disable prefilling host connection value to local QDR in RsyslogAmqp1Setting.\", \"type\": \"boolean\"}, \"MetricsQdrPort\": {\"default\": 5666, \"description\": \"Service name or port number on which the qdrouterd will accept connections.\", \"type\": \"number\"}, \"RsyslogMaxMessageSize\": {\"default\": \"32k\", \"description\": \"Maximum supported message size (both for sending and receiving) for rsyslogd.\", \"type\": \"string\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerRsyslogImage\": \"ContainerRsyslogImage\", \"ContainerRsyslogConfigImage\": \"ContainerRsyslogConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerRsyslogImage\": {\"get_param\": \"ContainerRsyslogImage\"}, \"ContainerRsyslogConfigImage\": {\"get_param\": \"ContainerRsyslogConfigImage\"}}}]}}}}, \"conditions\": {\"use_tls\": {\"not\": {\"and\": [{\"equals\": [{\"get_param\": \"RsyslogElasticsearchTlsCACert\"}, \"\"]}, {\"equals\": [{\"get_param\": \"RsyslogElasticsearchTlsClientCert\"}, \"\"]}, {\"equals\": [{\"get_param\": \"RsyslogElasticsearchTlsClientKey\"}, \"\"]}]}}, \"use_elasticsearch\": {\"not\": {\"equals\": [{\"get_param\": \"RsyslogElasticsearchSetting\"}, {}]}}, \"use_amqp1\": {\"not\": {\"equals\": [{\"get_param\": \"RsyslogAmqp1Setting\"}, {}]}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the rsyslog role.\", \"value\": {\"service_name\": \"rsyslog\", \"config_settings\": {\"map_merge\": [{\"rsyslog::server::global_config\": {\"WorkDirectory\": {\"type\": \"legacy\", \"target\": \"00_rsyslog.conf\", \"value\": \"/var/lib/rsyslog\"}, \"MaxMessageSize\": {\"type\": \"legacy\", \"target\": \"00_rsyslog.conf\", \"value\": {\"get_param\": \"RsyslogMaxMessageSize\"}}}, \"rsyslog::confdir\": \"/etc/rsyslog.d\", \"rsyslog::package_name\": \"rsyslog\", \"rsyslog::package_version\": \"installed\", \"rsyslog::manage_package\": true, \"rsyslog::manage_confdir\": true, \"rsyslog::purge_config_files\": true, \"rsyslog::override_default_config\": true, \"rsyslog::config_file\": \"/etc/rsyslog.conf\", \"rsyslog::manage_service\": true, \"rsyslog::service_name\": \"rsyslog\", \"rsyslog::service_status\": \"running\", \"rsyslog::service_enabled\": true, \"rsyslog::external_service\": false, \"rsyslog::use_upstream_repo\": false, \"rsyslog::feature_packages\": [\"rsyslog-elasticsearch\", \"rsyslog-mmnormalize\"], \"rsyslog::global_config_priority\": 10, \"rsyslog::module_load_priority\": 20, \"rsyslog::input_priority\": 30, \"rsyslog::main_queue_priority\": 40, \"rsyslog::parser_priority\": 45, \"rsyslog::template_priority\": 50, \"rsyslog::filter_priority\": 55, \"rsyslog::action_priority\": 60, \"rsyslog::ruleset_priority\": 65, \"rsyslog::lookup_table_priority\": 70, \"rsyslog::legacy_config_priority\": 80, \"rsyslog::custom_priority\": 90, \"rsyslog::target_file\": \"50_openstack_logs.conf\", \"rsyslog::server::modules\": {\"imfile\": {}, \"omelasticsearch\": {}, \"omamqp1\": {}}, \"rsyslog::server::templates\": {\"rsyslog-node-index\": {\"type\": \"list\", \"list_descriptions\": [{\"constant\": {\"value\": \"%{hiera(\'fqdn_canonical\')}-\"}}, {\"property\": {\"name\": \"timereported\", \"dateFormat\": \"year\"}}, {\"constant\": {\"value\": \".\"}}, {\"property\": {\"name\": \"timereported\", \"dateFormat\": \"month\"}}, {\"constant\": {\"value\": \".\"}}, {\"property\": {\"name\": \"timereported\", \"dateFormat\": \"day\"}}]}, \"rsyslog-record\": {\"type\": \"list\", \"options\": {\"jsonf\": \"on\"}, \"list_descriptions\": [{\"property\": {\"outname\": \"@timestamp\", \"name\": \"timereported\", \"dateFormat\": \"rfc3339\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"host\", \"name\": \"hostname\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"severity\", \"name\": \"syslogseverity\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"facility\", \"name\": \"syslogfacility-text\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"tag\", \"name\": \"syslogtag\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"source\", \"name\": \"app-name\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"message\", \"name\": \"msg\", \"format\": \"jsonf\"}}, {\"property\": {\"outname\": \"file\", \"name\": \"$!metadata!filename\", \"format\": \"jsonf\"}}, {\"constant\": {\"outname\": \"cloud\", \"value\": {\"get_param\": \"CloudName\"}, \"format\": \"jsonf\"}}, {\"constant\": {\"outname\": \"region\", \"value\": {\"get_param\": \"KeystoneRegion\"}, \"format\": \"jsonf\"}}]}}}, {\"if\": [\"use_elasticsearch\", {\"tripleo::profile::base::logging::rsyslog::elasticsearch\": {\"map_merge\": [{\"get_param\": \"RsyslogElasticsearchSetting\"}, {\"template\": \"rsyslog-record\", \"searchIndex\": \"rsyslog-node-index\", \"dynSearchIndex\": \"on\", \"errorfile\": \"/var/log/rsyslog/omelasticsearch.log\"}]}}, {}]}, {\"if\": [\"use_amqp1\", {\"tripleo::profile::base::logging::rsyslog::amqp1\": {\"map_merge\": [{\"get_param\": \"RsyslogAmqp1Setting\"}, {\"template\": \"rsyslog-record\"}, {\"if\": [{\"get_param\": \"RsyslogAmqp1Local\"}, {\"host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}:$PORT\", \"params\": {\"$PORT\": {\"get_param\": \"MetricsQdrPort\"}, \"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}}]}]}}, {}]}, {\"if\": [{\"get_param\": \"RsyslogReopenOnTruncate\"}, {\"tripleo::profile::base::logging::rsyslog::reopen_on_truncate\": \"on\"}, {}]}, {\"if\": [\"use_tls\", {\"tripleo::profile::base::logging::rsyslog::elasticsearch_tls_ca_cert\": {\"get_param\": \"RsyslogElasticsearchTlsCACert\"}, \"tripleo::profile::base::logging::rsyslog::elasticsearch_tls_client_cert\": {\"get_param\": \"RsyslogElasticsearchTlsClientCert\"}, \"tripleo::profile::base::logging::rsyslog::elasticsearch_tls_client_key\": {\"get_param\": \"RsyslogElasticsearchTlsClientKey\"}}]}]}, \"puppet_config\": {\"config_volume\": \"rsyslog\", \"puppet_tags\": \"rsyslog::generate_concat,concat::fragment\", \"step_config\": \"include tripleo::profile::base::logging::rsyslog\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRsyslogConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/rsyslog.json\": {\"command\": \"/usr/sbin/rsyslogd -n -iNONE\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/lib/rsyslog\", \"owner\": \"root:root\", \"recurse\": true}, {\"path\": \"/var/log/rsyslog\", \"owner\": \"root:root\", \"recurse\": true}]}}, \"docker_config\": {\"step_3\": {\"rsyslog\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerRsyslogImage\"]}, \"net\": \"host\", \"privileged\": true, \"user\": \"root\", \"restart\": \"always\", \"security_opt\": [\"label=disable\"], \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/rsyslog.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/rsyslog:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers:/var/log/containers:ro\", \"/var/log/containers/rsyslog:/var/log/rsyslog:rw,z\", \"/var/log:/var/log/host:ro\", \"/var/lib/rsyslog.container:/var/lib/rsyslog:rw,z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent logs directory for rsyslog\", \"file\": {\"path\": \"/var/log/containers/rsyslog\", \"state\": \"directory\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}}, {\"name\": \"create persistent state directory for rsyslog\", \"file\": {\"path\": \"/var/lib/rsyslog.container\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(153,'2026-06-09 08:02:14',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(154,'2026-06-09 08:02:14',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (155,'2026-06-09 08:02:15',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Prepare container images\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerImagePrepare\": {\"default\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images.\", \"type\": \"json\"}, \"ContainerImagePrepareLogFile\": {\"default\": \"/var/log/tripleo-container-image-prepare.log\", \"type\": \"string\", \"description\": \"Used to store outputs of \\\"openstack tripleo container image prepare\\\".\"}, \"DockerInsecureRegistryAddress\": {\"description\": \"Optional. The IP Address and Port of an insecure docker namespace that will be configured in /etc/sysconfig/docker. The value can be multiple addresses separated by commas.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"NeutronMechanismDrivers\": {\"default\": \"ovn\", \"description\": \"The mechanism drivers for the Neutron tenant network.\\n\", \"type\": \"comma_delimited_list\"}, \"DockerRegistryMirror\": {\"description\": \"Optional. Mirror to use for registry docker.io\", \"default\": \"\", \"type\": \"string\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"ContainerImagePrepareDebug\": {\"default\": false, \"description\": \"Whether or not we want to activate --debug in tripleo container image prepare.\", \"type\": \"boolean\"}, \"ContainerImageRegistryCredentials\": {\"type\": \"json\", \"hidden\": true, \"default\": {}, \"description\": \"Mapping of image registry hosts to login credentials. Must be in the following example format\\n\\n  docker.io:\\n    username: pa55word\\n  \'192.0.2.1:8787\':\\n    registry_username: password\\n\"}, \"AdditionalArchitectures\": {\"default\": [], \"description\": \"List of additional architectures to enable.\", \"type\": \"comma_delimited_list\"}, \"ControllerContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"ControllerServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the Controller role.\", \"type\": \"comma_delimited_list\", \"default\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"]}, \"ControllerCount\": {\"description\": \"Number of Controller nodes to deploy\", \"type\": \"number\", \"default\": 3}, \"CellControllerContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"CellControllerServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the CellController role.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"CellControllerCount\": {\"description\": \"Number of CellController nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"CellControllerComputeContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"CellControllerComputeServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the CellControllerCompute role.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"CellControllerComputeCount\": {\"description\": \"Number of CellControllerCompute nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"ComputeContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"ComputeServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the Compute role.\", \"type\": \"comma_delimited_list\", \"default\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"]}, \"ComputeCount\": {\"description\": \"Number of Compute nodes to deploy\", \"type\": \"number\", \"default\": 3}, \"BlockStorageContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"BlockStorageServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the BlockStorage role.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"BlockStorageCount\": {\"description\": \"Number of BlockStorage nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"ObjectStorageContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"ObjectStorageServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the ObjectStorage role.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"ObjectStorageCount\": {\"description\": \"Number of ObjectStorage nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"CephStorageContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"CephStorageServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the CephStorage role.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"CephStorageCount\": {\"description\": \"Number of CephStorage nodes to deploy\", \"type\": \"number\", \"default\": 0}, \"NetworkerContainerImagePrepare\": {\"description\": \"Used to run \\\"openstack tripleo container image prepare\\\". This is run after the registry is installed to populate the registry with images. This is used for a specific role and replaces the ContainerImagePrepare parameter.\", \"type\": \"json\", \"default\": {}}, \"NetworkerServices\": {\"description\": \"A list of service resources (configured in the Heat resource_registry) which represent nested stacks for each service that should get installed on the Networker role.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"NetworkerCount\": {\"description\": \"Number of Networker nodes to deploy\", \"type\": \"number\", \"default\": 0}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for container image prepare\", \"value\": {\"service_name\": \"container_image_prepare\", \"external_deploy_tasks\": [{\"name\": \"Run tripleo-container-image-prepare role\", \"import_role\": {\"name\": \"tripleo_container_image_prepare\"}, \"vars\": {\"tripleo_container_image_prepare_log_file\": {\"get_param\": \"ContainerImagePrepareLogFile\"}, \"tripleo_container_image_prepare_debug\": {\"if\": [{\"get_param\": \"ContainerImagePrepareDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"tripleo_container_image_prepare_roles\": [{\"name\": \"Controller\", \"description\": \"Controller role that has all the controler services loaded and handles\\\\nDatabase, Messaging and Network functions.\\\\n\", \"CountDefault\": 1, \"tags\": [\"primary\", \"controller\", \"external_bridge\"], \"networks\": {\"External\": {\"subnet\": \"external_subnet\"}, \"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-controller-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"uses_deprecated_params\": true, \"deprecated_param_extraconfig\": \"controllerExtraConfig\", \"deprecated_param_flavor\": \"OvercloudControlFlavor\", \"deprecated_param_image\": \"controllerImage\", \"deprecated_nic_config_name\": \"controller.yaml\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AodhApi\", \"OS::TripleO::Services::AodhEvaluator\", \"OS::TripleO::Services::AodhListener\", \"OS::TripleO::Services::AodhNotifier\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BarbicanApi\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\", \"OS::TripleO::Services::BarbicanBackendDogtag\", \"OS::TripleO::Services::BarbicanBackendKmip\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephExternal\", \"OS::TripleO::Services::CephGrafana\", \"OS::TripleO::Services::CephMds\", \"OS::TripleO::Services::CephMgr\", \"OS::TripleO::Services::CephMon\", \"OS::TripleO::Services::CephNfs\", \"OS::TripleO::Services::CephRbdMirror\", \"OS::TripleO::Services::CephRgw\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackendDellSc\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\", \"OS::TripleO::Services::CinderBackendDellEMCSc\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\", \"OS::TripleO::Services::CinderBackendNetApp\", \"OS::TripleO::Services::CinderBackendPure\", \"OS::TripleO::Services::CinderBackendScaleIO\", \"OS::TripleO::Services::CinderBackendNVMeOF\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::DesignateApi\", \"OS::TripleO::Services::DesignateCentral\", \"OS::TripleO::Services::DesignateProducer\", \"OS::TripleO::Services::DesignateWorker\", \"OS::TripleO::Services::DesignateMDNS\", \"OS::TripleO::Services::DesignateSink\", \"OS::TripleO::Services::DesignateBind\", \"OS::TripleO::Services::Etcd\", \"OS::TripleO::Services::ExternalSwiftProxy\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::GnocchiApi\", \"OS::TripleO::Services::GnocchiMetricd\", \"OS::TripleO::Services::GnocchiStatsd\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::IronicApi\", \"OS::TripleO::Services::IronicConductor\", \"OS::TripleO::Services::IronicInspector\", \"OS::TripleO::Services::IronicPxe\", \"OS::TripleO::Services::IronicNeutronAgent\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaBackendFlashBlade\", \"OS::TripleO::Services::ManilaBackendIsilon\", \"OS::TripleO::Services::ManilaBackendNetapp\", \"OS::TripleO::Services::ManilaBackendPowerMax\", \"OS::TripleO::Services::ManilaBackendUnity\", \"OS::TripleO::Services::ManilaBackendVNX\", \"OS::TripleO::Services::ManilaBackendVMAX\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronBgpVpnApi\", \"OS::TripleO::Services::NeutronSfcApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NeutronDhcpAgent\", \"OS::TripleO::Services::NeutronL2gwAgent\", \"OS::TripleO::Services::NeutronL2gwApi\", \"OS::TripleO::Services::NeutronL3Agent\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NeutronOvsAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::NeutronAgentsIBConfig\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaIronic\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OctaviaApi\", \"OS::TripleO::Services::OctaviaDeploymentConfig\", \"OS::TripleO::Services::OctaviaHealthManager\", \"OS::TripleO::Services::OctaviaHousekeeping\", \"OS::TripleO::Services::OctaviaWorker\", \"OS::TripleO::Services::OpenStackClients\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftDispersion\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Unbound\", \"OS::TripleO::Services::Vpp\"]}, {\"name\": \"CellController\", \"description\": \"Controller role that has the cell controler specific\\\\nservices and handles Database, Messaging and Network functions.\\\\n\", \"CountDefault\": 1, \"tags\": [\"primary\", \"controller\"], \"networks\": {\"External\": {\"subnet\": \"external_subnet\"}, \"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-controller-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"uses_deprecated_params\": true, \"deprecated_param_extraconfig\": \"controllerExtraConfig\", \"deprecated_param_flavor\": \"OvercloudControlFlavor\", \"deprecated_param_image\": \"controllerImage\", \"deprecated_nic_config_name\": \"controller.yaml\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Ptp\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Vpp\"]}, {\"name\": \"CellControllerCompute\", \"description\": \"Controller and Compute AIO role that has compute and cell controler specific\\\\nservices loaded and handles Database, Messaging and Network functions.\\\\n\", \"CountDefault\": 1, \"tags\": [\"primary\", \"controller\", \"external_bridge\"], \"networks\": {\"External\": {\"subnet\": \"external_subnet\"}, \"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-controller-compute-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"uses_deprecated_params\": true, \"deprecated_param_extraconfig\": \"controllerExtraConfig\", \"deprecated_param_flavor\": \"OvercloudControlFlavor\", \"deprecated_param_image\": \"controllerImage\", \"deprecated_nic_config_name\": \"controller.yaml\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephExternal\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\", \"OS::TripleO::Services::ComputeNeutronL3Agent\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::NovaAZConfig\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Ptp\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Vpp\"]}, {\"name\": \"Compute\", \"description\": \"Basic Compute Node role\\\\n\", \"CountDefault\": 1, \"tags\": [\"compute\", \"external_bridge\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}}, \"default_route_networks\": [\"ControlPlane\"], \"HostnameFormatDefault\": \"%stackname%-novacompute-%index%\", \"RoleParametersDefault\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"uses_deprecated_params\": true, \"deprecated_param_image\": \"NovaImage\", \"deprecated_param_extraconfig\": \"NovaComputeExtraConfig\", \"deprecated_param_metadata\": \"NovaComputeServerMetadata\", \"deprecated_param_scheduler_hints\": \"NovaComputeSchedulerHints\", \"deprecated_param_ips\": \"NovaComputeIPs\", \"deprecated_server_resource_name\": \"NovaCompute\", \"deprecated_nic_config_name\": \"compute.yaml\", \"update_serial\": 25, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephClient\", \"OS::TripleO::Services::CephExternal\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\", \"OS::TripleO::Services::ComputeNeutronL3Agent\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::NovaAZConfig\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Vpp\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"]}, {\"name\": \"BlockStorage\", \"description\": \"Cinder Block Storage node role\\\\n\", \"tags\": [\"storage\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}}, \"uses_deprecated_params\": false, \"deprecated_nic_config_name\": \"cinder-storage.yaml\", \"update_serial\": 25, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BlockStorageCinderVolume\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::Multipathd\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"]}, {\"name\": \"ObjectStorage\", \"description\": \"Swift Object Storage node role\\\\n\", \"tags\": [\"storage\"], \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}}, \"uses_deprecated_params\": true, \"deprecated_param_metadata\": \"SwiftStorageServerMetadata\", \"deprecated_param_ips\": \"SwiftStorageIPs\", \"deprecated_param_image\": \"SwiftStorageImage\", \"deprecated_param_flavor\": \"OvercloudSwiftStorageFlavor\", \"deprecated_nic_config_name\": \"swift-storage.yaml\", \"deprecated_server_resource_name\": \"SwiftStorage\", \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::Ptp\"]}, {\"name\": \"CephStorage\", \"description\": \"Ceph OSD Storage node role\\\\n\", \"tags\": [\"ceph\", \"storage\"], \"networks\": {\"Storage\": {\"subnet\": \"storage_subnet\"}, \"StorageMgmt\": {\"subnet\": \"storage_mgmt_subnet\"}}, \"uses_deprecated_params\": false, \"HostnameFormatDefault\": \"%stackname%-cephstorage-%index%\", \"deprecated_nic_config_name\": \"ceph-storage.yaml\", \"update_serial\": 1, \"rhsm_enforce\": false, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CephOSD\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::RsyslogSidecar\", \"OS::TripleO::Services::Securetty\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"]}, {\"name\": \"Networker\", \"description\": \"Standalone networking role to run Neutron agents on their own.\\\\n\", \"networks\": {\"InternalApi\": {\"subnet\": \"internal_api_subnet\"}, \"Tenant\": {\"subnet\": \"tenant_subnet\"}}, \"tags\": [\"external_bridge\"], \"HostnameFormatDefault\": \"%stackname%-networker-%index%\", \"RoleParametersDefault\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"update_serial\": 1, \"ServicesDefault\": [\"OS::TripleO::Services::Aide\", \"OS::TripleO::Services::AuditD\", \"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::Frr\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Ipsec\", \"OS::TripleO::Services::IronicNeutronAgent\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::LoginDefs\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronDhcpAgent\", \"OS::TripleO::Services::NeutronL2gwAgent\", \"OS::TripleO::Services::NeutronL3Agent\", \"OS::TripleO::Services::NeutronMetadataAgent\", \"OS::TripleO::Services::NeutronOvsAgent\", \"OS::TripleO::Services::NeutronVppAgent\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OctaviaDeploymentConfig\", \"OS::TripleO::Services::OctaviaHealthManager\", \"OS::TripleO::Services::OctaviaHousekeeping\", \"OS::TripleO::Services::OctaviaWorker\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rhsm\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"]}], \"tripleo_container_image_prepare_content\": {\"parameter_defaults\": {\"ContainerImagePrepare\": {\"get_param\": \"ContainerImagePrepare\"}, \"DockerInsecureRegistryAddress\": {\"get_param\": \"DockerInsecureRegistryAddress\"}, \"NeutronMechanismDrivers\": {\"get_param\": \"NeutronMechanismDrivers\"}, \"DockerRegistryMirror\": {\"get_param\": \"DockerRegistryMirror\"}, \"ContainerImageRegistryCredentials\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"AdditionalArchitectures\": {\"get_param\": \"AdditionalArchitectures\"}, \"ControllerContainerImagePrepare\": {\"get_param\": \"ControllerContainerImagePrepare\"}, \"ControllerServices\": {\"get_param\": \"ControllerServices\"}, \"ControllerCount\": {\"get_param\": \"ControllerCount\"}, \"CellControllerContainerImagePrepare\": {\"get_param\": \"CellControllerContainerImagePrepare\"}, \"CellControllerServices\": {\"get_param\": \"CellControllerServices\"}, \"CellControllerCount\": {\"get_param\": \"CellControllerCount\"}, \"CellControllerComputeContainerImagePrepare\": {\"get_param\": \"CellControllerComputeContainerImagePrepare\"}, \"CellControllerComputeServices\": {\"get_param\": \"CellControllerComputeServices\"}, \"CellControllerComputeCount\": {\"get_param\": \"CellControllerComputeCount\"}, \"ComputeContainerImagePrepare\": {\"get_param\": \"ComputeContainerImagePrepare\"}, \"ComputeServices\": {\"get_param\": \"ComputeServices\"}, \"ComputeCount\": {\"get_param\": \"ComputeCount\"}, \"BlockStorageContainerImagePrepare\": {\"get_param\": \"BlockStorageContainerImagePrepare\"}, \"BlockStorageServices\": {\"get_param\": \"BlockStorageServices\"}, \"BlockStorageCount\": {\"get_param\": \"BlockStorageCount\"}, \"ObjectStorageContainerImagePrepare\": {\"get_param\": \"ObjectStorageContainerImagePrepare\"}, \"ObjectStorageServices\": {\"get_param\": \"ObjectStorageServices\"}, \"ObjectStorageCount\": {\"get_param\": \"ObjectStorageCount\"}, \"CephStorageContainerImagePrepare\": {\"get_param\": \"CephStorageContainerImagePrepare\"}, \"CephStorageServices\": {\"get_param\": \"CephStorageServices\"}, \"CephStorageCount\": {\"get_param\": \"CephStorageCount\"}, \"NetworkerContainerImagePrepare\": {\"get_param\": \"NetworkerContainerImagePrepare\"}, \"NetworkerServices\": {\"get_param\": \"NetworkerServices\"}, \"NetworkerCount\": {\"get_param\": \"NetworkerCount\"}}}}, \"when\": [\"(step | int) == 1\"]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(156,'2026-06-09 08:02:15',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Configure sshd_config\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"BannerText\": {\"default\": \"\", \"description\": \"Configures Banner text in sshd_config\", \"type\": \"string\"}, \"MessageOfTheDay\": {\"default\": \"\", \"description\": \"Configures /etc/motd text\", \"type\": \"string\"}, \"SshServerOptions\": {\"default\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"description\": \"Mapping of sshd_config values\", \"type\": \"json\"}, \"PasswordAuthentication\": {\"default\": \"yes\", \"description\": \"Whether or not disable password authentication\", \"type\": \"string\"}, \"SshFirewallAllowAll\": {\"default\": true, \"description\": \"Set this to true to open up ssh access from all sources.\", \"type\": \"boolean\"}, \"SshServerOptionsOverrides\": {\"default\": {}, \"description\": \"Mapping of sshd_config values to override definitions in SshServerOptions\", \"type\": \"json\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"SshServerOptionsOverrides\"]}], \"conditions\": {\"ssh_firewall_allow_all\": {\"equals\": [{\"get_param\": \"SshFirewallAllowAll\"}, true]}, \"ssh_banner_text_set\": {\"not\": {\"equals\": [{\"get_param\": \"BannerText\"}, \"\"]}}, \"ssh_motd_text_set\": {\"not\": {\"equals\": [{\"get_param\": \"MessageOfTheDay\"}, \"\"]}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the ssh\", \"value\": {\"service_name\": \"sshd\", \"firewall_rules\": {\"003 accept ssh from all\": {\"proto\": \"tcp\", \"dport\": 22, \"extras\": {\"ensure\": {\"if\": [\"ssh_firewall_allow_all\", \"present\", \"absent\"]}}}}, \"host_prep_tasks\": [{\"include_role\": {\"name\": \"tripleo_sshd\"}, \"vars\": {\"tripleo_sshd_server_options\": {\"map_merge\": [{\"get_param\": \"SshServerOptions\"}, {\"get_param\": \"SshServerOptionsOverrides\"}]}, \"tripleo_sshd_password_authentication\": {\"get_param\": \"PasswordAuthentication\"}, \"tripleo_sshd_banner_enabled\": {\"if\": [\"ssh_banner_text_set\", true, false]}, \"tripleo_sshd_banner_text\": {\"get_param\": \"BannerText\"}, \"tripleo_sshd_motd_enabled\": {\"if\": [\"ssh_motd_text_set\", true, false]}, \"tripleo_sshd_message_of_the_day\": {\"get_param\": \"MessageOfTheDay\"}}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(157,'2026-06-09 08:02:15',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Configures podman on the host\\n\", \"parameters\": {\"DockerInsecureRegistryAddress\": {\"description\": \"Optional. The IP Address and Port of an insecure docker namespace that will be configured in /etc/sysconfig/docker. The value can be multiple addresses separated by commas.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerImageRegistryLogin\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Flag to enable container registry login actions during the deployment. Setting this to true will cause login calls to be performed during the deployment.\"}, \"ContainerImageRegistryCredentials\": {\"type\": \"json\", \"hidden\": true, \"default\": {}, \"description\": \"Mapping of image registry hosts to login credentials. Must be in the following example format\\n\\n  docker.io:\\n    username: pa55word\\n  \'192.0.2.1:8787\':\\n    registry_username: password\\n\"}, \"ContainerDefaultPidsLimit\": {\"type\": \"number\", \"default\": 4096, \"description\": \"Setting to configure the default pids_limit in /etc/container/container.conf. This is supported starting with podman 2.0.x\"}, \"ContainerDefaultEventsLogger\": {\"type\": \"string\", \"default\": \"journald\", \"description\": \"Setting to configure where podman logs its events. Uses journald by default as that will rotate data stored in tmpfs.\", \"constraints\": [{\"allowed_values\": [\"journald\", \"file\", \"none\"]}]}, \"SystemdDropInDependencies\": {\"default\": true, \"description\": \"tell the tripleo_container_manage to inject additional ordering dependencies for the systemd scopes associated to podman containers.\", \"type\": \"boolean\"}, \"deployment_source_hosts\": {\"default\": \"Undercloud\", \"type\": \"string\", \"description\": \"Host or hostgroup that runs the deployment\"}}, \"conditions\": {\"insecure_registry_is_empty\": {\"equals\": [{\"get_param\": \"DockerInsecureRegistryAddress\"}, []]}, \"systemd_drop_in_dependencies_enabled\": {\"get_param\": \"SystemdDropInDependencies\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the podman service\", \"value\": {\"service_name\": \"podman\", \"config_settings\": {}, \"step_config\": \"\", \"host_prep_tasks\": [{\"name\": \"Install and configure Podman\", \"block\": [{\"name\": \"Set login facts\", \"no_log\": true, \"set_fact\": {\"container_registry_insecure_registries\": {\"if\": [\"insecure_registry_is_empty\", [], {\"get_param\": \"DockerInsecureRegistryAddress\"}]}, \"container_registry_login\": {\"get_param\": \"ContainerImageRegistryLogin\"}, \"container_registry_logins\": {}, \"container_registry_logins_json\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"container_default_pids_limit\": {\"get_param\": \"ContainerDefaultPidsLimit\"}, \"container_events_logger_mechanism\": {\"get_param\": \"ContainerDefaultEventsLogger\"}}}, {\"name\": \"Convert logins json to dict\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json | from_json }}\"}, \"when\": [\"container_registry_logins_json is string\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Set registry logins\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json }}\"}, \"when\": [\"container_registry_logins_json is mapping\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Run podman install\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_install.yml\"}, \"vars\": {\"tripleo_container_registry_insecure_registries\": \"{{ container_registry_insecure_registries }}\", \"tripleo_container_default_pids_limit\": \"{{ container_default_pids_limit }}\", \"tripleo_container_events_logger_mechanism\": \"{{ container_events_logger_mechanism }}\"}}, {\"name\": \"Run podman login\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_login.yml\"}, \"vars\": {\"tripleo_container_registry_logins\": \"{{ container_registry_logins }}\", \"tripleo_container_registry_login\": \"{{ container_registry_login | bool }}\"}}]}, {\"if\": [\"systemd_drop_in_dependencies_enabled\", [{\"name\": \"Configure tripleo_container_manage to generate systemd drop-in dependencies\", \"copy\": {\"dest\": \"/etc/sysconfig/podman_drop_in\", \"content\": \"This file makes tripleo_container_manage generate additional systemd\\ndependencies for containers that have special\\nstart/stop ordering constraints. It ensures that\\nthose constraints are enforced on reboot/shutdown.\\n\"}}], [{\"name\": \"Configure tripleo_container_manage to not generate drop-in dependencies\", \"file\": {\"path\": \"/etc/sysconfig/podman_drop_in\", \"state\": \"absent\"}}]]}], \"deploy_steps_tasks\": [{\"when\": [\"(step|int) == 1\"], \"block\": [{\"name\": \"Pre-fetch all the containers\", \"become\": true, \"containers.podman.podman_image\": {\"name\": \"{{ prefetch_image }}\", \"validate_certs\": false, \"force\": true}, \"register\": \"result\", \"until\": \"result is succeeded\", \"retries\": 5, \"delay\": 5, \"loop_control\": {\"loop_var\": \"prefetch_image\"}, \"loop\": \"{{ lookup(\'template\', tripleo_role_name + \'/docker_config.yaml\', errors=\'ignore\') | default(\'{}\', True) | from_yaml | recursive_get_key_from_dict(key=\'image\') | unique }}\"}]}], \"service_config_settings\": {}, \"workaround_upgrade_tasks\": [{\"name\": \"Configure Podman registry\", \"when\": [\"step|int == 0\"], \"tags\": [\"setup_packages\"], \"block\": [{\"name\": \"Make sure the Undercloud hostname is included in /etc/hosts\", \"when\": [\"undercloud_hosts_entries is defined\"], \"lineinfile\": {\"dest\": \"/etc/hosts\", \"line\": \"{{ undercloud_hosts_entries | join(\'\') }}\", \"state\": \"present\"}}]}, {\"name\": \"Run podman install\", \"tags\": [\"system_upgrade\", \"system_upgrade_run\", \"setup_packages\"], \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Set login facts\", \"no_log\": true, \"set_fact\": {\"container_registry_insecure_registries\": {\"if\": [\"insecure_registry_is_empty\", [], {\"get_param\": \"DockerInsecureRegistryAddress\"}]}, \"container_registry_login\": {\"get_param\": \"ContainerImageRegistryLogin\"}, \"container_registry_logins\": {}, \"container_registry_logins_json\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"container_default_pids_limit\": {\"get_param\": \"ContainerDefaultPidsLimit\"}, \"container_events_logger_mechanism\": {\"get_param\": \"ContainerDefaultEventsLogger\"}}}, {\"name\": \"Convert logins json to dict\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json | from_json }}\"}, \"when\": [\"container_registry_logins_json is string\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Set registry logins\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json }}\"}, \"when\": [\"container_registry_logins_json is mapping\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Run podman install\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_install.yml\"}, \"vars\": {\"tripleo_container_registry_insecure_registries\": \"{{ container_registry_insecure_registries }}\", \"tripleo_container_default_pids_limit\": \"{{ container_default_pids_limit }}\", \"tripleo_container_events_logger_mechanism\": \"{{ container_events_logger_mechanism }}\"}}, {\"name\": \"Run podman login\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_login.yml\"}, \"vars\": {\"tripleo_container_registry_logins\": \"{{ container_registry_logins }}\", \"tripleo_container_registry_login\": \"{{ container_registry_login | bool }}\"}}]}, {\"name\": \"Comment infra_image in container.conf\", \"lineinfile\": {\"dest\": \"/usr/share/containers/containers.conf\", \"regexp\": \"(?i)^(infra_image.*)\", \"line\": \"#\\\\1\", \"backrefs\": true, \"state\": \"present\"}, \"tags\": [\"setup_packages\"], \"when\": [\"step|int == 0\"]}], \"upgrade_tasks\": [{\"name\": \"Configure Podman registry\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Make sure the Undercloud hostname is included in /etc/hosts\", \"when\": [\"undercloud_hosts_entries is defined\"], \"lineinfile\": {\"dest\": \"/etc/hosts\", \"line\": \"{{ undercloud_hosts_entries | join(\'\') }}\", \"state\": \"present\"}}]}, {\"name\": \"Run podman install\", \"tags\": [\"system_upgrade\", \"system_upgrade_run\"], \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Set login facts\", \"no_log\": true, \"set_fact\": {\"container_registry_insecure_registries\": {\"if\": [\"insecure_registry_is_empty\", [], {\"get_param\": \"DockerInsecureRegistryAddress\"}]}, \"container_registry_login\": {\"get_param\": \"ContainerImageRegistryLogin\"}, \"container_registry_logins\": {}, \"container_registry_logins_json\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"container_default_pids_limit\": {\"get_param\": \"ContainerDefaultPidsLimit\"}, \"container_events_logger_mechanism\": {\"get_param\": \"ContainerDefaultEventsLogger\"}}}, {\"name\": \"Convert logins json to dict\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json | from_json }}\"}, \"when\": [\"container_registry_logins_json is string\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Set registry logins\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json }}\"}, \"when\": [\"container_registry_logins_json is mapping\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Run podman install\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_install.yml\"}, \"vars\": {\"tripleo_container_registry_insecure_registries\": \"{{ container_registry_insecure_registries }}\", \"tripleo_container_default_pids_limit\": \"{{ container_default_pids_limit }}\", \"tripleo_container_events_logger_mechanism\": \"{{ container_events_logger_mechanism }}\"}}, {\"name\": \"Run podman login\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_login.yml\"}, \"vars\": {\"tripleo_container_registry_logins\": \"{{ container_registry_logins }}\", \"tripleo_container_registry_login\": \"{{ container_registry_login | bool }}\"}}]}], \"update_tasks\": [{\"name\": \"Force pre-fetch of container images\", \"when\": [\"(step|int) == 5\"], \"block\": [{\"name\": \"Pre-fetch all the containers\", \"become\": true, \"containers.podman.podman_image\": {\"name\": \"{{ prefetch_image }}\", \"validate_certs\": false, \"force\": true}, \"register\": \"result\", \"until\": \"result is succeeded\", \"retries\": 5, \"delay\": 5, \"loop_control\": {\"loop_var\": \"prefetch_image\"}, \"loop\": \"{{ lookup(\'template\', tripleo_role_name + \'/docker_config.yaml\', errors=\'ignore\') | default(\'{}\', True) | from_yaml | recursive_get_key_from_dict(key=\'image\') | unique }}\"}]}], \"post_upgrade_tasks\": [{\"name\": \"Purge Podman\", \"when\": [\"(step | int) == 3\", \"container_cli == \'podman\'\", \"deployment_source_hosts not in group_names\"], \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_purge.yml\"}, \"vars\": {\"deployment_source_hosts\": {\"get_param\": \"deployment_source_hosts\"}}}], \"post_update_tasks\": [{\"name\": \"Purge Podman\", \"when\": [\"(step | int) == 3\", \"container_cli == \'podman\'\", \"deployment_source_hosts not in group_names\"], \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_purge.yml\"}, \"vars\": {\"deployment_source_hosts\": {\"get_param\": \"deployment_source_hosts\"}}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(158,'2026-06-09 08:02:15',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Glance service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"DeployIdentifier\": {\"default\": 1780992067, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"GlanceDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Glance service.\", \"type\": \"boolean\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"GlancePassword\": {\"description\": \"The password for the glance service and db account, used by the glance services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"cjUKwpQUAKsA4fym1vJsXs888\"}, \"GlanceWorkers\": {\"default\": 1, \"description\": \"Number of API worker processes for Glance. If left unset (empty string), the\\ndefault value will result in the configuration being left unset and a\\nsystem-dependent default value will be chosen (e.g.: number of\\nprocessors). Please note that this will create a large number of\\nprocesses on systems with a large number of CPUs resulting in excess\\nmemory consumption. It is recommended that a suitable non-default value\\nbe selected on such systems.\\n\", \"type\": \"string\"}, \"MonitoringSubscriptionGlanceApi\": {\"default\": \"overcloud-glance-api\", \"type\": \"string\"}, \"GlanceApiLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.glance.api\", \"file\": \"/var/log/containers/glance/api.log\"}}, \"GlanceImageMemberQuota\": {\"default\": 128, \"description\": \"Maximum number of image members per image.\\nNegative values evaluate to unlimited.\\n\", \"type\": \"number\"}, \"GlanceNfsEnabled\": {\"default\": false, \"description\": \"When using GlanceBackend \'file\', mount NFS share for image storage.\\n\", \"type\": \"boolean\"}, \"GlanceCacheEnabled\": {\"description\": \"Enable Glance Image Cache\", \"type\": \"boolean\", \"default\": false}, \"GlanceImageCacheDir\": {\"description\": \"Base directory that the Image Cache uses\", \"type\": \"string\", \"default\": \"/var/lib/glance/image-cache\"}, \"GlanceImageCacheMaxSize\": {\"description\": \"The upper limit on cache size, in bytes, after which the cache-pruner cleans up the image cache.\\n\", \"type\": \"number\", \"default\": 10737418240}, \"GlanceImageCacheStallTime\": {\"description\": \"The amount of time, in seconds, to let an image remain in the cache without being accessed.\\n\", \"type\": \"number\", \"default\": 86400}, \"GlanceImagePrefetcherInterval\": {\"description\": \"The interval in seconds to run periodic job cache_images.\\n\", \"type\": \"number\", \"default\": 300}, \"GlanceNfsShare\": {\"default\": \"\", \"description\": \"NFS share to mount for image storage (when GlanceNfsEnabled is true)\\n\", \"type\": \"string\"}, \"GlanceNetappNfsEnabled\": {\"default\": false, \"description\": \"When using GlanceBackend \'file\', Netapp mount NFS share for image storage.\\n\", \"type\": \"boolean\"}, \"NetappShareLocation\": {\"default\": \"\", \"description\": \"Netapp share to mount for image storage (when GlanceNetappNfsEnabled is true)\\n\", \"type\": \"string\"}, \"GlanceNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options for image storage (when GlanceNfsEnabled is true)\\n\", \"type\": \"string\"}, \"GlanceRbdPoolName\": {\"default\": \"images\", \"type\": \"string\"}, \"NovaEnableRbdBackend\": {\"default\": false, \"description\": \"Whether to enable the Rbd backend for Nova ephemeral storage.\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"GlanceImageImportPlugins\": {\"default\": [\"no_op\"], \"description\": \"List of enabled Image Import Plugins. Valid values in the list are \'image_conversion\', \'inject_metadata\', \'no_op\'.\\n\", \"type\": \"comma_delimited_list\"}, \"GlanceDiskFormats\": {\"default\": \"\", \"description\": \"List of allowed disk formats in Glance; all formats are allowed when left unset.\\n\", \"type\": \"comma_delimited_list\"}, \"GlanceImageConversionOutputFormat\": {\"default\": \"raw\", \"description\": \"Desired output format for image conversion plugin.\", \"type\": \"string\"}, \"GlanceInjectMetadataProperties\": {\"default\": \"\", \"description\": \"Metadata properties to be injected in image.\", \"type\": \"comma_delimited_list\"}, \"GlanceIgnoreUserRoles\": {\"default\": \"admin\", \"description\": \"List of user roles to be ignored for injecting image metadata properties.\", \"type\": \"comma_delimited_list\"}, \"GlanceEnabledImportMethods\": {\"default\": \"web-download\", \"description\": \"List of enabled Image Import Methods. Valid values in the list are \'glance-direct\', \'web-download\', or \'copy-image\'\\n\", \"type\": \"comma_delimited_list\"}, \"GlanceStagingNfsShare\": {\"default\": \"\", \"description\": \"NFS share to mount for image import staging\\n\", \"type\": \"string\"}, \"GlanceNodeStagingUri\": {\"default\": \"file:///var/lib/glance/staging\", \"description\": \"URI that specifies the staging location to use when importing images\\n\", \"type\": \"string\"}, \"GlanceStagingNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options for NFS image import staging\\n\", \"type\": \"string\"}, \"GlanceSparseUploadEnabled\": {\"default\": false, \"description\": \"When using GlanceBackend \'file\' and \'rbd\' to enable or not sparse upload.\\n\", \"type\": \"boolean\"}, \"EnforceSecureRbac\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Setting this option to True will configure each OpenStack service to enforce Secure RBAC by setting `[oslo_policy] enforce_new_defaults` and `[oslo_policy] enforce_scope` to True. This introduces a consistent set of RBAC personas across OpenStack services that include support for system and project scope, as well as keystone\'s default roles, admin, member, and reader. Do not enable this functionality until all services in your deployment actually support secure RBAC.\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"GlanceApiPolicies\": {\"description\": \"A hash of policies to configure for Glance API.\\ne.g. { glance-context_is_admin: { key: context_is_admin, value: \'role:admin\' } }\\n\", \"default\": {}, \"type\": \"json\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"GlanceNotifierStrategy\": {\"description\": \"Strategy to use for Glance notification queue\", \"type\": \"string\", \"default\": \"noop\"}, \"GlanceLogFile\": {\"description\": \"The filepath of the file to use for logging messages from Glance.\", \"type\": \"string\", \"default\": \"\"}, \"GlanceBackend\": {\"default\": \"swift\", \"description\": \"The short name of the Glance backend to use. Should be one of swift, rbd, cinder, or file\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"swift\", \"file\", \"rbd\", \"cinder\"]}]}, \"GlanceBackendID\": {\"type\": \"string\", \"default\": \"default_backend\", \"description\": \"The default backend\'s identifier.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9_-]+\"}]}, \"GlanceStoreDescription\": {\"type\": \"string\", \"default\": \"Default glance store backend.\", \"description\": \"User facing description for the Glance backend.\"}, \"GlanceMultistoreConfig\": {\"type\": \"json\", \"default\": {}, \"description\": \"Dictionary of settings when configuring additional glance backends. The\\nhash key is the backend ID, and the value is a dictionary of parameter\\nvalues unique to that backend. Multiple rbd and cinder backends are allowed, but\\nfile and swift backends are limited to one each. Example:\\n  # Default glance store is rbd.\\n  GlanceBackend: rbd\\n  GlanceStoreDescription: \'Default rbd store\'\\n  # GlanceMultistoreConfig specifies a second rbd backend, plus a cinder\\n  # backend.\\n  GlanceMultistoreConfig:\\n    rbd2_store:\\n      GlanceBackend: rbd\\n      GlanceStoreDescription: \'Second rbd store\'\\n      CephClusterName: ceph2\\n      # Override CephClientUserName if this cluster uses a different\\n      # client name.\\n      CephClientUserName: client2\\n    cinder1_store:\\n      GlanceBackend: cinder\\n      GlanceCinderVolumeType: \'volume-type-1\'\\n      GlanceStoreDescription: \'First cinder store\'\\n    cinder2_store:\\n      GlanceBackend: cinder\\n      GlanceCinderVolumeType: \'volume-type-2\'\\n      GlanceStoreDescription: \'Seconde cinder store\'\\n\"}, \"GlanceCinderMountPointBase\": {\"default\": \"/var/lib/glance/mnt\", \"type\": \"string\", \"description\": \"The mount point base when glance is using cinder as store and cinder backend\\nis NFS. This mount point is where the NFS volume is mounted on the glance node.\\n\"}, \"GlanceCinderVolumeType\": {\"default\": \"\", \"type\": \"string\", \"description\": \"A unique volume type required for each cinder store while configuring multiple cinder\\nstores as glance backends. The same volume types must be configured in Cinder as well.\\nThe volume type must exist in cinder prior to any attempt to add an image in the associated\\ncinder store. If no volume type is specified then cinder\'s default volume type will be used.\\n\"}, \"GlanceCinderLockPath\": {\"default\": \"/var/lib/cinder/tmp\", \"type\": \"string\", \"description\": \"The oslo.coordination lock_path to use when glance is using cinder as a store. Using\\ncinder\'s lock_path ensures os-brick operations are synchronized across both services.\\n\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"MultipathdEnable\": {\"default\": false, \"description\": \"Whether to enable the multipath daemon\", \"type\": \"boolean\"}, \"GlanceApiOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"ContainerGlanceApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\"}, \"ContainerGlanceApiConfigImage\": {\"description\": \"The container image to use for the glance_api config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\"}, \"GlanceCronDbPurgeMinute\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Minute\\n\", \"default\": \"1\"}, \"GlanceCronDbPurgeHour\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Hour\\n\", \"default\": \"0\"}, \"GlanceCronDbPurgeMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month Day\\n\", \"default\": \"*\"}, \"GlanceCronDbPurgeMonth\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month\\n\", \"default\": \"*\"}, \"GlanceCronDbPurgeWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Week Day\\n\", \"default\": \"*\"}, \"GlanceCronDbPurgeUser\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - User\\n\", \"default\": \"glance\"}, \"GlanceCronDbPurgeAge\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age\\n\", \"default\": \"30\"}, \"GlanceCronDbPurgeMaxRows\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Rows\\n\", \"default\": \"100\"}, \"GlanceCronDbPurgeDestination\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Log destination\\n\", \"default\": \"/var/log/glance/glance-rowsflush.log\"}, \"GlanceCronDbPurgeMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Delay\\n\", \"default\": \"3600\"}, \"MemcacheUseAdvancedPool\": {\"type\": \"boolean\", \"description\": \"Use the advanced (eventlet safe) memcached client pool.\\n\", \"default\": true}, \"GlanceShowMultipleLocations\": {\"default\": false, \"description\": \"Whether to show multiple image locations e.g for copy-on-write support on\\nRBD or Netapp backends. Potential security risk, see glance.conf for more information.\\n\", \"type\": \"boolean\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments.\\n\", \"parameters\": [\"GlanceShowMultipleLocations\"]}], \"conditions\": {\"cinder_backend_enabled\": {\"or\": [{\"equals\": [{\"get_param\": \"GlanceBackend\"}, \"cinder\"]}, {\"yaql\": {\"expression\": \"$.data.values().any($.get(\\\"GlanceBackend\\\", \\\"\\\") = \\\"cinder\\\")\", \"data\": {\"get_param\": \"GlanceMultistoreConfig\"}}}]}, \"cinder_multipathd_enabled\": {\"and\": [\"cinder_backend_enabled\", {\"get_param\": \"MultipathdEnable\"}]}, \"rbd_backend_enabled\": {\"or\": [{\"equals\": [{\"get_param\": \"GlanceBackend\"}, \"rbd\"]}, {\"yaql\": {\"expression\": \"$.data.values().any($.get(\\\"GlanceBackend\\\", \\\"\\\") = \\\"rbd\\\")\", \"data\": {\"get_param\": \"GlanceMultistoreConfig\"}}}]}, \"force_image_conversion_plugin\": {\"or\": [{\"and\": [\"rbd_backend_enabled\", {\"equals\": [{\"get_param\": \"GlanceImageImportPlugins\"}, [\"no_op\"]]}, {\"get_param\": \"NovaEnableRbdBackend\"}]}, {\"get_param\": \"GlanceSparseUploadEnabled\"}]}, \"glance_workers_set\": {\"not\": {\"equals\": [{\"get_param\": \"GlanceWorkers\"}, \"\"]}}, \"glance_multiple_locations\": {\"or\": [{\"get_param\": \"GlanceShowMultipleLocations\"}, {\"get_param\": \"GlanceNetappNfsEnabled\"}, {\"and\": [\"rbd_backend_enabled\", {\"get_param\": \"NovaEnableRbdBackend\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"GlanceLogging\": {\"type\": \"OS::TripleO::Services::Logging::GlanceApi\"}, \"CinderNVMeOF\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\"}, \"TLSProxyBase\": {\"type\": \"OS::TripleO::Services::TLSProxyBase\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"EnableInternalTLS\": {\"get_param\": \"EnableInternalTLS\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerGlanceApiImage\": \"ContainerGlanceApiImage\", \"ContainerGlanceApiConfigImage\": \"ContainerGlanceApiConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerGlanceApiImage\": {\"get_param\": \"ContainerGlanceApiImage\"}, \"ContainerGlanceApiConfigImage\": {\"get_param\": \"ContainerGlanceApiConfigImage\"}}}]}}}}, \"outputs\": {\"glance_api_host_prep_and_system_upgrade_post_tasks\": {\"description\": \"Common host_prep and system_upgrade post tasks for glance_api\", \"value\": [{\"name\": \"Mount NFS on host\", \"vars\": {\"nfs_backend_enabled\": {\"get_param\": \"GlanceNfsEnabled\"}, \"glance_netapp_nfs_enabled\": {\"get_param\": \"GlanceNetappNfsEnabled\"}, \"glance_nfs_share\": {\"get_param\": \"GlanceNfsShare\"}, \"netapp_share_location\": {\"get_param\": \"NetappShareLocation\"}, \"nfs_share\": \"{{ glance_nfs_share if (glance_nfs_share) else netapp_share_location }}\", \"nfs_options\": {\"get_param\": \"GlanceNfsOptions\"}}, \"mount\": {\"name\": \"/var/lib/glance/images\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{nfs_share}}\", \"opts\": \"{{nfs_options}}\"}, \"when\": \"nfs_backend_enabled or glance_netapp_nfs_enabled\"}, {\"name\": \"Mount Node Staging Location\", \"vars\": {\"glance_node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance_staging_nfs_share\": {\"get_param\": \"GlanceStagingNfsShare\"}, \"glance_nfs_options\": {\"get_param\": \"GlanceStagingNfsOptions\"}}, \"mount\": {\"name\": \"{{glance_node_staging_uri[7:]}}\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{glance_staging_nfs_share}}\", \"opts\": \"{{glance_nfs_options}}\"}, \"when\": \"glance_staging_nfs_share != \'\'\"}]}, \"role_data\": {\"description\": \"Role data for the Glance API role.\", \"value\": {\"service_name\": \"glance_api\", \"firewall_rules\": {\"112 glance_api\": {\"dport\": [9292]}}, \"firewall_frontend_rules\": {\"100 glance_api_haproxy_frontend\": {\"dport\": [9292]}}, \"firewall_ssl_frontend_rules\": {\"100 glance_api_haproxy_frontend_ssl\": {\"dport\": [13292]}}, \"keystone_resources\": {\"glance\": {\"endpoints\": {\"public\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"uri\"]}, \"internal\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"uri\"]}, \"admin\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"uri\"]}}, \"users\": {\"glance\": {\"password\": {\"get_param\": \"GlancePassword\"}}}, \"region\": {\"get_param\": \"KeystoneRegion\"}, \"service\": \"image\"}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionGlanceApi\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"TLSProxyBase\", \"role_data\", \"config_settings\"]}, {\"glance::api::db::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"glance\", \"password\": {\"get_param\": \"GlancePassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/glance\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"glance\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"glance::api::authtoken::www_authenticate_uri\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"glance::api::authtoken::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"glance::api::enable_v1_api\": false, \"glance::api::enable_v2_api\": true, \"glance::api::authtoken::password\": {\"get_param\": \"GlancePassword\"}, \"glance::api::enable_proxy_headers_parsing\": true, \"glance::api::logging::debug\": {\"if\": [{\"get_param\": \"GlanceDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"glance::policy::policies\": {\"get_param\": \"GlanceApiPolicies\"}, \"glance::api::authtoken::project_name\": \"service\", \"glance::api::authtoken::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"glance::api::authtoken::user_domain_name\": \"Default\", \"glance::api::authtoken::project_domain_name\": \"Default\", \"glance::api::authtoken::interface\": \"internal\", \"glance::api::authtoken::memcache_use_advanced_pool\": {\"get_param\": \"MemcacheUseAdvancedPool\"}, \"glance::api::pipeline\": {\"if\": [{\"get_param\": \"GlanceCacheEnabled\"}, \"keystone+cachemanagement\", \"keystone\"]}, \"glance::api::os_region_name\": {\"get_param\": \"KeystoneRegion\"}, \"glance::api::image_member_quota\": {\"get_param\": \"GlanceImageMemberQuota\"}, \"glance::api::enabled_import_methods\": {\"get_param\": \"GlanceEnabledImportMethods\"}, \"glance::api::node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance::api::image_import_plugins\": {\"if\": [\"force_image_conversion_plugin\", {\"list_concat_unique\": [{\"get_param\": \"GlanceImageImportPlugins\"}, [\"image_conversion\"]]}, {\"get_param\": \"GlanceImageImportPlugins\"}]}, \"glance::api::image_conversion_output_format\": {\"get_param\": \"GlanceImageConversionOutputFormat\"}, \"glance::api::inject_metadata_properties\": {\"get_param\": \"GlanceInjectMetadataProperties\"}, \"glance::api::ignore_user_roles\": {\"get_param\": \"GlanceIgnoreUserRoles\"}, \"tripleo::profile::base::glance::api::tls_proxy_bind_ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}}}, \"tripleo::profile::base::glance::api::tls_proxy_fqdn\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}}}, \"tripleo::profile::base::glance::api::tls_proxy_port\": 9292, \"glance::api::bind_host\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, \"%{hiera(\'localhost_address\')}\", {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}}}]}, \"glance_notifier_strategy\": {\"get_param\": \"GlanceNotifierStrategy\"}, \"glance_log_file\": {\"get_param\": \"GlanceLogFile\"}, \"glance::backend::rbd::rbd_thin_provisioning\": {\"get_param\": \"GlanceSparseUploadEnabled\"}, \"glance::backend::file::filesystem_thin_provisioning\": {\"get_param\": \"GlanceSparseUploadEnabled\"}, \"glance::backend::swift::swift_store_auth_address\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"glance::backend::swift::swift_store_user\": \"service:glance\", \"glance::backend::swift::swift_store_key\": {\"get_param\": \"GlancePassword\"}, \"glance::backend::swift::swift_store_create_container_on_put\": true, \"glance::backend::swift::swift_store_auth_version\": 3, \"glance::backend::rbd::rbd_store_ceph_conf\": {\"list_join\": [\"\", [\"/etc/ceph/\", {\"get_param\": \"CephClusterName\"}, \".conf\"]]}, \"glance::backend::rbd::rbd_store_pool\": {\"get_param\": \"GlanceRbdPoolName\"}, \"glance::backend::rbd::rbd_store_user\": {\"get_param\": \"CephClientUserName\"}, \"glance_backend\": {\"get_param\": \"GlanceBackend\"}, \"tripleo::profile::base::glance::api::glance_backend_id\": {\"get_param\": \"GlanceBackendID\"}, \"tripleo::profile::base::glance::api::glance_store_description\": {\"get_param\": \"GlanceStoreDescription\"}, \"tripleo::profile::base::glance::api::multistore_config\": {\"get_param\": \"GlanceMultistoreConfig\"}, \"tripleo::profile::base::glance::backend::rbd::glance_rbd_ceph_conf_path\": {\"get_param\": \"CephConfigPath\"}, \"glance::notify::rabbitmq::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"glance::notify::rabbitmq::rabbit_heartbeat_in_pthread\": false, \"glance::cron::db_purge::minute\": {\"get_param\": \"GlanceCronDbPurgeMinute\"}, \"glance::cron::db_purge::hour\": {\"get_param\": \"GlanceCronDbPurgeHour\"}, \"glance::cron::db_purge::monthday\": {\"get_param\": \"GlanceCronDbPurgeMonthday\"}, \"glance::cron::db_purge::month\": {\"get_param\": \"GlanceCronDbPurgeMonth\"}, \"glance::cron::db_purge::weekday\": {\"get_param\": \"GlanceCronDbPurgeWeekday\"}, \"glance::cron::db_purge::user\": {\"get_param\": \"GlanceCronDbPurgeUser\"}, \"glance::cron::db_purge::age\": {\"get_param\": \"GlanceCronDbPurgeAge\"}, \"glance::cron::db_purge::max_rows\": {\"get_param\": \"GlanceCronDbPurgeMaxRows\"}, \"glance::cron::db_purge::destination\": {\"get_param\": \"GlanceCronDbPurgeDestination\"}, \"glance::cron::db_purge::maxdelay\": {\"get_param\": \"GlanceCronDbPurgeMaxDelay\"}}, {\"if\": [\"glance_workers_set\", {\"glance::api::workers\": {\"get_param\": \"GlanceWorkers\"}}]}, {\"if\": [{\"get_param\": \"EnforceSecureRbac\"}, {\"glance::api::enforce_secure_rbac\": true, \"glance::policy::enforce_new_defaults\": true}]}, {\"if\": [\"cinder_backend_enabled\", {\"glance::backend::cinder::cinder_store_auth_address\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"glance::backend::cinder::cinder_store_project_name\": \"service\", \"glance::backend::cinder::cinder_store_user_name\": \"glance\", \"glance::backend::cinder::cinder_store_password\": {\"get_param\": \"GlancePassword\"}, \"glance::api::lock_path\": {\"get_param\": \"GlanceCinderLockPath\"}, \"tripleo::profile::base::glance::backend::cinder::cinder_mount_point_base\": {\"get_param\": \"GlanceCinderMountPointBase\"}, \"tripleo::profile::base::glance::backend::cinder::cinder_volume_type\": {\"get_param\": \"GlanceCinderVolumeType\"}}]}, {\"if\": [\"cinder_multipathd_enabled\", {\"glance::backend::cinder::cinder_use_multipath\": true}]}, {\"if\": [{\"get_param\": \"GlanceCacheEnabled\"}, {\"tripleo::profile::base::glance::api::glance_enable_cache\": true, \"glance::api::image_cache_dir\": {\"get_param\": \"GlanceImageCacheDir\"}, \"glance::api::image_cache_max_size\": {\"get_param\": \"GlanceImageCacheMaxSize\"}, \"glance::api::image_cache_stall_time\": {\"get_param\": \"GlanceImageCacheStallTime\"}, \"glance::api::cache_prefetcher_interval\": {\"get_param\": \"GlanceImagePrefetcherInterval\"}}]}, {\"if\": [{\"get_param\": \"GlanceNetappNfsEnabled\"}, {\"tripleo::profile::base::glance::netapp::netapp_share\": {\"get_param\": \"NetappShareLocation\"}, \"glance::api::filesystem_store_metadata_file\": \"/etc/glance/glance-metadata-file.json\", \"glance::api::filesystem_store_file_perm\": \"0644\"}]}, {\"if\": [{\"contains\": [\"glance-direct\", {\"get_param\": \"GlanceEnabledImportMethods\"}]}, {\"glance::api::worker_self_reference_url\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"str_replace\": {\"template\": \"https://%{hiera(\'fqdn_NETWORK\')}:PORT\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}, \"PORT\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}}}}, {\"str_replace\": {\"template\": \"http://%{hiera(\'NETWORK_uri\')}:PORT\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}, \"PORT\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}}}}]}}]}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"GlanceDiskFormats\"}, []]}}, {\"glance::api::disk_formats\": {\"get_param\": \"GlanceDiskFormats\"}}]}]}, \"service_config_settings\": {\"mysql\": {\"glance::db::mysql::password\": {\"get_param\": \"GlancePassword\"}, \"glance::db::mysql::user\": \"glance\", \"glance::db::mysql::host\": \"%\", \"glance::db::mysql::dbname\": \"glance\"}, \"rsyslog\": {\"tripleo_logging_sources_glance_api\": [{\"get_param\": \"GlanceApiLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"glance_api\", \"puppet_tags\": \"glance_api_config,glance_api_paste_ini,glance_swift_config,glance_cache_config,glance_image_import_config\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::glance::api\", {\"if\": [{\"get_param\": \"GlanceNetappNfsEnabled\"}, \"include tripleo::profile::base::glance::netapp\"]}, {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/glance_api.json\": {\"command\": \"/usr/bin/glance-api --config-file /usr/share/glance/glance-api-dist.conf --config-file /etc/glance/glance-api.conf --config-file /etc/glance/glance-image-import.conf\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-iscsid/*\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": {\"list_concat\": [[{\"path\": \"/var/lib/glance\", \"owner\": \"glance:glance\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"glance:glance\", \"perm\": \"0600\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%keyring%>\", \"owner\": \"glance:glance\", \"perm\": \"0600\"}, \"for_each\": {\"<%keyring%>\": {\"yaql\": {\"expression\": \"let(u => $.data.user) -> $.data.multistore.values().where($.get(\\\"CephClusterName\\\")).select($.CephClusterName + \\\".client.\\\" + $.get(\\\"CephClientUserName\\\", $u) +\\\".keyring\\\")\", \"data\": {\"user\": {\"get_param\": \"CephClientUserName\"}, \"multistore\": {\"get_param\": \"GlanceMultistoreConfig\"}}}}}}}]}}, \"/var/lib/kolla/config_files/glance_api_tls_proxy.json\": {\"command\": \"/usr/sbin/httpd -DFOREGROUND\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}, \"/var/lib/kolla/config_files/glance_api_cron.json\": {\"command\": \"/usr/sbin/crond -n\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/glance\", \"owner\": \"glance:glance\", \"recurse\": true}]}}, \"docker_config\": {\"step_2\": {\"get_attr\": [\"GlanceLogging\", \"docker_config\", \"step_2\"]}, \"step_3\": {\"glance_api_db_sync\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"cap_add\": [\"AUDIT_WRITE\"], \"net\": \"host\", \"privileged\": false, \"detach\": false, \"user\": \"root\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"GlanceLogging\", \"volumes\"]}, {\"get_param\": \"GlanceApiOptVolumes\"}, [\"/var/lib/kolla/config_files/glance_api.json:/var/lib/kolla/config_files/config.json\", \"/var/lib/config-data/puppet-generated/glance_api:/var/lib/kolla/config_files/src:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", \"/var/lib/glance:/var/lib/glance:shared\"], {\"if\": [\"cinder_backend_enabled\", {\"list_concat\": [[\"/dev:/dev\", \"/var/lib/iscsi:/var/lib/iscsi:z\", {\"list_join\": [\":\", [{\"get_param\": \"GlanceCinderLockPath\"}, {\"get_param\": \"GlanceCinderLockPath\"}, \"z\"]]}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}]}]}, {\"if\": [\"cinder_multipathd_enabled\", [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}, \"environment\": {\"KOLLA_BOOTSTRAP\": true, \"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}, \"command\": \"/usr/bin/bootstrap_host_exec glance_api su glance -s /bin/bash -c \'/usr/local/bin/kolla_start\'\"}}, \"step_4\": {\"glance_api\": {\"start_order\": 2, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"net\": \"host\", \"privileged\": {\"if\": [\"cinder_backend_enabled\", true, false]}, \"restart\": \"always\", \"depends_on\": {\"if\": [{\"or\": [{\"get_param\": \"GlanceNfsEnabled\"}, {\"get_param\": \"GlanceNetappNfsEnabled\"}]}, \"var-lib-glance-images.mount\"]}, \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"GlanceLogging\", \"volumes\"]}, {\"get_param\": \"GlanceApiOptVolumes\"}, [\"/var/lib/kolla/config_files/glance_api.json:/var/lib/kolla/config_files/config.json\", \"/var/lib/config-data/puppet-generated/glance_api:/var/lib/kolla/config_files/src:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", \"/var/lib/glance:/var/lib/glance:shared\"], {\"if\": [\"cinder_backend_enabled\", {\"list_concat\": [[\"/dev:/dev\", \"/var/lib/iscsi:/var/lib/iscsi:z\", {\"list_join\": [\":\", [{\"get_param\": \"GlanceCinderLockPath\"}, {\"get_param\": \"GlanceCinderLockPath\"}, \"z\"]]}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}]}]}, {\"if\": [\"cinder_multipathd_enabled\", [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"glance_api_tls_proxy\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"start_order\": 3, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"net\": \"host\", \"user\": \"root\", \"restart\": \"always\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"GlanceLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/glance_api_tls_proxy.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/glance_api:/var/lib/kolla/config_files/src:ro\", \"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}]}, \"glance_api_cron\": {\"start_order\": 2, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"net\": \"host\", \"user\": \"root\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/usr/share/openstack-tripleo-common/healthcheck/cron glance\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"GlanceLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/glance_api_cron.json:/var/lib/kolla/config_files/config.json\", \"/var/lib/config-data/puppet-generated/glance_api:/var/lib/kolla/config_files/src:ro\", \"/var/lib/glance:/var/lib/glance:shared\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"GlanceLogging\", \"host_prep_tasks\"]}, [{\"name\": \"Mount NFS on host\", \"vars\": {\"nfs_backend_enabled\": {\"get_param\": \"GlanceNfsEnabled\"}, \"glance_netapp_nfs_enabled\": {\"get_param\": \"GlanceNetappNfsEnabled\"}, \"glance_nfs_share\": {\"get_param\": \"GlanceNfsShare\"}, \"netapp_share_location\": {\"get_param\": \"NetappShareLocation\"}, \"nfs_share\": \"{{ glance_nfs_share if (glance_nfs_share) else netapp_share_location }}\", \"nfs_options\": {\"get_param\": \"GlanceNfsOptions\"}}, \"mount\": {\"name\": \"/var/lib/glance/images\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{nfs_share}}\", \"opts\": \"{{nfs_options}}\"}, \"when\": \"nfs_backend_enabled or glance_netapp_nfs_enabled\"}, {\"name\": \"Mount Node Staging Location\", \"vars\": {\"glance_node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance_staging_nfs_share\": {\"get_param\": \"GlanceStagingNfsShare\"}, \"glance_nfs_options\": {\"get_param\": \"GlanceStagingNfsOptions\"}}, \"mount\": {\"name\": \"{{glance_node_staging_uri[7:]}}\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{glance_staging_nfs_share}}\", \"opts\": \"{{glance_nfs_options}}\"}, \"when\": \"glance_staging_nfs_share != \'\'\"}], [{\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}, {\"name\": \"ensure /var/lib/glance exists\", \"file\": {\"path\": \"/var/lib/glance\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}], {\"if\": [\"cinder_backend_enabled\", [{\"name\": \"Allow glance to use cinder\'s lock_path\", \"file\": {\"path\": {\"get_param\": \"GlanceCinderLockPath\"}, \"state\": \"directory\", \"setype\": \"container_file_t\", \"mode\": 504, \"group\": 42400}}, {\"name\": \"Identify dynamic os-brick lock files used by glance\", \"vars\": {\"lock_path\": {\"get_param\": \"GlanceCinderLockPath\"}}, \"ansible.builtin.find\": {\"paths\": \"{{ lock_path }}\", \"patterns\": \"os-brick-connect_to_iscsi_portal-*\"}, \"register\": \"find_dynamic_locks\"}, {\"name\": \"Prepare the os-brick lock files used by glance\", \"vars\": {\"lock_path\": {\"get_param\": \"GlanceCinderLockPath\"}, \"static_brick_locks\": [\"{{ lock_path }}/os-brick-connect_volume\", \"{{ lock_path }}/os-brick-extend_volume\", \"{{ lock_path }}/scaleio-scaleio\"], \"dynamic_brick_locks\": \"{{ find_dynamic_locks.files | map(attribute=\'path\') }}\"}, \"file\": {\"path\": \"{{ item }}\", \"state\": \"touch\", \"setype\": \"container_file_t\", \"mode\": 432, \"group\": 42400}, \"loop\": \"{{ (static_brick_locks + dynamic_brick_locks) | flatten}}\"}]]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}, \"upgrade_tasks\": [{\"name\": \"glance-api pre system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Unmount and remove NFS glance entry\", \"vars\": {\"nfs_backend_enabled\": {\"get_param\": \"GlanceNfsEnabled\"}, \"glance_netapp_nfs_enabled\": {\"get_param\": \"GlanceNetappNfsEnabled\"}}, \"mount\": {\"name\": \"/var/lib/glance/images\", \"fstype\": \"nfs\", \"state\": \"absent\"}, \"when\": \"nfs_backend_enabled or glance_netapp_nfs_enabled\"}, {\"name\": \"Unmount and remove NFS glance-staging entry\", \"vars\": {\"glance_node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance_staging_nfs_share\": {\"get_param\": \"GlanceStagingNfsShare\"}}, \"mount\": {\"name\": \"{{glance_node_staging_uri[7:]}}\", \"fstype\": \"nfs\", \"state\": \"absent\"}, \"when\": \"glance_staging_nfs_share != \'\'\"}]}, {\"name\": \"glance-api post system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 5\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Mount NFS on host\", \"vars\": {\"nfs_backend_enabled\": {\"get_param\": \"GlanceNfsEnabled\"}, \"glance_netapp_nfs_enabled\": {\"get_param\": \"GlanceNetappNfsEnabled\"}, \"glance_nfs_share\": {\"get_param\": \"GlanceNfsShare\"}, \"netapp_share_location\": {\"get_param\": \"NetappShareLocation\"}, \"nfs_share\": \"{{ glance_nfs_share if (glance_nfs_share) else netapp_share_location }}\", \"nfs_options\": {\"get_param\": \"GlanceNfsOptions\"}}, \"mount\": {\"name\": \"/var/lib/glance/images\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{nfs_share}}\", \"opts\": \"{{nfs_options}}\"}, \"when\": \"nfs_backend_enabled or glance_netapp_nfs_enabled\"}, {\"name\": \"Mount Node Staging Location\", \"vars\": {\"glance_node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance_staging_nfs_share\": {\"get_param\": \"GlanceStagingNfsShare\"}, \"glance_nfs_options\": {\"get_param\": \"GlanceStagingNfsOptions\"}}, \"mount\": {\"name\": \"{{glance_node_staging_uri[7:]}}\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{glance_staging_nfs_share}}\", \"opts\": \"{{glance_nfs_options}}\"}, \"when\": \"glance_staging_nfs_share != \'\'\"}]}], \"metadata_settings\": {\"get_attr\": [\"TLSProxyBase\", \"role_data\", \"metadata_settings\"]}, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop glance api container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"glance_api\", \"glance_api_cron\"], \"tripleo_delegate_to\": \"{{ groups[\'glance_api\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}], \"deploy_steps_tasks\": {\"get_attr\": [\"TLSProxyBase\", \"role_data\", \"deploy_steps_tasks\"]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(159,'2026-06-09 08:02:16',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Heat API service\\n\", \"parameters\": {\"ContainerHeatApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\"}, \"ContainerHeatApiConfigImage\": {\"description\": \"The container image to use for the heat_api config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\"}, \"HeatApiLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.heat.api\", \"file\": \"/var/log/containers/heat/heat_api.log\"}}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"HeatApiOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"HeatApiOptEnvVars\": {\"default\": {}, \"description\": \"hash of optional environment variables\", \"type\": \"json\"}, \"HeatWorkers\": {\"default\": 1, \"description\": \"Number of workers for Heat service.\", \"type\": \"number\"}, \"HeatPassword\": {\"description\": \"The password for the Heat service and db account, used by the Heat services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"IWxKbYHIBwLTomkhalUwDCUxO\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"MonitoringSubscriptionHeatApi\": {\"default\": \"overcloud-heat-api\", \"type\": \"string\"}, \"HeatStackDomainAdminPassword\": {\"description\": \"Password for heat_stack_domain_admin user.\", \"type\": \"string\", \"hidden\": true, \"default\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\"}}, \"conditions\": {\"heat_workers_set\": {\"not\": {\"equals\": [{\"get_param\": \"HeatWorkers\"}, 0]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"ApacheServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"EnableInternalTLS\": {\"get_param\": \"EnableInternalTLS\"}}}, \"HeatBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-base-puppet.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"HeatApiLogging\": {\"type\": \"OS::TripleO::Services::Logging::HeatApi\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerHeatApiImage\": \"ContainerHeatApiImage\", \"ContainerHeatApiConfigImage\": \"ContainerHeatApiConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerHeatApiImage\": {\"get_param\": \"ContainerHeatApiImage\"}, \"ContainerHeatApiConfigImage\": {\"get_param\": \"ContainerHeatApiConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Heat API role.\", \"value\": {\"service_name\": \"heat_api\", \"firewall_rules\": {\"125 heat_api\": {\"dport\": [8004]}}, \"firewall_frontend_rules\": {\"100 heat_api_haproxy_frontend\": {\"dport\": [8004]}}, \"firewall_ssl_frontend_rules\": {\"100 heat_api_haproxy_frontend_ssl\": {\"dport\": [13004]}}, \"keystone_resources\": {\"heat\": {\"endpoints\": {\"public\": {\"get_param\": [\"EndpointMap\", \"HeatPublic\", \"uri\"]}, \"internal\": {\"get_param\": [\"EndpointMap\", \"HeatInternal\", \"uri\"]}, \"admin\": {\"get_param\": [\"EndpointMap\", \"HeatAdmin\", \"uri\"]}}, \"users\": {\"heat\": {\"password\": {\"get_param\": \"HeatPassword\"}}, \"heat_stack_domain_admin\": {\"password\": {\"get_param\": \"HeatStackDomainAdminPassword\"}, \"roles\": [\"admin\"], \"domain\": \"heat_stack\"}}, \"region\": {\"get_param\": \"KeystoneRegion\"}, \"service\": \"orchestration\", \"roles\": [\"heat_stack_user\"], \"domains\": [\"heat_stack\"]}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionHeatApi\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"HeatBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"HeatApiLogging\", \"config_settings\"]}, {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"config_settings\"]}, {\"apache::default_vhost\": false, \"heat::api::bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}}}, \"heat::wsgi::apache_api::ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"heat::wsgi::apache_api::vhost_custom_fragment\": \"Timeout 600\", \"heat::api::service_name\": \"httpd\", \"heat::wsgi::apache_api::bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}}}, \"heat::wsgi::apache_api::servername\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiNetwork\"]}}}}}, {\"if\": [\"heat_workers_set\", {\"heat::wsgi::apache_api::workers\": {\"get_param\": \"HeatWorkers\"}}]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_heat_api\": [{\"get_param\": \"HeatApiLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"heat_api\", \"puppet_tags\": \"heat_config,file,concat,file_line,heat_api_paste_ini\", \"step_config\": \"include tripleo::profile::base::heat::api\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHeatApiConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/heat_api.json\": {\"command\": \"/usr/sbin/httpd -DFOREGROUND\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/heat\", \"owner\": \"heat:heat\", \"recurse\": true}]}, \"/var/lib/kolla/config_files/heat_api_cron.json\": {\"command\": \"/usr/sbin/crond -n\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/heat\", \"owner\": \"heat:heat\", \"recurse\": true}]}}, \"docker_config\": {\"step_2\": {\"get_attr\": [\"HeatApiLogging\", \"docker_config\", \"step_2\"]}, \"step_4\": {\"heat_api\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHeatApiImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"user\": \"root\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"HeatApiLogging\", \"volumes\"]}, {\"get_param\": \"HeatApiOptVolumes\"}, [\"/var/lib/kolla/config_files/heat_api.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/heat_api:/var/lib/kolla/config_files/src:ro\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}]}, \"environment\": {\"map_merge\": [{\"get_param\": \"HeatApiOptEnvVars\"}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}]}}, \"heat_api_cron\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHeatApiImage\"]}, \"net\": \"host\", \"user\": \"root\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/usr/share/openstack-tripleo-common/healthcheck/cron heat\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"HeatApiLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/heat_api_cron.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/heat_api:/var/lib/kolla/config_files/src:ro\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": {\"get_attr\": [\"HeatApiLogging\", \"host_prep_tasks\"]}, \"upgrade_tasks\": [], \"metadata_settings\": {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"metadata_settings\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"deploy_steps_tasks\"]}, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop heat api container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"heat_api\", \"heat_api_cron\"], \"tripleo_delegate_to\": \"{{ groups[\'heat_api\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(160,'2026-06-09 08:02:16',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Glance API service\\n\", \"parameters\": {\"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerGlanceApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\"}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerGlanceApiImage\": \"ContainerGlanceApiImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerGlanceApiImage\": {\"get_param\": \"ContainerGlanceApiImage\"}}}]}}}}, \"outputs\": {\"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/glance:/var/log/glance:z\", \"/var/log/containers/httpd/glance:/var/log/httpd:z\"]}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_2\": {\"glance_init_logs\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/glance:/var/log/glance:z\", \"/var/log/containers/httpd/glance:/var/log/httpd:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R glance:glance /var/log/glance\"]}}}}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent logs directory\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/glance\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/log/containers/httpd/glance\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(161,'2026-06-09 08:02:16',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"TripleO Package installation settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnablePackageInstall\": {\"default\": true, \"description\": \"Set to true to enable package installation at deploy time\", \"type\": \"boolean\"}, \"UpgradeLeappEnabled\": {\"description\": \"Use Leapp for operating system upgrade\", \"type\": \"boolean\", \"default\": false}, \"UpgradeLeappDebug\": {\"description\": \"Print debugging output when running Leapp\", \"type\": \"boolean\", \"default\": false}, \"UpgradeLeappDevelSkip\": {\"description\": \"Skip Leapp checks by setting env variables when running Leapp in\\ndevelopment/testing. For example, LEAPP_DEVEL_SKIP_RHSM=1.\\n\", \"type\": \"string\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"UpgradeLeappCommandOptions\": {\"description\": \"In case or using UpgradeLeappDevelSkip with LEAPP_NO_RHSM=1 user\\ncan specify --enablerepo <repo1> --enablerepo <repo2> options for\\nleapp to use these repositories for the upgrade process.\\n\", \"type\": \"string\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"UpgradeLeappRebootTimeout\": {\"description\": \"Timeout (seconds) for the OS upgrade phase via Leapp\", \"type\": \"number\", \"default\": 3600}, \"UpgradeLeappPostRebootDelay\": {\"description\": \"Maximum (seconds) to wait for machine to reboot and respond to a test\\ncommand.\\n\", \"type\": \"number\", \"default\": 120}, \"UpgradeLeappToRemove\": {\"default\": [], \"description\": \"List of packages to remove during Leapp upgrade.\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"UpgradeLeappToInstall\": {\"default\": [], \"description\": \"List of packages to install after Leapp upgrade.\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"LeappUnloadKernelDrivers\": {\"type\": \"comma_delimited_list\", \"default\": [], \"description\": \"List of modules to unload from the system due to being incompatible\\nwith the next RHEL version. If not being unloaded Leapp will\\ninhibit the upgrade.\\n\"}, \"LeappActorsToRemove\": {\"type\": \"comma_delimited_list\", \"default\": [], \"description\": \"List of actors to remove from the leapp process to prevent them\\nfrom inhibiting the upgrade.\\n\"}, \"LeappRepoInitCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\ninitialize the Leapp process. E.g. a repository switch.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"LeappInitCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\napply any necessary workarounds to get Leapp working.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"NICsPrefixesToUdev\": {\"default\": [], \"description\": \"List of NIC prefixes to hardcode into udev in order to prevent\\nrenaming.\\n\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"LeappPreRebootCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\napply any necessary workarounds before rebooting into Leapp.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"LeappPostRebootCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\napply any necessary workarounds after rebooting from Leapp.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"UpgradeInitCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\ninitialize the upgrade process. E.g. a repository switch.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"UpgradeInitCommonCommand\": {\"type\": \"string\", \"description\": \"Common commands required by the upgrades process. This should not\\nnormally be modified by the operator and is set and unset in the\\nmajor-upgrade-composable-steps.yaml and major-upgrade-converge.yaml\\nenvironment files.\\n\", \"default\": \"\"}, \"SkipPackageUpdate\": {\"default\": false, \"description\": \"Set to true to skip the update all packages\", \"type\": \"boolean\"}, \"SkipRhelEnforcement\": {\"default\": false, \"description\": \"Whether to avoid or not RHEL/OSP policies enforcement on Red Hat. Mainly for CI purpose.  It shouldn\'t matter on other distributions where it\'s disabled in the role. Set to true to skip the enforcement.\", \"type\": \"boolean\"}, \"DnfStreams\": {\"default\": [], \"description\": \"List of streams to be configured before updating packages. Each list element contains a dictionary with the following values defined module[mandatory], stream[mandatory], distribution_version[mandatory] and profile[optional]. If the profile is not specified \'common\' will be used instead.\", \"type\": \"json\", \"tags\": [\"role_specific\"]}, \"BaseTripleoPackages\": {\"default\": [], \"description\": \"List of packages to install.\", \"type\": \"comma_delimited_list\", \"tags\": [\"role_specific\"]}, \"ContainerImageRegistryLogin\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Flag to enable container registry login actions during the deployment. Setting this to true will cause login calls to be performed during the deployment.\"}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"dnf_module_list\": \"DnfStreams\", \"upgrade_leapp_devel_skip\": \"UpgradeLeappDevelSkip\", \"upgrade_leapp_command_options\": \"UpgradeLeappCommandOptions\", \"upgrade_leapp_to_remove\": \"UpgradeLeappToRemove\", \"upgrade_leapp_to_install\": \"UpgradeLeappToInstall\", \"leapp_repo_init_command\": \"LeappRepoInitCommand\", \"leapp_init_command\": \"LeappInitCommand\", \"nics_prefixes_to_keep\": \"NICsPrefixesToUdev\", \"upgrade_leapp_modules_to_unload\": \"LeappUnloadKernelDrivers\", \"upgrade_leapp_actors_to_remove\": \"LeappActorsToRemove\", \"upgrade_init_command\": \"UpgradeInitCommand\", \"base_tripleo_packages\": \"BaseTripleoPackages\", \"leapp_pre_reboot_command\": \"LeappPreRebootCommand\", \"leapp_post_reboot_command\": \"LeappPostRebootCommand\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"DnfStreams\": {\"get_param\": \"DnfStreams\"}, \"UpgradeLeappDevelSkip\": {\"get_param\": \"UpgradeLeappDevelSkip\"}, \"UpgradeLeappCommandOptions\": {\"get_param\": \"UpgradeLeappCommandOptions\"}, \"UpgradeLeappToRemove\": {\"get_param\": \"UpgradeLeappToRemove\"}, \"UpgradeLeappToInstall\": {\"get_param\": \"UpgradeLeappToInstall\"}, \"LeappUnloadKernelDrivers\": {\"get_param\": \"LeappUnloadKernelDrivers\"}, \"LeappPreRebootCommand\": {\"get_param\": \"LeappPreRebootCommand\"}, \"LeappPostRebootCommand\": {\"get_param\": \"LeappPostRebootCommand\"}, \"LeappActorsToRemove\": {\"get_param\": \"LeappActorsToRemove\"}, \"UpgradeInitCommand\": {\"get_param\": \"UpgradeInitCommand\"}, \"LeappRepoInitCommand\": {\"get_param\": \"LeappRepoInitCommand\"}, \"LeappInitCommand\": {\"get_param\": \"LeappInitCommand\"}, \"NICsPrefixesToUdev\": {\"get_param\": \"NICsPrefixesToUdev\"}, \"BaseTripleoPackages\": {\"get_param\": \"BaseTripleoPackages\"}}}]}}}, \"Podman\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}}, \"conditions\": {\"podman_requires_login\": {\"equals\": [{\"get_param\": \"ContainerImageRegistryLogin\"}, true]}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the TripleO package settings\", \"value\": {\"service_name\": \"tripleo_packages\", \"config_settings\": {\"tripleo::packages::enable_install\": {\"get_param\": \"EnablePackageInstall\"}}, \"step_config\": \"include ::tripleo::packages\\n\", \"upgrade_tasks\": {\"list_concat\": [[{\"name\": \"Gather missing facts\", \"setup\": {\"gather_subset\": [\"!all\", \"!min\", \"distribution\"]}, \"tags\": [\"always\"]}, {\"name\": \"Set leapp facts\", \"set_fact\": {\"upgrade_leapp_enabled\": \"{{ _upgradeLeappEnabled | bool and\\n   ansible_facts[\'distribution\'] == \'RedHat\' and\\n   ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\') }}\", \"upgrade_leapp_debug\": {\"get_param\": \"UpgradeLeappDebug\"}, \"upgrade_leapp_devel_skip\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"upgrade_leapp_devel_skip\"]}, \"upgrade_leapp_command_options\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"upgrade_leapp_command_options\"]}, \"upgrade_leapp_reboot_timeout\": {\"get_param\": \"UpgradeLeappRebootTimeout\"}, \"upgrade_leapp_post_reboot_delay\": {\"get_param\": \"UpgradeLeappPostRebootDelay\"}}, \"vars\": {\"_upgradeLeappEnabled\": {\"get_param\": \"UpgradeLeappEnabled\"}}, \"tags\": [\"always\"]}, {\"name\": \"system_upgrade_prepare step 3\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_prepare\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Run LeappRepoInitCommand\", \"shell\": {\"list_join\": [\"\", [\"#!/bin/bash\\n\\n\", {\"get_attr\": [\"RoleParametersValue\", \"value\", \"leapp_repo_init_command\"]}]]}}, {\"name\": \"Remove firewalld bindings\", \"package\": {\"name\": \"python3-firewall\", \"state\": \"absent\"}}, {\"name\": \"install leapp\", \"package\": {\"name\": \"leapp-repository-openstack\", \"state\": \"latest\"}}, {\"name\": \"Run LeappInitCommand\", \"shell\": {\"list_join\": [\"\", [\"#!/bin/bash\\n\\n\", {\"get_attr\": [\"RoleParametersValue\", \"value\", \"leapp_init_command\"]}]]}}, {\"name\": \"Remove vdo\", \"package\": {\"name\": \"vdo\", \"state\": \"absent\"}}, {\"name\": \"add packages into Leapp\'s to_remove file\", \"vars\": {\"pkg_to_remove\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"upgrade_leapp_to_remove\"]}}, \"lineinfile\": {\"path\": \"/etc/leapp/transaction/to_remove\", \"line\": \"{{ item }}\"}, \"loop\": \"{{ pkg_to_remove }}\"}, {\"name\": \"add packages into Leapp\'s to_install file\", \"vars\": {\"pkg_to_install\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"upgrade_leapp_to_install\"]}}, \"lineinfile\": {\"path\": \"/etc/leapp/transaction/to_install\", \"line\": \"{{ item }}\"}, \"loop\": \"{{ pkg_to_install }}\"}, {\"name\": \"check sshd_config file\", \"stat\": {\"path\": \"/etc/ssh/sshd_config\"}, \"register\": \"sshd_config_result\"}, {\"name\": \"add PermitRootLogin option for leapp\", \"lineinfile\": {\"path\": \"/etc/ssh/sshd_config\", \"regexp\": \"^(# *)?PermitRootLogin\", \"line\": \"PermitRootLogin without-password\"}}, {\"name\": \"Remove paunch-services\", \"package\": {\"name\": \"paunch-services\", \"state\": \"absent\"}}, {\"name\": \"tripleo_container_manage reconfiguration\", \"import_role\": {\"name\": \"tripleo_container_manage\", \"tasks_from\": \"shutdown.yml\"}}]}, {\"name\": \"system_upgrade_prepare step 4\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_prepare\"], \"when\": [\"step|int == 4\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Delete the kernel modules in Leapp database (device_driver_deprecation_data.json)\", \"vars\": {\"modules_to_unload\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"upgrade_leapp_modules_to_unload\"]}}, \"shell\": \"set -o pipefail && jq \'. | del(.data[] | select(.driver_name == \\\"{{ item }}\\\"))\' /etc/leapp/files/device_driver_deprecation_data.json > /etc/leapp/files/device_driver_deprecation_data.json_modified && mv /etc/leapp/files/device_driver_deprecation_data.json_modified /etc/leapp/files/device_driver_deprecation_data.json\\n\", \"loop\": \"{{ modules_to_unload }}\"}, {\"name\": \"Remove leapp actors to prevent them inhibiting the upgrade\", \"vars\": {\"actors_to_remove\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"upgrade_leapp_actors_to_remove\"]}}, \"command\": {\"cmd\": \"find /usr/share/leapp-repository/repositories/ -name {{ item }} -type d -print -exec rm -rf \\\"{}\\\" +\"}, \"loop\": \"{{ actors_to_remove }}\"}, {\"name\": \"set leapp required answers\", \"shell\": \"leapp answer --add --section check_vdo.confirm=True\\n\"}, {\"name\": \"Replace EFI grub.cfg with redirect to /boot/grub2/grub.cfg\", \"import_role\": {\"name\": \"tripleo_kernel\", \"tasks_from\": \"efigrub.yml\"}}, {\"name\": \"Keep nics with prefix in NICsPrefixesToUdev from renaming\", \"vars\": {\"nics_prefixes_to_keep\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"nics_prefixes_to_keep\"]}}, \"shell\": \"ip -j link show | \\\\ jq -r --arg prefix \\\"{{ item }}\\\" \'.[] |\\n  select((.ifname | startswith($prefix)) and\\n  (.ifname | test(\\\"^.*v[0-9]*$\\\") | not) and\\n  (.ifname | test(\\\"^.*_[0-9]*$\\\") | not) and\\n  (.ifname | test(\\\"^.*\\\\\\\\..*$\\\") | not)) |\\n  if .permaddr? then .address=.permaddr else . end |\\n  \\\"SUBSYSTEM==\\\\\\\"net\\\\\\\",ACTION==\\\\\\\"add\\\\\\\",DRIVERS==\\\\\\\"?*\\\\\\\",\\\" + \\\"NAME=\\\\\\\"\\\" + .ifname +\\\"\\\\\\\" ,ATTR{address}==\\\\\\\"\\\" + .address + \\\"\\\\\\\"\\\"\' >> /etc/udev/rules.d/70-rhosp-persistent-net.rules\\n\", \"loop\": \"{{ nics_prefixes_to_keep|list }}\"}, {\"name\": \"run leapp upgrade (download packages)\", \"shell\": \"{% if upgrade_leapp_devel_skip|default(false) %}{{ upgrade_leapp_devel_skip }}{% endif %} leapp upgrade {% if upgrade_leapp_debug|default(true) %}--debug{% endif %} {% if upgrade_leapp_command_options|default(false) %}{{ upgrade_leapp_command_options }}{% endif %}\\n\", \"when\": \"upgrade_leapp_enabled\"}]}, {\"name\": \"system_upgrade_run step 4\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_reboot\"], \"when\": [\"step|int == 4\", \"upgrade_leapp_enabled\", \"\'Undercloud\' not in group_names\"], \"block\": [{\"name\": \"Run LeappPreRebootCommand\", \"shell\": {\"list_join\": [\"\", [\"#!/bin/bash\\n\\n\", {\"get_attr\": [\"RoleParametersValue\", \"value\", \"leapp_pre_reboot_command\"]}]]}}, {\"name\": \"Check that nova_libvirt is running\", \"shell\": \"podman ps --filter name=^nova_virtlogd$ --format \\\"{% raw %}{{ .Image }}{% endraw %}\\\"\\n\", \"register\": \"is_virtlogd_image_running\"}, {\"name\": \"Remove systemd files to disable them\", \"file\": {\"path\": \"/etc/systemd/system/{{ item }}\", \"state\": \"absent\"}, \"with_items\": [\"tripleo_nova_libvirt.service\", \"tripleo_nova_virtlogd_wrapper.service\", \"tripleo_nova_libvirt.target\"], \"when\": \"is_virtlogd_image_running.stdout != \'\'\"}, {\"name\": \"reboot to perform the upgrade\", \"reboot\": {\"reboot_timeout\": \"{{upgrade_leapp_reboot_timeout}}\", \"test_command\": \"source /etc/os-release; [ \\\"${VERSION_ID%.*}\\\" -ge \\\"8\\\" ] && systemctl is-system-running | grep -qE \\\"running|degraded\\\" || exit 1\", \"post_reboot_delay\": \"{{ upgrade_leapp_post_reboot_delay }}\"}}, {\"name\": \"Set selinux back to enforcing after leapp reboot\", \"selinux\": {\"policy\": \"targeted\", \"state\": \"enforcing\"}}, {\"name\": \"Run LeappPostRebootCommand\", \"shell\": {\"list_join\": [\"\", [\"#!/bin/bash\\n\\n\", {\"get_attr\": [\"RoleParametersValue\", \"value\", \"leapp_post_reboot_command\"]}]]}}]}, {\"name\": \"Host packages setup step0\", \"tags\": \"setup_packages\", \"when\": \"step|int == 0\", \"block\": [{\"name\": \"Package and repo update tasks\", \"block\": [{\"name\": \"Run UpgradeInitCommand\", \"shell\": {\"list_join\": [\"\", [\"#!/bin/bash\\n\\n\", \"if [[ -f /etc/resolv.conf.save ]] ; then rm /etc/resolv.conf.save; fi\\n\\n\", {\"get_attr\": [\"RoleParametersValue\", \"value\", \"upgrade_init_command\"]}]]}}, {\"name\": \"Run UpgradeInitCommonCommand\", \"shell\": {\"list_join\": [\"\", [\"#!/bin/bash\\n\\n\", {\"get_param\": \"UpgradeInitCommonCommand\"}]]}}, {\"name\": \"Ensure DNF modules have the right stream\", \"vars\": {\"dnf_module_list\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"dnf_module_list\"]}}, \"dnf\": {\"name\": \"@{{ item.module }}:{{ item.stream }}/{{ item.profile|default(\'common\') }}\", \"state\": \"present\"}, \"loop\": \"{{ dnf_module_list|list }}\", \"when\": [\"dnf_module_list|length > 0\", \"item.distribution_version is defined\", \"ansible_facts[\'distribution_major_version\'] is version(item.distribution_version, \'==\')\"]}, {\"name\": \"Ensure TripleO prerequisite packages are installed\", \"package\": {\"name\": [\"jq\", \"lvm2\", \"openstack-selinux\", \"os-net-config\", \"puppet-tripleo\", \"python3-heat-agent*\", \"rsync\"], \"state\": \"present\"}, \"when\": \"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\"}, {\"name\": \"Ensure TripleO prerequisite packages are installed and use role based heat variable to provide specific list of packages\", \"vars\": {\"base_tripleo_packages\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"base_tripleo_packages\"]}}, \"package\": {\"name\": \"{{ base_tripleo_packages }}\", \"state\": \"present\"}, \"when\": [\"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\", \"base_tripleo_packages|length > 0\"]}, {\"name\": \"WA for 2240185 - If the image is schema 1 and lacks signatures than add empty signatures\", \"shell\": \"for manifest_file in `find /var/lib/containers/storage/overlay-images/ -name \'manifest\'`\\ndo\\n    cat <<< $( jq  \'if .schemaVersion == 1 then if has(\\\"signatures\\\") then . else .signatures=[] end else . end\' $manifest_file ) > $manifest_file\\ndone\\n\", \"when\": \"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\"}]}, {\"name\": \"check if libvirt is installed\", \"command\": \"/usr/bin/rpm -q libvirt-daemon\", \"failed_when\": false, \"register\": \"libvirt_installed\", \"check_mode\": false}, {\"name\": \"make sure libvirt services are disabled and masked\", \"service\": {\"name\": \"{{ item }}\", \"state\": \"stopped\", \"enabled\": false, \"masked\": true, \"daemon_reload\": true}, \"loop\": [\"libvirtd.service\", \"virtlogd.socket\"], \"when\": [\"libvirt_installed.rc == 0\"]}]}, {\"name\": \"Host packages setup step2\", \"tags\": \"setup_packages\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"Special treatment for OpenvSwitch\", \"tripleo_ovs_upgrade\": null, \"register\": \"ovs_upgrade\"}, {\"name\": \"Always ensure the openvswitch service is enabled and running after upgrades\", \"service\": {\"name\": \"openvswitch\", \"enabled\": true, \"state\": \"started\"}, \"when\": [\"ovs_upgrade.changed|bool\"]}]}, {\"name\": \"Host packages setup step3\", \"tags\": \"setup_packages\", \"when\": \"step|int == 3\", \"block\": [{\"name\": \"Check for os-net-config upgrade\", \"shell\": \"yum check-upgrade | awk \'/os-net-config/{print}\'\", \"register\": \"os_net_config_need_upgrade\"}, {\"name\": \"Check that os-net-config has legacy configuration\", \"stat\": {\"path\": \"/etc/os-net-config/config.json\", \"get_attributes\": false, \"get_checksum\": false, \"get_mime\": false}, \"register\": \"stat_config_json\"}, {\"name\": \"Check that os-net-config has new configuration\", \"stat\": {\"path\": \"/etc/os-net-config/config.yaml\", \"get_attributes\": false, \"get_checksum\": false, \"get_mime\": false}, \"register\": \"stat_config_yaml\"}, {\"name\": \"Slurp the os-net-config config.json\", \"slurp\": {\"src\": \"/etc/os-net-config/config.json\"}, \"register\": \"os_config_json\", \"when\": [\"stat_config_json.stat.exists\", \"not stat_config_yaml.stat.exists\"]}, {\"name\": \"Write updated /etc/os-net-config/config.yaml\", \"copy\": {\"content\": \"{{ os_config_json.content | b64decode | from_json | to_yaml }}\", \"dest\": \"/etc/os-net-config/config.yaml\"}, \"when\": [\"stat_config_json.stat.exists\", \"not stat_config_yaml.stat.exists\"]}, {\"name\": \"Remove legacy os-net-config configuration\", \"command\": \"mv /etc/os-net-config/config.json /etc/os-net-config/deprecated_config.json\", \"when\": [\"stat_config_json.stat.exists\"]}, {\"block\": [{\"name\": \"Upgrade os-net-config\", \"package\": \"name=os-net-config state=latest\"}, {\"name\": \"take new os-net-config parameters into account now\", \"command\": \"os-net-config --no-activate -c /etc/os-net-config/config.yaml -v --detailed-exit-codes\", \"register\": \"os_net_config_upgrade\", \"failed_when\": \"os_net_config_upgrade.rc not in [0,2]\", \"changed_when\": \"os_net_config_upgrade.rc == 2\"}], \"when\": [\"os_net_config_need_upgrade.stdout\", \"stat_config_yaml.stat.exists or stat_config_json.stat.exists\"]}, {\"name\": \"Update all packages\", \"when\": [\"not skip_package_update|bool\"], \"yum\": {\"name\": \"*\", \"state\": \"latest\", \"exclude\": \"ansible-core\"}, \"vars\": {\"skip_package_update\": {\"get_param\": \"SkipPackageUpdate\"}}}, {\"name\": \"Check whether openvswitch exits\", \"command\": \"systemctl status openvswitch.service\", \"register\": \"ovs_service\", \"ignore_errors\": true}, {\"name\": \"Always ensure the openvswitch service is enabled and running after upgrades rhbz#2329821\", \"service\": {\"name\": \"openvswitch\", \"enabled\": true, \"state\": \"started\"}, \"when\": [\"ovs_service.stderr != \\\"Unit openvswitch.service could not be found.\\\"\"]}]}], {\"if\": [\"podman_requires_login\", {\"get_attr\": [\"Podman\", \"role_data\", \"workaround_upgrade_tasks\"]}, []]}]}, \"external_upgrade_tasks\": [{\"name\": \"Clean up upgrade artifacts\", \"when\": \"step|int == 1\", \"tags\": [\"never\", \"system_upgrade_cleanup\"], \"block\": [{\"name\": \"cleanup tripleo_persist\", \"include_role\": {\"name\": \"tripleo_persist\", \"tasks_from\": \"cleanup.yml\"}}]}], \"update_tasks\": [{\"name\": \"Enforce RHOSP rules regarding subscription.\", \"include_role\": {\"name\": \"tripleo_redhat_enforce\"}, \"vars\": {\"skip_rhel_enforcement\": {\"get_param\": \"SkipRhelEnforcement\"}}, \"when\": [\"step|int == 0\", \"ansible_facts[\'distribution\'] == \'RedHat\'\", \"not (skip_rhel_enforcement | bool)\"]}, {\"name\": \"Ensure DNF modules have the right stream enabled\", \"vars\": {\"dnf_module_list\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"dnf_module_list\"]}}, \"tripleo_dnf_stream\": {\"name\": \"{{ item.module }}:{{ item.stream }}\", \"state\": \"enabled\"}, \"loop\": \"{{ dnf_module_list|list }}\", \"when\": [\"step|int == 0\", \"dnf_module_list|length > 0\", \"item.distribution_version is defined\", \"ansible_facts[\'distribution_major_version\'] is version(item.distribution_version, \'==\')\"]}, {\"name\": \"Check for existing yum.pid\", \"stat\": \"path=/run/yum.pid\", \"register\": \"yum_pid_file\", \"when\": \"step|int == 0 or step|int == 3\"}, {\"name\": \"Exit if existing yum process\", \"fail\": \"msg=\\\"ERROR existing yum.pid detected - can\'t continue! Please ensure there is no other package update process for the duration of the minor update worfklow. Exiting.\\\"\", \"when\": \"(step|int == 0 or step|int == 3) and yum_pid_file.stat.exists\"}, {\"name\": \"Special treatment for OpenvSwitch\", \"tripleo_ovs_upgrade\": null, \"when\": [\"step|int == 2\"], \"register\": \"ovs_upgrade\"}, {\"name\": \"Always ensure the openvswitch service is enabled and running after upgrades\", \"service\": {\"name\": \"openvswitch\", \"enabled\": true, \"state\": \"started\"}, \"when\": [\"step|int == 2\", \"ovs_upgrade.changed|bool\"]}, {\"name\": \"Update packages and EFI grub.cfg\", \"when\": [\"step|int == 3\", \"not skip_package_update|bool\"], \"block\": [{\"name\": \"Update all packages\", \"yum\": {\"name\": \"*\", \"state\": \"latest\", \"exclude\": \"ansible-core\"}}, {\"name\": \"Replace EFI grub.cfg with redirect to /boot/grub2/grub.cfg\", \"import_role\": {\"name\": \"tripleo_kernel\", \"tasks_from\": \"efigrub.yml\"}}], \"vars\": {\"skip_package_update\": {\"get_param\": \"SkipPackageUpdate\"}}}, {\"name\": \"Ensure openvswitch is running after update\", \"when\": \"step|int == 3\", \"service\": {\"name\": \"openvswitch\", \"enabled\": true, \"state\": \"started\"}, \"ignore_errors\": true}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (162,'2026-06-09 08:02:16',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Composable Timezone service\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"TimeZone\": {\"default\": \"UTC\", \"description\": \"The timezone to be set on the overcloud.\", \"type\": \"string\"}}, \"outputs\": {\"role_data\": {\"description\": \"Timezone role using composable services.\", \"value\": {\"service_name\": \"timezone\", \"host_prep_tasks\": [{\"name\": \"Run timezone role\", \"include_role\": {\"name\": \"tripleo_timezone\"}, \"vars\": {\"tripleo_timezone\": {\"get_param\": \"TimeZone\"}}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(163,'2026-06-09 08:02:16',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Chrony time service deployment using ansible, this YAML file creates the interface between the HOT template and the ansible role that actually installs and configure chronyd.\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"NtpServer\": {\"default\": \"pool.ntp.org\", \"description\": \"NTP servers list. Defaulted to a set of pool.ntp.org servers in order to have a sane default for Pacemaker deployments when not configuring this parameter by default.\", \"type\": \"comma_delimited_list\"}, \"NtpPool\": {\"default\": [], \"description\": \"NTP pool list.  Defaults to [], so only NtpServer is used by default.\", \"type\": \"comma_delimited_list\"}, \"ChronyGlobalServerOptions\": {\"default\": \"\", \"description\": \"Default server options for the configured NTP servers in chrony.conf. If this is specified, NtpIburstEnable, MaxPoll, and MinPoll are ignored.\", \"type\": \"string\"}, \"ChronyGlobalPoolOptions\": {\"default\": \"\", \"description\": \"Default pool options for the configured NTP pools in chrony.conf. If this is specified, NtpIburstEnable, MaxPoll, and MinPoll are ignored.\", \"type\": \"string\"}, \"NtpIburstEnable\": {\"default\": true, \"description\": \"Specifies whether to enable the iburst option for every NTP peer. If iburst is enabled, when the ntp server is unreachable ntp will send a burst of eight packages instead of one. This is designed to speed up the initial syncrhonization.\", \"type\": \"boolean\"}, \"MaxPoll\": {\"description\": \"Specify maximum poll interval of upstream servers for NTP messages, in seconds to the power of two. The maximum poll interval defaults to 10 (1,024 s). Allowed values are 4 to 17.\", \"type\": \"number\", \"default\": 10, \"constraints\": [{\"range\": {\"min\": 4, \"max\": 17}}]}, \"MinPoll\": {\"description\": \"Specify minimum poll interval of upstream servers for NTP messages, in seconds to the power of two. The minimum poll interval defaults to 6 (64 s). Allowed values are 4 to 17.\", \"type\": \"number\", \"default\": 6, \"constraints\": [{\"range\": {\"min\": 4, \"max\": 17}}]}, \"EnablePackageInstall\": {\"default\": true, \"description\": \"Set to true to enable package installation at deploy time\", \"type\": \"boolean\"}, \"ChronyAclRules\": {\"default\": [\"deny all\"], \"description\": \"Access Control List of NTP clients.  By default no clients are permitted.\", \"type\": \"comma_delimited_list\"}}, \"conditions\": {\"chrony_global_server_settings_is_empty\": {\"equals\": [{\"get_param\": \"ChronyGlobalServerOptions\"}, \"\"]}, \"chrony_global_pool_settings_is_empty\": {\"equals\": [{\"get_param\": \"ChronyGlobalPoolOptions\"}, \"\"]}, \"ntp_iburst\": {\"equals\": [{\"get_param\": \"NtpIburstEnable\"}, true]}}, \"outputs\": {\"role_data\": {\"description\": \"Role chrony using composable timesync services.\", \"value\": {\"service_name\": \"chrony\", \"firewall_rules\": {\"105 ntp\": {\"dport\": 123, \"proto\": \"udp\"}}, \"host_prep_tasks\": [{\"name\": \"Check for NTP service\", \"shell\": \"systemctl is-active ntpd.service || systemctl is-enabled ntpd.service\", \"failed_when\": false, \"become\": true, \"register\": \"ntp_service_check\"}, {\"name\": \"Disable NTP before configuring Chrony\", \"service\": {\"name\": \"ntpd\", \"state\": \"stopped\", \"enabled\": false}, \"when\": [\"ntp_service_check.rc is defined\", \"ntp_service_check.rc == 0\"]}, {\"name\": \"Install, Configure and Run Chrony\", \"include_role\": {\"name\": \"chrony\"}}, {\"name\": \"Force NTP sync\", \"command\": \"chronyc makestep\"}, {\"name\": \"Ensure system is NTP time synced\", \"command\": \"chronyc waitsync 30\"}], \"ansible_group_vars\": {\"chrony_role_action\": \"all\", \"chrony_ntp_servers\": {\"get_param\": \"NtpServer\"}, \"chrony_ntp_pools\": {\"get_param\": \"NtpPool\"}, \"chrony_global_server_settings\": {\"if\": [\"chrony_global_server_settings_is_empty\", {\"str_replace\": {\"template\": \"IBURST minpoll MINPOLL maxpoll MAXPOLL\", \"params\": {\"IBURST\": {\"if\": [\"ntp_iburst\", \"iburst\", \"\"]}, \"MINPOLL\": {\"get_param\": \"MinPoll\"}, \"MAXPOLL\": {\"get_param\": \"MaxPoll\"}}}}, {\"get_param\": \"ChronyGlobalServerOptions\"}]}, \"chrony_global_pool_settings\": {\"if\": [\"chrony_global_pool_settings_is_empty\", {\"str_replace\": {\"template\": \"IBURST minpoll MINPOLL maxpoll MAXPOLL\", \"params\": {\"IBURST\": {\"if\": [\"ntp_iburst\", \"iburst\", \"\"]}, \"MINPOLL\": {\"get_param\": \"MinPoll\"}, \"MAXPOLL\": {\"get_param\": \"MaxPoll\"}}}}, {\"get_param\": \"ChronyGlobalPoolOptions\"}]}, \"chrony_manage_package\": {\"get_param\": \"EnablePackageInstall\"}, \"chrony_acl_rules\": {\"get_param\": \"ChronyAclRules\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(164,'2026-06-09 08:02:17',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Heat API service\\n\", \"outputs\": {\"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_2\": {}}}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/heat:/var/log/heat:z\", \"/var/log/containers/httpd/heat-api:/var/log/httpd:z\"]}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/heat\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/log/containers/httpd/heat-api\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(165,'2026-06-09 08:02:17',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Containerized collectd service\\n\", \"parameters\": {\"ContainerCollectdImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\"}, \"ContainerCollectdConfigImage\": {\"description\": \"The container image to use for the collectd config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"KeystoneRegion\": {\"type\": \"string\", \"description\": \"Keystone region for endpoint\", \"default\": \"regionOne\"}, \"MetricsQdrPort\": {\"default\": 5666, \"description\": \"Service name or port number on which the qdrouterd will accept connections.\", \"type\": \"number\"}, \"MetricsQdrUsername\": {\"default\": \"guest\", \"description\": \"Username which should be used to authenticate to the deployed qdrouterd.\", \"type\": \"string\"}, \"MetricsQdrPassword\": {\"default\": \"guest\", \"description\": \"Password which should be used to authenticate to the deployed qdrouterd.\", \"type\": \"string\", \"hidden\": true}, \"MonitoringSubscriptionCollectd\": {\"default\": \"overcloud-collectd\", \"type\": \"string\"}, \"CollectdConnectionType\": {\"default\": \"amqp1\", \"description\": \"Define which write plugin should collectd use. Currently supported are \'amqp1\' and \'network\'.\", \"type\": \"string\"}, \"CollectdDefaultPollingInterval\": {\"default\": 120, \"type\": \"number\", \"description\": \"Controls how often registered read functions are called and with that the resolution of the collected data. This value can be overridden per plugin(per role) by setting \\\"::collectd::plugin::<plugin_name>::interval\\\" key in ExtraConfig(<role_name>ExtraConfig) if using puppet, and by setting \\\"collectd_plugin_<plugin_name>_interval\\\" in <role_name>ExtraConfig/CollectdVars if using ansible.\\n\"}, \"CollectdDefaultPlugins\": {\"default\": [\"cpu\", \"df\", \"disk\", \"hugepages\", \"interface\", \"load\", \"memory\", \"unixsock\", \"uptime\"], \"type\": \"comma_delimited_list\", \"description\": \"List of collectd plugins to activate on all overcloud hosts.  See the documentation for the puppet-collectd module for a list plugins supported by the module (https://github.com/voxpupuli/puppet-collectd). Set this key to override the default list of plugins.  Use CollectdExtraPlugins if you want to load additional plugins without overriding the defaults.\\n\"}, \"CollectdExtraPlugins\": {\"default\": [], \"type\": \"comma_delimited_list\", \"description\": \"List of collectd plugins to activate on all overcloud hosts.  See the documentation for the puppet-collectd module for a list plugins supported by the module (https://github.com/voxpupuli/puppet-collectd). Set this key to load plugins in addition to those in CollectdDefaultPlugins.\\n\"}, \"CollectdServer\": {\"type\": \"string\", \"description\": \"Address of remote collectd server to which we will send metrics.\\n\", \"default\": \"\"}, \"CollectdServerPort\": {\"type\": \"number\", \"default\": 25826, \"description\": \"Port on remote collectd server to which we will send metrics.\\n\"}, \"CollectdUsername\": {\"type\": \"string\", \"description\": \"Username for authenticating to the remote collectd server. The default is to not configure any authentication.\\n\", \"default\": \"\"}, \"CollectdPassword\": {\"type\": \"string\", \"hidden\": true, \"description\": \"Password for authenticating to the remote collectd server. The default is to not configure any authentication.\\n\", \"default\": \"\"}, \"CollectdSecurityLevel\": {\"type\": \"string\", \"description\": \"Security level setting for remote collectd connection. If it is set to Sign or Encrypt the CollectdPassword and CollectdUsername parameters need to be set.\\n\", \"default\": \"None\", \"constraints\": [{\"allowed_values\": [\"None\", \"Sign\", \"Encrypt\"]}]}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"CollectdSQLAlchemyLogMessages\": {\"type\": \"string\", \"description\": \"set to \\\"debug\\\" to enable message logging.\", \"default\": \"info\"}, \"CollectdSQLAlchemyBindHost\": {\"type\": \"string\", \"description\": \"hostname for SQLAlchemy-collectd plugin to bind on.  defaults to localhost.\\n\", \"default\": \"localhost\"}, \"CollectdAmqpHost\": {\"type\": \"string\", \"description\": \"Hostname or IP address of the AMQP 1.0 intermediary.\", \"default\": \"nil\"}, \"CollectdAmqpPort\": {\"type\": \"number\", \"description\": \"Service name or port number on which the AMQP 1.0 intermediary accepts connections. This argument must be a string, even if the numeric form is used.\\n\", \"default\": 5666}, \"CollectdAmqpUser\": {\"type\": \"string\", \"description\": \"User part of credentials used to authenticate to the AMQP 1.0 intermediary.\\n\", \"default\": \"guest\"}, \"CollectdAmqpPassword\": {\"type\": \"string\", \"description\": \"Password part of credentials used to authenticate to the AMQP 1.0 intermediary.\\n\", \"default\": \"guest\", \"hidden\": true}, \"CollectdAmqpTransportName\": {\"type\": \"string\", \"description\": \"Name of the AMQP 1.0 transport.\", \"default\": \"metrics\"}, \"CollectdAmqpAddress\": {\"type\": \"string\", \"description\": \"This option specifies the prefix for the send-to value in the message.\\n\", \"default\": \"collectd\"}, \"CollectdAmqpInstances\": {\"type\": \"json\", \"description\": \"Hash of hashes. Each inner hash represent Instance block in plugin configuration file. Key of outter hash represents instance name. The \'address\' value concatenated with the \'name\' given will be used as the send-to address for communications over the messaging link.\\n\", \"default\": {}}, \"CollectdAmqpRetryDelay\": {\"type\": \"number\", \"description\": \"When the AMQP 1.0 connection is lost, defines the time in seconds to wait before attempting to reconnect.\\n\", \"default\": 1}, \"CollectdAmqpInterval\": {\"type\": \"number\", \"description\": \"Interval on which metrics should be sent to AMQP intermediary. If not set the default for all collectd plugins is used.\\n\", \"default\": -666}, \"CollectdAmqpSendQueueLimit\": {\"type\": \"number\", \"description\": \"Number of data sets to be kept in memory, older sets will be discarded, if set to -1, this feature is disabled.\\n\", \"default\": -1}, \"CollectdEnableSensubility\": {\"type\": \"boolean\", \"description\": \"Set to true if sensubility should be executed by exec plugin.\", \"default\": false}, \"CollectdSensubilityExecSudoRule\": {\"type\": \"string\", \"description\": \"Given rule will be created in /etc/sudoers.d for sensubility to enable it calling restricted commands via sensubility executor.\\n\", \"default\": \"\"}, \"CollectdSensubilityLogLevel\": {\"type\": \"string\", \"description\": \"Use for override the default logging level (WARNING).\", \"default\": \"WARNING\"}, \"CollectdSensubilityConnection\": {\"type\": \"string\", \"description\": \"URL to Sensu sever side\", \"default\": \"amqp://sensu:sensu@localhost:5672//sensu\"}, \"CollectdSensubilityKeepaliveInterval\": {\"type\": \"number\", \"description\": \"Interval in seconds for sending keepalive messages to Sensu server side.\", \"default\": 20}, \"CollectdSensubilityTmpDir\": {\"type\": \"string\", \"description\": \"Path to temporary directory which is used for creation of check scripts.\", \"default\": \"/var/tmp/collectd-sensubility-checks\"}, \"CollectdSensubilityShellPath\": {\"type\": \"string\", \"description\": \"Path to shell used for executing check scripts.\", \"default\": \"/usr/bin/sh\"}, \"CollectdSensubilityWorkerCount\": {\"type\": \"number\", \"description\": \"Number of goroutines spawned for executing check scripts.\", \"default\": 2}, \"CollectdSensubilityChecks\": {\"type\": \"json\", \"description\": \"JSON formated definition of standalone checks to be scheduled on client side.\", \"default\": {}}, \"CollectdSensubilityTransport\": {\"type\": \"string\", \"description\": \"Bus type for sent data. Options are \'sensu\' (rabbitmq) and \'amqp1\'\", \"default\": \"sensu\"}, \"CollectdSensubilityResultsChannel\": {\"type\": \"string\", \"description\": \"AMQP1 channel address\", \"default\": \"collectd/notify\"}, \"CollectdSensubilityScripts\": {\"type\": \"json\", \"description\": \"List of hashes of scripts for download for sensubility usage. Value has to be in following format:\\n[{\\\"name\\\": \\\"<script name>\\\", \\\"source\\\": \\\"<http URI to download script>\\\", \\\"checksum\\\": \\\"<alogithm:sum>\\\"}]\\n\", \"default\": []}, \"CollectdEnableContainerHealthCheck\": {\"type\": \"boolean\", \"description\": \"Set to false if container health check should not be defined and attached to CollectdEnableContainerHealthCheck.\\n\", \"default\": true}, \"CollectdContainerHealthCheckCommand\": {\"type\": \"string\", \"default\": \"/config-scripts/collectd_check_health.py\"}, \"CollectdContainerHealthCheckInterval\": {\"type\": \"number\", \"description\": \"The frequency in seconds the docker health check is executed.\", \"default\": 10}, \"CollectdContainerHealthCheckHandlers\": {\"default\": [], \"description\": \"The Sensu event handler to use for events created by the docker health check.\", \"type\": \"comma_delimited_list\"}, \"CollectdContainerHealthCheckOccurrences\": {\"type\": \"number\", \"description\": \"The number of event occurrences before sensu-plugin-aware handler should take action.\", \"default\": 3}, \"CollectdContainerHealthCheckRefresh\": {\"type\": \"number\", \"description\": \"The number of seconds sensu-plugin-aware handlers should wait before taking second action.\", \"default\": 90}, \"EnableSTF\": {\"type\": \"boolean\", \"description\": \"Set to true to enable configuration for STF client.\", \"default\": false}, \"CollectdEnableMcelog\": {\"type\": \"boolean\", \"description\": \"Set to true to enable mcelog\", \"default\": false}, \"CollectdEnableLibpodstats\": {\"type\": \"boolean\", \"description\": \"Set to true if collectd should run the libpodstats plugin\", \"default\": false}, \"CollectdContainerAdditionalCapAdd\": {\"type\": \"comma_delimited_list\", \"description\": \"Additional container capabilities to add to the collectd container. By default is appended to IPC_LOCK.\", \"default\": []}, \"CollectdLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"collectd\", \"file\": \"/var/log/containers/collectd/collectd.log\"}}, \"DeployedCeph\": {\"default\": false, \"type\": \"boolean\", \"description\": \"If the Ceph cluster has already been deployed but needs to be configured\\nso that the overcloud can use it (create cephx keys, pools, configure RGW\\nwith haproxy, etc), then this parameter should be set to true. Set this\\nparameter to false to have cephadm deploy the ceph cluster during overcloud\\ndeployment. DeployedCeph and CephDynamicSpec are mutually exclusive.\\n\"}, \"CephClusterFSID\": {\"type\": \"string\", \"description\": \"The Ceph cluster FSID. Must be a UUID.\", \"default\": \"141c0b27-2417-411f-ad72-876254cd4eac\"}}, \"conditions\": {\"amqp_connection\": {\"equals\": [{\"get_param\": \"CollectdConnectionType\"}, \"amqp1\"]}, \"amqp_default_connection\": {\"equals\": [{\"get_param\": \"CollectdAmqpHost\"}, \"nil\"]}, \"amqp_default_interval\": {\"equals\": [{\"get_param\": \"CollectdAmqpInterval\"}, -666]}, \"amqp_default_send_queue_limit\": {\"equals\": [{\"get_param\": \"CollectdAmqpSendQueueLimit\"}, -1]}, \"collectd_connection\": {\"equals\": [{\"get_param\": \"CollectdConnectionType\"}, \"network\"]}, \"enable_sensubility\": {\"equals\": [{\"get_param\": \"CollectdEnableSensubility\"}, true]}, \"enable_stf\": {\"equals\": [{\"get_param\": \"EnableSTF\"}, true]}, \"enable_sqlalchemy_collectd\": {\"equals\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, true]}, \"sensubility_needs_sudo\": {\"not\": {\"equals\": [{\"get_param\": \"CollectdSensubilityExecSudoRule\"}, \"\"]}}, \"enable_libpodstats\": {\"equals\": [{\"get_param\": \"CollectdEnableLibpodstats\"}, true]}, \"ipmi_monitor\": {\"not\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"IpmiMonitor\"]}, \"\"]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerCollectdImage\": \"ContainerCollectdImage\", \"ContainerCollectdConfigImage\": \"ContainerCollectdConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerCollectdImage\": {\"get_param\": \"ContainerCollectdImage\"}, \"ContainerCollectdConfigImage\": {\"get_param\": \"ContainerCollectdConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the collectd role.\", \"value\": {\"service_name\": \"collectd\", \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::enable_file_logging\": true, \"collectd::plugin::logfile::log_file\": \"/var/log/collectd/collectd.log\"}, {\"collectd::manage_repo\": false, \"collectd::purge\": true, \"collectd::recurse\": true, \"collectd::purge_config\": true, \"collectd::minimum_version\": \"5.7\", \"collectd::interval\": {\"get_param\": \"CollectdDefaultPollingInterval\"}, \"collectd::plugin::unixsock::socketgroup\": \"root\", \"collectd::plugin::unixsock::socketfile\": \"/run/collectd-socket\", \"collectd::plugin::unixsock::deletesocket\": true, \"collectd::plugin::cpu::reportbycpu\": true, \"collectd::plugin::cpu::reportbystate\": true, \"collectd::plugin::cpu::reportnumcpu\": false, \"collectd::plugin::cpu::valuespercentage\": true, \"collectd::plugin::df::ignoreselected\": true, \"collectd::plugin::df::reportbydevice\": true, \"collectd::plugin::df::fstypes\": [\"xfs\"], \"collectd::plugin::load::reportrelative\": true, \"collectd::plugin::virt::connection\": \"qemu:///system\", \"collectd::plugin::virt::extra_stats\": {\"list_join\": [\" \", [\"pcpu\", \"cpu_util\", \"vcpu\", \"memory\", \"disk\", \"disk_err\", \"disk_allocation\", \"disk_capacity\", \"disk_physical\", \"domain_state\", \"job_stats_background\", \"perf\"]]}, \"collectd::plugin::virt::hostname_format\": \"hostname\", \"tripleo.collectd.plugins.collectd\": {\"yaql\": {\"data\": {\"default_plugins\": {\"get_param\": \"CollectdDefaultPlugins\"}, \"stf_plugins\": {\"if\": [\"enable_stf\", [\"cpu\", \"df\", \"load\", \"connectivity\", \"intel_rdt\", \"procevent\"], []]}, \"extra_plugins\": {\"get_param\": \"CollectdExtraPlugins\"}}, \"expression\": \"($.data.default_plugins + $.data.stf_plugins + $.data.extra_plugins) .flatten().distinct()\\n\"}}}, {\"if\": [\"amqp_connection\", {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::amqp_transport_name\": {\"get_param\": \"CollectdAmqpTransportName\"}, \"tripleo::profile::base::metrics::collectd::amqp_address\": {\"get_param\": \"CollectdAmqpAddress\"}, \"tripleo::profile::base::metrics::collectd::amqp_instances\": {\"get_param\": \"CollectdAmqpInstances\"}, \"tripleo::profile::base::metrics::collectd::amqp_retry_delay\": {\"get_param\": \"CollectdAmqpRetryDelay\"}}, {\"if\": [\"amqp_default_interval\", {}, {\"tripleo::profile::base::metrics::collectd::amqp_interval\": {\"get_param\": \"CollectdAmqpInterval\"}}]}, {\"if\": [\"amqp_default_send_queue_limit\", {}, {\"tripleo::profile::base::metrics::collectd::amqp_send_queue_limit\": {\"get_param\": \"CollectdAmqpSendQueueLimit\"}}]}, {\"if\": [\"amqp_default_connection\", {\"tripleo::profile::base::metrics::collectd::amqp_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"tripleo::profile::base::metrics::collectd::amqp_port\": {\"get_param\": \"MetricsQdrPort\"}, \"tripleo::profile::base::metrics::collectd::amqp_user\": {\"get_param\": \"MetricsQdrUsername\"}, \"tripleo::profile::base::metrics::collectd::amqp_password\": {\"get_param\": \"MetricsQdrPassword\"}}, {\"tripleo::profile::base::metrics::collectd::amqp_host\": {\"get_param\": \"CollectdAmqpHost\"}, \"tripleo::profile::base::metrics::collectd::amqp_port\": {\"get_param\": \"CollectdAmqpPort\"}, \"tripleo::profile::base::metrics::collectd::amqp_user\": {\"get_param\": \"CollectdAmqpUser\"}, \"tripleo::profile::base::metrics::collectd::amqp_password\": {\"get_param\": \"CollectdAmqpPassword\"}}]}]}, {}]}, {\"if\": [\"collectd_connection\", {\"tripleo::profile::base::metrics::collectd::collectd_server\": {\"get_param\": \"CollectdServer\"}, \"tripleo::profile::base::metrics::collectd::collectd_port\": {\"get_param\": \"CollectdServerPort\"}, \"tripleo::profile::base::metrics::collectd::collectd_username\": {\"get_param\": \"CollectdUsername\"}, \"tripleo::profile::base::metrics::collectd::collectd_password\": {\"get_param\": \"CollectdPassword\"}, \"tripleo::profile::base::metrics::collectd::collectd_securitylevel\": {\"get_param\": \"CollectdSecurityLevel\"}}, {}]}, {\"if\": [\"enable_sqlalchemy_collectd\", {\"map_merge\": [{\"tripleo::profile::base::metrics::collectd::enable_sqlalchemy_collectd\": true}, {\"tripleo::profile::base::metrics::collectd::sqlalchemy_collectd_bind_host\": {\"get_param\": \"CollectdSQLAlchemyBindHost\"}}, {\"tripleo::profile::base::metrics::collectd::sqlalchemy_collectd_log_messages\": {\"get_param\": \"CollectdSQLAlchemyLogMessages\"}}]}, {}]}, {\"if\": [\"enable_sensubility\", {\"map_merge\": [{\"if\": [\"sensubility_needs_sudo\", {\"tripleo::profile::base::metrics::collectd::sensubility::exec_sudo_rule\": {\"get_param\": \"CollectdSensubilityExecSudoRule\"}}, {}]}, {\"tripleo::profile::base::metrics::collectd::enable_sensubility\": {\"get_param\": \"CollectdEnableSensubility\"}, \"tripleo::profile::base::metrics::collectd::sensubility::connection\": {\"get_param\": \"CollectdSensubilityConnection\"}, \"tripleo::profile::base::metrics::collectd::sensubility::log_level\": {\"get_param\": \"CollectdSensubilityLogLevel\"}, \"tripleo::profile::base::metrics::collectd::sensubility::client_name\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_NETWORK\')}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"tripleo::profile::base::metrics::collectd::sensubility::client_address\": {\"str_replace\": {\"template\": \"%{hiera(\'NETWORK\')}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", {\"str_replace\": {\"template\": \"ROLENAMEMetricsQdrNetwork\", \"params\": {\"ROLENAME\": {\"get_param\": \"RoleName\"}}}}]}}}}, \"tripleo::profile::base::metrics::collectd::sensubility::keepalive_interval\": {\"get_param\": \"CollectdSensubilityKeepaliveInterval\"}, \"tripleo::profile::base::metrics::collectd::sensubility::tmp_base_dir\": {\"get_param\": \"CollectdSensubilityTmpDir\"}, \"tripleo::profile::base::metrics::collectd::sensubility::shell_path\": {\"get_param\": \"CollectdSensubilityShellPath\"}, \"tripleo::profile::base::metrics::collectd::sensubility::worker_count\": {\"get_param\": \"CollectdSensubilityWorkerCount\"}, \"tripleo::profile::base::metrics::collectd::sensubility::checks\": {\"map_merge\": [{\"get_param\": \"CollectdSensubilityChecks\"}, {\"if\": [{\"get_param\": \"CollectdEnableContainerHealthCheck\"}, {\"check-container-health\": {\"standalone\": true, \"command\": {\"get_param\": \"CollectdContainerHealthCheckCommand\"}, \"interval\": {\"get_param\": \"CollectdContainerHealthCheckInterval\"}, \"handlers\": {\"get_param\": \"CollectdContainerHealthCheckHandlers\"}, \"occurrences\": {\"get_param\": \"CollectdContainerHealthCheckOccurrences\"}, \"refresh\": {\"get_param\": \"CollectdContainerHealthCheckRefresh\"}}}, {}]}]}, \"tripleo::profile::base::metrics::collectd::sensubility::results_channel\": {\"get_param\": \"CollectdSensubilityResultsChannel\"}, \"tripleo::profile::base::metrics::collectd::sensubility::transport\": {\"get_param\": \"CollectdSensubilityTransport\"}, \"tripleo::profile::base::metrics::collectd::sensubility::amqp_port\": {\"get_param\": \"CollectdAmqpPort\"}}]}, {}]}, {\"if\": [\"enable_libpodstats\", {\"tripleo::profile::base::metrics::collectd::enable_libpodstats\": {\"get_param\": \"CollectdEnableLibpodstats\"}}, {}]}, {\"if\": [{\"get_param\": \"DeployedCeph\"}, {\"collectd::plugin::ceph::ceph_fsid\": {\"get_param\": \"CephClusterFSID\"}}]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_collectd\": [{\"get_param\": \"CollectdLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"collectd\", \"puppet_tags\": \"collectd_client_config,exec\", \"step_config\": \"include tripleo::profile::base::metrics::collectd\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCollectdConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/collectd.json\": {\"command\": \"/usr/sbin/collectd -f\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/collectd.d\", \"dest\": \"/etc/\", \"merge\": false, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/collectd\", \"owner\": \"collectd:collectd\", \"recurse\": true}, {\"path\": \"/scripts\", \"owner\": \"collectd:collectd\", \"recurse\": true}, {\"path\": \"/config-scripts\", \"owner\": \"collectd:collectd\", \"recurse\": true}]}}, \"container_config_scripts\": {\"map_merge\": [{\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, {\"collectd_check_health.py\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/monitoring/collectd_check_health.py\"}}}]}, \"docker_config\": {\"step_2\": {\"if\": [{\"get_param\": \"CollectdEnableSensubility\"}, {\"collectd_init_perm\": {\"image\": {\"get_param\": \"ContainerCollectdImage\"}, \"net\": \"none\", \"user\": \"root\", \"volumes\": [\"/var/lib/tripleo-podman/collectd:/tmp/run:rw,z\"], \"command\": [\"setfacl\", \"-R\", \"-m\", \"u:collectd:rwx\", \"/tmp/run\"]}}]}, \"step_3\": {\"collectd\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerCollectdImage\"]}, \"net\": \"host\", \"pid\": \"host\", \"user\": \"root\", \"restart\": \"always\", \"memory\": \"512m\", \"device\": {\"if\": [\"ipmi_monitor\", {\"get_param\": [\"RoleParameters\", \"IpmiMonitor\"]}]}, \"cap_add\": {\"list_concat\": [{\"get_param\": \"CollectdContainerAdditionalCapAdd\"}, [\"IPC_LOCK\"]]}, \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/collectd.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/containers/storage/overlay-containers:/var/lib/containers/storage/overlay-containers:ro\", \"/var/lib/config-data/puppet-generated/collectd:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/collectd:/var/log/collectd:rw,z\", \"/var/lib/container-config-scripts:/config-scripts:ro\", \"/var/lib/container-user-scripts:/scripts:z\", \"/run:/run:rw\", \"/sys/fs/cgroup:/sys/fs/cgroup:ro\"], {\"if\": [{\"get_param\": \"CollectdEnableSensubility\"}, [\"/var/lib/tripleo-podman/collectd:/run/podman:z\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/collectd\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/container-user-scripts/\", \"setype\": \"container_file_t\", \"mode\": \"0755\"}]}, {\"name\": \"import provision_mcelog\", \"include_role\": {\"name\": \"tripleo_provision_mcelog\"}, \"when\": {\"get_param\": \"CollectdEnableMcelog\"}}], \"deploy_steps_tasks\": [{\"name\": \"set enable_sensubility fact\", \"set_fact\": {\"enable_sensubility\": {\"get_param\": \"CollectdEnableSensubility\"}}}, {\"name\": \"create podman socket for sensubility purposes\", \"block\": [{\"name\": \"create podman socket and appropriate systemd service\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_service\"}, \"vars\": {\"tripleo_podman_socket_path\": \"/var/lib/tripleo-podman/collectd/podman.sock\"}}, {\"name\": \"create systemd service for ensuring socket file ACL contains collectd\", \"become\": true, \"ansible.builtin.copy\": {\"content\": \"[Unit]\\nDescription=ACL setting for /var/lib/tripleo-podman/collectd/podman.sock\\nRequires=tripleo_collectd.service\\nAfter=tripleo_podman.service\\nAfter=tripleo_collectd.service\\n\\n[Service]\\nType=oneshot\\nExecStart=/usr/bin/podman exec -it collectd setfacl -m m:rwx /run/podman/podman.sock\\nExecStart=/usr/bin/podman exec -it collectd setfacl -R -m u:collectd:rwx /run/podman\\nExecStart=/usr/bin/podman exec -it collectd setfacl -d -m u:collectd:rwx /run/podman\\n\\n[Install]\\nWantedBy=multi-user.target\\n\", \"dest\": \"/etc/systemd/system/tripleo_podman_collectd_acl.service\", \"mode\": 420}}, {\"name\": \"enable podman.sock ACL service\", \"ansible.builtin.service\": {\"name\": \"tripleo_podman_collectd_acl.service\", \"enabled\": true}}, {\"name\": \"create directory for downloads of users\' scripts\", \"file\": {\"path\": \"/var/lib/container-user-scripts\", \"state\": \"directory\", \"setype\": \"container_file_t\", \"mode\": \"0755\"}}, {\"name\": \"download exec scripts\", \"ansible.builtin.get_url\": {\"url\": \"{{ item.source }}\", \"checksum\": \"{{ item.checksum }}\", \"dest\": \"/var/lib/container-user-scripts/{{ item.name }}\", \"mode\": \"0755\"}, \"with_items\": {\"get_param\": \"CollectdSensubilityScripts\"}}], \"when\": [\"enable_sensubility|bool\", \"step|int == 1\"]}], \"update_tasks\": [{\"name\": \"remove rsyslog configuration for podman healthcheck log\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_rsyslog_cleanup\"}}], \"upgrade_tasks\": [{\"name\": \"remove rsyslog configuration for podman healthcheck log\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_rsyslog_cleanup\"}}, {\"name\": \"Force pull image collectd\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\"], \"when\": [\"step|int == 3\"], \"containers.podman.podman_image\": {\"name\": {\"get_param\": \"ContainerCollectdImage\"}, \"force\": true}}, {\"name\": \"UBI8 to UBI9 switch of collectd\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\"], \"when\": [\"step|int == 5\"], \"block\": [{\"name\": \"Update collectd to UBI9\", \"tripleo_container_manage\": {\"config_dir\": \"/var/lib/tripleo-config/container-startup-config/step_3\", \"config_patterns\": \"collectd.json\", \"config_id\": [\"tripleo_step3\"], \"log_base_path\": \"{{ container_log_stdout_path }}\", \"debug\": \"{{ enable_debug | bool }}\", \"config_overrides\": {\"collectd\": {\"image\": {\"get_param\": \"ContainerCollectdImage\"}}}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(166,'2026-06-09 08:02:17',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Configure tuned\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"TunedCustomProfile\": {\"default\": \"\", \"description\": \"The definition of a new tuned profile in INI format which will be named after the TunedProfileName and applied to the host. E.g. if TunedProfileName is \'my_profile\', it creates the file \'/etc/tuned/my_profile/tuned.conf\' on host whose content is the value of TunedCustomProfile, e.g. \\\"[main]\\\\n include=throughput-performance\\\\n[sysctl]\\\\nvm.dirty_ratio=10\\\"\", \"type\": \"string\", \"tags\": [\"role_specific\"]}, \"TunedProfileName\": {\"default\": \"throughput-performance\", \"description\": \"Tuned Profile to apply to the host\", \"type\": \"string\", \"tags\": [\"role_specific\"]}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"tuned_profile\": \"TunedProfileName\", \"tuned_custom_profile\": \"TunedCustomProfile\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"TunedProfileName\": {\"get_param\": \"TunedProfileName\"}, \"TunedCustomProfile\": {\"get_param\": \"TunedCustomProfile\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for tuned\", \"value\": {\"service_name\": \"tuned\", \"host_prep_tasks\": [{\"include_role\": {\"name\": \"tuned\"}}], \"ansible_group_vars\": {\"tuned_profile\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"tuned_profile\"]}, \"tuned_custom_profile\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"tuned_custom_profile\"]}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(167,'2026-06-09 08:02:17',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Apache service configured with Puppet. Note this is typically included automatically via other services which run via Apache.\\n\", \"parameters\": {\"ApacheMaxRequestWorkers\": {\"default\": 100, \"description\": \"Maximum number of simultaneously processed requests.\", \"type\": \"number\"}, \"ApacheServerLimit\": {\"default\": 100, \"description\": \"Maximum number of Apache processes.\", \"type\": \"number\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"ApacheCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"ApacheTimeout\": {\"type\": \"number\", \"default\": 90, \"description\": \"The timeout in seconds for Apache, which defines duration Apache waits for I/O operations\"}}, \"conditions\": {\"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"ApacheCertificateKeySize\"}, \"\"]}}}, \"resources\": {\"ApacheNetworks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"Controller\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"CellController\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"CellControllerCompute\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"Compute\": [\"ctlplane\", \"storage\", \"internal_api\"], \"BlockStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"ObjectStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"CephStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\"], \"Networker\": [\"ctlplane\", \"internal_api\"]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Apache role.\", \"value\": {\"service_name\": \"apache\", \"config_settings\": {\"map_merge\": [{\"apache::ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}}}}, \"apache::default_vhost\": false, \"apache::trace_enable\": \"Off\", \"apache::server_signature\": \"Off\", \"apache::server_tokens\": \"Prod\", \"apache::timeout\": {\"get_param\": \"ApacheTimeout\"}, \"apache::default_mods\": false, \"apache::mod::prefork::maxrequestworkers\": {\"get_param\": \"ApacheMaxRequestWorkers\"}, \"apache::mod::prefork::serverlimit\": {\"get_param\": \"ApacheServerLimit\"}, \"apache::mod::remoteip::proxy_ips\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}]}, \"apache::mod::alias::icons_options\": \"None\"}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"apache::mod::ssl::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}, \"apache::mod::ssl::ssl_protocol\": [\"all\", \"-SSLv2\", \"-SSLv3\", \"-TLSv1\"], \"apache_certificates_specs\": {\"map_merge\": {\"repeat\": {\"template\": {\"httpd-NETWORK\": {\"service_certificate\": \"/etc/pki/tls/certs/httpd/httpd-NETWORK.crt\", \"service_key\": \"/etc/pki/tls/private/httpd/httpd-NETWORK.key\"}}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}, \"metadata_settings\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"repeat\": {\"template\": [{\"service\": \"HTTP\", \"network\": \"$NETWORK\", \"type\": \"node\"}], \"for_each\": {\"$NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}]}, \"upgrade_tasks\": [], \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [\"/etc/pki/tls/certs/httpd\", \"/etc/pki/tls/private/httpd\"]}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": {\"repeat\": {\"template\": {\"name\": \"httpd-NETWORK\", \"dns\": \"{{ fqdn_NETWORK }}\", \"principal\": \"HTTP/{{ fqdn_NETWORK }}@{{ idm_realm }}\", \"run_after\": \"cp /etc/pki/tls/certs/httpd-NETWORK.crt /etc/pki/tls/certs/httpd/httpd-NETWORK.crt\\ncp /etc/pki/tls/private/httpd-NETWORK.key /etc/pki/tls/private/httpd/httpd-NETWORK.key\\npkill -USR1 httpd\\n\", \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"ApacheCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"EnableInternalTLS\": true}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(168,'2026-06-09 08:02:18',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Glance internal service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"GlanceApiInternalLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.glance.api\", \"file\": \"/var/log/containers/glance/api_internal.log\"}}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"GlanceNetappNfsEnabled\": {\"default\": false, \"description\": \"When using GlanceBackend \'file\', Netapp mount NFS share for image storage.\\n\", \"type\": \"boolean\"}, \"ContainerGlanceApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\"}, \"ContainerGlanceApiInternalConfigImage\": {\"description\": \"The container image to use for the glance_api_internal config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\"}}, \"resources\": {\"GlanceApi\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"EnableInternalTLS\": {\"get_param\": \"EnableInternalTLS\"}}}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"GlanceLogging\": {\"type\": \"OS::TripleO::Services::Logging::GlanceApi\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerGlanceApiImage\": \"ContainerGlanceApiImage\", \"ContainerGlanceApiInternalConfigImage\": \"ContainerGlanceApiInternalConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerGlanceApiImage\": {\"get_param\": \"ContainerGlanceApiImage\"}, \"ContainerGlanceApiInternalConfigImage\": {\"get_param\": \"ContainerGlanceApiInternalConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the internal Glance API.\", \"value\": {\"map_merge\": [{\"get_attr\": [\"GlanceApi\", \"role_data\"]}, {\"service_name\": \"glance_api_internal\", \"firewall_rules\": {\"112 glance_api_internal\": {\"dport\": [{\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}]}}, \"firewall_frontend_rules\": {\"100 glance_api_internal_haproxy_frontend\": {\"dport\": [{\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}]}}, \"keystone_resources\": {}, \"config_settings\": {\"get_attr\": [\"GlanceApi\", \"role_data\", \"config_settings\"]}, \"service_config_settings\": {\"map_merge\": [{\"get_attr\": [\"GlanceApi\", \"role_data\", \"service_config_settings\"]}, {\"rsyslog\": {\"tripleo_logging_sources_glance_api_internal\": [{\"get_param\": \"GlanceApiInternalLoggingSource\"}]}}]}, \"puppet_config\": {\"config_volume\": \"glance_api_internal\", \"puppet_tags\": \"glance_api_config,glance_api_paste_ini,glance_swift_config,glance_cache_config,glance_image_import_config\", \"step_config\": {\"list_join\": [\"\\n\", [{\"str_replace\": {\"template\": \"class { \'tripleo::profile::base::glance::api\':\\n  bind_port => PORT,\\n  tls_proxy_port => PORT,\\n  log_file => \'/var/log/glance/api_internal.log\',\\n  show_image_direct_url => true,\\n  show_multiple_locations => true,\\n}\\n\", \"params\": {\"PORT\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}}}}, {\"if\": [{\"get_param\": \"GlanceNetappNfsEnabled\"}, \"include tripleo::profile::base::glance::netapp\"]}, {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiInternalConfigImage\"]}}, \"docker_config\": {\"step_2\": {\"get_attr\": [\"GlanceLogging\", \"docker_config\", \"step_2\"]}, \"step_4\": {\"glance_api_internal\": {\"map_merge\": [{\"get_attr\": [\"GlanceApi\", \"role_data\", \"docker_config\", \"step_4\", \"glance_api\"]}, {\"volumes\": {\"yaql\": {\"expression\": \"$.data.vols.select($.replace(\'puppet-generated/glance_api\', \'puppet-generated/glance_api_internal\'))\", \"data\": {\"vols\": {\"get_attr\": [\"GlanceApi\", \"role_data\", \"docker_config\", \"step_4\", \"glance_api\", \"volumes\"]}}}}}]}, \"glance_api_internal_tls_proxy\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"map_merge\": [{\"get_attr\": [\"GlanceApi\", \"role_data\", \"docker_config\", \"step_4\", \"glance_api_tls_proxy\"]}, {\"volumes\": {\"yaql\": {\"expression\": \"$.data.vols.select($.replace(\'puppet-generated/glance_api\', \'puppet-generated/glance_api_internal\'))\", \"data\": {\"vols\": {\"get_attr\": [\"GlanceApi\", \"role_data\", \"docker_config\", \"step_4\", \"glance_api_tls_proxy\", \"volumes\"]}}}}}]}]}}}, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop glance api internal container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"glance_api_internal\"], \"tripleo_delegate_to\": \"{{ groups[\'glance_api_internal\'] | default([]) }}\"}}]}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(169,'2026-06-09 08:02:18',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Configures podman on the host\\n\", \"parameters\": {\"DockerInsecureRegistryAddress\": {\"description\": \"Optional. The IP Address and Port of an insecure docker namespace that will be configured in /etc/sysconfig/docker. The value can be multiple addresses separated by commas.\", \"type\": \"comma_delimited_list\", \"default\": []}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerImageRegistryLogin\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Flag to enable container registry login actions during the deployment. Setting this to true will cause login calls to be performed during the deployment.\"}, \"ContainerImageRegistryCredentials\": {\"type\": \"json\", \"hidden\": true, \"default\": {}, \"description\": \"Mapping of image registry hosts to login credentials. Must be in the following example format\\n\\n  docker.io:\\n    username: pa55word\\n  \'192.0.2.1:8787\':\\n    registry_username: password\\n\"}, \"ContainerDefaultPidsLimit\": {\"type\": \"number\", \"default\": 4096, \"description\": \"Setting to configure the default pids_limit in /etc/container/container.conf. This is supported starting with podman 2.0.x\"}, \"ContainerDefaultEventsLogger\": {\"type\": \"string\", \"default\": \"journald\", \"description\": \"Setting to configure where podman logs its events. Uses journald by default as that will rotate data stored in tmpfs.\", \"constraints\": [{\"allowed_values\": [\"journald\", \"file\", \"none\"]}]}, \"SystemdDropInDependencies\": {\"default\": true, \"description\": \"tell the tripleo_container_manage to inject additional ordering dependencies for the systemd scopes associated to podman containers.\", \"type\": \"boolean\"}, \"deployment_source_hosts\": {\"default\": \"Undercloud\", \"type\": \"string\", \"description\": \"Host or hostgroup that runs the deployment\"}}, \"conditions\": {\"insecure_registry_is_empty\": {\"equals\": [{\"get_param\": \"DockerInsecureRegistryAddress\"}, []]}, \"systemd_drop_in_dependencies_enabled\": {\"get_param\": \"SystemdDropInDependencies\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the podman service\", \"value\": {\"service_name\": \"podman\", \"config_settings\": {}, \"step_config\": \"\", \"host_prep_tasks\": [{\"name\": \"Install and configure Podman\", \"block\": [{\"name\": \"Set login facts\", \"no_log\": true, \"set_fact\": {\"container_registry_insecure_registries\": {\"if\": [\"insecure_registry_is_empty\", [], {\"get_param\": \"DockerInsecureRegistryAddress\"}]}, \"container_registry_login\": {\"get_param\": \"ContainerImageRegistryLogin\"}, \"container_registry_logins\": {}, \"container_registry_logins_json\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"container_default_pids_limit\": {\"get_param\": \"ContainerDefaultPidsLimit\"}, \"container_events_logger_mechanism\": {\"get_param\": \"ContainerDefaultEventsLogger\"}}}, {\"name\": \"Convert logins json to dict\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json | from_json }}\"}, \"when\": [\"container_registry_logins_json is string\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Set registry logins\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json }}\"}, \"when\": [\"container_registry_logins_json is mapping\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Run podman install\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_install.yml\"}, \"vars\": {\"tripleo_container_registry_insecure_registries\": \"{{ container_registry_insecure_registries }}\", \"tripleo_container_default_pids_limit\": \"{{ container_default_pids_limit }}\", \"tripleo_container_events_logger_mechanism\": \"{{ container_events_logger_mechanism }}\"}}, {\"name\": \"Run podman login\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_login.yml\"}, \"vars\": {\"tripleo_container_registry_logins\": \"{{ container_registry_logins }}\", \"tripleo_container_registry_login\": \"{{ container_registry_login | bool }}\"}}]}, {\"if\": [\"systemd_drop_in_dependencies_enabled\", [{\"name\": \"Configure tripleo_container_manage to generate systemd drop-in dependencies\", \"copy\": {\"dest\": \"/etc/sysconfig/podman_drop_in\", \"content\": \"This file makes tripleo_container_manage generate additional systemd\\ndependencies for containers that have special\\nstart/stop ordering constraints. It ensures that\\nthose constraints are enforced on reboot/shutdown.\\n\"}}], [{\"name\": \"Configure tripleo_container_manage to not generate drop-in dependencies\", \"file\": {\"path\": \"/etc/sysconfig/podman_drop_in\", \"state\": \"absent\"}}]]}], \"deploy_steps_tasks\": [{\"when\": [\"(step|int) == 1\"], \"block\": [{\"name\": \"Pre-fetch all the containers\", \"become\": true, \"containers.podman.podman_image\": {\"name\": \"{{ prefetch_image }}\", \"validate_certs\": false, \"force\": true}, \"register\": \"result\", \"until\": \"result is succeeded\", \"retries\": 5, \"delay\": 5, \"loop_control\": {\"loop_var\": \"prefetch_image\"}, \"loop\": \"{{ lookup(\'template\', tripleo_role_name + \'/docker_config.yaml\', errors=\'ignore\') | default(\'{}\', True) | from_yaml | recursive_get_key_from_dict(key=\'image\') | unique }}\"}]}], \"service_config_settings\": {}, \"workaround_upgrade_tasks\": [{\"name\": \"Configure Podman registry\", \"when\": [\"step|int == 0\"], \"tags\": [\"setup_packages\"], \"block\": [{\"name\": \"Make sure the Undercloud hostname is included in /etc/hosts\", \"when\": [\"undercloud_hosts_entries is defined\"], \"lineinfile\": {\"dest\": \"/etc/hosts\", \"line\": \"{{ undercloud_hosts_entries | join(\'\') }}\", \"state\": \"present\"}}]}, {\"name\": \"Run podman install\", \"tags\": [\"system_upgrade\", \"system_upgrade_run\", \"setup_packages\"], \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Set login facts\", \"no_log\": true, \"set_fact\": {\"container_registry_insecure_registries\": {\"if\": [\"insecure_registry_is_empty\", [], {\"get_param\": \"DockerInsecureRegistryAddress\"}]}, \"container_registry_login\": {\"get_param\": \"ContainerImageRegistryLogin\"}, \"container_registry_logins\": {}, \"container_registry_logins_json\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"container_default_pids_limit\": {\"get_param\": \"ContainerDefaultPidsLimit\"}, \"container_events_logger_mechanism\": {\"get_param\": \"ContainerDefaultEventsLogger\"}}}, {\"name\": \"Convert logins json to dict\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json | from_json }}\"}, \"when\": [\"container_registry_logins_json is string\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Set registry logins\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json }}\"}, \"when\": [\"container_registry_logins_json is mapping\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Run podman install\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_install.yml\"}, \"vars\": {\"tripleo_container_registry_insecure_registries\": \"{{ container_registry_insecure_registries }}\", \"tripleo_container_default_pids_limit\": \"{{ container_default_pids_limit }}\", \"tripleo_container_events_logger_mechanism\": \"{{ container_events_logger_mechanism }}\"}}, {\"name\": \"Run podman login\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_login.yml\"}, \"vars\": {\"tripleo_container_registry_logins\": \"{{ container_registry_logins }}\", \"tripleo_container_registry_login\": \"{{ container_registry_login | bool }}\"}}]}, {\"name\": \"Comment infra_image in container.conf\", \"lineinfile\": {\"dest\": \"/usr/share/containers/containers.conf\", \"regexp\": \"(?i)^(infra_image.*)\", \"line\": \"#\\\\1\", \"backrefs\": true, \"state\": \"present\"}, \"tags\": [\"setup_packages\"], \"when\": [\"step|int == 0\"]}], \"upgrade_tasks\": [{\"name\": \"Configure Podman registry\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Make sure the Undercloud hostname is included in /etc/hosts\", \"when\": [\"undercloud_hosts_entries is defined\"], \"lineinfile\": {\"dest\": \"/etc/hosts\", \"line\": \"{{ undercloud_hosts_entries | join(\'\') }}\", \"state\": \"present\"}}]}, {\"name\": \"Run podman install\", \"tags\": [\"system_upgrade\", \"system_upgrade_run\"], \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Set login facts\", \"no_log\": true, \"set_fact\": {\"container_registry_insecure_registries\": {\"if\": [\"insecure_registry_is_empty\", [], {\"get_param\": \"DockerInsecureRegistryAddress\"}]}, \"container_registry_login\": {\"get_param\": \"ContainerImageRegistryLogin\"}, \"container_registry_logins\": {}, \"container_registry_logins_json\": {\"get_param\": \"ContainerImageRegistryCredentials\"}, \"container_default_pids_limit\": {\"get_param\": \"ContainerDefaultPidsLimit\"}, \"container_events_logger_mechanism\": {\"get_param\": \"ContainerDefaultEventsLogger\"}}}, {\"name\": \"Convert logins json to dict\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json | from_json }}\"}, \"when\": [\"container_registry_logins_json is string\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Set registry logins\", \"no_log\": true, \"set_fact\": {\"container_registry_logins\": \"{{ container_registry_logins_json }}\"}, \"when\": [\"container_registry_logins_json is mapping\", \"container_registry_login | bool\", \"(container_registry_logins_json | length) > 0\"]}, {\"name\": \"Run podman install\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_install.yml\"}, \"vars\": {\"tripleo_container_registry_insecure_registries\": \"{{ container_registry_insecure_registries }}\", \"tripleo_container_default_pids_limit\": \"{{ container_default_pids_limit }}\", \"tripleo_container_events_logger_mechanism\": \"{{ container_events_logger_mechanism }}\"}}, {\"name\": \"Run podman login\", \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_login.yml\"}, \"vars\": {\"tripleo_container_registry_logins\": \"{{ container_registry_logins }}\", \"tripleo_container_registry_login\": \"{{ container_registry_login | bool }}\"}}]}], \"update_tasks\": [{\"name\": \"Force pre-fetch of container images\", \"when\": [\"(step|int) == 5\"], \"block\": [{\"name\": \"Pre-fetch all the containers\", \"become\": true, \"containers.podman.podman_image\": {\"name\": \"{{ prefetch_image }}\", \"validate_certs\": false, \"force\": true}, \"register\": \"result\", \"until\": \"result is succeeded\", \"retries\": 5, \"delay\": 5, \"loop_control\": {\"loop_var\": \"prefetch_image\"}, \"loop\": \"{{ lookup(\'template\', tripleo_role_name + \'/docker_config.yaml\', errors=\'ignore\') | default(\'{}\', True) | from_yaml | recursive_get_key_from_dict(key=\'image\') | unique }}\"}]}], \"post_upgrade_tasks\": [{\"name\": \"Purge Podman\", \"when\": [\"(step | int) == 3\", \"container_cli == \'podman\'\", \"deployment_source_hosts not in group_names\"], \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_purge.yml\"}, \"vars\": {\"deployment_source_hosts\": {\"get_param\": \"deployment_source_hosts\"}}}], \"post_update_tasks\": [{\"name\": \"Purge Podman\", \"when\": [\"(step | int) == 3\", \"container_cli == \'podman\'\", \"deployment_source_hosts not in group_names\"], \"include_role\": {\"name\": \"tripleo_podman\", \"tasks_from\": \"tripleo_podman_purge.yml\"}, \"vars\": {\"deployment_source_hosts\": {\"get_param\": \"deployment_source_hosts\"}}}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (170,'2026-06-09 08:02:18',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Ovn Controller agent.\\n\", \"parameters\": {\"RootStackName\": {\"description\": \"The name of the stack/plan.\", \"type\": \"string\", \"default\": \"overcloud\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ContainerOvnControllerImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\"}, \"ContainerOvnControllerConfigImage\": {\"description\": \"The container image to use for the ovn_controller config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"DeployIdentifier\": {\"default\": 1780992067, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"OVNSouthboundServerPort\": {\"description\": \"Port of the Southbound DB Server\", \"type\": \"number\", \"default\": 6642}, \"NeutronBridgeMappings\": {\"description\": \"The OVS logical->physical bridge mappings to use. See the Neutron documentation for details. Defaults to mapping br-ex - the external bridge on hosts - to a physical name \'datacentre\' which can be used to create provider networks (and we use this for the default floating network) - if changing this either use different post-install network scripts or be sure to keep \'datacentre\' as a mapping network name.\\n\", \"type\": \"comma_delimited_list\", \"default\": \"datacentre:br-ex\", \"tags\": [\"role_specific\"]}, \"EnableVLANTransparency\": {\"default\": false, \"description\": \"If True, then allow plugins that support it to create VLAN transparent networks.\\n\", \"type\": \"boolean\"}, \"OVNEncapType\": {\"description\": \"Type of encapsulation used in OVN. It can be \\\"geneve\\\" or \\\"vxlan\\\".\\n\", \"type\": \"string\", \"default\": \"geneve\", \"constraints\": [{\"allowed_values\": [\"geneve\", \"vxlan\"]}]}, \"OVNIntegrationBridge\": {\"description\": \"Name of the OVS bridge to use as integration bridge by OVN Controller.\\n\", \"type\": \"string\", \"default\": \"br-int\"}, \"OVNMetadataEnabled\": {\"description\": \"Whether Metadata Service has to be enabled\", \"type\": \"boolean\", \"default\": true}, \"OVNAvailabilityZone\": {\"description\": \"The az options to configure in ovs db. eg. [\'az-0\', \'az-1\', \'az-2\']\", \"type\": \"comma_delimited_list\", \"default\": [], \"tags\": [\"role_specific\"]}, \"OVNCMSOptions\": {\"description\": \"The CMS options to configure in ovs db\", \"type\": \"string\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"OVNEncapTos\": {\"description\": \"The value to be applied to OVN tunnel interface\'s option:tos as specified in the Open_vSwitch database Interface table. This feature is supported from OVN v21.12.0.\\n\", \"type\": \"string\", \"default\": \"0\", \"tags\": [\"role_specific\"]}, \"OvsHwOffload\": {\"default\": false, \"description\": \"Enable OVS Hardware Offload. This feature supported from OVS 2.8.0\\n\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"OVNRemoteProbeInterval\": {\"description\": \"Probe interval in ms\", \"type\": \"number\", \"default\": 60000}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"OVNOpenflowProbeInterval\": {\"description\": \"The inactivity probe interval of the OpenFlow connection to the OpenvSwitch integration bridge, in seconds.\\n\", \"type\": \"number\", \"default\": 60}, \"OVNOfctrlWaitBeforeClear\": {\"description\": \"Sets the time ovn-controller will wait on startup before clearing all openflow rules and installing the new ones, in ms.\\n\", \"type\": \"number\", \"default\": 8000}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"ContainerOvnCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"OVNContainerCpusetCpus\": {\"description\": \"Limit the specific CPUs or cores a container can use. It can be specified as a single core (ex. 0), as a comma-separated list (ex. 0,1), as a range (ex. 0-3) or a combination if previous methods (ex 0-3,7,11-15).  The selected cores should be isolated from guests and hypervisor in order to obtain best possible performance.\\n\", \"type\": \"string\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"OVNStaticBridgeMacMappings\": {\"type\": \"json\", \"default\": {}, \"description\": \"Static OVN Bridge MAC address mappings. Unique OVN bridge mac addresses\\nis dynamically allocated by creating neutron ports. When neutron isn\'t\\navailable, for instance in the standalone deployment, use this parameter\\nto provide static OVN bridge mac addresses. For example:\\n   controller-0:\\n     datacenter: 00:00:5E:00:53:00\\n     provider: 00:00:5E:00:53:01\\n   compute-0:\\n     datacenter: 00:00:5E:00:54:00\\n     provider: 00:00:5E:00:54:01\\n\", \"tags\": [\"role_specific\"]}, \"AuthCloudName\": {\"description\": \"Entry in clouds.yaml to use for authentication\", \"type\": \"string\", \"default\": \"\"}, \"OVNControllerImageUpdateTimeout\": {\"description\": \"During update, how long we wait for the container image to be updated, in seconds.\\n\", \"type\": \"number\", \"default\": 600}, \"OVNControllerUpdateTimeout\": {\"description\": \"During update, how long we wait for the container to be updated, in seconds.\\n\", \"type\": \"number\", \"default\": 600}, \"OVNControllerGarpMaxTimeout\": {\"description\": \"When used, this configuration value specifies the maximum timeout (in seconds) between two consecutive GARP packets sent by ovn-controller.\\n\", \"type\": \"number\", \"default\": 0}}, \"conditions\": {\"force_config_drive\": {\"equals\": [{\"get_param\": \"OVNMetadataEnabled\"}, false]}, \"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"key_size_override_unset\": {\"equals\": [{\"get_param\": \"ContainerOvnCertificateKeySize\"}, \"\"]}, \"enable_vlan_transparency\": {\"equals\": [{\"get_param\": \"EnableVLANTransparency\"}, true]}, \"auth_cloud_name_set\": {\"not\": {\"equals\": [{\"get_param\": \"AuthCloudName\"}, \"\"]}}, \"ovn_cpu_set\": {\"or\": [{\"not\": {\"equals\": [{\"get_param\": \"OVNContainerCpusetCpus\"}, \"\"]}}, {\"not\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"OVNContainerCpusetCpus\"]}, \"\"]}}]}, \"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"ContainerOvnCertificateKeySize\"}, \"\"]}}, \"az_ovn_unset\": {\"and\": [{\"equals\": [{\"get_param\": \"OVNAvailabilityZone\"}, []]}, {\"equals\": [{\"get_param\": [\"RoleParameters\", \"OVNAvailabilityZone\"]}, \"\"]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ovn::controller::ovn_bridge_mappings\": \"NeutronBridgeMappings\", \"ovn::controller::ovn_cms_options\": {\"if\": [\"az_ovn_unset\", \"OVNCMSOptions\", \"OVNCMSOptionsMerged\"]}, \"ovn::controller::ovn_encap_tos\": \"OVNEncapTos\", \"vswitch::ovs::enable_hw_offload\": \"OvsHwOffload\", \"container_cpuset_cpus\": \"OVNContainerCpusetCpus\", \"ContainerOvnControllerImage\": \"ContainerOvnControllerImage\", \"ContainerOvnControllerConfigImage\": \"ContainerOvnControllerConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"NeutronBridgeMappings\": {\"get_param\": \"NeutronBridgeMappings\"}, \"OVNCMSOptions\": {\"get_param\": \"OVNCMSOptions\"}, \"OVNCMSOptionsMerged\": {\"list_join\": [\"\", [{\"str_replace\": {\"template\": \"$OVNCMSOptions\", \"params\": {\"if\": [{\"not\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"OVNCMSOptions\"]}, \"\"]}}, {\"$OVNCMSOptions\": {\"get_param\": [\"RoleParameters\", \"OVNCMSOptions\"]}}, {\"$OVNCMSOptions\": {\"get_param\": \"OVNCMSOptions\"}}]}}}, {\"str_replace\": {\"template\": \",availability-zones=$OVNAvailabilityZone\", \"params\": {\"if\": [{\"not\": {\"equals\": [{\"get_param\": [\"RoleParameters\", \"OVNAvailabilityZone\"]}, \"\"]}}, {\"$OVNAvailabilityZone\": {\"get_param\": [\"RoleParameters\", \"OVNAvailabilityZone\"]}}, {\"$OVNAvailabilityZone\": {\"list_join\": [\",\", {\"get_param\": \"OVNAvailabilityZone\"}]}}]}}}]]}, \"OVNEncapTos\": {\"get_param\": \"OVNEncapTos\"}, \"OvsHwOffload\": {\"get_param\": \"OvsHwOffload\"}, \"OVNContainerCpusetCpus\": {\"get_param\": \"OVNContainerCpusetCpus\"}, \"ContainerOvnControllerImage\": {\"get_param\": \"ContainerOvnControllerImage\"}, \"ContainerOvnControllerConfigImage\": {\"get_param\": \"ContainerOvnControllerConfigImage\"}}}]}}}, \"OVNBridgeMappingsValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ovn_bridge_mappings\": \"NeutronBridgeMappings\", \"ovn_static_bridge_mac_mappings\": \"OVNStaticBridgeMacMappings\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"NeutronBridgeMappings\": {\"get_param\": \"NeutronBridgeMappings\"}, \"OVNStaticBridgeMacMappings\": {\"get_param\": \"OVNStaticBridgeMacMappings\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Ovn Controller agent.\", \"value\": {\"service_name\": \"ovn_controller\", \"firewall_rules\": {\"118 neutron vxlan networks\": {\"proto\": \"udp\", \"dport\": 4789, \"state\": []}, \"119 neutron geneve networks\": {\"proto\": \"udp\", \"dport\": 6081, \"state\": []}, \"120 neutron geneve networks no conntrack\": {\"proto\": \"udp\", \"dport\": 6081, \"table\": \"raw\", \"chain\": \"OUTPUT\", \"jump\": \"NOTRACK\", \"action\": \"append\", \"state\": [\"INVALID\"]}, \"121 neutron geneve networks no conntrack\": {\"proto\": \"udp\", \"dport\": 6081, \"table\": \"raw\", \"chain\": \"PREROUTING\", \"jump\": \"NOTRACK\", \"action\": \"append\", \"state\": [\"INVALID\"]}}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"RoleParametersValue\", \"value\"]}, {\"ovn::southbound::port\": {\"get_param\": \"OVNSouthboundServerPort\"}, \"ovn::controller::ovn_encap_ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"NeutronTenantNetwork\"]}}}}, \"ovn::controller::ovn_encap_type\": {\"get_param\": \"OVNEncapType\"}, \"ovn::controller::ovn_bridge\": {\"get_param\": \"OVNIntegrationBridge\"}, \"ovn::controller::hostname\": \"%{hiera(\'fqdn_canonical\')}\", \"ovn::controller::ovn_remote_probe_interval\": {\"get_param\": \"OVNRemoteProbeInterval\"}, \"ovn::controller::ovn_openflow_probe_interval\": {\"get_param\": \"OVNOpenflowProbeInterval\"}, \"ovn::controller::ovn_ofctrl_wait_before_clear\": {\"get_param\": \"OVNOfctrlWaitBeforeClear\"}, \"ovn::controller::garp_max_timeout_sec\": {\"get_param\": \"OVNControllerGarpMaxTimeout\"}, \"ovn::controller::ovn_monitor_all\": true}, {\"if\": [\"force_config_drive\", {\"nova::compute::force_config_drive\": true}, {}]}, {\"if\": [\"internal_tls_enabled\", {\"tripleo::profile::base::neutron::agents::ovn::protocol\": \"ssl\"}, {}]}, {\"if\": [\"enable_vlan_transparency\", {\"vswitch::ovs::vlan_limit\": 0}, {}]}]}, \"service_config_settings\": {}, \"puppet_config\": {\"puppet_tags\": \"vs_config,exec\", \"config_volume\": \"ovn_controller\", \"step_config\": \"include tripleo::profile::base::neutron::agents::ovn\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerOvnControllerConfigImage\"]}, \"volumes\": [\"/lib/modules:/lib/modules:ro\", \"/run/openvswitch:/run/openvswitch:shared,z\", \"/etc/sysconfig/modules:/etc/sysconfig/modules\"]}, \"kolla_config\": {\"/var/lib/kolla/config_files/ovn_controller.json\": {\"command\": {\"list_join\": [\" \", [\"/usr/bin/ovn-controller --pidfile --log-file unix:/run/openvswitch/db.sock\", {\"if\": [\"internal_tls_enabled\", {\"list_join\": [\" \", [\"-p /etc/pki/tls/private/ovn_controller.key -c /etc/pki/tls/certs/ovn_controller.crt -C\", {\"get_param\": \"InternalTLSCAFile\"}]]}, \"\"]}]]}, \"permissions\": [{\"path\": \"/var/log/openvswitch\", \"owner\": \"root:root\", \"recurse\": true}, {\"path\": \"/var/log/ovn\", \"owner\": \"root:root\", \"recurse\": true}]}}, \"metadata_settings\": {\"if\": [\"internal_tls_enabled\", [{\"service\": \"ovn_controller\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"OvnDbsNetwork\"]}, \"type\": \"node\"}], null]}, \"docker_config\": {\"step_4\": {\"configure_cms_options\": {\"start_order\": 0, \"detach\": false, \"net\": \"host\", \"privileged\": true, \"user\": \"root\", \"command\": [\"/bin/bash\", \"-c\", \"CMS_OPTS=$(hiera ovn::controller::ovn_cms_options -c /etc/puppet/hiera.yaml);  if [ X\\\"$CMS_OPTS\\\" !=  X ]; then ovs-vsctl set open . external_ids:ovn-cms-options=$CMS_OPTS;else ovs-vsctl remove open . external_ids ovn-cms-options; fi\"], \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerOvnControllerImage\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/lib/modules:/lib/modules:ro\", \"/run/openvswitch:/run/openvswitch:shared,z\"]]}, \"environment\": {\"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}}, \"ovn_controller\": {\"map_merge\": [{\"start_order\": 1, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerOvnControllerImage\"]}, \"net\": \"host\", \"privileged\": true, \"user\": \"root\", \"restart\": \"always\", \"depends_on\": [\"openvswitch.service\"]}, {\"if\": [\"ovn_cpu_set\", {\"cpuset_cpus\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"container_cpuset_cpus\"]}}]}, {\"healthcheck\": {\"test\": {\"list_join\": [\" \", [\"/openstack/healthcheck\", {\"yaql\": {\"expression\": \"str($.data.port)\", \"data\": {\"port\": {\"get_param\": \"OVNSouthboundServerPort\"}}}}]]}}, \"volumes\": {\"list_concat\": [[\"/var/lib/kolla/config_files/ovn_controller.json:/var/lib/kolla/config_files/config.json:ro\", \"/lib/modules:/lib/modules:ro\", \"/run:/run\", \"/var/lib/openvswitch/ovn:/run/ovn:shared,z\", \"/var/log/containers/openvswitch:/var/log/openvswitch:z\", \"/var/log/containers/openvswitch:/var/log/ovn:z\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}, \"/etc/pki/tls/certs/ovn_controller.crt:/etc/pki/tls/certs/ovn_controller.crt\", \"/etc/pki/tls/private/ovn_controller.key:/etc/pki/tls/private/ovn_controller.key\"], null]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}]}}}, \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"ovn_controller\", \"dns\": {\"str_replace\": {\"template\": \"{{fqdn_$NETWORK}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OvnDbsNetwork\"]}}}}, \"principal\": {\"str_replace\": {\"template\": \"ovn_controller/{{fqdn_$NETWORK}}@{{idm_realm}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"OvnDbsNetwork\"]}}}}, \"run_after\": \"systemctl restart tripleo_ovn_controller\\n\", \"key_size\": {\"if\": [\"key_size_override_unset\", {\"get_param\": \"CertificateKeySize\"}, {\"get_param\": \"ContainerOvnCertificateKeySize\"}]}, \"ca\": \"ipa\"}]}}]}], \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/openvswitch\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/openvswitch/ovn\", \"setype\": \"container_file_t\"}]}, {\"name\": \"enable virt_sandbox_use_netlink for healthcheck\", \"seboolean\": {\"name\": \"virt_sandbox_use_netlink\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}, {\"name\": \"Copy in cleanup script\", \"copy\": {\"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-cleanup\"}, \"dest\": \"/usr/libexec/neutron-cleanup\", \"force\": true, \"mode\": \"0755\"}}, {\"name\": \"Copy in cleanup service\", \"copy\": {\"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-cleanup.service\"}, \"dest\": \"/usr/lib/systemd/system/neutron-cleanup.service\", \"force\": true}}, {\"name\": \"Enabling the cleanup service\", \"service\": {\"name\": \"neutron-cleanup\", \"enabled\": true}, \"when\": \"not (ansible_check_mode|bool)\"}], \"external_deploy_tasks\": [{\"when\": [\"step|int == 0\"], \"name\": \"ovn_controller_external_deploy_init\", \"block\": [{\"name\": {\"str_replace\": {\"template\": \"create ovn mac address for $ROLE_NAME role nodes\", \"params\": {\"$ROLE_NAME\": {\"get_param\": \"RoleName\"}}}}, \"tripleo_ovn_mac_addresses\": {\"playbook_dir\": \"{{ playbook_dir }}\", \"stack_name\": {\"get_param\": \"RootStackName\"}, \"role_name\": {\"get_param\": \"RoleName\"}, \"server_resource_names\": {\"str_replace\": {\"template\": \"{{ groups[\\\"$ROLE_NAME\\\"] }}\", \"params\": {\"$ROLE_NAME\": {\"get_param\": \"RoleName\"}}}}, \"ovn_bridge_mappings\": {\"get_attr\": [\"OVNBridgeMappingsValue\", \"value\", \"ovn_bridge_mappings\"]}, \"ovn_static_bridge_mac_mappings\": {\"get_attr\": [\"OVNBridgeMappingsValue\", \"value\", \"ovn_static_bridge_mac_mappings\"]}}}]}], \"external_update_tasks\": [{\"name\": \"Force pull image in case image name doesn\'t change.\", \"when\": \"step|int == 1\", \"tags\": [\"ovn\", \"ovn_image\"], \"become\": true, \"loop\": \"{{ groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) }}\", \"delegate_to\": \"{{ item }}\", \"async\": {\"get_param\": \"OVNControllerImageUpdateTimeout\"}, \"poll\": 0, \"register\": \"ovn_controller_image_update\", \"containers.podman.podman_image\": {\"name\": {\"get_param\": \"ContainerOvnControllerConfigImage\"}, \"validate_certs\": false, \"force\": true}}, {\"name\": \"Was the ovn_controller image pull successful.\", \"when\": [\"step|int == 1\", \"\'results\' in ovn_controller_image_update\"], \"tags\": [\"ovn\", \"ovn_image\"], \"become\": true, \"delegate_to\": \"{{ async_result_item.item }}\", \"async_status\": {\"jid\": \"{{ async_result_item.ansible_job_id }}\"}, \"loop\": \"{{ovn_controller_image_update.results }}\", \"loop_control\": {\"loop_var\": \"async_result_item\"}, \"register\": \"async_poll_results\", \"until\": \"async_poll_results.finished\", \"retries\": {\"get_param\": \"OVNControllerImageUpdateTimeout\"}, \"delay\": 1}, {\"name\": \"OVN Container image used\", \"debug\": {\"msg\": \"ovn container will be using {{ image }}\"}, \"vars\": {\"image\": {\"get_param\": \"ContainerOvnControllerConfigImage\"}}, \"when\": \"step|int == 1\", \"tags\": \"ovn\"}, {\"name\": \"Update OVN OVS related parameters before update.\", \"when\": [\"step|int == 1\"], \"tags\": [\"ovn\"], \"become\": true, \"vars\": {\"timeout\": {\"get_param\": \"OVNOfctrlWaitBeforeClear\"}}, \"shell\": \"set -e\\novs-vsctl set Open_vSwitch . external_ids:ovn-ofctrl-wait-before-clear={{ timeout }}\\novs-vsctl set Open_vSwitch . external_ids:ovn-monitor-all=true\\novs-vsctl set Open_vSwitch . external_ids:ovn-match-northd-version=false\\n\", \"async\": {\"get_param\": \"OVNControllerUpdateTimeout\"}, \"poll\": 0, \"register\": \"ovs_vsctl\", \"loop\": \"{{ groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) }}\", \"delegate_to\": \"{{ item }}\"}, {\"name\": \"Was the update of OVN OVS related parameter successful.\", \"when\": [\"step|int == 1\", \"\'results\' in ovs_vsctl\"], \"become\": true, \"tags\": [\"ovn\"], \"delegate_to\": \"{{ async_result_item.item }}\", \"async_status\": {\"jid\": \"{{ async_result_item.ansible_job_id }}\"}, \"loop\": \"{{ovs_vsctl.results }}\", \"loop_control\": {\"loop_var\": \"async_result_item\"}, \"register\": \"async_poll_results\", \"until\": \"async_poll_results.finished\", \"retries\": {\"get_param\": \"OVNControllerUpdateTimeout\"}, \"delay\": 1}, {\"set_fact\": {\"any_ovn_host\": \"{{groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) | first }}\"}, \"tags\": \"ovn\", \"when\": \"step|int == 1\"}, {\"name\": \"Find ovn_controller configs in container-startup-configs\", \"find\": {\"paths\": \"/var/lib/tripleo-config/container-startup-config/\", \"patterns\": \"*ovn_controller.json\", \"recurse\": true}, \"register\": \"ovn_cont_17_0\", \"delegate_to\": \"{{ any_ovn_host }}\", \"when\": \"(step|int == 1) and (any_ovn_host is defined) and (any_ovn_host|length > 0)\", \"tags\": [\"ovn\"], \"become\": true}, {\"name\": \"get directory path from the ovn_cont_17_0\", \"set_fact\": {\"ovn_config_path\": \"{{ ovn_cont_17_0.files.0.path | dirname }}\"}, \"when\": \"step|int == 1\", \"tags\": \"ovn\"}, {\"name\": \"Get PIDfile used by systemd on each ovn node\", \"when\": [\"step|int == 1\"], \"tags\": [\"ovn\"], \"become\": true, \"shell\": \"set -e\\ngrep PID /etc/systemd/system/tripleo_ovn_controller.service | cut -d= -f2\\n\", \"register\": \"pidfile\", \"loop\": \"{{ groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) }}\", \"delegate_to\": \"{{ item }}\"}, {\"name\": \"Update ovn_controller.\", \"vars\": {\"config_step\": \"{{ (\'step_4\' in ovn_config_path) | ternary(\'4\', \'3\')}}\", \"query\": \"results[?item == \'{{item}}\'].stdout\"}, \"when\": \"step|int == 1\", \"tags\": \"ovn\", \"become\": true, \"loop\": \"{{ groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) }}\", \"delegate_to\": \"{{ item }}\", \"async\": {\"get_param\": \"OVNControllerUpdateTimeout\"}, \"poll\": 0, \"register\": \"ovn_controller_update\", \"tripleo_container_manage\": {\"config_dir\": \"{{ ovn_config_path }}\", \"config_patterns\": \"*ovn_controller.json\", \"config_id\": [\"tripleo_step{{config_step}}\"], \"log_base_path\": \"{{ container_log_stdout_path }}\", \"debug\": \"{{ enable_debug | bool }}\", \"config_overrides\": {\".*ovn_controller\": {\"image\": {\"get_param\": \"ContainerOvnControllerConfigImage\"}, \"conmon_pidfile\": \"{{ pidfile | json_query(query) | first }}\", \"name\": \"ovn_controller\"}}}}, {\"name\": \"Was the ovn_controller successful.\", \"when\": [\"step|int == 1\", \"\'results\' in ovn_controller_update\"], \"tags\": \"ovn\", \"become\": true, \"delegate_to\": \"{{ async_result_item.item }}\", \"async_status\": {\"jid\": \"{{ async_result_item.ansible_job_id }}\"}, \"loop\": \"{{ovn_controller_update.results }}\", \"loop_control\": {\"loop_var\": \"async_result_item\"}, \"register\": \"async_poll_results\", \"until\": \"async_poll_results.finished\", \"retries\": {\"get_param\": \"OVNControllerUpdateTimeout\"}, \"delay\": 1}, {\"name\": \"Pause for 30s to give ovn_controllers time to reconnect to dbs\", \"when\": [\"step|int == 1\"], \"tags\": \"ovn\", \"wait_for\": {\"timeout\": 30}}], \"upgrade_tasks\": [{\"name\": \"Fetch running ovn_controller image\", \"shell\": \"set -e\\npodman inspect --format \\\"{{\'{{\'}}.ImageName{{\'}}\'}}\\\" ovn_controller\\n\", \"register\": \"running_ovn_image\", \"when\": [\"step|int == 4\"], \"tags\": [\"ovn\", \"ovn_image\"]}, {\"name\": \"Run ovn_controller upgrade\", \"tags\": [\"ovn\", \"ovn_image\"], \"vars\": {\"ovn_controller_image\": {\"get_param\": \"ContainerOvnControllerConfigImage\"}}, \"when\": [\"step|int == 4\", \"running_ovn_image.stdout != ovn_controller_image\"], \"block\": [{\"name\": \"Force pull image in case image name doesn\'t change.\", \"when\": \"step|int == 4\", \"tags\": [\"ovn\", \"ovn_image\"], \"containers.podman.podman_image\": {\"name\": {\"get_param\": \"ContainerOvnControllerConfigImage\"}, \"validate_certs\": false, \"force\": true}}, {\"name\": \"Update OVN OVS related parameters before update.\", \"when\": [\"step|int == 4\"], \"tags\": [\"ovn\"], \"vars\": {\"timeout\": {\"get_param\": \"OVNOfctrlWaitBeforeClear\"}}, \"shell\": \"set -e\\novs-vsctl set Open_vSwitch . external_ids:ovn-ofctrl-wait-before-clear={{ timeout }}\\novs-vsctl set Open_vSwitch . external_ids:ovn-monitor-all=true\\novs-vsctl set Open_vSwitch . external_ids:ovn-match-northd-version=false\\n\"}, {\"name\": \"Find ovn_controller configs in container-startup-configs\", \"find\": {\"paths\": \"/var/lib/tripleo-config/container-startup-config/\", \"patterns\": \"*ovn_controller.json\", \"recurse\": true}, \"register\": \"ovn_cont_17_0\", \"when\": [\"step|int == 4\"], \"tags\": [\"ovn\"]}, {\"name\": \"get directory path from the ovn_cont_17_0\", \"set_fact\": {\"ovn_config_path\": \"{{ ovn_cont_17_0.files.0.path | dirname }}\"}, \"when\": \"step|int == 4\", \"tags\": \"ovn\"}, {\"name\": \"Get PIDfile used by systemd on each ovn node\", \"when\": [\"step|int == 4\"], \"tags\": [\"ovn\"], \"shell\": \"set -e\\ngrep PID /etc/systemd/system/tripleo_ovn_controller.service | cut -d= -f2\\n\", \"register\": \"pidfile\"}, {\"name\": \"Update ovn_controller.\", \"vars\": {\"config_step\": \"{{ (\'step_4\' in ovn_config_path) | ternary(\'4\', \'3\')}}\"}, \"when\": \"step|int == 4\", \"tags\": \"ovn\", \"tripleo_container_manage\": {\"config_dir\": \"{{ ovn_config_path }}\", \"config_patterns\": \"*ovn_controller.json\", \"config_id\": [\"tripleo_step{{config_step}}\"], \"log_base_path\": \"{{ container_log_stdout_path }}\", \"debug\": \"{{ enable_debug | bool }}\", \"config_overrides\": {\".*ovn_controller\": {\"image\": {\"get_param\": \"ContainerOvnControllerConfigImage\"}, \"conmon_pidfile\": \"{{ pidfile.stdout }}\", \"name\": \"ovn_controller\"}}}}, {\"name\": \"Pause for 30s to give ovn_controllers time to reconnect to dbs\", \"when\": [\"step|int == 4\"], \"tags\": \"ovn\", \"wait_for\": {\"timeout\": 30}}]}], \"scale_tasks\": [{\"when\": [\"step|int == 1\", \"container_cli == \'podman\'\"], \"tags\": \"down\", \"become\": true, \"environment\": {\"OS_CLOUD\": {\"if\": [\"auth_cloud_name_set\", {\"get_param\": \"AuthCloudName\"}, {\"get_param\": \"RootStackName\"}]}}, \"block\": [{\"name\": \"Get neutron agents ID\", \"command\": \"openstack network agent list --column ID --column Host --column Binary --format yaml\", \"register\": \"neutron_agents_result\", \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"check_mode\": false, \"changed_when\": false}, {\"name\": \"Filter only current host\", \"set_fact\": {\"neutron_agents\": \"{{ neutron_agents_result.stdout | from_yaml | selectattr(\'Host\', \'match\', ansible_facts[\'fqdn\'] ~ \'.*\') | list }}\"}, \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"check_mode\": false}, {\"name\": \"Deleting OVN agents\", \"block\": [{\"name\": \"Stop OVN containers\", \"loop\": [\"tripleo_ovn_controller\", \"tripleo_ovn_metadata_agent\"], \"service\": {\"name\": \"{{ item }}\", \"state\": \"stopped\", \"enabled\": false}, \"become\": true, \"register\": \"stop_containers\", \"failed_when\": \"(\'msg\' in stop_containers and \'Could not find the requested service\' not in stop_containers.msg) or (\'rc\' in stop_containers and stop_containers.rc != 0)\"}, {\"name\": \"Delete neutron agents\", \"loop\": \"{{ neutron_agents }}\", \"loop_control\": {\"loop_var\": \"agent\", \"label\": \"{{ agent.Host }}/{{ agent.Binary }}\"}, \"command\": \"openstack network agent delete {{ agent.ID }}\", \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"check_mode\": false}]}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"RoleName\": \"Compute\", \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(171,'2026-06-09 08:02:18',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(172,'2026-06-09 08:02:18',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(173,'2026-06-09 08:02:19',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Heat base service. Shared for all Heat services.\\n\", \"parameters\": {\"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"HeatDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Heat services.\", \"type\": \"boolean\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"HeatPassword\": {\"description\": \"The password for the Heat service and db account, used by the Heat services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"IWxKbYHIBwLTomkhalUwDCUxO\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"HeatCronPurgeDeletedEnsure\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Ensure\\n\", \"default\": \"present\"}, \"HeatCronPurgeDeletedMinute\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Minute\\n\", \"default\": \"1\"}, \"HeatCronPurgeDeletedHour\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Hour\\n\", \"default\": \"0\"}, \"HeatCronPurgeDeletedMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month Day\\n\", \"default\": \"*\"}, \"HeatCronPurgeDeletedMonth\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month\\n\", \"default\": \"*\"}, \"HeatCronPurgeDeletedWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Week Day\\n\", \"default\": \"*\"}, \"HeatCronPurgeDeletedMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Delay\\n\", \"default\": \"3600\"}, \"HeatCronPurgeDeletedUser\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - User\\n\", \"default\": \"heat\"}, \"HeatCronPurgeDeletedAge\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age\\n\", \"default\": \"30\"}, \"HeatCronPurgeDeletedAgeType\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age type\\n\", \"default\": \"days\"}, \"HeatCronPurgeDeletedDestination\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Log destination\\n\", \"default\": \"/dev/null\"}, \"HeatYaqlLimitIterators\": {\"type\": \"number\", \"description\": \"The maximum number of elements in collection yaql expressions can take for its evaluation.\\n\", \"default\": 1000}, \"HeatYaqlMemoryQuota\": {\"type\": \"number\", \"description\": \"The maximum size of memory in bytes that yaql exrpessions can take for its evaluation.\\n\", \"default\": 100000}, \"HeatMaxJsonBodySize\": {\"default\": 4194304, \"description\": \"Maximum raw byte size of the Heat API JSON request body.\", \"type\": \"number\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"HeatCorsAllowedOrigin\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Indicate whether this resource may be shared with the domain received in the request \\\"origin\\\" header.\"}, \"MemcachedTLS\": {\"default\": true, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}, \"MemcacheUseAdvancedPool\": {\"type\": \"boolean\", \"description\": \"Use the advanced (eventlet safe) memcached client pool.\\n\", \"default\": true}, \"HeatApiPolicies\": {\"description\": \"A hash of policies to configure for Heat API.\\ne.g. { heat-context_is_admin: { key: context_is_admin, value: \'role:admin\' } }\\n\", \"default\": {}, \"type\": \"json\"}, \"EnforceSecureRbac\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Setting this option to True will configure each OpenStack service to enforce Secure RBAC by setting `[oslo_policy] enforce_new_defaults` and `[oslo_policy] enforce_scope` to True. This introduces a consistent set of RBAC personas across OpenStack services that include support for system and project scope, as well as keystone\'s default roles, admin, member, and reader. Do not enable this functionality until all services in your deployment actually support secure RBAC.\"}}, \"conditions\": {\"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}, \"cors_allowed_origin_set\": {\"not\": {\"equals\": [{\"get_param\": \"HeatCorsAllowedOrigin\"}, \"\"]}}}, \"outputs\": {\"role_data\": {\"description\": \"Shared role data for the Heat services.\", \"value\": {\"service_name\": \"heat_base\", \"config_settings\": {\"map_merge\": [{\"if\": [{\"get_param\": \"EnforceSecureRbac\"}, {\"heat::policy::enforce_scope\": true, \"heat::policy::enforce_new_defaults\": true}]}, {\"if\": [\"cors_allowed_origin_set\", {\"heat::cors::allowed_origin\": {\"get_param\": \"HeatCorsAllowedOrigin\"}}]}, {\"heat::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"heat::logging::debug\": {\"if\": [{\"get_param\": \"HeatDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"heat::policy::policies\": {\"get_param\": \"HeatApiPolicies\"}, \"heat::enable_proxy_headers_parsing\": true, \"heat::rpc_response_timeout\": 600, \"heat::rabbit_heartbeat_timeout_threshold\": 60, \"heat::rabbit_heartbeat_in_pthread\": false, \"heat::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"heat::keystone::authtoken::project_name\": \"service\", \"heat::keystone::authtoken::user_domain_name\": \"Default\", \"heat::keystone::authtoken::project_domain_name\": \"Default\", \"heat::keystone::authtoken::www_authenticate_uri\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"heat::keystone::authtoken::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"heat::keystone::authtoken::password\": {\"get_param\": \"HeatPassword\"}, \"heat::keystone::authtoken::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"heat::keystone::authtoken::interface\": \"internal\", \"heat::keystone::authtoken::memcache_use_advanced_pool\": {\"get_param\": \"MemcacheUseAdvancedPool\"}, \"heat::keystone::domain::domain_name\": \"heat_stack\", \"heat::keystone::domain::domain_admin\": \"heat_stack_domain_admin\", \"heat::keystone::domain::domain_admin_email\": \"heat_stack_domain_admin@localhost\", \"heat::db::database_db_max_retries\": -1, \"heat::db::database_max_retries\": -1, \"heat::yaql_memory_quota\": {\"get_param\": \"HeatYaqlMemoryQuota\"}, \"heat::yaql_limit_iterators\": {\"get_param\": \"HeatYaqlLimitIterators\"}, \"heat::cors::max_age\": 3600, \"heat::cors::allow_headers\": \"Content-Type,Cache-Control,Content-Language,Expires,Last-Modified,Pragma,X-Auth-Token\", \"heat::cors::expose_headers\": \"Content-Type,Cache-Control,Content-Language,Expires,Last-Modified,Pragma\", \"heat::cron::purge_deleted::ensure\": {\"get_param\": \"HeatCronPurgeDeletedEnsure\"}, \"heat::cron::purge_deleted::minute\": {\"get_param\": \"HeatCronPurgeDeletedMinute\"}, \"heat::cron::purge_deleted::hour\": {\"get_param\": \"HeatCronPurgeDeletedHour\"}, \"heat::cron::purge_deleted::monthday\": {\"get_param\": \"HeatCronPurgeDeletedMonthday\"}, \"heat::cron::purge_deleted::month\": {\"get_param\": \"HeatCronPurgeDeletedMonth\"}, \"heat::cron::purge_deleted::weekday\": {\"get_param\": \"HeatCronPurgeDeletedWeekday\"}, \"heat::cron::purge_deleted::maxdelay\": {\"get_param\": \"HeatCronPurgeDeletedMaxDelay\"}, \"heat::cron::purge_deleted::user\": {\"get_param\": \"HeatCronPurgeDeletedUser\"}, \"heat::cron::purge_deleted::age\": {\"get_param\": \"HeatCronPurgeDeletedAge\"}, \"heat::cron::purge_deleted::age_type\": {\"get_param\": \"HeatCronPurgeDeletedAgeType\"}, \"heat::cron::purge_deleted::destination\": {\"get_param\": \"HeatCronPurgeDeletedDestination\"}, \"heat::max_json_body_size\": {\"get_param\": \"HeatMaxJsonBodySize\"}}, {\"heat::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"heat::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}, \"heat::cache::resource_finder_caching\": false}, {\"if\": [\"tls_cache_enabled\", {\"heat::cache::backend\": \"dogpile.cache.pymemcache\"}, {\"heat::cache::backend\": \"dogpile.cache.memcached\"}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(174,'2026-06-09 08:02:19',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Glance service configured with Puppet\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"DeployIdentifier\": {\"default\": 1780992067, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"GlanceDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Glance service.\", \"type\": \"boolean\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"GlancePassword\": {\"description\": \"The password for the glance service and db account, used by the glance services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"cjUKwpQUAKsA4fym1vJsXs888\"}, \"GlanceWorkers\": {\"default\": 1, \"description\": \"Number of API worker processes for Glance. If left unset (empty string), the\\ndefault value will result in the configuration being left unset and a\\nsystem-dependent default value will be chosen (e.g.: number of\\nprocessors). Please note that this will create a large number of\\nprocesses on systems with a large number of CPUs resulting in excess\\nmemory consumption. It is recommended that a suitable non-default value\\nbe selected on such systems.\\n\", \"type\": \"string\"}, \"MonitoringSubscriptionGlanceApi\": {\"default\": \"overcloud-glance-api\", \"type\": \"string\"}, \"GlanceApiLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.glance.api\", \"file\": \"/var/log/containers/glance/api.log\"}}, \"GlanceImageMemberQuota\": {\"default\": 128, \"description\": \"Maximum number of image members per image.\\nNegative values evaluate to unlimited.\\n\", \"type\": \"number\"}, \"GlanceNfsEnabled\": {\"default\": false, \"description\": \"When using GlanceBackend \'file\', mount NFS share for image storage.\\n\", \"type\": \"boolean\"}, \"GlanceCacheEnabled\": {\"description\": \"Enable Glance Image Cache\", \"type\": \"boolean\", \"default\": false}, \"GlanceImageCacheDir\": {\"description\": \"Base directory that the Image Cache uses\", \"type\": \"string\", \"default\": \"/var/lib/glance/image-cache\"}, \"GlanceImageCacheMaxSize\": {\"description\": \"The upper limit on cache size, in bytes, after which the cache-pruner cleans up the image cache.\\n\", \"type\": \"number\", \"default\": 10737418240}, \"GlanceImageCacheStallTime\": {\"description\": \"The amount of time, in seconds, to let an image remain in the cache without being accessed.\\n\", \"type\": \"number\", \"default\": 86400}, \"GlanceImagePrefetcherInterval\": {\"description\": \"The interval in seconds to run periodic job cache_images.\\n\", \"type\": \"number\", \"default\": 300}, \"GlanceNfsShare\": {\"default\": \"\", \"description\": \"NFS share to mount for image storage (when GlanceNfsEnabled is true)\\n\", \"type\": \"string\"}, \"GlanceNetappNfsEnabled\": {\"default\": false, \"description\": \"When using GlanceBackend \'file\', Netapp mount NFS share for image storage.\\n\", \"type\": \"boolean\"}, \"NetappShareLocation\": {\"default\": \"\", \"description\": \"Netapp share to mount for image storage (when GlanceNetappNfsEnabled is true)\\n\", \"type\": \"string\"}, \"GlanceNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options for image storage (when GlanceNfsEnabled is true)\\n\", \"type\": \"string\"}, \"GlanceRbdPoolName\": {\"default\": \"images\", \"type\": \"string\"}, \"NovaEnableRbdBackend\": {\"default\": false, \"description\": \"Whether to enable the Rbd backend for Nova ephemeral storage.\", \"type\": \"boolean\", \"tags\": [\"role_specific\"]}, \"GlanceImageImportPlugins\": {\"default\": [\"no_op\"], \"description\": \"List of enabled Image Import Plugins. Valid values in the list are \'image_conversion\', \'inject_metadata\', \'no_op\'.\\n\", \"type\": \"comma_delimited_list\"}, \"GlanceDiskFormats\": {\"default\": \"\", \"description\": \"List of allowed disk formats in Glance; all formats are allowed when left unset.\\n\", \"type\": \"comma_delimited_list\"}, \"GlanceImageConversionOutputFormat\": {\"default\": \"raw\", \"description\": \"Desired output format for image conversion plugin.\", \"type\": \"string\"}, \"GlanceInjectMetadataProperties\": {\"default\": \"\", \"description\": \"Metadata properties to be injected in image.\", \"type\": \"comma_delimited_list\"}, \"GlanceIgnoreUserRoles\": {\"default\": \"admin\", \"description\": \"List of user roles to be ignored for injecting image metadata properties.\", \"type\": \"comma_delimited_list\"}, \"GlanceEnabledImportMethods\": {\"default\": \"web-download\", \"description\": \"List of enabled Image Import Methods. Valid values in the list are \'glance-direct\', \'web-download\', or \'copy-image\'\\n\", \"type\": \"comma_delimited_list\"}, \"GlanceStagingNfsShare\": {\"default\": \"\", \"description\": \"NFS share to mount for image import staging\\n\", \"type\": \"string\"}, \"GlanceNodeStagingUri\": {\"default\": \"file:///var/lib/glance/staging\", \"description\": \"URI that specifies the staging location to use when importing images\\n\", \"type\": \"string\"}, \"GlanceStagingNfsOptions\": {\"default\": \"_netdev,bg,intr,context=system_u:object_r:container_file_t:s0\", \"description\": \"NFS mount options for NFS image import staging\\n\", \"type\": \"string\"}, \"GlanceSparseUploadEnabled\": {\"default\": false, \"description\": \"When using GlanceBackend \'file\' and \'rbd\' to enable or not sparse upload.\\n\", \"type\": \"boolean\"}, \"EnforceSecureRbac\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Setting this option to True will configure each OpenStack service to enforce Secure RBAC by setting `[oslo_policy] enforce_new_defaults` and `[oslo_policy] enforce_scope` to True. This introduces a consistent set of RBAC personas across OpenStack services that include support for system and project scope, as well as keystone\'s default roles, admin, member, and reader. Do not enable this functionality until all services in your deployment actually support secure RBAC.\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"GlanceApiPolicies\": {\"description\": \"A hash of policies to configure for Glance API.\\ne.g. { glance-context_is_admin: { key: context_is_admin, value: \'role:admin\' } }\\n\", \"default\": {}, \"type\": \"json\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"GlanceNotifierStrategy\": {\"description\": \"Strategy to use for Glance notification queue\", \"type\": \"string\", \"default\": \"noop\"}, \"GlanceLogFile\": {\"description\": \"The filepath of the file to use for logging messages from Glance.\", \"type\": \"string\", \"default\": \"\"}, \"GlanceBackend\": {\"default\": \"swift\", \"description\": \"The short name of the Glance backend to use. Should be one of swift, rbd, cinder, or file\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"swift\", \"file\", \"rbd\", \"cinder\"]}]}, \"GlanceBackendID\": {\"type\": \"string\", \"default\": \"default_backend\", \"description\": \"The default backend\'s identifier.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9_-]+\"}]}, \"GlanceStoreDescription\": {\"type\": \"string\", \"default\": \"Default glance store backend.\", \"description\": \"User facing description for the Glance backend.\"}, \"GlanceMultistoreConfig\": {\"type\": \"json\", \"default\": {}, \"description\": \"Dictionary of settings when configuring additional glance backends. The\\nhash key is the backend ID, and the value is a dictionary of parameter\\nvalues unique to that backend. Multiple rbd and cinder backends are allowed, but\\nfile and swift backends are limited to one each. Example:\\n  # Default glance store is rbd.\\n  GlanceBackend: rbd\\n  GlanceStoreDescription: \'Default rbd store\'\\n  # GlanceMultistoreConfig specifies a second rbd backend, plus a cinder\\n  # backend.\\n  GlanceMultistoreConfig:\\n    rbd2_store:\\n      GlanceBackend: rbd\\n      GlanceStoreDescription: \'Second rbd store\'\\n      CephClusterName: ceph2\\n      # Override CephClientUserName if this cluster uses a different\\n      # client name.\\n      CephClientUserName: client2\\n    cinder1_store:\\n      GlanceBackend: cinder\\n      GlanceCinderVolumeType: \'volume-type-1\'\\n      GlanceStoreDescription: \'First cinder store\'\\n    cinder2_store:\\n      GlanceBackend: cinder\\n      GlanceCinderVolumeType: \'volume-type-2\'\\n      GlanceStoreDescription: \'Seconde cinder store\'\\n\"}, \"GlanceCinderMountPointBase\": {\"default\": \"/var/lib/glance/mnt\", \"type\": \"string\", \"description\": \"The mount point base when glance is using cinder as store and cinder backend\\nis NFS. This mount point is where the NFS volume is mounted on the glance node.\\n\"}, \"GlanceCinderVolumeType\": {\"default\": \"\", \"type\": \"string\", \"description\": \"A unique volume type required for each cinder store while configuring multiple cinder\\nstores as glance backends. The same volume types must be configured in Cinder as well.\\nThe volume type must exist in cinder prior to any attempt to add an image in the associated\\ncinder store. If no volume type is specified then cinder\'s default volume type will be used.\\n\"}, \"GlanceCinderLockPath\": {\"default\": \"/var/lib/cinder/tmp\", \"type\": \"string\", \"description\": \"The oslo.coordination lock_path to use when glance is using cinder as a store. Using\\ncinder\'s lock_path ensures os-brick operations are synchronized across both services.\\n\"}, \"CephClientUserName\": {\"default\": \"openstack\", \"type\": \"string\"}, \"CephClusterName\": {\"type\": \"string\", \"default\": \"ceph\", \"description\": \"The Ceph cluster name.\", \"constraints\": [{\"allowed_pattern\": \"[a-zA-Z0-9]+\", \"description\": \"The Ceph cluster name must be at least 1 character and contain only letters and numbers.\\n\"}]}, \"CephConfigPath\": {\"type\": \"string\", \"default\": \"/var/lib/tripleo-config/ceph\", \"description\": \"The path where the Ceph Cluster config files are stored on the host.\\n\"}, \"MultipathdEnable\": {\"default\": false, \"description\": \"Whether to enable the multipath daemon\", \"type\": \"boolean\"}, \"GlanceApiOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"ContainerGlanceApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\"}, \"ContainerGlanceApiConfigImage\": {\"description\": \"The container image to use for the glance_api config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\"}, \"GlanceCronDbPurgeMinute\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Minute\\n\", \"default\": \"1\"}, \"GlanceCronDbPurgeHour\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Hour\\n\", \"default\": \"0\"}, \"GlanceCronDbPurgeMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month Day\\n\", \"default\": \"*\"}, \"GlanceCronDbPurgeMonth\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month\\n\", \"default\": \"*\"}, \"GlanceCronDbPurgeWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Week Day\\n\", \"default\": \"*\"}, \"GlanceCronDbPurgeUser\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - User\\n\", \"default\": \"glance\"}, \"GlanceCronDbPurgeAge\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age\\n\", \"default\": \"30\"}, \"GlanceCronDbPurgeMaxRows\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Rows\\n\", \"default\": \"100\"}, \"GlanceCronDbPurgeDestination\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Log destination\\n\", \"default\": \"/var/log/glance/glance-rowsflush.log\"}, \"GlanceCronDbPurgeMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Delay\\n\", \"default\": \"3600\"}, \"MemcacheUseAdvancedPool\": {\"type\": \"boolean\", \"description\": \"Use the advanced (eventlet safe) memcached client pool.\\n\", \"default\": true}, \"GlanceShowMultipleLocations\": {\"default\": false, \"description\": \"Whether to show multiple image locations e.g for copy-on-write support on\\nRBD or Netapp backends. Potential security risk, see glance.conf for more information.\\n\", \"type\": \"boolean\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments.\\n\", \"parameters\": [\"GlanceShowMultipleLocations\"]}], \"conditions\": {\"cinder_backend_enabled\": {\"or\": [{\"equals\": [{\"get_param\": \"GlanceBackend\"}, \"cinder\"]}, {\"yaql\": {\"expression\": \"$.data.values().any($.get(\\\"GlanceBackend\\\", \\\"\\\") = \\\"cinder\\\")\", \"data\": {\"get_param\": \"GlanceMultistoreConfig\"}}}]}, \"cinder_multipathd_enabled\": {\"and\": [\"cinder_backend_enabled\", {\"get_param\": \"MultipathdEnable\"}]}, \"rbd_backend_enabled\": {\"or\": [{\"equals\": [{\"get_param\": \"GlanceBackend\"}, \"rbd\"]}, {\"yaql\": {\"expression\": \"$.data.values().any($.get(\\\"GlanceBackend\\\", \\\"\\\") = \\\"rbd\\\")\", \"data\": {\"get_param\": \"GlanceMultistoreConfig\"}}}]}, \"force_image_conversion_plugin\": {\"or\": [{\"and\": [\"rbd_backend_enabled\", {\"equals\": [{\"get_param\": \"GlanceImageImportPlugins\"}, [\"no_op\"]]}, {\"get_param\": \"NovaEnableRbdBackend\"}]}, {\"get_param\": \"GlanceSparseUploadEnabled\"}]}, \"glance_workers_set\": {\"not\": {\"equals\": [{\"get_param\": \"GlanceWorkers\"}, \"\"]}}, \"glance_multiple_locations\": {\"or\": [{\"get_param\": \"GlanceShowMultipleLocations\"}, {\"get_param\": \"GlanceNetappNfsEnabled\"}, {\"and\": [\"rbd_backend_enabled\", {\"get_param\": \"NovaEnableRbdBackend\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"GlanceLogging\": {\"type\": \"OS::TripleO::Services::Logging::GlanceApi\"}, \"CinderNVMeOF\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backend-nvmeof-puppet.yaml\"}, \"TLSProxyBase\": {\"type\": \"OS::TripleO::Services::TLSProxyBase\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"EnableInternalTLS\": {\"get_param\": \"EnableInternalTLS\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerGlanceApiImage\": \"ContainerGlanceApiImage\", \"ContainerGlanceApiConfigImage\": \"ContainerGlanceApiConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerGlanceApiImage\": {\"get_param\": \"ContainerGlanceApiImage\"}, \"ContainerGlanceApiConfigImage\": {\"get_param\": \"ContainerGlanceApiConfigImage\"}}}]}}}}, \"outputs\": {\"glance_api_host_prep_and_system_upgrade_post_tasks\": {\"description\": \"Common host_prep and system_upgrade post tasks for glance_api\", \"value\": [{\"name\": \"Mount NFS on host\", \"vars\": {\"nfs_backend_enabled\": {\"get_param\": \"GlanceNfsEnabled\"}, \"glance_netapp_nfs_enabled\": {\"get_param\": \"GlanceNetappNfsEnabled\"}, \"glance_nfs_share\": {\"get_param\": \"GlanceNfsShare\"}, \"netapp_share_location\": {\"get_param\": \"NetappShareLocation\"}, \"nfs_share\": \"{{ glance_nfs_share if (glance_nfs_share) else netapp_share_location }}\", \"nfs_options\": {\"get_param\": \"GlanceNfsOptions\"}}, \"mount\": {\"name\": \"/var/lib/glance/images\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{nfs_share}}\", \"opts\": \"{{nfs_options}}\"}, \"when\": \"nfs_backend_enabled or glance_netapp_nfs_enabled\"}, {\"name\": \"Mount Node Staging Location\", \"vars\": {\"glance_node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance_staging_nfs_share\": {\"get_param\": \"GlanceStagingNfsShare\"}, \"glance_nfs_options\": {\"get_param\": \"GlanceStagingNfsOptions\"}}, \"mount\": {\"name\": \"{{glance_node_staging_uri[7:]}}\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{glance_staging_nfs_share}}\", \"opts\": \"{{glance_nfs_options}}\"}, \"when\": \"glance_staging_nfs_share != \'\'\"}]}, \"role_data\": {\"description\": \"Role data for the Glance API role.\", \"value\": {\"service_name\": \"glance_api\", \"firewall_rules\": {\"112 glance_api\": {\"dport\": [9292]}}, \"firewall_frontend_rules\": {\"100 glance_api_haproxy_frontend\": {\"dport\": [9292]}}, \"firewall_ssl_frontend_rules\": {\"100 glance_api_haproxy_frontend_ssl\": {\"dport\": [13292]}}, \"keystone_resources\": {\"glance\": {\"endpoints\": {\"public\": {\"get_param\": [\"EndpointMap\", \"GlancePublic\", \"uri\"]}, \"internal\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"uri\"]}, \"admin\": {\"get_param\": [\"EndpointMap\", \"GlanceAdmin\", \"uri\"]}}, \"users\": {\"glance\": {\"password\": {\"get_param\": \"GlancePassword\"}}}, \"region\": {\"get_param\": \"KeystoneRegion\"}, \"service\": \"image\"}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionGlanceApi\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"TLSProxyBase\", \"role_data\", \"config_settings\"]}, {\"glance::api::db::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"glance\", \"password\": {\"get_param\": \"GlancePassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/glance\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"glance\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"glance::api::authtoken::www_authenticate_uri\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"glance::api::authtoken::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"glance::api::enable_v1_api\": false, \"glance::api::enable_v2_api\": true, \"glance::api::authtoken::password\": {\"get_param\": \"GlancePassword\"}, \"glance::api::enable_proxy_headers_parsing\": true, \"glance::api::logging::debug\": {\"if\": [{\"get_param\": \"GlanceDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"glance::policy::policies\": {\"get_param\": \"GlanceApiPolicies\"}, \"glance::api::authtoken::project_name\": \"service\", \"glance::api::authtoken::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"glance::api::authtoken::user_domain_name\": \"Default\", \"glance::api::authtoken::project_domain_name\": \"Default\", \"glance::api::authtoken::interface\": \"internal\", \"glance::api::authtoken::memcache_use_advanced_pool\": {\"get_param\": \"MemcacheUseAdvancedPool\"}, \"glance::api::pipeline\": {\"if\": [{\"get_param\": \"GlanceCacheEnabled\"}, \"keystone+cachemanagement\", \"keystone\"]}, \"glance::api::os_region_name\": {\"get_param\": \"KeystoneRegion\"}, \"glance::api::image_member_quota\": {\"get_param\": \"GlanceImageMemberQuota\"}, \"glance::api::enabled_import_methods\": {\"get_param\": \"GlanceEnabledImportMethods\"}, \"glance::api::node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance::api::image_import_plugins\": {\"if\": [\"force_image_conversion_plugin\", {\"list_concat_unique\": [{\"get_param\": \"GlanceImageImportPlugins\"}, [\"image_conversion\"]]}, {\"get_param\": \"GlanceImageImportPlugins\"}]}, \"glance::api::image_conversion_output_format\": {\"get_param\": \"GlanceImageConversionOutputFormat\"}, \"glance::api::inject_metadata_properties\": {\"get_param\": \"GlanceInjectMetadataProperties\"}, \"glance::api::ignore_user_roles\": {\"get_param\": \"GlanceIgnoreUserRoles\"}, \"tripleo::profile::base::glance::api::tls_proxy_bind_ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}}}, \"tripleo::profile::base::glance::api::tls_proxy_fqdn\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}}}, \"tripleo::profile::base::glance::api::tls_proxy_port\": 9292, \"glance::api::bind_host\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, \"%{hiera(\'localhost_address\')}\", {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}}}}]}, \"glance_notifier_strategy\": {\"get_param\": \"GlanceNotifierStrategy\"}, \"glance_log_file\": {\"get_param\": \"GlanceLogFile\"}, \"glance::backend::rbd::rbd_thin_provisioning\": {\"get_param\": \"GlanceSparseUploadEnabled\"}, \"glance::backend::file::filesystem_thin_provisioning\": {\"get_param\": \"GlanceSparseUploadEnabled\"}, \"glance::backend::swift::swift_store_auth_address\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"glance::backend::swift::swift_store_user\": \"service:glance\", \"glance::backend::swift::swift_store_key\": {\"get_param\": \"GlancePassword\"}, \"glance::backend::swift::swift_store_create_container_on_put\": true, \"glance::backend::swift::swift_store_auth_version\": 3, \"glance::backend::rbd::rbd_store_ceph_conf\": {\"list_join\": [\"\", [\"/etc/ceph/\", {\"get_param\": \"CephClusterName\"}, \".conf\"]]}, \"glance::backend::rbd::rbd_store_pool\": {\"get_param\": \"GlanceRbdPoolName\"}, \"glance::backend::rbd::rbd_store_user\": {\"get_param\": \"CephClientUserName\"}, \"glance_backend\": {\"get_param\": \"GlanceBackend\"}, \"tripleo::profile::base::glance::api::glance_backend_id\": {\"get_param\": \"GlanceBackendID\"}, \"tripleo::profile::base::glance::api::glance_store_description\": {\"get_param\": \"GlanceStoreDescription\"}, \"tripleo::profile::base::glance::api::multistore_config\": {\"get_param\": \"GlanceMultistoreConfig\"}, \"tripleo::profile::base::glance::backend::rbd::glance_rbd_ceph_conf_path\": {\"get_param\": \"CephConfigPath\"}, \"glance::notify::rabbitmq::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"glance::notify::rabbitmq::rabbit_heartbeat_in_pthread\": false, \"glance::cron::db_purge::minute\": {\"get_param\": \"GlanceCronDbPurgeMinute\"}, \"glance::cron::db_purge::hour\": {\"get_param\": \"GlanceCronDbPurgeHour\"}, \"glance::cron::db_purge::monthday\": {\"get_param\": \"GlanceCronDbPurgeMonthday\"}, \"glance::cron::db_purge::month\": {\"get_param\": \"GlanceCronDbPurgeMonth\"}, \"glance::cron::db_purge::weekday\": {\"get_param\": \"GlanceCronDbPurgeWeekday\"}, \"glance::cron::db_purge::user\": {\"get_param\": \"GlanceCronDbPurgeUser\"}, \"glance::cron::db_purge::age\": {\"get_param\": \"GlanceCronDbPurgeAge\"}, \"glance::cron::db_purge::max_rows\": {\"get_param\": \"GlanceCronDbPurgeMaxRows\"}, \"glance::cron::db_purge::destination\": {\"get_param\": \"GlanceCronDbPurgeDestination\"}, \"glance::cron::db_purge::maxdelay\": {\"get_param\": \"GlanceCronDbPurgeMaxDelay\"}}, {\"if\": [\"glance_workers_set\", {\"glance::api::workers\": {\"get_param\": \"GlanceWorkers\"}}]}, {\"if\": [{\"get_param\": \"EnforceSecureRbac\"}, {\"glance::api::enforce_secure_rbac\": true, \"glance::policy::enforce_new_defaults\": true}]}, {\"if\": [\"cinder_backend_enabled\", {\"glance::backend::cinder::cinder_store_auth_address\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"glance::backend::cinder::cinder_store_project_name\": \"service\", \"glance::backend::cinder::cinder_store_user_name\": \"glance\", \"glance::backend::cinder::cinder_store_password\": {\"get_param\": \"GlancePassword\"}, \"glance::api::lock_path\": {\"get_param\": \"GlanceCinderLockPath\"}, \"tripleo::profile::base::glance::backend::cinder::cinder_mount_point_base\": {\"get_param\": \"GlanceCinderMountPointBase\"}, \"tripleo::profile::base::glance::backend::cinder::cinder_volume_type\": {\"get_param\": \"GlanceCinderVolumeType\"}}]}, {\"if\": [\"cinder_multipathd_enabled\", {\"glance::backend::cinder::cinder_use_multipath\": true}]}, {\"if\": [{\"get_param\": \"GlanceCacheEnabled\"}, {\"tripleo::profile::base::glance::api::glance_enable_cache\": true, \"glance::api::image_cache_dir\": {\"get_param\": \"GlanceImageCacheDir\"}, \"glance::api::image_cache_max_size\": {\"get_param\": \"GlanceImageCacheMaxSize\"}, \"glance::api::image_cache_stall_time\": {\"get_param\": \"GlanceImageCacheStallTime\"}, \"glance::api::cache_prefetcher_interval\": {\"get_param\": \"GlanceImagePrefetcherInterval\"}}]}, {\"if\": [{\"get_param\": \"GlanceNetappNfsEnabled\"}, {\"tripleo::profile::base::glance::netapp::netapp_share\": {\"get_param\": \"NetappShareLocation\"}, \"glance::api::filesystem_store_metadata_file\": \"/etc/glance/glance-metadata-file.json\", \"glance::api::filesystem_store_file_perm\": \"0644\"}]}, {\"if\": [{\"contains\": [\"glance-direct\", {\"get_param\": \"GlanceEnabledImportMethods\"}]}, {\"glance::api::worker_self_reference_url\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"str_replace\": {\"template\": \"https://%{hiera(\'fqdn_NETWORK\')}:PORT\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}, \"PORT\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}}}}, {\"str_replace\": {\"template\": \"http://%{hiera(\'NETWORK_uri\')}:PORT\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"GlanceApiNetwork\"]}, \"PORT\": {\"get_param\": [\"EndpointMap\", \"GlanceInternal\", \"port\"]}}}}]}}]}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"GlanceDiskFormats\"}, []]}}, {\"glance::api::disk_formats\": {\"get_param\": \"GlanceDiskFormats\"}}]}]}, \"service_config_settings\": {\"mysql\": {\"glance::db::mysql::password\": {\"get_param\": \"GlancePassword\"}, \"glance::db::mysql::user\": \"glance\", \"glance::db::mysql::host\": \"%\", \"glance::db::mysql::dbname\": \"glance\"}, \"rsyslog\": {\"tripleo_logging_sources_glance_api\": [{\"get_param\": \"GlanceApiLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"glance_api\", \"puppet_tags\": \"glance_api_config,glance_api_paste_ini,glance_swift_config,glance_cache_config,glance_image_import_config\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::glance::api\", {\"if\": [{\"get_param\": \"GlanceNetappNfsEnabled\"}, \"include tripleo::profile::base::glance::netapp\"]}, {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/glance_api.json\": {\"command\": \"/usr/bin/glance-api --config-file /usr/share/glance/glance-api-dist.conf --config-file /etc/glance/glance-api.conf --config-file /etc/glance/glance-image-import.conf\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-ceph/\", \"dest\": \"/etc/ceph/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-iscsid/*\", \"dest\": \"/etc/iscsi/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": {\"list_concat\": [[{\"path\": \"/var/lib/glance\", \"owner\": \"glance:glance\", \"recurse\": true}, {\"path\": {\"str_replace\": {\"template\": \"/etc/ceph/CLUSTER.client.USER.keyring\", \"params\": {\"CLUSTER\": {\"get_param\": \"CephClusterName\"}, \"USER\": {\"get_param\": \"CephClientUserName\"}}}}, \"owner\": \"glance:glance\", \"perm\": \"0600\"}], {\"repeat\": {\"template\": {\"path\": \"/etc/ceph/<%keyring%>\", \"owner\": \"glance:glance\", \"perm\": \"0600\"}, \"for_each\": {\"<%keyring%>\": {\"yaql\": {\"expression\": \"let(u => $.data.user) -> $.data.multistore.values().where($.get(\\\"CephClusterName\\\")).select($.CephClusterName + \\\".client.\\\" + $.get(\\\"CephClientUserName\\\", $u) +\\\".keyring\\\")\", \"data\": {\"user\": {\"get_param\": \"CephClientUserName\"}, \"multistore\": {\"get_param\": \"GlanceMultistoreConfig\"}}}}}}}]}}, \"/var/lib/kolla/config_files/glance_api_tls_proxy.json\": {\"command\": \"/usr/sbin/httpd -DFOREGROUND\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}, \"/var/lib/kolla/config_files/glance_api_cron.json\": {\"command\": \"/usr/sbin/crond -n\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/glance\", \"owner\": \"glance:glance\", \"recurse\": true}]}}, \"docker_config\": {\"step_2\": {\"get_attr\": [\"GlanceLogging\", \"docker_config\", \"step_2\"]}, \"step_3\": {\"glance_api_db_sync\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"cap_add\": [\"AUDIT_WRITE\"], \"net\": \"host\", \"privileged\": false, \"detach\": false, \"user\": \"root\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"GlanceLogging\", \"volumes\"]}, {\"get_param\": \"GlanceApiOptVolumes\"}, [\"/var/lib/kolla/config_files/glance_api.json:/var/lib/kolla/config_files/config.json\", \"/var/lib/config-data/puppet-generated/glance_api:/var/lib/kolla/config_files/src:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", \"/var/lib/glance:/var/lib/glance:shared\"], {\"if\": [\"cinder_backend_enabled\", {\"list_concat\": [[\"/dev:/dev\", \"/var/lib/iscsi:/var/lib/iscsi:z\", {\"list_join\": [\":\", [{\"get_param\": \"GlanceCinderLockPath\"}, {\"get_param\": \"GlanceCinderLockPath\"}, \"z\"]]}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}]}]}, {\"if\": [\"cinder_multipathd_enabled\", [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}, \"environment\": {\"KOLLA_BOOTSTRAP\": true, \"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}, \"command\": \"/usr/bin/bootstrap_host_exec glance_api su glance -s /bin/bash -c \'/usr/local/bin/kolla_start\'\"}}, \"step_4\": {\"glance_api\": {\"start_order\": 2, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"net\": \"host\", \"privileged\": {\"if\": [\"cinder_backend_enabled\", true, false]}, \"restart\": \"always\", \"depends_on\": {\"if\": [{\"or\": [{\"get_param\": \"GlanceNfsEnabled\"}, {\"get_param\": \"GlanceNetappNfsEnabled\"}]}, \"var-lib-glance-images.mount\"]}, \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"GlanceLogging\", \"volumes\"]}, {\"get_param\": \"GlanceApiOptVolumes\"}, [\"/var/lib/kolla/config_files/glance_api.json:/var/lib/kolla/config_files/config.json\", \"/var/lib/config-data/puppet-generated/glance_api:/var/lib/kolla/config_files/src:ro\", {\"list_join\": [\":\", [{\"get_param\": \"CephConfigPath\"}], [\"/var/lib/kolla/config_files/src-ceph\"], [\"z\"]]}, \"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\", \"/var/lib/glance:/var/lib/glance:shared\"], {\"if\": [\"cinder_backend_enabled\", {\"list_concat\": [[\"/dev:/dev\", \"/var/lib/iscsi:/var/lib/iscsi:z\", {\"list_join\": [\":\", [{\"get_param\": \"GlanceCinderLockPath\"}, {\"get_param\": \"GlanceCinderLockPath\"}, \"z\"]]}], {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_volumes\"]}]}]}, {\"if\": [\"cinder_multipathd_enabled\", [\"/etc/multipath:/etc/multipath:z\", \"/etc/multipath.conf:/etc/multipath.conf:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"glance_api_tls_proxy\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"start_order\": 3, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"net\": \"host\", \"user\": \"root\", \"restart\": \"always\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"GlanceLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/glance_api_tls_proxy.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/glance_api:/var/lib/kolla/config_files/src:ro\", \"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}]}, \"glance_api_cron\": {\"start_order\": 2, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"net\": \"host\", \"user\": \"root\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/usr/share/openstack-tripleo-common/healthcheck/cron glance\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"GlanceLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/glance_api_cron.json:/var/lib/kolla/config_files/config.json\", \"/var/lib/config-data/puppet-generated/glance_api:/var/lib/kolla/config_files/src:ro\", \"/var/lib/glance:/var/lib/glance:shared\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"GlanceLogging\", \"host_prep_tasks\"]}, [{\"name\": \"Mount NFS on host\", \"vars\": {\"nfs_backend_enabled\": {\"get_param\": \"GlanceNfsEnabled\"}, \"glance_netapp_nfs_enabled\": {\"get_param\": \"GlanceNetappNfsEnabled\"}, \"glance_nfs_share\": {\"get_param\": \"GlanceNfsShare\"}, \"netapp_share_location\": {\"get_param\": \"NetappShareLocation\"}, \"nfs_share\": \"{{ glance_nfs_share if (glance_nfs_share) else netapp_share_location }}\", \"nfs_options\": {\"get_param\": \"GlanceNfsOptions\"}}, \"mount\": {\"name\": \"/var/lib/glance/images\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{nfs_share}}\", \"opts\": \"{{nfs_options}}\"}, \"when\": \"nfs_backend_enabled or glance_netapp_nfs_enabled\"}, {\"name\": \"Mount Node Staging Location\", \"vars\": {\"glance_node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance_staging_nfs_share\": {\"get_param\": \"GlanceStagingNfsShare\"}, \"glance_nfs_options\": {\"get_param\": \"GlanceStagingNfsOptions\"}}, \"mount\": {\"name\": \"{{glance_node_staging_uri[7:]}}\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{glance_staging_nfs_share}}\", \"opts\": \"{{glance_nfs_options}}\"}, \"when\": \"glance_staging_nfs_share != \'\'\"}], [{\"name\": \"ensure ceph configurations exist\", \"file\": {\"path\": {\"get_param\": \"CephConfigPath\"}, \"state\": \"directory\"}}, {\"name\": \"ensure /var/lib/glance exists\", \"file\": {\"path\": \"/var/lib/glance\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}], {\"if\": [\"cinder_backend_enabled\", [{\"name\": \"Allow glance to use cinder\'s lock_path\", \"file\": {\"path\": {\"get_param\": \"GlanceCinderLockPath\"}, \"state\": \"directory\", \"setype\": \"container_file_t\", \"mode\": 504, \"group\": 42400}}, {\"name\": \"Identify dynamic os-brick lock files used by glance\", \"vars\": {\"lock_path\": {\"get_param\": \"GlanceCinderLockPath\"}}, \"ansible.builtin.find\": {\"paths\": \"{{ lock_path }}\", \"patterns\": \"os-brick-connect_to_iscsi_portal-*\"}, \"register\": \"find_dynamic_locks\"}, {\"name\": \"Prepare the os-brick lock files used by glance\", \"vars\": {\"lock_path\": {\"get_param\": \"GlanceCinderLockPath\"}, \"static_brick_locks\": [\"{{ lock_path }}/os-brick-connect_volume\", \"{{ lock_path }}/os-brick-extend_volume\", \"{{ lock_path }}/scaleio-scaleio\"], \"dynamic_brick_locks\": \"{{ find_dynamic_locks.files | map(attribute=\'path\') }}\"}, \"file\": {\"path\": \"{{ item }}\", \"state\": \"touch\", \"setype\": \"container_file_t\", \"mode\": 432, \"group\": 42400}, \"loop\": \"{{ (static_brick_locks + dynamic_brick_locks) | flatten}}\"}]]}, {\"get_attr\": [\"CinderNVMeOF\", \"cinder_nvmeof_host_prep_tasks\"]}]}, \"upgrade_tasks\": [{\"name\": \"glance-api pre system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 3\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Unmount and remove NFS glance entry\", \"vars\": {\"nfs_backend_enabled\": {\"get_param\": \"GlanceNfsEnabled\"}, \"glance_netapp_nfs_enabled\": {\"get_param\": \"GlanceNetappNfsEnabled\"}}, \"mount\": {\"name\": \"/var/lib/glance/images\", \"fstype\": \"nfs\", \"state\": \"absent\"}, \"when\": \"nfs_backend_enabled or glance_netapp_nfs_enabled\"}, {\"name\": \"Unmount and remove NFS glance-staging entry\", \"vars\": {\"glance_node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance_staging_nfs_share\": {\"get_param\": \"GlanceStagingNfsShare\"}}, \"mount\": {\"name\": \"{{glance_node_staging_uri[7:]}}\", \"fstype\": \"nfs\", \"state\": \"absent\"}, \"when\": \"glance_staging_nfs_share != \'\'\"}]}, {\"name\": \"glance-api post system_upgrade tasks\", \"tags\": [\"never\", \"system_upgrade\", \"system_upgrade_run\", \"system_upgrade_nfsmounts\"], \"when\": [\"step|int == 5\", \"upgrade_leapp_enabled\"], \"block\": [{\"name\": \"Mount NFS on host\", \"vars\": {\"nfs_backend_enabled\": {\"get_param\": \"GlanceNfsEnabled\"}, \"glance_netapp_nfs_enabled\": {\"get_param\": \"GlanceNetappNfsEnabled\"}, \"glance_nfs_share\": {\"get_param\": \"GlanceNfsShare\"}, \"netapp_share_location\": {\"get_param\": \"NetappShareLocation\"}, \"nfs_share\": \"{{ glance_nfs_share if (glance_nfs_share) else netapp_share_location }}\", \"nfs_options\": {\"get_param\": \"GlanceNfsOptions\"}}, \"mount\": {\"name\": \"/var/lib/glance/images\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{nfs_share}}\", \"opts\": \"{{nfs_options}}\"}, \"when\": \"nfs_backend_enabled or glance_netapp_nfs_enabled\"}, {\"name\": \"Mount Node Staging Location\", \"vars\": {\"glance_node_staging_uri\": {\"get_param\": \"GlanceNodeStagingUri\"}, \"glance_staging_nfs_share\": {\"get_param\": \"GlanceStagingNfsShare\"}, \"glance_nfs_options\": {\"get_param\": \"GlanceStagingNfsOptions\"}}, \"mount\": {\"name\": \"{{glance_node_staging_uri[7:]}}\", \"state\": \"mounted\", \"fstype\": \"nfs\", \"src\": \"{{glance_staging_nfs_share}}\", \"opts\": \"{{glance_nfs_options}}\"}, \"when\": \"glance_staging_nfs_share != \'\'\"}]}], \"metadata_settings\": {\"get_attr\": [\"TLSProxyBase\", \"role_data\", \"metadata_settings\"]}, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop glance api container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"glance_api\", \"glance_api_cron\"], \"tripleo_delegate_to\": \"{{ groups[\'glance_api\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}], \"deploy_steps_tasks\": {\"get_attr\": [\"TLSProxyBase\", \"role_data\", \"deploy_steps_tasks\"]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"EnableInternalTLS\": true}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(175,'2026-06-09 08:02:19',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(176,'2026-06-09 08:02:20',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(177,'2026-06-09 08:02:20',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (178,'2026-06-09 08:02:20',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Glance API service\\n\", \"parameters\": {\"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerGlanceApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\"}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerGlanceApiImage\": \"ContainerGlanceApiImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerGlanceApiImage\": {\"get_param\": \"ContainerGlanceApiImage\"}}}]}}}}, \"outputs\": {\"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/glance:/var/log/glance:z\", \"/var/log/containers/httpd/glance:/var/log/httpd:z\"]}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_2\": {\"glance_init_logs\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/glance:/var/log/glance:z\", \"/var/log/containers/httpd/glance:/var/log/httpd:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R glance:glance /var/log/glance\"]}}}}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent logs directory\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/glance\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/log/containers/httpd/glance\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(179,'2026-06-09 08:02:20',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(180,'2026-06-09 08:02:20',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Cinder NVMeOF backend\\n\", \"parameters\": {\"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderNVMeOFBackendName\": {\"type\": \"string\", \"default\": \"tripleo_nvmeof\"}, \"CinderNVMeOFAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NVMeOF Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNVMeOFTargetPort\": {\"type\": \"number\", \"default\": 4420}, \"CinderNVMeOFTargetHelper\": {\"type\": \"string\", \"default\": \"nvmet\"}, \"CinderNVMeOFTargetProtocol\": {\"type\": \"string\", \"default\": \"nvmet_rdma\", \"description\": \"The target protocol, supported values are nvmet_rdma and nvmet_tcp.\\n\", \"constraints\": [{\"allowed_values\": [\"nvmet_rdma\", \"nvmet_tcp\"]}]}, \"CinderNVMeOFTargetPrefix\": {\"type\": \"string\", \"default\": \"nvme-subsystem\"}, \"CinderNVMeOFTargetPortId\": {\"type\": \"number\", \"default\": 1}, \"CinderNVMeOFTargetNameSpaceId\": {\"type\": \"number\", \"default\": 10}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"type\": \"json\", \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}}, \"outputs\": {\"cinder_nvmeof_host_prep_tasks\": {\"description\": \"Host prep tasks related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [{\"name\": \"ensure /etc/nvme exists\", \"file\": {\"path\": \"/etc/nvme\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]]}}, \"cinder_nvmeof_volumes\": {\"description\": \"Volumes related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [\"/etc/nvme:/etc/nvme:z\"]]}}, \"role_data\": {\"description\": \"Role data for the Cinder NVMeOF backend.\", \"value\": {\"service_name\": \"cinder_backend_nvmeof\", \"firewall_rules\": {\"120 LVM nvmet target\": {\"dport\": {\"get_param\": \"CinderNVMeOFTargetPort\"}}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::cinder::volume::cinder_enable_nvmeof_backend\": {\"get_param\": \"CinderEnableNVMeOFBackend\"}, \"tripleo::profile::base::cinder::volume::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_port\": {\"get_param\": \"CinderNVMeOFTargetPort\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_helper\": {\"get_param\": \"CinderNVMeOFTargetHelper\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_protocol\": {\"get_param\": \"CinderNVMeOFTargetProtocol\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_prefix\": {\"get_param\": \"CinderNVMeOFTargetPrefix\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_port_id\": {\"get_param\": \"CinderNVMeOFTargetPortId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_ns_id\": {\"get_param\": \"CinderNVMeOFTargetNameSpaceId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_ip_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}, \"cinder::backend::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNVMeOFAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nvmeof::backend_availability_zone\": {\"get_param\": \"CinderNVMeOFAvailabilityZone\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(181,'2026-06-09 08:02:20',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized HAproxy service for pacemaker\\n\", \"parameters\": {\"ContainerHAProxyImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\"}, \"ContainerHAProxyConfigImage\": {\"description\": \"The container image to use for the haproxy config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\"}, \"ClusterCommonTag\": {\"default\": false, \"description\": \"When set to false, a pacemaker service is configured to use a floating tag for its container image name, e.g. \'REGISTRY/NAMESPACE/IMAGENAME:pcmklatest\'. When set to true, the service uses a floating prefix as well, e.g. \'cluster.common.tag/IMAGENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"ClusterFullTag\": {\"default\": true, \"description\": \"When set to true, the pacemaker service uses a fully constant tag for its container image name, e.g. \'cluster.common.tag/SERVICENAME:pcmklatest\'.\", \"type\": \"boolean\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"SSLCertificate\": {\"default\": \"\", \"description\": \"The content of the SSL certificate (without Key) in PEM format.\\n\", \"type\": \"string\"}, \"PublicSSLCertificateAutogenerated\": {\"default\": true, \"description\": \"Whether the public SSL certificate was autogenerated or not.\\n\", \"type\": \"boolean\"}, \"EnablePublicTLS\": {\"default\": true, \"description\": \"Whether to enable TLS on the public interface or not.\\n\", \"type\": \"boolean\"}, \"DeployedSSLCertificatePath\": {\"default\": \"/etc/pki/tls/private/overcloud_endpoint.pem\", \"description\": \"The filepath of the certificate as it will be stored in the controller.\\n\", \"type\": \"string\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"HAProxyInternalTLSCertsDirectory\": {\"default\": \"/etc/pki/tls/certs/haproxy\", \"type\": \"string\"}, \"HAProxyInternalTLSKeysDirectory\": {\"default\": \"/etc/pki/tls/private/haproxy\", \"type\": \"string\"}, \"HAProxyLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.haproxy\", \"file\": \"/var/log/containers/haproxy/haproxy.log\", \"startmsg.regex\": \"^[a-zA-Z]{3} [ 123][0-9] [:0-9]{8}\"}}, \"HAProxySyslogAddress\": {\"default\": \"/dev/log\", \"description\": \"Syslog address where HAproxy will send its log\", \"type\": \"string\"}, \"HAProxySyslogFacility\": {\"default\": \"local0\", \"description\": \"Syslog facility HAProxy will use for its logs\", \"type\": \"string\"}, \"ConfigDebug\": {\"default\": false, \"description\": \"Whether to run config management (e.g. Puppet) in debug mode.\", \"type\": \"boolean\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}, \"DeployIdentifier\": {\"default\": 1780992067, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}}, \"conditions\": {\"public_tls_enabled\": {\"and\": [{\"get_param\": \"EnablePublicTLS\"}, {\"or\": [{\"not\": {\"equals\": [{\"get_param\": \"SSLCertificate\"}, \"\"]}}, {\"get_param\": \"PublicSSLCertificateAutogenerated\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"HAProxyBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-container-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"HAProxyPublicTLS\": {\"type\": \"OS::TripleO::Services::HAProxyPublicTLS\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"HAProxyInternalTLS\": {\"type\": \"OS::TripleO::Services::HAProxyInternalTLS\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerHAProxyImage\": \"ContainerHAProxyImage\", \"ContainerHAProxyConfigImage\": \"ContainerHAProxyConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerHAProxyImage\": {\"get_param\": \"ContainerHAProxyImage\"}, \"ContainerHAProxyConfigImage\": {\"get_param\": \"ContainerHAProxyConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the HAproxy role.\", \"value\": {\"service_name\": \"haproxy\", \"firewall_rules\": {\"get_attr\": [\"HAProxyBase\", \"role_data\", \"firewall_rules\"]}, \"monitoring_subscription\": {\"get_attr\": [\"HAProxyBase\", \"role_data\", \"monitoring_subscription\"]}, \"ansible_group_vars\": {\"get_attr\": [\"HAProxyBase\", \"role_data\", \"ansible_group_vars\"]}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"HAProxyBase\", \"role_data\", \"config_settings\"]}, {\"tripleo::haproxy::haproxy_service_manage\": false, \"tripleo::haproxy::mysql_clustercheck\": true, \"tripleo::haproxy::haproxy_log_address\": {\"get_param\": \"HAProxySyslogAddress\"}, \"tripleo::haproxy::haproxy_log_facility\": {\"get_param\": \"HAProxySyslogFacility\"}}, {\"haproxy_docker\": true, \"tripleo::profile::pacemaker::haproxy_bundle::container_backend\": {\"get_param\": \"ContainerCli\"}, \"tripleo::profile::pacemaker::haproxy_bundle::tls_mapping\": {\"list_concat\": [{\"if\": [\"public_tls_enabled\", [{\"get_param\": \"DeployedSSLCertificatePath\"}]]}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}, {\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}]]}]}, \"tripleo::profile::pacemaker::haproxy_bundle::tls_mapping_init_bundle\": {\"list_concat\": [{\"if\": [\"public_tls_enabled\", [{\"get_param\": \"DeployedSSLCertificatePath\"}]]}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [{\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}, {\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}]]}]}, \"tripleo::profile::pacemaker::haproxy_bundle::internal_certs_directory\": {\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}, \"tripleo::profile::pacemaker::haproxy_bundle::internal_keys_directory\": {\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}, \"tripleo::profile::pacemaker::haproxy_bundle::haproxy_docker_image\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/haproxy:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_haproxy\": [{\"get_param\": \"HAProxyLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"haproxy\", \"puppet_tags\": \"haproxy_config\", \"step_config\": {\"list_join\": [\"\\n\", [\"exec {\'wait-for-settle\': command => \'/bin/true\' }\", \"class tripleo::firewall(){}; define tripleo::firewall::rule( $port = undef, $dport = undef, $sport = undef, $proto = undef, $action = undef, $state = undef, $source = undef, $iniface = undef, $chain = undef, $destination = undef, $extras = undef){}\", \"[\'pcmk_bundle\', \'pcmk_resource\', \'pcmk_property\', \'pcmk_constraint\', \'pcmk_resource_default\'].each |String $val| { noop_resource($val) }\", \"include tripleo::profile::pacemaker::haproxy_bundle\"]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyConfigImage\"]}, \"volumes\": {\"yaql\": {\"expression\": \"$.data.select($+\\\":\\\"+$+\\\":ro\\\")\", \"data\": {\"list_concat\": [{\"if\": [\"public_tls_enabled\", [{\"get_param\": \"DeployedSSLCertificatePath\"}]]}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}, {\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}]]}]}}}}, \"kolla_config\": {\"/var/lib/kolla/config_files/haproxy.json\": {\"command\": \"bash -c $* -- eval if [ -f /usr/sbin/haproxy-systemd-wrapper ]; then exec /usr/sbin/haproxy-systemd-wrapper -f /etc/haproxy/haproxy.cfg; else exec /usr/sbin/haproxy -f /etc/haproxy/haproxy.cfg -Ws; fi\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"optional\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/lib/haproxy\", \"owner\": \"haproxy:haproxy\", \"recurse\": true}, {\"path\": {\"list_join\": [\"\", [{\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}, \"/*\"]]}, \"owner\": \"haproxy:haproxy\", \"perm\": \"0600\", \"optional\": true}, {\"path\": {\"list_join\": [\"\", [{\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}, \"/*\"]]}, \"owner\": \"haproxy:haproxy\", \"perm\": \"0600\", \"optional\": true}]}}, \"container_config_scripts\": {\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HAProxyBase\", \"role_data\", \"host_prep_tasks\"]}, [{\"name\": \"Run puppet on the host to apply IPtables rules\", \"no_log\": true, \"shell\": \"puppet apply {{ (puppet_debug|bool) | ternary(\'--debug --verbose\', \'\') }} --detailed-exitcodes --summarize --color=false \\\\\\n    --modulepath \'{{ puppet_modulepath }}\' --tags \'{{ puppet_tags }}\' -e \'{{ puppet_execute }}\'\\n\", \"register\": \"puppet_host_outputs\", \"changed_when\": \"puppet_host_outputs.rc == 2\", \"failed_when\": false, \"vars\": {\"puppet_execute\": \"if hiera(\'enable_load_balancer\', true) { class {\'::tripleo::haproxy\': use_internal_certificates => false, manage_firewall => hiera(\'tripleo::firewall::manage_firewall\', true), }}\", \"puppet_tags\": \"tripleo::firewall::rule\", \"puppet_modulepath\": \"/etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules\", \"puppet_debug\": {\"get_param\": \"ConfigDebug\"}}}, {\"name\": \"Debug output for task: Run puppet on the host to apply IPtables rules\", \"debug\": {\"var\": \"puppet_host_outputs.stdout_lines | default([]) | union(puppet_host_outputs.stderr_lines | default([]))\"}, \"when\": [\"not (ansible_check_mode | bool)\", \"puppet_host_outputs.rc is defined\"], \"failed_when\": \"puppet_host_outputs.rc not in [0, 2]\"}]]}, \"metadata_settings\": {\"get_attr\": [\"HAProxyBase\", \"role_data\", \"metadata_settings\"]}, \"deploy_steps_tasks\": {\"list_concat\": [[{\"name\": \"Configure rsyslog for HAproxy container managed by Pacemaker\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Check if rsyslog exists\", \"shell\": \"systemctl is-active rsyslog\", \"register\": \"rsyslog_config\"}, {\"when\": [\"rsyslog_config is changed\", \"rsyslog_config.rc == 0\"], \"block\": [{\"name\": \"Forward logging to haproxy.log file\", \"blockinfile\": {\"content\": \"if $syslogfacility-text == \'{{facility}}\' and $programname == \'haproxy\' then -/var/log/containers/haproxy/haproxy.log\\n& stop\\n\", \"create\": true, \"path\": \"/etc/rsyslog.d/openstack-haproxy.conf\"}, \"vars\": {\"facility\": {\"get_param\": \"HAProxySyslogFacility\"}}, \"register\": \"logconfig\"}, {\"name\": \"restart rsyslog service after logging conf change\", \"service\": {\"name\": \"rsyslog\", \"state\": \"restarted\"}, \"when\": \"logconfig is changed\"}]}]}, {\"name\": \"HAproxy tag container image for pacemaker\", \"when\": \"step|int == 1\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"container_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/haproxy:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}}}, {\"name\": \"HAproxy HA Wrappers Step\", \"when\": \"step|int == 2\", \"block\": [{\"name\": \"HAproxy puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"haproxy\", \"tripleo_ha_wrapper_resource_name\": \"haproxy-bundle\", \"tripleo_ha_wrapper_bundle_name\": \"haproxy-bundle\", \"tripleo_ha_wrapper_resource_state\": \"Started\", \"tripleo_ha_wrapper_puppet_config_volume\": \"haproxy\", \"tripleo_ha_wrapper_puppet_execute\": \"include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::haproxy_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".previous_run\"}}]}], {\"if\": [\"public_tls_enabled\", {\"get_attr\": [\"HAProxyPublicTLS\", \"role_data\", \"deploy_steps_tasks\"]}, []]}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"get_attr\": [\"HAProxyInternalTLS\", \"role_data\", \"deploy_steps_tasks\"]}]}]}, \"external_update_tasks\": [{\"when\": \"step|int == 1\", \"tags\": \"ha_image_update\", \"block\": [{\"block\": [{\"name\": \"Get haproxy image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_haproxy_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'haproxy-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container haproxy image\", \"set_fact\": {\"haproxy_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"haproxy_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/haproxy:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_haproxy_image\": \"{{xmllint_pcmk_haproxy_image.stdout}}\"}}], \"delegate_to\": \"{{ (groups[\\\"haproxy\\\"] | difference(groups[\\\"excluded_overcloud\\\"]))[0] }}\"}, {\"name\": \"haproxy temporary pacemaker container tag in case of image switch\", \"become\": true, \"import_role\": {\"name\": \"tripleo_ha_image_update\"}, \"vars\": {\"tripleo_ha_image_update_node_names\": \"{{ groups[\\\"haproxy\\\"] | difference(groups[\\\"excluded_overcloud\\\"]) }}\", \"tripleo_ha_image_update_bundle\": \"haproxy-bundle\", \"tripleo_ha_image_update_new_image\": \"{{haproxy_image_latest}}\", \"tripleo_ha_image_update_old_image\": \"{{pcmk_haproxy_image}}\"}, \"when\": [\"(pcmk_haproxy_image != \\\"\\\")\", \"(pcmk_haproxy_image != haproxy_image_latest)\"]}]}], \"update_tasks\": [{\"block\": [{\"name\": \"Get haproxy image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_haproxy_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'haproxy-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container haproxy image\", \"set_fact\": {\"haproxy_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"haproxy_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/haproxy:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_haproxy_image\": \"{{xmllint_pcmk_haproxy_image.stdout}}\"}}], \"when\": \"(step|int == 0 or step|int == 2)\"}, {\"name\": \"Check for update of haproxy container image name\", \"when\": \"step|int == 0\", \"assert\": {\"that\": \"pcmk_haproxy_image == haproxy_image_latest\", \"fail_msg\": \"haproxy image change detected, run overcloud external-update --tags ha_image_update first\"}}, {\"name\": \"Tear-down non-HA haproxy container\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Remove non-HA haproxy container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"haproxy\"]}}]}, {\"name\": \"Set HAProxy upgrade facts\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"set is_haproxy_bootstrap_node fact\", \"tags\": \"common\", \"set_fact\": \"is_haproxy_bootstrap_node={{haproxy_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower}}\", \"when\": [\"haproxy_short_bootstrap_node_name|default(false)\"]}]}, {\"name\": \"Mount TLS cert if needed\", \"when\": [\"step|int == 1\", \"is_haproxy_bootstrap_node\"], \"block\": [{\"name\": \"Check haproxy public certificate configuration in pacemaker\", \"command\": \"cibadmin --query --xpath \\\"//storage-mapping[@id=\'haproxy-cert\']\\\"\", \"failed_when\": false, \"register\": \"haproxy_cert_mounted\"}, {\"name\": \"Disable the haproxy cluster resource\", \"pacemaker_resource\": {\"resource\": \"haproxy-bundle\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\", \"when\": \"haproxy_cert_mounted.rc == 6\"}, {\"name\": \"Set HAProxy public cert volume mount fact\", \"set_fact\": {\"haproxy_public_cert_path\": {\"get_param\": \"DeployedSSLCertificatePath\"}, \"haproxy_public_tls_enabled\": {\"if\": [\"public_tls_enabled\", true, false]}}}, {\"name\": \"Add a bind mount for public certificate in the haproxy bundle\", \"command\": \"pcs resource bundle update haproxy-bundle storage-map add id=haproxy-cert source-dir={{ haproxy_public_cert_path }} target-dir=/var/lib/kolla/config_files/src-tls/{{ haproxy_public_cert_path }} options=ro\", \"when\": \"haproxy_cert_mounted.rc == 6 and haproxy_public_tls_enabled|bool\"}, {\"name\": \"Enable the haproxy cluster resource\", \"pacemaker_resource\": {\"resource\": \"haproxy-bundle\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\", \"when\": \"haproxy_cert_mounted.rc == 6\"}]}, {\"name\": \"Haproxy fetch and retag container image for pacemaker\", \"tags\": \"haproxy_syn_block\", \"when\": [\"step|int == 2\"], \"block\": [{\"name\": \"Retag pcmklatest to latest haproxy image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{haproxy_image}}\", \"container_image_latest\": \"{{haproxy_image_latest}}\"}}]}, {\"name\": \"Move virtual IPs to another node before stopping pacemaker\", \"when\": [\"step|int == 1\", \"hostvars[inventory_hostname][\\\"haproxy_node_names\\\"]|default([])|length > 1\"], \"shell\": \"CLUSTER_NODE=$(crm_node -n)\\necho \\\"Retrieving all the VIPs which are hosted on this node\\\"\\nVIPS_TO_MOVE=$(crm_mon --as-xml | xmllint --xpath \'//resource[@resource_agent=\\\"ocf:heartbeat:IPaddr2\\\" and @role = \\\"Started\\\" and @managed = \\\"true\\\" and ./node[@name = \\\"\'${CLUSTER_NODE}\'\\\"]]/@id\' - | sed -e \'s/id=//g\' -e \'s/\\\"//g\')\\nfor v in ${VIPS_TO_MOVE}; do\\n    echo \\\"Moving VIP $v on another node\\\"\\n    pcs resource ban $v ${CLUSTER_NODE} --wait=300\\ndone\\necho \\\"Removing the location constraints that were created to move the VIPs\\\"\\nfor v in ${VIPS_TO_MOVE}; do\\n    echo \\\"Removing location ban for VIP $v\\\"\\n    ban_id=$(cibadmin --query | xmllint --xpath \'string(//rsc_location[@rsc=\\\"\'${v}\'\\\" and @node=\\\"\'${CLUSTER_NODE}\'\\\" and @score=\\\"-INFINITY\\\"]/@id)\' -)\\n    if [ -n \\\"$ban_id\\\" ]; then\\n        pcs constraint remove ${ban_id}\\n    else\\n        echo \\\"Could not retrieve and clear location constraint for VIP $v\\\" 2>&1\\n    fi\\ndone\\n\"}, {\"name\": \"Wait for 10s to settle connections on new VIPs\", \"wait_for\": {\"timeout\": 10}, \"when\": [\"step|int == 1\", \"hostvars[inventory_hostname][\\\"haproxy_node_names\\\"]|default([])|length > 1\"]}, {\"name\": \"Block local INPUT SYN packets on the backends except mysql\", \"tags\": \"haproxy_syn_block\", \"when\": [\"step|int == 1\"], \"shell\": \"# server controller-0.storage.redhat.local 172.17.3.93:8080 check fall 5 inter 2000 rise 2\\n# server controller-0.internalapi.redhat.local fd00:fd00:fd00:2000::176:9292 check fall 5 inter 2000 rise 2\\nset -o pipefail\\nsource /etc/os-release; test  \\\"${VERSION_ID%*}\\\" = \\\"9.0\\\" && exit 0\\ngrep {{ ansible_facts[\\\"hostname\\\"]|lower }} /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg  | grep -v \\\":3306 \\\" | \\\\\\nawk \'{print $3}\' | \\\\\\nwhile read BACKEND; do\\n    IP=${BACKEND%:*}\\n    PORT=${BACKEND#\\\"$IP:\\\"}\\n    if [[ $IP =~ .*:.* ]]\\n      then PROTOCOL=\\\"ip6\\\"\\n      else PROTOCOL=\\\"ip\\\"\\n    fi\\necho \\\"insert rule $PROTOCOL filter INPUT $PROTOCOL daddr $IP tcp dport $PORT tcp flags syn / fin,syn,rst,ack meta time\\\"\\ndone | xargs -i nft {} $(date +%s)-$(date -d\'+20 minutes\' +%s) counter drop comment \\\"{{ ansible_facts[\\\"hostname\\\"]|lower }}_haproxy_drop\\\"\\n\"}, {\"name\": \"Generate block for other nodes OUTPUT SYN packets on the backends except mysql\", \"tags\": \"haproxy_syn_block\", \"when\": [\"step|int == 1\"], \"shell\": \"set -o pipefail\\nsource /etc/os-release; test  \\\"${VERSION_ID%*}\\\" = \\\"9.0\\\" && exit 0\\ngrep {{ ansible_facts[\\\"hostname\\\"]|lower }} /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg  | grep -v \\\":3306 \\\" | \\\\\\nawk \'{print $3}\' | \\\\\\nwhile read BACKEND; do\\n    IP=${BACKEND%:*}\\n    PORT=${BACKEND#\\\"$IP:\\\"}\\n    if [[ $IP =~ .*:.* ]]\\n      then PROTOCOL=\\\"ip6\\\"\\n      else PROTOCOL=\\\"ip\\\"\\n    fi\\n echo \\\"nft insert rule $PROTOCOL \\\\$TABLE OUTPUT $PROTOCOL daddr $IP tcp dport $PORT tcp flags syn / fin,syn,rst,ack meta time $(date +%s)-$(date -d\'+20 minutes\' +%s) counter drop comment \\\\\\\"{{ ansible_facts[\\\"hostname\\\"]|lower }}_haproxy_drop\\\\\\\" \\\"\\ndone\\n\", \"register\": \"haproxy_iptables_block\"}, {\"name\": \"Block OUTPUT SYN packets to this node on other haproxy nodes\", \"tags\": \"haproxy_syn_block\", \"delegate_to\": \"{{ item }}\", \"when\": [\"step|int == 1\"], \"shell\": \"set -o pipefail\\ngrep {{ ansible_facts[\\\"hostname\\\"]|lower }} /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg | head -n 1 \\\\\\nawk \'{print $3}\' | while read BACKEND; do\\n    IP=${BACKEND%:*}\\n    if [[ $IP =~ .*:.* ]]\\n      then PROTOCOL=\\\"ip6\\\"\\n      else PROTOCOL=\\\"ip\\\"\\n    fi\\ndone\\nTABLE=$(nft list tables | grep -q \\\"$PROTOCOL raw\\\" && echo raw || echo filter )\\necho \\\"{{ haproxy_iptables_block.stdout}}\\\" | while read i; do bash -c \\\"$i\\\"; done\\n\", \"loop\": \"{{ groups[\\\"haproxy\\\"] | difference(groups[\\\"excluded_overcloud\\\"]) | difference(ansible_facts[\\\"hostname\\\"]|lower) }}\"}], \"post_update_tasks\": [{\"name\": \"HAProxy bundle post update\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"HAproxy puppet bundle\", \"import_role\": {\"name\": \"tripleo_ha_wrapper\"}, \"vars\": {\"tripleo_ha_wrapper_service_name\": \"haproxy\", \"tripleo_ha_wrapper_resource_name\": \"haproxy-bundle\", \"tripleo_ha_wrapper_bundle_name\": \"haproxy-bundle\", \"tripleo_ha_wrapper_resource_state\": \"Started\", \"tripleo_ha_wrapper_puppet_config_volume\": \"haproxy\", \"tripleo_ha_wrapper_puppet_execute\": \"include ::tripleo::profile::base::pacemaker; include ::tripleo::profile::pacemaker::haproxy_bundle\", \"tripleo_ha_wrapper_puppet_tags\": \"pacemaker::resource::bundle,pacemaker::property,pacemaker::resource::ip,pacemaker::resource::ocf,pacemaker::constraint::order,pacemaker::constraint::colocation\", \"tripleo_ha_wrapper_puppet_debug\": {\"get_param\": \"ConfigDebug\"}, \"tripleo_ha_wrapper_config_suffix\": \".previous_run\"}}], \"vars\": {\"tripleo_ha_wrapper_minor_update\": true}}, {\"name\": \"Cleanup local SYN DROP rules\", \"tags\": \"haproxy_syn_block\", \"when\": \"step|int == 1\", \"shell\": \"nft -a list chain filter INPUT | grep {{ ansible_facts[\\\"hostname\\\"]|lower }} | grep haproxy_drop | \\\\\\nawk -F# \'{print \\\"nft delete rule filter INPUT \\\"$2}\' | \\\\\\nwhile read i; do bash -c \\\"$i\\\"; done\\n\"}, {\"name\": \"Cleanup SYN DROP rules from other haproxy nodes\", \"tags\": \"haproxy_syn_block\", \"when\": \"step|int == 1\", \"delegate_to\": \"{{ item }}\", \"loop\": \"{{ groups[\\\"haproxy\\\"] | difference(groups[\\\"excluded_overcloud\\\"]) | difference(ansible_facts[\\\"hostname\\\"]|lower) }}\", \"shell\": \"nft -a list chain raw OUTPUT | grep {{ ansible_facts[\\\"hostname\\\"]|lower }} | grep haproxy_drop | \\\\\\nawk -F# \'{print \\\"nft delete rule raw OUTPUT \\\"$2}\' | \\\\\\nwhile read i; do bash -c \\\"$i\\\"; done\\n\"}], \"upgrade_tasks\": [{\"name\": \"Tear-down non-HA haproxy container\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Remove non-HA haproxy container\", \"include_role\": {\"name\": \"tripleo_container_rm\"}, \"vars\": {\"tripleo_container_cli\": \"{{ container_cli }}\", \"tripleo_containers_to_rm\": [\"haproxy\"]}}]}, {\"name\": \"Prepare switch of haproxy image name\", \"when\": [\"step|int == 0\"], \"block\": [{\"name\": \"Get haproxy image id currently used by pacemaker\", \"shell\": \"pcs resource config haproxy-bundle | grep -Eo \'image=[^ ]+\' | awk -F= \'{print $2;}\'\", \"register\": \"haproxy_image_current_res\", \"failed_when\": false}, {\"name\": \"Image facts for haproxy\", \"set_fact\": {\"haproxy_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/haproxy:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"haproxy_image_current\": \"{{haproxy_image_current_res.stdout}}\"}}, {\"name\": \"Temporarily tag the current haproxy image id with the upgraded image name\", \"import_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{haproxy_image_current}}\", \"container_image_latest\": \"{{haproxy_image_latest}}\", \"pull_image\": false}, \"when\": [\"haproxy_image_current != \'\'\", \"haproxy_image_current != haproxy_image_latest\"]}, {\"name\": \"Create haproxy retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/haproxy_needs_retag\", \"state\": \"touch\"}, \"when\": [\"haproxy_image_current != \'\'\", \"haproxy_image_current != haproxy_image_latest\"]}]}, {\"name\": \"Update haproxy pcs resource bundle for new container image\", \"when\": [\"step|int == 1\"], \"block\": [{\"name\": \"Set upgrade haproxy facts\", \"set_fact\": {\"is_haproxy_bootstrap_node\": \"{{haproxy_short_bootstrap_node_name|lower == ansible_facts[\'hostname\']|lower}}\"}}, {\"name\": \"Check for haproxy retag statefile\", \"stat\": {\"path\": \"/var/lib/tripleo/haproxy_needs_retag\"}, \"register\": \"haproxy_retag_state_file\"}]}, {\"name\": \"Update haproxy pcs resource bundle for new container image\", \"when\": [\"step|int == 1\", \"is_haproxy_bootstrap_node|bool\", \"haproxy_retag_state_file.stat.exists|bool\"], \"block\": [{\"name\": \"Disable the haproxy cluster resource before container upgrade\", \"pacemaker_resource\": {\"resource\": \"haproxy-bundle\", \"state\": \"disable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Expose HAProxy stats socket on the host and mount TLS cert if needed\", \"block\": [{\"name\": \"Check haproxy stats socket configuration in pacemaker\", \"command\": \"cibadmin --query --xpath \\\"//storage-mapping[@id=\'haproxy-var-lib\']\\\"\", \"failed_when\": false, \"register\": \"haproxy_stats_exposed\"}, {\"name\": \"Check haproxy public certificate configuration in pacemaker\", \"command\": \"cibadmin --query --xpath \\\"//storage-mapping[@id=\'haproxy-cert\']\\\"\", \"failed_when\": false, \"register\": \"haproxy_cert_mounted\"}, {\"name\": \"Add a bind mount for stats socket in the haproxy bundle\", \"command\": \"pcs resource bundle update haproxy-bundle storage-map add id=haproxy-var-lib source-dir=/var/lib/haproxy target-dir=/var/lib/haproxy options=rw\", \"when\": \"haproxy_stats_exposed.rc == 6\"}, {\"name\": \"Set HAProxy public cert volume mount fact\", \"set_fact\": {\"haproxy_public_cert_path\": {\"get_param\": \"DeployedSSLCertificatePath\"}, \"haproxy_public_tls_enabled\": {\"if\": [\"public_tls_enabled\", true, false]}}}, {\"name\": \"Add a bind mount for public certificate in the haproxy bundle\", \"command\": \"pcs resource bundle update haproxy-bundle storage-map add id=haproxy-cert source-dir={{ haproxy_public_cert_path }} target-dir=/var/lib/kolla/config_files/src-tls/{{ haproxy_public_cert_path }} options=ro\", \"when\": [\"haproxy_cert_mounted.rc == 6\", \"haproxy_public_tls_enabled|bool\"]}]}, {\"name\": \"Update the haproxy bundle to use the new container image name\", \"command\": \"pcs resource bundle update haproxy-bundle container image={{haproxy_image_latest}}\"}, {\"name\": \"Enable the haproxy cluster resource\", \"pacemaker_resource\": {\"resource\": \"haproxy-bundle\", \"state\": \"enable\", \"wait_for_resource\": true}, \"register\": \"output\", \"retries\": 5, \"until\": \"output.rc == 0\"}, {\"name\": \"Remove haproxy retag statefile\", \"file\": {\"path\": \"/var/lib/tripleo/haproxy_needs_retag\", \"state\": \"absent\"}}]}, {\"name\": \"Retag the pacemaker image if containerized\", \"when\": [\"step|int == 3\"], \"block\": [{\"block\": [{\"name\": \"Get haproxy image from pacemaker\", \"become\": true, \"register\": \"xmllint_pcmk_haproxy_image\", \"shell\": \"xmllint --xpath \\\"string(//bundle[@id=\'haproxy-bundle\']/podman/@image)\\\" /var/lib/pacemaker/cib/cib.xml\"}, {\"name\": \"Get container haproxy image\", \"set_fact\": {\"haproxy_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"haproxy_image_latest\": {\"if\": [{\"get_param\": \"ClusterFullTag\"}, \"cluster.common.tag/haproxy:pcmklatest\", {\"yaql\": {\"data\": {\"if\": [{\"get_param\": \"ClusterCommonTag\"}, {\"yaql\": {\"data\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"expression\": \"concat(\\\"cluster.common.tag/\\\", $.data.rightSplit(separator => \\\"/\\\", maxSplits => 1)[1])\"}}, {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}]}, \"expression\": \"concat($.data.rightSplit(separator => \\\":\\\", maxSplits => 1)[0], \\\":pcmklatest\\\")\"}}]}, \"pcmk_haproxy_image\": \"{{xmllint_pcmk_haproxy_image.stdout}}\"}}]}, {\"block\": [{\"name\": \"Retag pcmklatest to latest haproxy image\", \"include_role\": {\"name\": \"tripleo_container_tag\"}, \"vars\": {\"container_image\": \"{{haproxy_image}}\", \"container_image_latest\": \"{{haproxy_image_latest}}\"}}]}, {\"name\": \"Ensure config works for the new config\", \"shell\": \"set -o pipefail\\nawk -i inplace -v INPLACE_SUFFIX=.bak \'/  rsprep/ {print \\\"  http-response replace-header Location \\\" $3\\\" \\\"$5; next;}; {print} \' /var/lib/config-data/puppet-generated/haproxy/etc/haproxy/haproxy.cfg\"}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(182,'2026-06-09 08:02:21',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Glance API service\\n\", \"parameters\": {\"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerGlanceApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\"}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerGlanceApiImage\": \"ContainerGlanceApiImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerGlanceApiImage\": {\"get_param\": \"ContainerGlanceApiImage\"}}}]}}}}, \"outputs\": {\"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/glance:/var/log/glance:z\", \"/var/log/containers/httpd/glance:/var/log/httpd:z\"]}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_2\": {\"glance_init_logs\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerGlanceApiImage\"]}, \"net\": \"none\", \"privileged\": false, \"user\": \"root\", \"volumes\": [\"/var/log/containers/glance:/var/log/glance:z\", \"/var/log/containers/httpd/glance:/var/log/httpd:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R glance:glance /var/log/glance\"]}}}}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent logs directory\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/glance\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/log/containers/httpd/glance\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(183,'2026-06-09 08:02:21',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Apache service configured with Puppet. Note this is typically included automatically via other services which run via Apache.\\n\", \"parameters\": {\"ApacheMaxRequestWorkers\": {\"default\": 100, \"description\": \"Maximum number of simultaneously processed requests.\", \"type\": \"number\"}, \"ApacheServerLimit\": {\"default\": 100, \"description\": \"Maximum number of Apache processes.\", \"type\": \"number\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"ApacheCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"ApacheTimeout\": {\"type\": \"number\", \"default\": 90, \"description\": \"The timeout in seconds for Apache, which defines duration Apache waits for I/O operations\"}}, \"conditions\": {\"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"ApacheCertificateKeySize\"}, \"\"]}}}, \"resources\": {\"ApacheNetworks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"Controller\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"CellController\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"CellControllerCompute\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"Compute\": [\"ctlplane\", \"storage\", \"internal_api\"], \"BlockStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"ObjectStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"CephStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\"], \"Networker\": [\"ctlplane\", \"internal_api\"]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Apache role.\", \"value\": {\"service_name\": \"apache\", \"config_settings\": {\"map_merge\": [{\"apache::ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}}}}, \"apache::default_vhost\": false, \"apache::trace_enable\": \"Off\", \"apache::server_signature\": \"Off\", \"apache::server_tokens\": \"Prod\", \"apache::timeout\": {\"get_param\": \"ApacheTimeout\"}, \"apache::default_mods\": false, \"apache::mod::prefork::maxrequestworkers\": {\"get_param\": \"ApacheMaxRequestWorkers\"}, \"apache::mod::prefork::serverlimit\": {\"get_param\": \"ApacheServerLimit\"}, \"apache::mod::remoteip::proxy_ips\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}]}, \"apache::mod::alias::icons_options\": \"None\"}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"apache::mod::ssl::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}, \"apache::mod::ssl::ssl_protocol\": [\"all\", \"-SSLv2\", \"-SSLv3\", \"-TLSv1\"], \"apache_certificates_specs\": {\"map_merge\": {\"repeat\": {\"template\": {\"httpd-NETWORK\": {\"service_certificate\": \"/etc/pki/tls/certs/httpd/httpd-NETWORK.crt\", \"service_key\": \"/etc/pki/tls/private/httpd/httpd-NETWORK.key\"}}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}, \"metadata_settings\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"repeat\": {\"template\": [{\"service\": \"HTTP\", \"network\": \"$NETWORK\", \"type\": \"node\"}], \"for_each\": {\"$NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}]}, \"upgrade_tasks\": [], \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [\"/etc/pki/tls/certs/httpd\", \"/etc/pki/tls/private/httpd\"]}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": {\"repeat\": {\"template\": {\"name\": \"httpd-NETWORK\", \"dns\": \"{{ fqdn_NETWORK }}\", \"principal\": \"HTTP/{{ fqdn_NETWORK }}@{{ idm_realm }}\", \"run_after\": \"cp /etc/pki/tls/certs/httpd-NETWORK.crt /etc/pki/tls/certs/httpd/httpd-NETWORK.crt\\ncp /etc/pki/tls/private/httpd-NETWORK.key /etc/pki/tls/private/httpd/httpd-NETWORK.key\\npkill -USR1 httpd\\n\", \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"ApacheCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"EnableInternalTLS\": true}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(184,'2026-06-09 08:02:21',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized HAproxy service\\n\", \"parameters\": {\"ContainerHAProxyImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\"}, \"ContainerHAProxyConfigImage\": {\"description\": \"The container image to use for the haproxy config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"HAProxyStatsPassword\": {\"description\": \"Password for HAProxy stats endpoint\", \"hidden\": true, \"type\": \"string\", \"default\": \"UfhE8R9DggTnnqHWkS53kenTr\"}, \"HAProxyStatsUser\": {\"description\": \"User for HAProxy stats endpoint\", \"default\": \"admin\", \"type\": \"string\"}, \"HAProxyLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.haproxy\", \"file\": \"/var/log/containers/haproxy/haproxy.log\", \"startmsg.regex\": \"^[a-zA-Z]{3} [ 123][0-9] [:0-9]{8}\"}}, \"HAProxySyslogAddress\": {\"default\": \"/dev/log\", \"description\": \"Syslog address where HAproxy will send its log\", \"type\": \"string\"}, \"HAProxySyslogFacility\": {\"default\": \"local0\", \"description\": \"Syslog facility HAProxy will use for its logs\", \"type\": \"string\"}, \"SSLCertificate\": {\"default\": \"\", \"description\": \"The content of the SSL certificate (without Key) in PEM format.\\n\", \"type\": \"string\"}, \"PublicSSLCertificateAutogenerated\": {\"default\": true, \"description\": \"Whether the public SSL certificate was autogenerated or not.\\n\", \"type\": \"boolean\"}, \"EnablePublicTLS\": {\"default\": true, \"description\": \"Whether to enable TLS on the public interface or not.\\n\", \"type\": \"boolean\"}, \"DeployedSSLCertificatePath\": {\"default\": \"/etc/pki/tls/private/overcloud_endpoint.pem\", \"description\": \"The filepath of the certificate as it will be stored in the controller.\\n\", \"type\": \"string\"}, \"RedisPassword\": {\"description\": \"The password for the redis service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"Qw5poqjrA95kbXlQw5cMcjZDa\"}, \"MonitoringSubscriptionHaproxy\": {\"default\": \"overcloud-haproxy\", \"type\": \"string\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"ConfigDebug\": {\"default\": false, \"description\": \"Whether to run config management (e.g. Puppet) in debug mode.\", \"type\": \"boolean\"}, \"EnableLoadBalancer\": {\"default\": true, \"description\": \"Whether to deploy a LoadBalancer, set to false when an external load balancer is used.\", \"type\": \"boolean\"}, \"HAProxyStatsEnabled\": {\"default\": true, \"description\": \"Whether or not to enable the HAProxy stats interface.\", \"type\": \"boolean\"}, \"InternalTLSCRLPEMFile\": {\"default\": \"/etc/pki/CA/crl/overcloud-crl.pem\", \"type\": \"string\", \"description\": \"Specifies the default CRL PEM file to use for revocation if TLS is used for services in the internal network.\"}, \"InternalTLSCRLPEMDir\": {\"default\": \"/etc/pki/CA/crl/\", \"type\": \"string\", \"description\": \"The directory of the CRL PEM file to be mounted.\"}}, \"conditions\": {\"public_tls_enabled\": {\"and\": [{\"get_param\": \"EnablePublicTLS\"}, {\"or\": [{\"not\": {\"equals\": [{\"get_param\": \"SSLCertificate\"}, \"\"]}}, {\"get_param\": \"PublicSSLCertificateAutogenerated\"}]}]}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"HAProxyLogging\": {\"type\": \"OS::TripleO::Services::Logging::HAProxy\"}, \"HAProxyPublicTLS\": {\"type\": \"OS::TripleO::Services::HAProxyPublicTLS\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"HAProxyInternalTLS\": {\"type\": \"OS::TripleO::Services::HAProxyInternalTLS\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerHAProxyImage\": \"ContainerHAProxyImage\", \"ContainerHAProxyConfigImage\": \"ContainerHAProxyConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerHAProxyImage\": {\"get_param\": \"ContainerHAProxyImage\"}, \"ContainerHAProxyConfigImage\": {\"get_param\": \"ContainerHAProxyConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the HAproxy role.\", \"value\": {\"service_name\": \"haproxy\", \"firewall_rules\": {\"107 haproxy stats\": {\"dport\": 1993}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionHaproxy\"}, \"ansible_group_vars\": {\"tripleo_firewall_frontend_enabled\": true, \"tripleo_firewall_ssl_frontend_enabled\": {\"if\": [\"public_tls_enabled\", true]}}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"HAProxyLogging\", \"config_settings\"]}, {\"tripleo::haproxy::haproxy_service_manage\": false, \"tripleo::haproxy::haproxy_log_address\": {\"get_param\": \"HAProxySyslogAddress\"}, \"tripleo::haproxy::haproxy_log_facility\": {\"get_param\": \"HAProxySyslogFacility\"}, \"tripleo::haproxy::haproxy_stats_user\": {\"get_param\": \"HAProxyStatsUser\"}, \"tripleo::haproxy::haproxy_stats_password\": {\"get_param\": \"HAProxyStatsPassword\"}, \"tripleo::haproxy::haproxy_stats_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HaproxyNetwork\"]}}}}, \"tripleo::haproxy::redis_password\": {\"get_param\": \"RedisPassword\"}, \"tripleo::haproxy::crl_file\": null, \"tripleo::haproxy::haproxy_stats\": {\"get_param\": \"HAProxyStatsEnabled\"}, \"enable_load_balancer\": {\"get_param\": \"EnableLoadBalancer\"}, \"tripleo::profile::base::haproxy::certificates_specs\": {\"map_merge\": [{\"get_attr\": [\"HAProxyPublicTLS\", \"role_data\", \"certificates_specs\"]}, {\"get_attr\": [\"HAProxyInternalTLS\", \"role_data\", \"certificates_specs\"]}]}, \"tripleo::haproxy::service_certificate\": {\"if\": [\"public_tls_enabled\", {\"get_param\": \"DeployedSSLCertificatePath\"}]}, \"tripleo::haproxy::ca_bundle\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"get_param\": \"InternalTLSCAFile\"}]}}, {\"get_attr\": [\"HAProxyPublicTLS\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"HAProxyInternalTLS\", \"role_data\", \"config_settings\"]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_haproxy\": [{\"get_param\": \"HAProxyLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"haproxy\", \"puppet_tags\": \"haproxy_config\", \"step_config\": \"class {\'tripleo::profile::base::haproxy\': manage_firewall => false}\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyConfigImage\"]}, \"volumes\": {\"list_concat\": [{\"if\": [\"public_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"DeployedSSLCertificatePath\"}, {\"get_param\": \"DeployedSSLCertificatePath\"}, \"ro,shared\"]]}]]}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/haproxy:/etc/pki/tls/certs/haproxy:ro,shared\", \"/etc/pki/tls/private/haproxy:/etc/pki/tls/private/haproxy:ro,shared\", {\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro,shared\"]]}, {\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCRLPEMDir\"}, {\"get_param\": \"InternalTLSCRLPEMDir\"}, \"ro,shared\"]]}]]}]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/haproxy.json\": {\"command\": \"bash -c $* -- eval if [ -f /usr/sbin/haproxy-systemd-wrapper ]; then exec /usr/sbin/haproxy-systemd-wrapper -f /etc/haproxy/haproxy.cfg; else exec /usr/sbin/haproxy -f /etc/haproxy/haproxy.cfg -Ws; fi\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}], \"permissions\": [{\"path\": \"/var/lib/haproxy\", \"owner\": \"haproxy:haproxy\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/haproxy\", \"owner\": \"haproxy:haproxy\", \"recurse\": true, \"optional\": true}]}}, \"container_config_scripts\": {\"get_attr\": [\"ContainersCommon\", \"container_config_scripts\"]}, \"docker_config\": {\"step_1\": {\"map_merge\": [{\"get_attr\": [\"HAProxyLogging\", \"docker_config\", \"step_1\"]}, {\"haproxy\": {\"start_order\": 1, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHAProxyImage\"]}, \"net\": \"host\", \"restart\": \"always\", \"security_opt\": [\"label=disable\"], \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"HAProxyLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/haproxy.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/haproxy:/var/lib/kolla/config_files/src:ro\", \"/var/lib/haproxy:/var/lib/haproxy:rw,z\"], {\"if\": [\"public_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"DeployedSSLCertificatePath\"}, {\"list_join\": [\"\", [\"/var/lib/kolla/config_files/src-tls\", {\"get_param\": \"DeployedSSLCertificatePath\"}]]}, \"ro,shared\"]]}]]}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/haproxy:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/haproxy:ro,shared\", \"/etc/pki/tls/private/haproxy:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/haproxy:ro,shared\", {\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCRLPEMDir\"}, {\"get_param\": \"InternalTLSCRLPEMDir\"}, \"ro\"]]}]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}]}}, \"deploy_steps_tasks\": {\"list_concat\": [[{\"name\": \"Configure rsyslog for HAproxy container\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Check if rsyslog exists\", \"shell\": \"systemctl is-active rsyslog\", \"register\": \"rsyslog_config\"}, {\"when\": [\"rsyslog_config is changed\", \"rsyslog_config.rc == 0\"], \"block\": [{\"name\": \"Forward logging to haproxy.log file\", \"blockinfile\": {\"content\": \"if $syslogfacility-text == \'{{facility}}\' and $programname == \'haproxy\' then -/var/log/containers/haproxy/haproxy.log\\n& stop\\n\", \"create\": true, \"path\": \"/etc/rsyslog.d/openstack-haproxy.conf\"}, \"vars\": {\"facility\": {\"get_param\": \"HAProxySyslogFacility\"}}, \"register\": \"logconfig\"}, {\"name\": \"restart rsyslog service after logging conf change\", \"service\": {\"name\": \"rsyslog\", \"state\": \"restarted\"}, \"when\": \"logconfig is changed\"}]}]}, {\"name\": \"Run puppet on the host to apply IPtables rules\", \"no_log\": true, \"when\": \"step|int == 1\", \"register\": \"puppet_host_outputs\", \"shell\": \"puppet apply {{ (puppet_debug|bool) | ternary(\'--debug --verbose\', \'\') }} --detailed-exitcodes --summarize --color=false \\\\\\n    --modulepath \'{{ puppet_modulepath }}\' --tags \'{{ puppet_tags }}\' -e \'{{ puppet_execute }}\'\\n\", \"changed_when\": \"puppet_host_outputs.rc == 2\", \"failed_when\": false, \"vars\": {\"puppet_execute\": \"include tripleo::profile::base::haproxy\", \"puppet_tags\": \"tripleo::firewall::rule\", \"puppet_modulepath\": \"/etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules\", \"puppet_debug\": {\"get_param\": \"ConfigDebug\"}}}, {\"name\": \"Debug output for task: Run puppet on the host to apply IPtables rules\", \"debug\": {\"var\": \"puppet_host_outputs.stdout_lines | default([]) | union(puppet_host_outputs.stderr_lines | default([]))\"}, \"when\": [\"not (ansible_check_mode | bool)\", \"puppet_host_outputs.rc is defined\"], \"failed_when\": \"puppet_host_outputs.rc not in [0, 2]\"}], {\"if\": [\"public_tls_enabled\", {\"get_attr\": [\"HAProxyPublicTLS\", \"role_data\", \"deploy_steps_tasks\"]}]}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"get_attr\": [\"HAProxyInternalTLS\", \"role_data\", \"deploy_steps_tasks\"]}]}]}, \"upgrade_tasks\": [{\"name\": \"ensure we have haproxy log dir with the correct setype\", \"file\": {\"path\": \"/var/log/containers/haproxy\", \"state\": \"directory\", \"setype\": \"var_log_t\", \"recurse\": true}, \"when\": \"step|int == 1\"}], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop haproxy container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"haproxy\"], \"tripleo_delegate_to\": \"{{ groups[\'haproxy\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}], \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HAProxyPublicTLS\", \"role_data\", \"host_prep_tasks\"]}, [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/haproxy\", \"setype\": \"var_log_t\", \"mode\": \"0750\"}, {\"path\": \"/var/lib/haproxy\", \"setype\": \"container_file_t\"}]}]]}, \"metadata_settings\": {\"list_concat\": [{\"get_attr\": [\"HAProxyPublicTLS\", \"role_data\", \"metadata_settings\"]}, {\"get_attr\": [\"HAProxyInternalTLS\", \"role_data\", \"metadata_settings\"]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(185,'2026-06-09 08:02:21',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (186,'2026-06-09 08:02:21',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"HAProxy deployment with TLS enabled, powered by certmonger\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"HAProxyInternalTLSCertsDirectory\": {\"default\": \"/etc/pki/tls/certs/haproxy\", \"type\": \"string\"}, \"HAProxyInternalTLSKeysDirectory\": {\"default\": \"/etc/pki/tls/private/haproxy\", \"type\": \"string\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"HAProxyCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}}, \"conditions\": {\"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"HAProxyCertificateKeySize\"}, \"\"]}}}, \"resources\": {\"HAProxyNetworks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"Controller\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"]}}}, \"CellController\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"]}}}, \"CellControllerCompute\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"]}}}, \"Compute\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"storage\", \"internal_api\"]}}}, \"BlockStorage\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"]}}}, \"ObjectStorage\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"]}}}, \"CephStorage\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\"]}}}, \"Networker\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"internal_api\"]}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the HAProxy internal TLS via certmonger role.\", \"value\": {\"service_name\": \"haproxy_internal_tls_certmonger\", \"config_settings\": {\"tripleo::haproxy::use_internal_certificates\": true}, \"certificates_specs\": {\"map_merge\": {\"repeat\": {\"template\": {\"haproxy-NETWORK\": {\"service_pem\": {\"list_join\": [\"\", [{\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}, \"/overcloud-haproxy-NETWORK.pem\"]]}}}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"HAProxyNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}, \"metadata_settings\": {\"repeat\": {\"template\": [{\"service\": \"haproxy\", \"network\": \"$NETWORK\", \"type\": \"vip\"}, {\"service\": \"haproxy\", \"network\": \"$NETWORK\", \"type\": \"node\"}], \"for_each\": {\"$NETWORK\": {\"get_attr\": [\"HAProxyNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}, \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [{\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}, {\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}]}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": {\"repeat\": {\"template\": {\"name\": \"haproxy-NETWORK-cert\", \"dns\": [\"{{fqdn_NETWORK}}\", \"{{cloud_names.cloud_name_NETWORK}}\"], \"principal\": \"haproxy/{{fqdn_NETWORK}}@{{idm_realm}}\", \"run_after\": {\"str_replace\": {\"template\": \"# Copy crt and key for backward compatibility\\ncp \\\"/etc/pki/tls/certs/haproxy-NETWORK-cert.crt\\\" \\\"CERTSDIR/overcloud-haproxy-NETWORK.crt\\\"\\ncp \\\"/etc/pki/tls/private/haproxy-NETWORK-cert.key\\\" \\\"KEYSDIR/overcloud-haproxy-NETWORK.key\\\"\\n\\nca_path=\\\"/etc/ipa/ca.crt\\\"\\nservice_crt=\\\"CERTSDIR/overcloud-haproxy-NETWORK.crt\\\"\\nservice_key=\\\"KEYSDIR/overcloud-haproxy-NETWORK.key\\\"\\nservice_pem=\\\"CERTSDIR/overcloud-haproxy-NETWORK.pem\\\"\\n\\ncat \\\"$service_crt\\\" \\\"$ca_path\\\" \\\"$service_key\\\" > \\\"$service_pem\\\"\\n\\ncontainer_name=$({{container_cli}} ps --format=\\\\{\\\\{.Names\\\\}\\\\} | grep -w -E \'haproxy(-bundle-.*-[0-9]+)?\')\\n# Inject the new pem into the running container\\nif echo \\\"$container_name\\\" | grep -q \\\"^haproxy-bundle\\\"; then\\n  # lp#1917868: Do not use podman cp with HA containers as they get\\n  # frozen temporarily and that can make pacemaker operation fail.\\n  tar -c \\\"$service_pem\\\" | {{container_cli}} exec -i \\\"$container_name\\\" tar -C / -xv\\n  # no need to update the mount point, because pacemaker\\n  # recreates the container when it\'s restarted\\nelse\\n  # Refresh the pem at the mount-point\\n  {{container_cli}} cp $service_pem \\\"$container_name:/var/lib/kolla/config_files/src-tls/$service_pem\\\"\\n  # Copy the new pem from the mount-point to the real path\\n  {{container_cli}} exec \\\"$container_name\\\" cp \\\"/var/lib/kolla/config_files/src-tls$service_pem\\\" \\\"$service_pem\\\"\\nfi\\n# Set appropriate permissions\\n{{container_cli}} exec \\\"$container_name\\\" chown haproxy:haproxy \\\"$service_pem\\\"\\n# Trigger a reload for HAProxy to read the new certificates\\n{{container_cli}} kill --signal HUP \\\"$container_name\\\"\\n\", \"params\": {\"CERTSDIR\": {\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}, \"KEYSDIR\": {\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}}}}, \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"HAProxyCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"HAProxyNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(187,'2026-06-09 08:02:22',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(188,'2026-06-09 08:02:22',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(189,'2026-06-09 08:02:22',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Heat CloudWatch API service, disabled by default since Pike\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the disabled Heat CloudWatch API\", \"value\": {\"service_name\": \"heat_api_cloudwatch_disabled\", \"upgrade_tasks\": []}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(190,'2026-06-09 08:02:23',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Cinder NVMeOF backend\\n\", \"parameters\": {\"CinderEnableNVMeOFBackend\": {\"default\": false, \"description\": \"Whether to enable or not the NVMeOF backend for Cinder\", \"type\": \"boolean\"}, \"CinderNVMeOFBackendName\": {\"type\": \"string\", \"default\": \"tripleo_nvmeof\"}, \"CinderNVMeOFAvailabilityZone\": {\"default\": \"\", \"description\": \"The availability zone of the NVMeOF Cinder backend. When set, it overrides the default CinderStorageAvailabilityZone.\\n\", \"type\": \"string\"}, \"CinderNVMeOFTargetPort\": {\"type\": \"number\", \"default\": 4420}, \"CinderNVMeOFTargetHelper\": {\"type\": \"string\", \"default\": \"nvmet\"}, \"CinderNVMeOFTargetProtocol\": {\"type\": \"string\", \"default\": \"nvmet_rdma\", \"description\": \"The target protocol, supported values are nvmet_rdma and nvmet_tcp.\\n\", \"constraints\": [{\"allowed_values\": [\"nvmet_rdma\", \"nvmet_tcp\"]}]}, \"CinderNVMeOFTargetPrefix\": {\"type\": \"string\", \"default\": \"nvme-subsystem\"}, \"CinderNVMeOFTargetPortId\": {\"type\": \"number\", \"default\": 1}, \"CinderNVMeOFTargetNameSpaceId\": {\"type\": \"number\", \"default\": 10}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"type\": \"json\", \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\"}}, \"outputs\": {\"cinder_nvmeof_host_prep_tasks\": {\"description\": \"Host prep tasks related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [{\"name\": \"ensure /etc/nvme exists\", \"file\": {\"path\": \"/etc/nvme\", \"state\": \"directory\", \"setype\": \"container_file_t\"}}]]}}, \"cinder_nvmeof_volumes\": {\"description\": \"Volumes related to cinder\'s NVMeOF backend\", \"value\": {\"if\": [{\"get_param\": \"CinderEnableNVMeOFBackend\"}, [\"/etc/nvme:/etc/nvme:z\"]]}}, \"role_data\": {\"description\": \"Role data for the Cinder NVMeOF backend.\", \"value\": {\"service_name\": \"cinder_backend_nvmeof\", \"firewall_rules\": {\"120 LVM nvmet target\": {\"dport\": {\"get_param\": \"CinderNVMeOFTargetPort\"}}}, \"config_settings\": {\"map_merge\": [{\"tripleo::profile::base::cinder::volume::cinder_enable_nvmeof_backend\": {\"get_param\": \"CinderEnableNVMeOFBackend\"}, \"tripleo::profile::base::cinder::volume::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_port\": {\"get_param\": \"CinderNVMeOFTargetPort\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_helper\": {\"get_param\": \"CinderNVMeOFTargetHelper\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_protocol\": {\"get_param\": \"CinderNVMeOFTargetProtocol\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_prefix\": {\"get_param\": \"CinderNVMeOFTargetPrefix\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_port_id\": {\"get_param\": \"CinderNVMeOFTargetPortId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::nvmet_ns_id\": {\"get_param\": \"CinderNVMeOFTargetNameSpaceId\"}, \"tripleo::profile::base::cinder::volume::nvmeof::target_ip_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"CinderIscsiNetwork\"]}}}}, \"cinder::backend::nvmeof::volume_backend_name\": {\"get_param\": \"CinderNVMeOFBackendName\"}}, {\"if\": [{\"not\": {\"equals\": [{\"get_param\": \"CinderNVMeOFAvailabilityZone\"}, \"\"]}}, {\"tripleo::profile::base::cinder::volume::nvmeof::backend_availability_zone\": {\"get_param\": \"CinderNVMeOFAvailabilityZone\"}}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(191,'2026-06-09 08:02:23',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"HAProxy deployment with TLS enabled, powered by certmonger\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"HAProxyInternalTLSCertsDirectory\": {\"default\": \"/etc/pki/tls/certs/haproxy\", \"type\": \"string\"}, \"HAProxyInternalTLSKeysDirectory\": {\"default\": \"/etc/pki/tls/private/haproxy\", \"type\": \"string\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"HAProxyCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}}, \"conditions\": {\"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"HAProxyCertificateKeySize\"}, \"\"]}}}, \"resources\": {\"HAProxyNetworks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"Controller\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"]}}}, \"CellController\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"]}}}, \"CellControllerCompute\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"]}}}, \"Compute\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"storage\", \"internal_api\"]}}}, \"BlockStorage\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"]}}}, \"ObjectStorage\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"]}}}, \"CephStorage\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"storage\", \"storage_mgmt\"]}}}, \"Networker\": {\"yaql\": {\"expression\": \"let(public_network => $.data.public_network) -> $.data.networks.where($ != $public_network or $ = \'ctlplane\')\", \"data\": {\"public_network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"networks\": [\"ctlplane\", \"internal_api\"]}}}}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the HAProxy internal TLS via certmonger role.\", \"value\": {\"service_name\": \"haproxy_internal_tls_certmonger\", \"config_settings\": {\"tripleo::haproxy::use_internal_certificates\": true}, \"certificates_specs\": {\"map_merge\": {\"repeat\": {\"template\": {\"haproxy-NETWORK\": {\"service_pem\": {\"list_join\": [\"\", [{\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}, \"/overcloud-haproxy-NETWORK.pem\"]]}}}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"HAProxyNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}, \"metadata_settings\": {\"repeat\": {\"template\": [{\"service\": \"haproxy\", \"network\": \"$NETWORK\", \"type\": \"vip\"}, {\"service\": \"haproxy\", \"network\": \"$NETWORK\", \"type\": \"node\"}], \"for_each\": {\"$NETWORK\": {\"get_attr\": [\"HAProxyNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}, \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": \"step|int == 1\", \"block\": [{\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [{\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}, {\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}]}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": {\"repeat\": {\"template\": {\"name\": \"haproxy-NETWORK-cert\", \"dns\": [\"{{fqdn_NETWORK}}\", \"{{cloud_names.cloud_name_NETWORK}}\"], \"principal\": \"haproxy/{{fqdn_NETWORK}}@{{idm_realm}}\", \"run_after\": {\"str_replace\": {\"template\": \"# Copy crt and key for backward compatibility\\ncp \\\"/etc/pki/tls/certs/haproxy-NETWORK-cert.crt\\\" \\\"CERTSDIR/overcloud-haproxy-NETWORK.crt\\\"\\ncp \\\"/etc/pki/tls/private/haproxy-NETWORK-cert.key\\\" \\\"KEYSDIR/overcloud-haproxy-NETWORK.key\\\"\\n\\nca_path=\\\"/etc/ipa/ca.crt\\\"\\nservice_crt=\\\"CERTSDIR/overcloud-haproxy-NETWORK.crt\\\"\\nservice_key=\\\"KEYSDIR/overcloud-haproxy-NETWORK.key\\\"\\nservice_pem=\\\"CERTSDIR/overcloud-haproxy-NETWORK.pem\\\"\\n\\ncat \\\"$service_crt\\\" \\\"$ca_path\\\" \\\"$service_key\\\" > \\\"$service_pem\\\"\\n\\ncontainer_name=$({{container_cli}} ps --format=\\\\{\\\\{.Names\\\\}\\\\} | grep -w -E \'haproxy(-bundle-.*-[0-9]+)?\')\\n# Inject the new pem into the running container\\nif echo \\\"$container_name\\\" | grep -q \\\"^haproxy-bundle\\\"; then\\n  # lp#1917868: Do not use podman cp with HA containers as they get\\n  # frozen temporarily and that can make pacemaker operation fail.\\n  tar -c \\\"$service_pem\\\" | {{container_cli}} exec -i \\\"$container_name\\\" tar -C / -xv\\n  # no need to update the mount point, because pacemaker\\n  # recreates the container when it\'s restarted\\nelse\\n  # Refresh the pem at the mount-point\\n  {{container_cli}} cp $service_pem \\\"$container_name:/var/lib/kolla/config_files/src-tls/$service_pem\\\"\\n  # Copy the new pem from the mount-point to the real path\\n  {{container_cli}} exec \\\"$container_name\\\" cp \\\"/var/lib/kolla/config_files/src-tls$service_pem\\\" \\\"$service_pem\\\"\\nfi\\n# Set appropriate permissions\\n{{container_cli}} exec \\\"$container_name\\\" chown haproxy:haproxy \\\"$service_pem\\\"\\n# Trigger a reload for HAProxy to read the new certificates\\n{{container_cli}} kill --signal HUP \\\"$container_name\\\"\\n\", \"params\": {\"CERTSDIR\": {\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}, \"KEYSDIR\": {\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}}}}, \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"HAProxyCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"HAProxyNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(192,'2026-06-09 08:02:23',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Horizon service\\n\", \"parameters\": {\"ContainerHorizonImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\"}, \"ContainerHorizonConfigImage\": {\"description\": \"The container image to use for the horizon config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"HorizonDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Horizon service.\", \"type\": \"boolean\"}, \"HorizonAllowedHosts\": {\"default\": \"*\", \"description\": \"A list of IP/Hostname for the server Horizon is running on. Used for header checks.\", \"type\": \"comma_delimited_list\"}, \"HorizonPasswordValidator\": {\"description\": \"Regex for password validation\", \"type\": \"string\", \"default\": \"\"}, \"HorizonPasswordValidatorHelp\": {\"description\": \"Help text for password validation\", \"type\": \"string\", \"default\": \"\"}, \"HorizonSecret\": {\"description\": \"Secret key for Django\", \"type\": \"string\", \"hidden\": true, \"default\": \"EnFZnXQGEH\"}, \"HorizonSecureCookies\": {\"description\": \"Set CSRF_COOKIE_SECURE / SESSION_COOKIE_SECURE in Horizon\", \"type\": \"boolean\", \"default\": false}, \"HorizonSessionTimeout\": {\"description\": \"Set session timeout for horizon in seconds\", \"type\": \"number\", \"default\": 1800}, \"MemcachedIPv6\": {\"default\": false, \"description\": \"Enable IPv6 features in Memcached.\", \"type\": \"boolean\"}, \"MonitoringSubscriptionHorizon\": {\"default\": \"overcloud-horizon\", \"type\": \"string\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"HorizonVhostExtraParams\": {\"default\": {\"add_listen\": true, \"priority\": 10, \"access_log_format\": \"%a %l %u %t \\\\\\\"%r\\\\\\\" %>s %b \\\\\\\"%%{}{Referer}i\\\\\\\" \\\\\\\"%%{}{User-Agent}i\\\\\\\"\", \"options\": [\"FollowSymLinks\", \"MultiViews\"]}, \"description\": \"Extra parameters for Horizon vhost configuration\", \"type\": \"json\"}, \"HorizonCustomizationModule\": {\"default\": \"\", \"description\": \"Horizon has a global overrides mechanism available to perform customizations\", \"type\": \"string\"}, \"HorizonHelpURL\": {\"default\": \"http://docs.openstack.org\", \"description\": \"On top of dashboard there is a Help button. This button could be used to re-direct user to vendor documentation or dedicated help portal.\", \"type\": \"string\"}, \"TimeZone\": {\"default\": \"UTC\", \"description\": \"The timezone to be set on the overcloud.\", \"type\": \"string\"}, \"WebSSOEnable\": {\"default\": false, \"type\": \"boolean\", \"description\": \"Enable support for Web Single Sign-On\"}, \"WebSSOInitialChoice\": {\"default\": \"OIDC\", \"type\": \"string\", \"description\": \"The initial authentication choice to select by default\"}, \"WebSSOChoicesHideKeystone\": {\"default\": false, \"type\": \"boolean\", \"description\": \"Hide Keystone crednetials login when WebSSO is enabled.\"}, \"WebSSOChoices\": {\"default\": [[\"OIDC\", \"OpenID Connect\"]], \"type\": \"json\", \"description\": \"Specifies the list of SSO authentication choices to present. Each item is a list of an SSO choice identifier and a display message.\"}, \"WebSSOIDPMapping\": {\"default\": {\"OIDC\": [\"myidp\", \"openid\"]}, \"type\": \"json\", \"description\": \"Specifies a mapping from SSO authentication choice to identity provider and protocol.  The identity provider and protocol names must match the resources defined in keystone.\"}, \"HorizonDomainChoices\": {\"default\": [], \"type\": \"json\", \"description\": \"Specifies available domains to choose from. We expect an array of hashes, and the hashes should have two items each (name, display) containing Keystone domain name and a human-readable description of the domain respectively.\"}, \"HorizonLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.horizon\", \"file\": \"/var/log/containers/horizon/horizon.log\"}}, \"HorizonHstsHeaderValue\": {\"default\": [], \"description\": \"Enables HTTP Strict-Transport-Security header in response.\", \"type\": \"comma_delimited_list\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"The following parameters are deprecated and will be removed. They should not\\nbe relied on for new deployments. If you have concerns regarding deprecated\\nparameters, please contact the TripleO development team on IRC or the\\nOpenStack mailing list.\\n\", \"parameters\": [\"MemcachedIPv6\"]}], \"conditions\": {\"horizon_domain_choices_set\": {\"not\": {\"equals\": [{\"get_param\": \"HorizonDomainChoices\"}, []]}}, \"is_ipv6\": {\"equals\": [{\"get_param\": [\"ServiceData\", \"net_ip_version_map\", {\"get_param\": [\"ServiceNetMap\", \"HorizonNetwork\"]}]}, 6]}, \"horizon_logger_debug\": {\"or\": [{\"get_param\": \"Debug\"}, {\"get_param\": \"HorizonDebug\"}]}, \"horizon_hsts_header_value_set\": {\"not\": {\"equals\": [{\"get_param\": \"HorizonHstsHeaderValue\"}, []]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerHorizonImage\": \"ContainerHorizonImage\", \"ContainerHorizonConfigImage\": \"ContainerHorizonConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerHorizonImage\": {\"get_param\": \"ContainerHorizonImage\"}, \"ContainerHorizonConfigImage\": {\"get_param\": \"ContainerHorizonConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Horizon API role.\", \"value\": {\"service_name\": \"horizon\", \"firewall_rules\": {\"126 horizon\": {\"dport\": [{\"if\": [{\"get_param\": \"EnableInternalTLS\"}, 443, 80]}]}}, \"firewall_frontend_rules\": {\"100 horizon_haproxy_frontend\": {\"dport\": [80]}}, \"firewall_ssl_frontend_rules\": {\"100 horizon_haproxy_frontend_ssl\": {\"dport\": [443]}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionHorizon\"}, \"config_settings\": {\"map_merge\": [{\"horizon::allowed_hosts\": {\"get_param\": \"HorizonAllowedHosts\"}, \"horizon::enable_secure_proxy_ssl_header\": true, \"horizon::secure_proxy_addr_header\": \"HTTP_X_FORWARDED_FOR\", \"horizon::disable_password_reveal\": true, \"horizon::enforce_password_check\": true, \"horizon::disallow_iframe_embed\": true, \"horizon::cache_backend\": \"django.core.cache.backends.memcached.MemcachedCache\", \"horizon::django_session_engine\": \"django.contrib.sessions.backends.cache\", \"horizon::vhost_extra_params\": {\"get_param\": \"HorizonVhostExtraParams\"}, \"horizon::bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HorizonNetwork\"]}}}}, \"horizon::keystone_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneV3Public\", \"uri\"]}, \"horizon::password_validator\": {\"get_param\": [\"HorizonPasswordValidator\"]}, \"horizon::password_validator_help\": {\"get_param\": [\"HorizonPasswordValidatorHelp\"]}, \"horizon::secret_key\": {\"get_param\": \"HorizonSecret\"}, \"horizon::secure_cookies\": {\"get_param\": [\"HorizonSecureCookies\"]}, \"horizon::session_timeout\": {\"get_param\": \"HorizonSessionTimeout\"}, \"memcached_ipv6\": {\"if\": [\"is_ipv6\", true, false]}, \"horizon::servername\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HorizonNetwork\"]}}}}, \"horizon::listen_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"horizon::customization_module\": {\"get_param\": \"HorizonCustomizationModule\"}, \"horizon::timezone\": {\"get_param\": \"TimeZone\"}, \"horizon::file_upload_temp_dir\": \"/var/tmp\", \"horizon::help_url\": {\"get_param\": \"HorizonHelpURL\"}, \"horizon::enable_user_pass\": \"UNSET\"}, {\"if\": [{\"get_param\": \"WebSSOEnable\"}, {\"horizon::websso_enabled\": {\"get_param\": \"WebSSOEnable\"}, \"horizon::websso_initial_choice\": {\"get_param\": \"WebSSOInitialChoice\"}, \"horizon::websso_choices\": {\"get_param\": \"WebSSOChoices\"}, \"horizon::websso_idp_mapping\": {\"get_param\": \"WebSSOIDPMapping\"}, \"horizon::websso_choices_hide_keystone\": {\"get_param\": \"WebSSOChoicesHideKeystone\"}}]}, {\"if\": [{\"get_param\": \"HorizonDebug\"}, {\"horizon::django_debug\": true}, {\"horizon::django_debug\": {\"get_param\": \"Debug\"}}]}, {\"if\": [\"horizon_logger_debug\", {\"horizon::log_level\": \"DEBUG\"}]}, {\"if\": [\"horizon_domain_choices_set\", {\"horizon::keystone_domain_choices\": {\"get_param\": \"HorizonDomainChoices\"}}]}]}, \"ansible_group_vars\": {\"keystone_enable_member\": true}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_horizon\": {\"yaql\": {\"expression\": \"$.data.sources.flatten()\", \"data\": {\"sources\": [{\"get_param\": \"HorizonLoggingSource\"}]}}}}, \"haproxy\": {\"if\": [\"horizon_hsts_header_value_set\", {\"tripleo::profile::base::horizon::hsts_header_value\": {\"get_param\": \"HorizonHstsHeaderValue\"}}]}}, \"puppet_config\": {\"config_volume\": \"horizon\", \"puppet_tags\": \"horizon_config\", \"step_config\": \"include tripleo::profile::base::horizon\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHorizonConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/horizon.json\": {\"command\": \"/usr/sbin/httpd -DFOREGROUND\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/horizon/\", \"owner\": \"apache:apache\", \"recurse\": true}, {\"path\": \"/etc/openstack-dashboard/\", \"owner\": \"apache:apache\", \"recurse\": true}, {\"path\": \"/usr/share/openstack-dashboard/openstack_dashboard/local/\", \"owner\": \"apache:apache\", \"recurse\": false}, {\"path\": \"/usr/share/openstack-dashboard/openstack_dashboard/local/local_settings.d/\", \"owner\": \"apache:apache\", \"recurse\": false}]}}, \"docker_config\": {\"step_2\": {\"horizon_fix_perms\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHorizonImage\"]}, \"net\": \"none\", \"user\": \"root\", \"command\": [\"/bin/bash\", \"-c\", \"touch /var/log/horizon/horizon.log ; chown -R apache:apache /var/log/horizon && chmod -R a+rx /etc/openstack-dashboard\"], \"volumes\": [\"/var/log/containers/horizon:/var/log/horizon:z\", \"/var/log/containers/httpd/horizon:/var/log/httpd:z\", \"/var/lib/config-data/puppet-generated/horizon/etc/openstack-dashboard:/etc/openstack-dashboard\"]}}, \"step_3\": {\"horizon\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHorizonImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/horizon.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/horizon:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/horizon:/var/log/horizon:z\", \"/var/log/containers/httpd/horizon:/var/log/httpd:z\", \"/var/tmp/horizon:/var/tmp:z\", \"/var/www:/var/www:ro\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"ENABLE_DESIGNATE\": \"yes\", \"ENABLE_HEAT\": \"yes\", \"ENABLE_IRONIC\": \"yes\", \"ENABLE_MANILA\": \"yes\", \"ENABLE_OCTAVIA\": \"yes\"}}}}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/horizon\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/log/containers/httpd/horizon\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/www\", \"setype\": \"container_file_t\"}, {\"path\": \"/var/tmp/horizon\", \"setype\": \"container_file_t\", \"mode\": \"01777\"}]}, {\"name\": \"ensure /var/tmp/horizon exists on boot\", \"copy\": {\"dest\": \"/etc/tmpfiles.d/var-tmp-horizon.conf\", \"content\": \"d /var/tmp/horizon 01777 root root - -\\n\"}}], \"upgrade_tasks\": [{\"name\": \"Anchor for upgrade and update tasks\", \"when\": \"step|int == 0\", \"block\": [{\"name\": \"Reset selinux label on /var/tmp\", \"file\": {\"path\": \"/var/tmp\", \"state\": \"directory\", \"setype\": \"tmp_t\", \"mode\": 1023}}]}], \"update_tasks\": [{\"name\": \"Anchor for upgrade and update tasks\", \"when\": \"step|int == 0\", \"block\": [{\"name\": \"Reset selinux label on /var/tmp\", \"file\": {\"path\": \"/var/tmp\", \"state\": \"directory\", \"setype\": \"tmp_t\", \"mode\": 1023}}]}], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop horizon container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"horizon\"], \"tripleo_delegate_to\": \"{{ groups[\'horizon\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(193,'2026-06-09 08:02:23',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (194,'2026-06-09 08:02:24',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Generates the relevant service principals for a Compute server\", \"parameters\": {\"RoleData\": {\"type\": \"json\", \"description\": \"the list containing the \'role_data\' output for the ServiceChain\"}, \"CloudNameStorage\": {\"default\": \"overcloud.storage.ooo.test\", \"description\": \"The DNS name of this cloud\'s storage endpoint. E.g. \'ci-overcloud.storage.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameInternal\": {\"default\": \"overcloud.internalapi.ooo.test\", \"description\": \"The DNS name of this cloud\'s internal_api endpoint. E.g. \'ci-overcloud.internalapi.tripleo.org\'.\\n\", \"type\": \"string\"}, \"CloudNameCtlplane\": {\"default\": \"overcloud.ctlplane.ooo.test\", \"description\": \"The DNS name of this cloud\'s provisioning network endpoint. E.g. \'ci-overcloud.ctlplane.tripleo.org\'.\\n\", \"type\": \"string\"}}, \"resources\": {\"IncomingMetadataSettings\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"let(role_networks => $.data.role_networks) -> list(coalesce($.data.role_data, []).where($ != null).where($.containsKey(\'metadata_settings\')).metadata_settings.flatten().distinct().where($ != null and $.containsKey(\'network\')).where($role_networks.contains($.network))).flatten()\", \"data\": {\"role_data\": {\"get_param\": \"RoleData\"}, \"role_networks\": [\"ctlplane\", \"storage\", \"internal_api\", \"tenant\"]}}}}}, \"IndividualServices\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"let(fqdns => $.data.fqdns) -> dict(coalesce($.data.metadata, []).where($ != null and $.type = \'vip\').select([concat(\'managed_service_\', $.service, $.network), concat($.service, \'/\', $fqdns.get($.network))]))\", \"data\": {\"metadata\": {\"get_attr\": [\"IncomingMetadataSettings\", \"value\"]}, \"fqdns\": {\"storage\": {\"get_param\": \"CloudNameStorage\"}, \"internal_api\": {\"get_param\": \"CloudNameInternal\"}, \"ctlplane\": {\"get_param\": \"CloudNameCtlplane\"}}}}}}}, \"CompactServices\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"yaql\": {\"expression\": \"dict(coalesce($.data, []).where($ != null and $.type = \'node\').groupBy(concat(\'compact_service_\', $.service), $.network.replace(\'_\', \'\')))\", \"data\": {\"get_attr\": [\"IncomingMetadataSettings\", \"value\"]}}}}}}, \"outputs\": {\"metadata\": {\"description\": \"actual metadata entries that will be passed to the server.\", \"value\": {\"map_merge\": [{\"get_attr\": [\"IndividualServices\", \"value\"]}, {\"get_attr\": [\"CompactServices\", \"value\"]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"RoleData\": \"[{\\\"service_name\\\": \\\"boot_params_service\\\", \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"Configure tuned before reboot\\\", \\\"when\\\": \\\"step|int == 0\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tuned\\\"}, \\\"vars\\\": {\\\"tuned_profile\\\": \\\"throughput-performance\\\", \\\"tuned_isolated_cores\\\": \\\"\\\"}}, {\\\"name\\\": \\\"Configure kernel args and reboot\\\", \\\"when\\\": \\\"step|int == 0\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_kernel\\\", \\\"tasks_from\\\": \\\"kernelargs.yml\\\"}, \\\"vars\\\": {\\\"tripleo_kernel_args\\\": \\\"\\\", \\\"tripleo_kernel_hugepages\\\": {}, \\\"tripleo_kernel_hugepages_remove\\\": false, \\\"tripleo_kernel_defer_reboot\\\": false, \\\"tripleo_kernel_reboot_timeout\\\": 900}}], \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"upgrade prepare for leapp to align kernel arg shortcommings in leapp\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade\\\", \\\"system_upgrade_prepare\\\"], \\\"when\\\": [\\\"step|int == 3\\\", \\\"upgrade_leapp_enabled\\\"], \\\"block\\\": [{\\\"name\\\": \\\"fix grub entries to have name start with GRUB_\\\", \\\"replace\\\": {\\\"path\\\": \\\"/etc/default/grub\\\", \\\"regexp\\\": \\\"^(TRIPLEO_HEAT_TEMPLATE_KERNEL_ARGS)(.*)\\\", \\\"replace\\\": \\\"GRUB_\\\\\\\\1\\\\\\\\2\\\"}}, {\\\"name\\\": \\\"fix grub entries in append statement\\\", \\\"replace\\\": {\\\"path\\\": \\\"/etc/default/grub\\\", \\\"regexp\\\": \\\"(.*){(TRIPLEO_HEAT_TEMPLATE_KERNEL_ARGS)}(.*)\\\", \\\"replace\\\": \\\"\\\\\\\\1{GRUB_\\\\\\\\2}\\\\\\\\3\\\"}}]}]}, {\\\"service_name\\\": \\\"ca_certs\\\", \\\"config_settings\\\": {\\\"tripleo::trusted_cas::ca_map\\\": {}}, \\\"step_config\\\": \\\"include tripleo::trusted_cas\\\"}, {\\\"service_name\\\": \\\"collectd\\\", \\\"config_settings\\\": {\\\"tripleo::profile::base::metrics::collectd::enable_file_logging\\\": true, \\\"collectd::plugin::logfile::log_file\\\": \\\"/var/log/collectd/collectd.log\\\", \\\"collectd::manage_repo\\\": false, \\\"collectd::purge\\\": true, \\\"collectd::recurse\\\": true, \\\"collectd::purge_config\\\": true, \\\"collectd::minimum_version\\\": \\\"5.7\\\", \\\"collectd::interval\\\": 120, \\\"collectd::plugin::unixsock::socketgroup\\\": \\\"root\\\", \\\"collectd::plugin::unixsock::socketfile\\\": \\\"/run/collectd-socket\\\", \\\"collectd::plugin::unixsock::deletesocket\\\": true, \\\"collectd::plugin::cpu::reportbycpu\\\": true, \\\"collectd::plugin::cpu::reportbystate\\\": true, \\\"collectd::plugin::cpu::reportnumcpu\\\": false, \\\"collectd::plugin::cpu::valuespercentage\\\": true, \\\"collectd::plugin::df::ignoreselected\\\": true, \\\"collectd::plugin::df::reportbydevice\\\": true, \\\"collectd::plugin::df::fstypes\\\": [\\\"xfs\\\"], \\\"collectd::plugin::load::reportrelative\\\": true, \\\"collectd::plugin::virt::connection\\\": \\\"qemu:///system\\\", \\\"collectd::plugin::virt::extra_stats\\\": \\\"pcpu cpu_util vcpu memory disk disk_err disk_allocation disk_capacity disk_physical domain_state job_stats_background perf\\\", \\\"collectd::plugin::virt::hostname_format\\\": \\\"hostname\\\", \\\"tripleo.collectd.plugins.collectd\\\": [\\\"cpu\\\", \\\"df\\\", \\\"disk\\\", \\\"hugepages\\\", \\\"interface\\\", \\\"load\\\", \\\"memory\\\", \\\"unixsock\\\", \\\"uptime\\\"], \\\"tripleo::profile::base::metrics::collectd::amqp_transport_name\\\": \\\"metrics\\\", \\\"tripleo::profile::base::metrics::collectd::amqp_address\\\": \\\"collectd\\\", \\\"tripleo::profile::base::metrics::collectd::amqp_instances\\\": {}, \\\"tripleo::profile::base::metrics::collectd::amqp_retry_delay\\\": 1, \\\"tripleo::profile::base::metrics::collectd::amqp_host\\\": \\\"%{hiera(\'internal_api\')}\\\", \\\"tripleo::profile::base::metrics::collectd::amqp_port\\\": 5666, \\\"tripleo::profile::base::metrics::collectd::amqp_user\\\": \\\"guest\\\", \\\"tripleo::profile::base::metrics::collectd::amqp_password\\\": \\\"guest\\\"}, \\\"service_config_settings\\\": {\\\"rsyslog\\\": {\\\"tripleo_logging_sources_collectd\\\": [{\\\"tag\\\": \\\"collectd\\\", \\\"file\\\": \\\"/var/log/containers/collectd/collectd.log\\\"}]}}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"collectd\\\", \\\"puppet_tags\\\": \\\"collectd_client_config,exec\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::metrics::collectd\\\", \\\"config_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\\\"}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/collectd.json\\\": {\\\"command\\\": \\\"/usr/sbin/collectd -f\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src/etc/collectd.d\\\", \\\"dest\\\": \\\"/etc/\\\", \\\"merge\\\": false, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/collectd\\\", \\\"owner\\\": \\\"collectd:collectd\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/scripts\\\", \\\"owner\\\": \\\"collectd:collectd\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/config-scripts\\\", \\\"owner\\\": \\\"collectd:collectd\\\", \\\"recurse\\\": true}]}}, \\\"container_config_scripts\\\": {\\\"container_puppet_apply.sh\\\": {\\\"mode\\\": \\\"0700\\\", \\\"content\\\": \\\"#!/bin/bash\\\\nset -eux\\\\nSTEP=$1\\\\nTAGS=$2\\\\nCONFIG=$3\\\\nEXTRA_ARGS=${4:-\'\'}\\\\nif [ -d /tmp/puppet-etc ]; then\\\\n  # ignore copy failures as these may be the same file depending on docker mounts\\\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\\\nfi\\\\necho \\\\\\\"{\\\\\\\\\\\\\\\"step\\\\\\\\\\\\\\\": ${STEP}}\\\\\\\" > /etc/puppet/hieradata/docker_puppet.json\\\\n# $::deployment_type in puppet-tripleo\\\\nexport FACTER_deployment_type=containers\\\\nset +e\\\\npuppet apply $EXTRA_ARGS \\\\\\\\\\\\n    --verbose \\\\\\\\\\\\n    --detailed-exitcodes \\\\\\\\\\\\n    --summarize \\\\\\\\\\\\n    --color=false \\\\\\\\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\\\\\\\n    --tags $TAGS \\\\\\\\\\\\n    -e \\\\\\\"noop_resource(\'package\'); ${CONFIG}\\\\\\\"\\\\nrc=$?\\\\nset -e\\\\nset +ux\\\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\\\n    exit 0\\\\nfi\\\\nexit $rc\\\\n\\\"}, \\\"pyshim.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n# Copyright 2018 Red Hat Inc.\\\\n#\\\\n# Licensed under the Apache License, Version 2.0 (the \\\\\\\"License\\\\\\\"); you may\\\\n# not use this file except in compliance with the License. You may obtain\\\\n# a copy of the License at\\\\n#\\\\n#      http://www.apache.org/licenses/LICENSE-2.0\\\\n#\\\\n# Unless required by applicable law or agreed to in writing, software\\\\n# distributed under the License is distributed on an \\\\\\\"AS IS\\\\\\\" BASIS, WITHOUT\\\\n# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the\\\\n# License for the specific language governing permissions and limitations\\\\n# under the License.\\\\n#\\\\n# Usage: pyshim.sh <script and/or arguments>\\\\n#\\\\n# Unfortunately THT doesn\'t know which version of python might be in a\\\\n# container so we need this script to be able to try python3 or python2\\\\n# depending on availability.  Since this is a temporary shim until we\'ve\\\\n# fully cut over to python3, we check for the existence of python3 first\\\\n# before falling back to python2. This will help in the transition from\\\\n# python2 based containers to python3.\\\\n\\\\nshow_usage() {\\\\n    echo \\\\\\\"Usage: pyshim.sh <script and/or arguments>\\\\\\\"\\\\n}\\\\n\\\\nif [ $# -lt 1 ]\\\\nthen\\\\n    show_usage\\\\n    exit 1\\\\nfi\\\\n\\\\nset -x\\\\nif command -v python3 >/dev/null; then\\\\n    python3 \\\\\\\"$@\\\\\\\"\\\\nelif command -v python2 >/dev/null; then\\\\n    python2 \\\\\\\"$@\\\\\\\"\\\\nelif command -v python >/dev/null; then\\\\n    python \\\\\\\"$@\\\\\\\"\\\\nelse\\\\n    echo \\\\\\\"ERROR: python is not available!\\\\\\\"\\\\n    exit 1\\\\nfi\\\\n\\\"}, \\\"pacemaker_restart_bundle.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\nset -u\\\\n\\\\n# ./pacemaker_restart_bundle.sh mysql galera galera-bundle Master _\\\\n# ./pacemaker_restart_bundle.sh redis redis redis-bundle Slave Master\\\\n# ./pacemaker_restart_bundle.sh ovn_dbs ovndb_servers ovn-dbs-bundle Slave Master\\\\nRESTART_SCRIPTS_DIR=$(dirname $0)\\\\nTRIPLEO_SERVICE=$1\\\\nRESOURCE_NAME=$2\\\\nBUNDLE_NAME=$3\\\\nWAIT_TARGET_LOCAL=$4\\\\nWAIT_TARGET_ANYWHERE=${5:-_}\\\\nTRIPLEO_MINOR_UPDATE=\\\\\\\"${TRIPLEO_MINOR_UPDATE:-false}\\\\\\\"\\\\nTRIPLEO_HA_WRAPPER_RESOURCE_EXISTS=\\\\\\\"${TRIPLEO_HA_WRAPPER_RESOURCE_EXISTS:-false}\\\\\\\"\\\\n\\\\nbundle_can_be_restarted() {\\\\n    local bundle=$1\\\\n    # As long as the resource bundle is managed by pacemaker and is\\\\n    # not meant to stay stopped, no matter the state of any inner\\\\n    # pcmk_remote or ocf resource, we should restart it to give it a\\\\n    # chance to read the new config.\\\\n    [ \\\\\\\"$(crm_resource --meta -r $1 -g is-managed 2>/dev/null)\\\\\\\" != \\\\\\\"false\\\\\\\" ] && \\\\\\\\\\\\n    [ \\\\\\\"$(crm_resource --meta -r $1 -g target-role 2>/dev/null)\\\\\\\" != \\\\\\\"Stopped\\\\\\\" ]\\\\n}\\\\n\\\\nlog() {\\\\n    local msg=$1\\\\n    logger -t pcmkrestart \\\\\\\"$1\\\\\\\"\\\\n}\\\\n\\\\nHOSTNAME=$(/bin/hostname -s)\\\\nif [ x\\\\\\\"${TRIPLEO_MINOR_UPDATE,,}\\\\\\\" != x\\\\\\\"true\\\\\\\" ]; then\\\\n    if [ x\\\\\\\"${TRIPLEO_HA_WRAPPER_RESOURCE_EXISTS,,}\\\\\\\" = x\\\\\\\"false\\\\\\\" ]; then\\\\n        # Do not restart during initial deployment, as the resource\\\\n        # has just been created.\\\\n        SERVICE_NODEID=$(/bin/hiera -c /etc/puppet/hiera.yaml \\\\\\\"${TRIPLEO_SERVICE}_short_bootstrap_node_name\\\\\\\")\\\\n        if [[ \\\\\\\"${HOSTNAME,,}\\\\\\\" == \\\\\\\"${SERVICE_NODEID,,}\\\\\\\" ]]; then\\\\n            log \\\\\\\"Initial deployment, skipping the restart of ${BUNDLE_NAME}\\\\\\\"\\\\n\\\\tfi\\\\n        exit 0\\\\n    else\\\\n        # During a stack update, this script is called in parallel on\\\\n        # every node the resource runs on, after the service\'s configs\\\\n        # have been updated on all nodes. So we need to run pcs only\\\\n        # once (e.g. on the service\'s boostrap node).\\\\n        if bundle_can_be_restarted ${BUNDLE_NAME}; then\\\\n            SERVICE_NODEID=$(/bin/hiera -c /etc/puppet/hiera.yaml \\\\\\\"${TRIPLEO_SERVICE}_short_bootstrap_node_name\\\\\\\")\\\\n            if [[ \\\\\\\"${HOSTNAME,,}\\\\\\\" == \\\\\\\"${SERVICE_NODEID,,}\\\\\\\" ]]; then\\\\n                replicas_running=$(crm_resource -Q -r $BUNDLE_NAME --locate 2>&1 | wc -l)\\\\n                if [ \\\\\\\"$replicas_running\\\\\\\" != \\\\\\\"0\\\\\\\" ]; then\\\\n                    log \\\\\\\"Restarting ${BUNDLE_NAME} globally. Stopping:\\\\\\\"\\\\n                    /sbin/pcs resource disable --wait=600 $BUNDLE_NAME\\\\n                    log \\\\\\\"Restarting ${BUNDLE_NAME} globally. Starting:\\\\\\\"\\\\n                    /sbin/pcs resource enable --wait=600 $BUNDLE_NAME\\\\n                else\\\\n                    log \\\\\\\"${BUNDLE_NAME} is not running anywhere,\\\\\\\" \\\\\\\\\\\\n                         \\\\\\\"cleaning up to restart it globally if necessary\\\\\\\"\\\\n                    /sbin/pcs resource cleanup $BUNDLE_NAME\\\\n                fi\\\\n            else\\\\n                log \\\\\\\"Skipping global restart of ${BUNDLE_NAME} on ${HOSTNAME} it will be restarted by node ${SERVICE_NODEID}\\\\\\\"\\\\n            fi\\\\n\\\\n        else\\\\n            log \\\\\\\"No global restart needed for ${BUNDLE_NAME}.\\\\\\\"\\\\n        fi\\\\n    fi\\\\nelse\\\\n    # During a minor update workflow however, a host gets fully\\\\n    # updated before updating the next one. So unlike stack\\\\n    # update, at the time this script is called, the service\'s\\\\n    # configs aren\'t updated on all nodes yet. So only restart the\\\\n    # resource locally, where it\'s guaranteed that the config is\\\\n    # up to date.\\\\n    HOST=$(facter hostname)\\\\n\\\\n    if bundle_can_be_restarted ${BUNDLE_NAME}; then\\\\n\\\\t# if the resource is running locally, restart it\\\\n\\\\tif crm_resource -r $BUNDLE_NAME --locate 2>&1 | grep -w -q \\\\\\\"${HOST}\\\\\\\"; then\\\\n            log \\\\\\\"Restarting ${BUNDLE_NAME} locally on \'${HOST}\'\\\\\\\"\\\\n            /sbin/pcs resource restart $BUNDLE_NAME \\\\\\\"${HOST}\\\\\\\"\\\\n\\\\n\\\\telse\\\\n\\\\t    # At this point, if no resource is running locally, it\'s\\\\n\\\\t    # either because a) it has failed previously, or b) because\\\\n\\\\t    # it\'s an A/P resource running elsewhere.\\\\n\\\\t    # By cleaning up resource, we ensure that a) it will try to\\\\n\\\\t    # restart, or b) it won\'t do anything if the resource is\\\\n\\\\t    # already running elsewhere.\\\\n            log \\\\\\\"${BUNDLE_NAME} is currently not running on \'${HOST}\',\\\\\\\" \\\\\\\\\\\\n                 \\\\\\\"cleaning up its state to restart it if necessary\\\\\\\"\\\\n            /sbin/pcs resource cleanup $BUNDLE_NAME node=\\\\\\\"${HOST}\\\\\\\"\\\\n\\\\tfi\\\\n\\\\n\\\\t# Wait until the resource is in the expected target state\\\\n\\\\t$RESTART_SCRIPTS_DIR/pacemaker_wait_bundle.sh \\\\\\\\\\\\n            $RESOURCE_NAME $BUNDLE_NAME \\\\\\\\\\\\n            \\\\\\\"$WAIT_TARGET_LOCAL\\\\\\\" \\\\\\\"$WAIT_TARGET_ANYWHERE\\\\\\\" \\\\\\\\\\\\n\\\\t    \\\\\\\"${HOST}\\\\\\\" 600\\\\n    else\\\\n        log \\\\\\\"No restart needed for ${BUNDLE_NAME}.\\\\\\\"\\\\n    fi\\\\nfi\\\\n\\\"}, \\\"pacemaker_wait_bundle.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\n# ----\\\\n# Wait for an OCF resource or a bundle to be restarted\\\\n# ----\\\\n# e.g.:\\\\n# M/S OCF:      $0 galera galera-bundle Master\\\\n# clone OCF:    $0 rabbitmq rabbitmq-bundle Started\\\\n# A/P M/S OCF:  $0 redis redis-bundle Slave Master\\\\n# A/P bundle:   $0 openstack-cinder-volume openstack-cinder-volume _ Started\\\\n# clone bundle: $0 haproxy-bundle haproxy-bundle Started\\\\n\\\\n# design note 1:\\\\n#  - this script is called during a minor update; it is called\\\\n#    once per node that hosts a service replica.\\\\n#  - the purpose of this script is to ensure that restarting the\\\\n#    service replica locally won\'t disrupt the service availability\\\\n#    for the end user. To reach that goal, the script waits until the\\\\n#    service is restarted locally or globallu and reaches a given\\\\n#    target state (i.e. Started, Slave or Master).\\\\n# design note 2:\\\\n#   - we don\'t want to track restart error: our only job is to ensure\\\\n#     service restart synchronization, not service health.\\\\n#   - In particular, we don\'t want to error out in case the resource\\\\n#     cannot be restarted locally, because that would make the minor\\\\n#     update fail, even if potentially other replicas still provide\\\\n#     the service.\\\\n# design note 3:\\\\n#   - we can bail out early if we determine that the resource can\'t\\\\n#     be restarted automatically by pacemaker (e.g. its \\\\\\\"blocked\\\\\\\",\\\\n#     unmanaged or disabled).\\\\n\\\\nlog() {\\\\n    local msg=$1\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\"\\\\n}\\\\n\\\\nusage() {\\\\n    echo 2>&1 \\\\\\\"Usage: $0 NAME BUNDLE_NAME ROLE_LOCAL [ROLE_ANYWHERE] [HOST] [TIMEOUT]\\\\\\\"\\\\n    exit 1\\\\n}\\\\n\\\\npacemaker_supports_promoted() {\\\\n    # The Promoted token is only matched in recent pacemaker versions\\\\n    grep -wq \\\\\\\"<value>Promoted</value>\\\\\\\" /usr/share/pacemaker/resources-*.rng\\\\n}\\\\n\\\\n#\\\\n# Utility functions to detect stuck resources\\\\n#\\\\n\\\\nbundle_failures_locally() {\\\\n    local engine=$BUNDLE_CONTAINER_ENGINE\\\\n    local replicas=$BUNDLE_REPLICAS\\\\n    local last=$(($replicas - 1))\\\\n    local replica_name\\\\n    for i in $(seq 0 $last); do\\\\n\\\\treplica_name=${BUNDLE_NAME}-${engine}-${i}\\\\n\\\\tcrm_failcount -q -G -r $replica_name -N $HOST\\\\n    done\\\\n}\\\\n\\\\nbundle_failures_globally() {\\\\n    local engine=$BUNDLE_CONTAINER_ENGINE\\\\n    local replicas=$BUNDLE_REPLICAS\\\\n    local last=$(($replicas - 1))\\\\n    for i in $(seq 0 $last); do\\\\n\\\\tcrm_failcount -q -G -r ${BUNDLE_NAME}-${engine}-${i}\\\\n    done\\\\n}\\\\n\\\\nbundle_running_globally() {\\\\n    local engine=$BUNDLE_CONTAINER_ENGINE\\\\n    # return the number of running bundles replica, i.e. the number of\\\\n    # docker/podman resource replicas currently running in the cluster\\\\n    crm_mon --as-xml | xmllint --xpath \\\\\\\"count(//resources/bundle[@id=\'${BUNDLE_NAME}\']/replica/resource[@resource_agent=\'${OCF}:heartbeat:${engine}\']/node)\\\\\\\" -\\\\n}\\\\n\\\\nocf_failures_globally() {\\\\n    local replicas=$BUNDLE_REPLICAS\\\\n    local last=$(($replicas - 1))\\\\n    local bundle_node\\\\n    for i in $(seq 0 $last); do\\\\n\\\\tbundle_node=${BUNDLE_NAME}-${i}\\\\n\\\\tcrm_failcount -q -G -r $NAME -N $bundle_node\\\\n    done\\\\n}\\\\n\\\\ndid_resource_failed_locally() {\\\\n    local failures\\\\n    local running\\\\n    local remotehost\\\\n    if [ \\\\\\\"${NAME}\\\\\\\" != \\\\\\\"${BUNDLE_NAME}\\\\\\\" ]; then\\\\n\\\\t# if we\'re dealing with an ocf resource, it is running on a\\\\n\\\\t# pacemaker_remote rather that on the real host, and the\\\\n\\\\t# failcounts are thus associated to the pcmk remote. Replace\\\\n\\\\t# the host\'s name with the pcmk remote\'s name.\\\\n        remotehost=$(crm_mon --as-xml | xmllint --xpath \\\\\\\"string(//resources/bundle[@id=\'${BUNDLE_NAME}\']/replica/resource/node[@name=\'${HOST}\']/../../resource[@resource_agent=\'${OCF}:pacemaker:remote\']/@id)\\\\\\\" -)\\\\n\\\\tif [ -n \\\\\\\"${remotehost}\\\\\\\" ]; then\\\\n\\\\t    crm_failcount -q -G -r $NAME -N $remotehost | grep -q -w INFINITY\\\\n\\\\t    return $?\\\\n\\\\tfi\\\\n\\\\t# If no pcmk remote is currently running, the failcount from\\\\n\\\\t# the ocf resource is useless, compute the failcount from the\\\\n\\\\t# bundle case instead (computed below).\\\\n    fi\\\\n\\\\n    # for bundles, pacemaker can run any bundle replica locally\\\\n    # (e.g. galera-bundle-docker-{0,1,2}), and a failure happens when\\\\n    # there are no more replica to try.\\\\n    # That is, when _at least_ one replica failed locally, and all the\\\\n    # others either failed or are currently running elsewhere.\\\\n    failures=$(bundle_failures_locally $HOST | grep -c -w INFINITY)\\\\n    running=$(bundle_running_globally)\\\\n    test $failures -gt 0 && \\\\\\\\\\\\n    test $(( $failures + $running )) -ge $BUNDLE_REPLICAS\\\\n}\\\\n\\\\ndid_resource_failed_globally() {\\\\n    local remotecount\\\\n    local failures\\\\n    if [ \\\\\\\"${NAME}\\\\\\\" != \\\\\\\"${BUNDLE_NAME}\\\\\\\" ]; then\\\\n\\\\t# we check the state of an ocf resource only if the\\\\n\\\\t# pcmkremotes are started\\\\n        remotecount=$(crm_mon --as-xml | xmllint --xpath \\\\\\\"count(//resources/bundle[@id=\'${BUNDLE_NAME}\']/replica/resource[@resource_agent=\'${OCF}:pacemaker:remote\']/node)\\\\\\\" -)\\\\n\\\\tif [ \\\\\\\"${remotecount}\\\\\\\" = \\\\\\\"0\\\\\\\" ]; then\\\\n\\\\t    # no pcmkremote is running, so check the bundle state\\\\n\\\\t    # instead of checking the ocf resource\\\\n\\\\t    # bundle failed if all ${BUNDLE_REPLICAS} replicas failed\\\\n\\\\t    failures=$(bundle_failures_globally | grep -c -w INFINITY)\\\\n\\\\t    test $failures -eq $BUNDLE_REPLICAS\\\\n\\\\telse\\\\n\\\\t    # ocf resource failed if it failed to start on\\\\n\\\\t    # all $BUNDLE_REPLICAS bundle nodes\\\\n\\\\t    failures=$(ocf_failures_globally | grep -c -w INFINITY)\\\\n\\\\t    test $failures -eq $BUNDLE_REPLICAS\\\\n\\\\tfi\\\\n    else\\\\n\\\\t# bundle failed if all ${BUNDLE_REPLICAS} replicas failed\\\\n\\\\tfailures=$(bundle_failures_globally | grep -c -w INFINITY)\\\\n\\\\ttest $failures -eq $BUNDLE_REPLICAS\\\\n    fi\\\\n}\\\\n\\\\n\\\\n# Input validation\\\\n#\\\\n\\\\nNAME=$1\\\\nif [ -z \\\\\\\"${NAME}\\\\\\\" ]; then\\\\n    echo 2>&1 \\\\\\\"Error: argument NAME must not be empty\\\\\\\"\\\\n    exit 1\\\\nfi\\\\n\\\\nBUNDLE_NAME=$2\\\\nif [ -z \\\\\\\"${BUNDLE_NAME}\\\\\\\" ]; then\\\\n    echo 2>&1 \\\\\\\"Error: argument BUNDLE_NAME must not be empty\\\\\\\"\\\\n    exit 1\\\\nfi\\\\n\\\\nROLE_LOCAL=$3\\\\nif [ \\\\\\\"${ROLE_LOCAL}\\\\\\\" = \\\\\\\"_\\\\\\\" ]; then\\\\n    ROLE_LOCAL=\\\\\\\"\\\\\\\"\\\\nfi\\\\n\\\\nROLE_ANYWHERE=$4\\\\nif [ \\\\\\\"${ROLE_ANYWHERE}\\\\\\\" = \\\\\\\"_\\\\\\\" ]; then\\\\n    ROLE_ANYWHERE=\\\\\\\"\\\\\\\"\\\\nfi\\\\n\\\\nif [ -z \\\\\\\"${ROLE_LOCAL}\\\\\\\" ]; then\\\\n    if [ -z \\\\\\\"${ROLE_ANYWHERE}\\\\\\\" ]; then\\\\n        echo 2>&1 \\\\\\\"Error: either ROLE_LOCAL or ROLE_ANYWHERE must be non empty\\\\\\\"\\\\n        exit 1\\\\n    fi\\\\nelse\\\\n    if !(echo \\\\\\\"${ROLE_LOCAL}\\\\\\\" | grep -q -x -E \\\\\\\"(Started|Slave|Master|Unpromoted|Promoted)\\\\\\\"); then\\\\n        echo 2>&1 \\\\\\\"Error: argument ROLE_LOCAL must be either \'Started\' \'Slave\' \'Master\' \'Unpromoted\' or \'Promoted\'\\\\\\\"\\\\n        exit 1\\\\n    fi\\\\nfi\\\\n\\\\nif [ -n \\\\\\\"${ROLE_ANYWHERE}\\\\\\\" ] && !(echo \\\\\\\"${ROLE_ANYWHERE}\\\\\\\" | grep -q -x -E \\\\\\\"(Started|Slave|Master|Unpromoted|Promoted)\\\\\\\"); then\\\\n    echo 2>&1 \\\\\\\"Error: argument ROLE_ANYWHERE must be either \'Started\' \'Slave\' \'Master\' \'Unpromoted\' or \'Promoted\'\\\\\\\"\\\\n    exit 1\\\\nfi\\\\n\\\\n# Ensure compatibility with pacemaker 2.1\\\\nif pacemaker_supports_promoted; then\\\\n    ROLE_LOCAL=$(echo \\\\\\\"$ROLE_LOCAL\\\\\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\\\n    ROLE_ANYWHERE=$(echo \\\\\\\"$ROLE_ANYWHERE\\\\\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\\\n    OCF=\\\\\\\"ocf\\\\\\\"\\\\nelse\\\\n    OCF=\\\\\\\"ocf:\\\\\\\"\\\\nfi\\\\n\\\\nHOST=${5:-$(facter hostname)}\\\\nTIMEOUT=${6:-600}\\\\n\\\\n\\\\n# Configure the search\\\\n# ----\\\\n# Note: we can\'t use crm_resource in all searches because we can\'t\\\\n# easily extract the host the OCF resources run on (crm_resource\\\\n# returns the pcmk-remote nodes rather than the hosts)\\\\n# So instead, we implement various searches with XPath directly.\\\\n\\\\nif [ \\\\\\\"${BUNDLE_NAME}\\\\\\\" != \\\\\\\"${NAME}\\\\\\\" ]; then\\\\n# ocf resource\\\\nlocal_resource_xpath=\\\\\\\"//bundle/replica/resource[@resource_agent=\'${OCF}:pacemaker:remote\']/node[@name=\'${HOST}\']/../../resource[@id=\'${NAME}\']\\\\\\\"\\\\nany_resource_xpath=\\\\\\\"//bundle//resource[@id=\'${NAME}\']\\\\\\\"\\\\nreplicas_xpath=\\\\\\\"//bundle/primitive[@id=\'${BUNDLE_NAME}\']/../*[boolean(@image) and boolean(@replicas)]\\\\\\\"\\\\nelse\\\\n# bundle resource\\\\nlocal_resource_xpath=\\\\\\\"//bundle[@id=\'${NAME}\']/replica/resource/node[@name=\'${HOST}\']/../../resource\\\\\\\"\\\\nany_resource_xpath=\\\\\\\"//bundle[@id=\'${NAME}\']//resource\\\\\\\"\\\\nreplicas_xpath=\\\\\\\"//bundle[@id=\'${BUNDLE_NAME}\']/*[boolean(@image) and boolean(@replicas)]\\\\\\\"\\\\nfi\\\\n\\\\nbundle_def_xpath=\\\\\\\"//bundle[@id=\'${BUNDLE_NAME}\']/*[boolean(@image) and boolean(@replicas)]\\\\\\\"\\\\nBUNDLE_CONTAINER_ENGINE=$(cibadmin -Q | xmllint --xpath \\\\\\\"name(${bundle_def_xpath})\\\\\\\" -)\\\\nBUNDLE_REPLICAS=$(cibadmin -Q | xmllint --xpath \\\\\\\"string(${bundle_def_xpath}/@replicas)\\\\\\\" -)\\\\n\\\\n\\\\n# The wait algorithm follows a two-stage approach\\\\n#  1. Depending on how the script is called, we first check whether\\\\n#     the resource is restarted locally. An A/P resource may be\\\\n#     restarted elsewhere in the cluster.\\\\n#  2. If needed, check whether the A/P resource has restarted\\\\n#     elsewhere. For A/P M/S resources, in case the resource is\\\\n#     restarted as Slave locally, ensure a Master is available.\\\\n\\\\nsuccess=1\\\\nbailout=1\\\\ntimeout=$TIMEOUT\\\\nrole=\\\\\\\"\\\\\\\"\\\\n\\\\n# Stage 1: local check\\\\nif [ -n \\\\\\\"$ROLE_LOCAL\\\\\\\" ]; then\\\\n    log \\\\\\\"Waiting until ${NAME} has restarted on ${HOST} and is in state ${ROLE_LOCAL}\\\\\\\"\\\\n    log \\\\\\\"Will probe resource state with the following XPath pattern: ${local_resource_xpath}\\\\\\\"\\\\n\\\\n    while [ $timeout -gt 0 ] && [ $bailout -ne 0 ] && [ $success -ne 0 ]; do\\\\n        resource=$(crm_mon -r --as-xml | xmllint --xpath \\\\\\\"${local_resource_xpath}\\\\\\\" - 2>/dev/null)\\\\n        role=$(echo \\\\\\\"${resource}\\\\\\\" | sed -ne \'s/.*\\\\\\\\Wrole=\\\\\\\"\\\\\\\\([^\\\\\\\"]*\\\\\\\\)\\\\\\\".*/\\\\\\\\1/p\')\\\\n\\\\n\\\\tif [ \\\\\\\"$(crm_resource --meta -r ${NAME} -g is-managed 2>/dev/null)\\\\\\\" = \\\\\\\"false\\\\\\\" ]; then\\\\n            log \\\\\\\"${NAME} is unmanaged, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n\\\\telif [ \\\\\\\"$(crm_resource --meta -r ${NAME} -g target-role 2>/dev/null)\\\\\\\" = \\\\\\\"Stopped\\\\\\\" ]; then\\\\n            log \\\\\\\"${NAME} is disabled, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n        elif echo \\\\\\\"${resource}\\\\\\\" | grep -q -w \\\\\\\"\\\\\\\\Wblocked=\\\\\\\\\\\\\\\"true\\\\\\\\\\\\\\\"\\\\\\\"; then\\\\n            log \\\\\\\"${NAME} is blocked, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n\\\\telif did_resource_failed_locally; then\\\\n            log \\\\\\\"${NAME} is in failed state, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n        elif [ \\\\\\\"$role\\\\\\\" = \\\\\\\"$ROLE_LOCAL\\\\\\\" ]; then\\\\n            success=0\\\\n            continue\\\\n        elif [ -n \\\\\\\"$ROLE_ANYWHERE\\\\\\\" ] && [ \\\\\\\"$role\\\\\\\" = \\\\\\\"$ROLE_ANYWHERE\\\\\\\" ]; then\\\\n            # A/P: we are restarted in the expected state\\\\n            success=0\\\\n            continue\\\\n        else\\\\n            log \\\\\\\"Waiting for ${NAME} to transition to role ${ROLE_LOCAL} on ${HOST}\\\\\\\"\\\\n        fi\\\\n\\\\n        if [ $bailout -ne 0 ] && [ $success -ne 0 ]; then\\\\n            sleep 4\\\\n            timeout=$((timeout-4))\\\\n        fi\\\\n    done\\\\nfi\\\\n\\\\n# Stage 2: global check\\\\nif [ $timeout -gt 0 ] && [ -n \\\\\\\"$ROLE_ANYWHERE\\\\\\\" ] && [ \\\\\\\"$role\\\\\\\" != \\\\\\\"$ROLE_ANYWHERE\\\\\\\" ]; then\\\\n    log \\\\\\\"Wait until ${NAME} is restarted anywhere in the cluster in state ${ROLE_ANYWHERE}\\\\\\\"\\\\n    log \\\\\\\"Will probe resource state with the following XPath pattern: ${any_resource_xpath}\\\\\\\"\\\\n\\\\n    success=1\\\\n    bailout=1\\\\n    while [ $timeout -gt 0 ] && [ $bailout -ne 0 ] && [ $success -ne 0 ]; do\\\\n        resources=$(crm_mon -r --as-xml | xmllint --xpath \\\\\\\"${any_resource_xpath}\\\\\\\" - 2>/dev/null)\\\\n\\\\tif [ \\\\\\\"$(crm_resource --meta -r ${NAME} -g is-managed 2>/dev/null)\\\\\\\" = \\\\\\\"false\\\\\\\" ]; then\\\\n            log \\\\\\\"${NAME} is unmanaged, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n\\\\telif [ \\\\\\\"$(crm_resource --meta -r ${NAME} -g target-role 2>/dev/null)\\\\\\\" = \\\\\\\"Stopped\\\\\\\" ]; then\\\\n            log \\\\\\\"${NAME} is disabled, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n        elif ! (echo \\\\\\\"${resources}\\\\\\\" | grep -q -w \\\\\\\"\\\\\\\\Wblocked=\\\\\\\\\\\\\\\"false\\\\\\\\\\\\\\\"\\\\\\\"); then\\\\n            log \\\\\\\"${NAME} blocked, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n\\\\telif did_resource_failed_globally; then\\\\n            log \\\\\\\"${NAME} is in failed state, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n        elif echo \\\\\\\"${resources}\\\\\\\" | grep -q -w \\\\\\\"\\\\\\\\Wrole=\\\\\\\\\\\\\\\"${ROLE_ANYWHERE}\\\\\\\\\\\\\\\"\\\\\\\"; then\\\\n            success=0\\\\n            continue\\\\n        else\\\\n            log \\\\\\\"Waiting for ${NAME} to transition to role ${ROLE_ANYWHERE} anywhere in the cluster\\\\\\\"\\\\n        fi\\\\n\\\\n        if [ $bailout -ne 0 ] && [ $success -ne 0 ]; then\\\\n            sleep 4\\\\n            timeout=$((timeout-4))\\\\n        fi\\\\n    done\\\\nfi\\\\n\\\\nif [ $timeout -le 0 ]; then\\\\n    log \\\\\\\"Timeout reached after ${TIMEOUT}s while waiting for ${NAME} to be restarted\\\\\\\"\\\\nelif [ $bailout -le 0 ]; then\\\\n    log \\\\\\\"Restart monitoring for ${NAME} cancelled\\\\\\\"\\\\nfi\\\\n\\\\nif [ $success -eq 0 ]; then\\\\n    log \\\\\\\"${NAME} successfully restarted\\\\\\\"\\\\nelse\\\\n    log \\\\\\\"${NAME} was not restarted properly\\\\\\\"\\\\nfi\\\\n\\\\n# Don\'t block minor update or stack update if the wait was unsuccessful\\\\nexit 0\\\\n\\\"}, \\\"wait-port-and-run.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\nset -eu\\\\n\\\\nHOST=$1\\\\nPORT=$2\\\\n\\\\necho \\\\\\\"$(date -u): Checking whether we can bind to ${HOST}:${PORT}\\\\\\\"\\\\nwhile (ss -Htnl src \\\\\\\"${HOST}\\\\\\\" \\\\\\\"sport = :${PORT}\\\\\\\" | grep -wq \\\\\\\"${PORT}\\\\\\\"); do\\\\n    echo \\\\\\\"$(date -u): ${HOST}:${PORT} still in use, waiting...\\\\\\\";\\\\n    sleep 10;\\\\ndone\\\\n\\\\nshift 2\\\\nCOMMAND=\\\\\\\"$*\\\\\\\"\\\\nif [ -z \\\\\\\"${COMMAND}\\\\\\\" ]; then\\\\n    COMMAND=\\\\\\\"true\\\\\\\"\\\\nfi\\\\nexec $COMMAND\\\\n\\\"}, \\\"pacemaker_resource_lock.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\nMAX_RETRIES=10\\\\nCIB_ENOTFOUND=105\\\\n\\\\nusage() {\\\\n   echo \\\\\\\"Set a global property in the cluster with a validity timestamp.\\\\\\\"\\\\n   echo \\\\\\\"Usage:\\\\\\\"\\\\n   echo \\\\\\\"   $0 --acquire <lock_name> <lock_owner> <lock_ttl_in_seconds>\\\\\\\"\\\\n   echo \\\\\\\"   $0 --release <lock_name> <lock_owner>\\\\\\\"\\\\n   echo\\\\n}\\\\n\\\\nlog() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\" 1>&2\\\\n}\\\\n\\\\nerror() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\" 1>&2\\\\n    exit 1\\\\n}\\\\n\\\\nlock_create() {\\\\n    local name=$1\\\\n    local data=$2\\\\n    # cibadmin won\'t overwrite a key if someone else succeeded to create it concurrently\\\\n    cibadmin --sync-call --scope crm_config --create --xml-text \\\\\\\"<cluster_property_set id=\'${name}\'><nvpair id=\'${name}-pair\' name=\'${name}\' value=\'${data}\'/></cluster_property_set>\\\\\\\" &>/dev/null\\\\n    return $?\\\\n}\\\\n\\\\nlock_update() {\\\\n    local name=$1\\\\n    local expected_data=$2\\\\n    local new_data=$3\\\\n    # we only update the lock we expect to see, so we can\'t update someone else\'s lock\\\\n    cibadmin --sync-call --scope crm_config --modify --xpath \\\\\\\"//cluster_property_set/nvpair[@name=\'${name}\' and @value=\'${expected_data}\']/..\\\\\\\" --xml-text \\\\\\\"<nvpair id=\'${name}-pair\' name=\'${name}\' value=\'${new_data}\'/>\\\\\\\" &>/dev/null\\\\n    return $?\\\\n}\\\\n\\\\nlock_delete() {\\\\n    local name=$1\\\\n    local expected_data=$2\\\\n    # we only delete the lock we expect to see, so we can\'t delete someone else\'s lock\\\\n    cibadmin --sync-call --scope crm_config --delete --xpath \\\\\\\"//cluster_property_set/nvpair[@name=\'${name}\' and @value=\'${expected_data}\']/..\\\\\\\" &>/dev/null\\\\n    return $?\\\\n}\\\\n\\\\nlock_get() {\\\\n    local lockname=$1\\\\n    local res\\\\n    local rc\\\\n    res=$(cibadmin --query --scope crm_config --xpath \\\\\\\"//cluster_property_set/nvpair[@name=\'$lockname\']\\\\\\\" 2>/dev/null)\\\\n    rc=$?\\\\n    if [ $rc -eq 0 ]; then\\\\n        echo \\\\\\\"$res\\\\\\\" | sed -n \'s/.*value=\\\\\\\"\\\\\\\\([^\\\\\\\"]*\\\\\\\\)\\\\\\\".*/\\\\\\\\1/p\'\\\\n    fi\\\\n    return $rc\\\\n}\\\\n\\\\nlock_owner() {\\\\n    local lock=$1\\\\n    echo \\\\\\\"$lock\\\\\\\" | cut -d\':\' -f1\\\\n}\\\\n\\\\nlock_has_expired() {\\\\n    local lock=$1\\\\n    local expiry=$(echo \\\\\\\"$lock\\\\\\\" | cut -d\':\' -f2)\\\\n    local now=$(date +%s)\\\\n    test $now -ge $expiry\\\\n}\\\\n\\\\n\\\\n# Perform a lock action and restart if the CIB has been modified before\\\\n# committing the lock action\\\\ntry_action() {\\\\n    local fun=$1\\\\n    local lock=$2\\\\n    local requester=$3\\\\n    local args=${4:-}\\\\n    local tries=$MAX_RETRIES\\\\n    local rc=1\\\\n    if [ \\\\\\\"$fun\\\\\\\" = \\\\\\\"lock_acquire\\\\\\\" ] || [ \\\\\\\"$fun\\\\\\\" = \\\\\\\"lock_release\\\\\\\" ]; then\\\\n        log \\\\\\\"Try running $fun\\\\\\\"\\\\n    else\\\\n        return 2\\\\n    fi\\\\n    while [ $rc -ne 0 ]; do\\\\n        $fun $lock $requester $args\\\\n        rc=$?\\\\n        if [ $rc -eq 0 ]; then\\\\n            log \\\\\\\"Operation $1 succeeded\\\\\\\"\\\\n            return 0\\\\n        elif [ $rc -eq 3 ]; then\\\\n            # rc == 3 -> CIB changed before push\\\\n            if [ $tries -eq 0 ]; then\\\\n                log \\\\\\\"Failed to commit after $MAX_RETRIES retries. Bailing out.\\\\\\\"\\\\n                return 2\\\\n            else\\\\n                log \\\\\\\"Failed to commit. Retrying operation.\\\\\\\"\\\\n                tries=$(($tries - 1))\\\\n            fi\\\\n        elif [ $rc -eq 2 ]; then\\\\n            # rc == 2 -> unrecoverable cib error (e.g. pacemaker down)\\\\n            log \\\\\\\"Unexpected failure. Bailing out\\\\\\\"\\\\n            return $rc\\\\n        else\\\\n            # rc == 1 -> lock error (not owner, lock doesn\'t exists)\\\\n            return $rc\\\\n        fi\\\\n    done\\\\n}\\\\n\\\\n# The lock mechanism uses cibadmin\'s atomic creation so cluster-wide\\\\n# state coherency is guaranteed by pacemaker\\\\nlock_acquire() {\\\\n    local lockname=$1\\\\n    local requester=$2\\\\n    local ttl=$3\\\\n    local rc\\\\n    local lock\\\\n    local expiry\\\\n    local owner\\\\n\\\\n    log \\\\\\\"Check whether the lock is already held in the CIB\\\\\\\"\\\\n    lock=$(lock_get $lockname)\\\\n    rc=$?\\\\n    if [ $rc -ne 0 ] && [ $rc -ne $CIB_ENOTFOUND ]; then\\\\n        log \\\\\\\"Could not retrieve info from the CIB\\\\\\\"\\\\n        return 2\\\\n    fi\\\\n\\\\n    if [ -n \\\\\\\"$lock\\\\\\\" ]; then\\\\n        lock_has_expired $lock\\\\n        rc=$?\\\\n        if [ $rc -eq 0 ]; then\\\\n            log \\\\\\\"Lock has expired, now available for being held\\\\\\\"\\\\n        else\\\\n            # lock is still held. check whether we\'re the owner\\\\n            owner=$(lock_owner $lock)\\\\n            if [ \\\\\\\"$owner\\\\\\\" = \\\\\\\"$requester\\\\\\\" ];then\\\\n                log \\\\\\\"Requester already owns the lock, acquiring attempt will just reconfigure the TTL\\\\\\\"\\\\n            else\\\\n                log \\\\\\\"Lock is held by someone else ($owner)\\\\\\\"\\\\n                return 1\\\\n            fi\\\\n        fi\\\\n    else\\\\n        log \\\\\\\"Lock is not held yet\\\\\\\"\\\\n    fi\\\\n\\\\n    # prepare the lock info\\\\n    expiry=$(($(date +%s) + $ttl))\\\\n\\\\n    if [ -n \\\\\\\"$lock\\\\\\\" ]; then\\\\n        log \\\\\\\"Attempting to update the lock\\\\\\\"\\\\n        lock_update $lockname \\\\\\\"$lock\\\\\\\" \\\\\\\"$requester:$expiry\\\\\\\"\\\\n        rc=$?\\\\n    else\\\\n        log \\\\\\\"Attempting to acquire the lock\\\\\\\"\\\\n        lock_create $lockname \\\\\\\"$requester:$expiry\\\\\\\"\\\\n        rc=$?\\\\n    fi\\\\n\\\\n    if [ $rc -eq 0 ]; then\\\\n        log \\\\\\\"Lock \'$lockname\' acquired by \'$requester\', valid until $(date -d @$expiry)\\\\\\\"\\\\n        return 0\\\\n    else\\\\n        log \\\\\\\"CIB changed, lock cannot be acquired\\\\\\\"\\\\n        return 3\\\\n    fi\\\\n}\\\\n\\\\n\\\\n# The lock mechanism uses the CIB\'s num_updates tag to implement\\\\n# a conditional store. Cluster-wide locking is guaranteed by pacemaker\\\\nlock_release() {\\\\n    local lockname=$1\\\\n    local requester=$2\\\\n    local rc\\\\n    local lock\\\\n    local owner\\\\n\\\\n    log \\\\\\\"Check whether the lock is already held in the CIB\\\\\\\"\\\\n    lock=$(lock_get $lockname)\\\\n    rc=$?\\\\n    if [ $rc -ne 0 ] && [ $rc -ne $CIB_ENOTFOUND ]; then\\\\n        log \\\\\\\"Could not retrieve info from the CIB\\\\\\\"\\\\n        return 2\\\\n    fi\\\\n\\\\n    if [ -z \\\\\\\"$lock\\\\\\\" ]; then\\\\n        log \\\\\\\"Lock doesn\'t exist. Nothing to release\\\\\\\"\\\\n        return 0\\\\n    else\\\\n        log \\\\\\\"Lock exists, check whether we\'re the owner\\\\\\\"\\\\n        owner=$(lock_owner $lock)\\\\n        if [ \\\\\\\"$owner\\\\\\\" != \\\\\\\"$requester\\\\\\\" ];then\\\\n            log \\\\\\\"Lock is held by someone else ($owner), will not unlock\\\\\\\"\\\\n            return 1\\\\n        fi\\\\n    fi\\\\n\\\\n    lock_delete $lockname \\\\\\\"$lock\\\\\\\"\\\\n    rc=$?\\\\n\\\\n    if [ $rc -eq 0 ]; then\\\\n        log \\\\\\\"Lock \'$lockname\' released by \'$requester\'\\\\\\\"\\\\n        return 0\\\\n    else\\\\n        log \\\\\\\"CIB deletion error, lock cannot be released\\\\\\\"\\\\n        return 3\\\\n    fi\\\\n}\\\\n\\\\n\\\\n# Retrieve the owner of a lock from the CIB\\\\n# this is a read-only operation, so no need to log debug info\\\\nlock_get_owner() {\\\\n    local lockname=$1\\\\n    local rc\\\\n    local lock\\\\n    local owner\\\\n\\\\n    lock=$(lock_get $lockname)\\\\n    rc=$?\\\\n    if [ $rc -ne 0 ] && [ $rc -ne $CIB_ENOTFOUND ]; then\\\\n        return 2\\\\n    fi\\\\n\\\\n    if [ -z \\\\\\\"$lock\\\\\\\" ]; then\\\\n        return 1\\\\n    else\\\\n        lock_owner $lock\\\\n        return 0\\\\n    fi\\\\n}\\\\n\\\\n\\\\nACTION=$1\\\\nLOCKNAME=$2\\\\nREQUESTER=$3\\\\nTTL=${4:-60}\\\\n\\\\nif [ -z \\\\\\\"$ACTION\\\\\\\" ]; then\\\\n    error \\\\\\\"Action must be specified\\\\\\\"\\\\nfi\\\\n\\\\nif [ $ACTION != \\\\\\\"--help\\\\\\\" ]; then\\\\n    if [ -z \\\\\\\"$LOCKNAME\\\\\\\" ]; then\\\\n        error \\\\\\\"You must specific a lock name\\\\\\\"\\\\n    fi\\\\n    if [ $ACTION != \\\\\\\"--owner\\\\\\\" ] && [ $ACTION != \\\\\\\"-o\\\\\\\" ]; then\\\\n        if [ -z \\\\\\\"$REQUESTER\\\\\\\" ]; then\\\\n            error \\\\\\\"You must specific a lock requester\\\\\\\"\\\\n        fi\\\\n    fi\\\\nfi\\\\n\\\\ncase $ACTION in\\\\n    --help) usage; exit 0;;\\\\n    --acquire|-a) try_action lock_acquire $LOCKNAME $REQUESTER $TTL;;\\\\n    --release|-r) try_action lock_release $LOCKNAME $REQUESTER;;\\\\n    --acquire-once|-A) lock_acquire $LOCKNAME $REQUESTER $TTL;;\\\\n    --owner|-o) lock_get_owner $LOCKNAME;;\\\\n    *) error \\\\\\\"Invalid action\\\\\\\";;\\\\nesac\\\\nexit $?\\\\n\\\"}, \\\"pacemaker_mutex_restart_bundle.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\n# pacemaker_mutex_restart_bundle.sh --lock mysql galera galera-bundle Master _\\\\n# pacemaker_mutex_restart_bundle.sh --lock ovn_dbs ovndb_servers ovn-dbs-bundle Slave Master\\\\n\\\\nset -u\\\\n\\\\nusage() {\\\\n    echo \\\\\\\"Restart a clustered resource in a coordinated way across the cluster\\\\\\\"\\\\n    echo \\\\\\\"Usage:\\\\\\\"\\\\n    echo \\\\\\\"   $0 --lock <tripleo-service> <pcmk-resource> <pcmk-bundle> <target-state-local> <target-state-cluster>\\\\\\\"\\\\n    echo\\\\n}\\\\n\\\\nlog() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\"\\\\n}\\\\n\\\\nerror() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\" 1>&2\\\\n    exit 1\\\\n}\\\\n\\\\npacemaker_supports_promoted() {\\\\n    # The Promoted token is only matched in recent pacemaker versions\\\\n    grep -wq \\\\\\\"<value>Promoted</value>\\\\\\\" /usr/share/pacemaker/resources-*.rng\\\\n}\\\\n\\\\nACTION=$1\\\\ncase $ACTION in\\\\n    --help) usage; exit 0;;\\\\n    --lock) ;;\\\\n    *) error \\\\\\\"Unknown action \'$ACTION\'\\\\\\\";;\\\\nesac\\\\n\\\\nTRIPLEO_SERVICE=$2\\\\nLOCK_NAME=${TRIPLEO_SERVICE}-restart-lock\\\\nLOCK_OWNER=$(crm_node -n 2>/dev/null)\\\\nrc=$?\\\\nif [ $rc -ne 0 ]; then\\\\n    if [ $rc -eq 102 ]; then\\\\n        log \\\\\\\"Cluster is not running locally, no need to restart resource $TRIPLEO_SERVICE\\\\\\\"\\\\n        exit 0\\\\n    else\\\\n        error \\\\\\\"Unexpected error while connecting to the cluster (rc: $rc), bailing out\\\\\\\"\\\\n    fi\\\\nfi\\\\n\\\\nRESOURCE_NAME=$3\\\\nBUNDLE_NAME=$4\\\\nWAIT_TARGET_LOCAL=$5\\\\nWAIT_TARGET_ANYWHERE=${6:-_}\\\\n\\\\nif pacemaker_supports_promoted; then\\\\n    WAIT_TARGET_LOCAL=$(echo \\\\\\\"$5\\\\\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\\\n    WAIT_TARGET_ANYWHERE=$(echo \\\\\\\"${6:-_}\\\\\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\\\n    promoted_role=\\\\\\\"Promoted\\\\\\\"\\\\nelse\\\\n    promoted_role=\\\\\\\"Master\\\\\\\"\\\\nfi\\\\n\\\\n# The lock TTL should accomodate for the resource start/promote timeout\\\\nif [ \\\\\\\"$RESOURCE_NAME\\\\\\\" != \\\\\\\"$BUNDLE_NAME\\\\\\\" ]; then\\\\n    if [ \\\\\\\"$WAIT_TARGET_LOCAL\\\\\\\" = \\\\\\\"$promoted_role\\\\\\\" ] || [ \\\\\\\"$WAIT_TARGET_ANYWHERE\\\\\\\" = \\\\\\\"$promoted_role\\\\\\\" ]; then\\\\n        rsc_op=\\\\\\\"promote\\\\\\\"\\\\n    else\\\\n        rsc_op=\\\\\\\"start\\\\\\\"\\\\n    fi\\\\n    # <op id=\\\\\\\"galera-promote-interval-0s\\\\\\\" interval=\\\\\\\"0s\\\\\\\" name=\\\\\\\"promote\\\\\\\" on-fail=\\\\\\\"block\\\\\\\" timeout=\\\\\\\"300s\\\\\\\"/>\\\\n    PCMK_TTL=$(cibadmin -Q | xmllint -xpath \\\\\\\"string(//primitive[@id=\'${RESOURCE_NAME}\']/operations/op[@name=\'${rsc_op}\']/@timeout)\\\\\\\" - | sed \'s/s$//\')\\\\n    LOCK_TTL=$((PCMK_TTL + 30))\\\\nelse\\\\n    # The podman RA\'s default start timeout\\\\n    LOCK_TTL=90\\\\nfi\\\\n\\\\nlog \\\\\\\"Acquire a ${LOCK_TTL}s restart lock for service $TRIPLEO_SERVICE before restarting it\\\\\\\"\\\\n# Loop until we hold the lock. The lock has a TTL, so we\'re guaranteed to get it eventually\\\\nrc=1\\\\nwhile [ $rc -ne 0 ]; do\\\\n    /var/lib/container-config-scripts/pacemaker_resource_lock.sh --acquire $LOCK_NAME $LOCK_OWNER $LOCK_TTL\\\\n    rc=$?\\\\n    if [ $rc != 0 ]; then\\\\n        if [ $rc -gt 1 ]; then\\\\n            error \\\\\\\"Could not acquire lock due to unrecoverable error (rc: $rc), bailing out\\\\\\\"\\\\n        else\\\\n            log \\\\\\\"Could not acquire lock, retrying\\\\\\\"\\\\n            sleep 10\\\\n        fi\\\\n    fi\\\\ndone\\\\n\\\\nlog \\\\\\\"Restart the service $TRIPLEO_SERVICE locally\\\\\\\"\\\\n# Reuse the local restart script in t-h-t (driven by env var TRIPLEO_MINOR_UPDATE)\\\\nTRIPLEO_MINOR_UPDATE=true /var/lib/container-config-scripts/pacemaker_restart_bundle.sh $TRIPLEO_SERVICE $RESOURCE_NAME $BUNDLE_NAME $WAIT_TARGET_LOCAL $WAIT_TARGET_ANYWHERE\\\\n\\\\n# If we reached this point, always try to release the lock\\\\nlog \\\\\\\"Release the restart lock for service $TRIPLEO_SERVICE\\\\\\\"\\\\n/var/lib/container-config-scripts/pacemaker_resource_lock.sh --release $LOCK_NAME $LOCK_OWNER\\\\nrc=$?\\\\nif [ $rc -ne 0 ] && [ $rc -ne 1 ]; then\\\\n    error \\\\\\\"Could not release held lock (rc: $rc)\\\\\\\"\\\\nfi\\\\n\\\"}, \\\"pacemaker_mutex_shutdown.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\n# pacemaker_mutex_shutdown.sh --acquire\\\\n# pacemaker_mutex_shutdown.sh --release\\\\n\\\\nset -u\\\\n\\\\nusage() {\\\\n    echo \\\\\\\"Shutdown a cluster node in a coordinated way across the cluster\\\\\\\"\\\\n    echo \\\\\\\"Usage:\\\\\\\"\\\\n    echo \\\\\\\"   $0 --acquire # prevent other node from shutting down until we hold the lock\\\\\\\"\\\\n    echo \\\\\\\"   $0 --release # release the lock, other node can compete for the shutdown lock\\\\\\\"\\\\n    echo\\\\n}\\\\n\\\\nlog() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\"\\\\n}\\\\n\\\\nerror() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\" 1>&2\\\\n    exit 1\\\\n}\\\\n\\\\n# Loop until we hold the lock. The lock has a TTL, so we\'re guaranteed to get it eventually\\\\nshutdown_lock_acquire() {\\\\n    local lockname=$1\\\\n    local requester=$2\\\\n    local ttl=$3\\\\n    local rc=1\\\\n    local current_owner\\\\n    local owner_stopped\\\\n    local owner_rc\\\\n\\\\n    log \\\\\\\"Acquiring the shutdown lock\\\\\\\"\\\\n    while [ $rc -ne 0 ]; do\\\\n        /var/lib/container-config-scripts/pacemaker_resource_lock.sh --acquire-once $lockname $requester $ttl\\\\n        rc=$?\\\\n        if [ $rc -ne 0 ]; then\\\\n            if [ $rc -eq 2 ]; then\\\\n                error \\\\\\\"Could not acquire the shutdown lock due to unrecoverable error (rc: $rc), bailing out\\\\\\\"\\\\n            else\\\\n                # The lock is held by another node.\\\\n                current_owner=$(/var/lib/container-config-scripts/pacemaker_resource_lock.sh --owner $lockname)\\\\n                owner_rc=$?\\\\n                if [ $owner_rc -eq 2 ]; then\\\\n                    error \\\\\\\"Could not get the shutdown lock owner due to unrecoverable error (rc: $owner_rc), bailing out\\\\\\\"\\\\n                fi\\\\n                if [ $owner_rc -eq 0 ]; then\\\\n                    # If the owner is marked as offline, that means it has shutdown and\\\\n                    # we can clean the lock preemptively and try to acquire it.\\\\n                    owner_stopped=$(crm_mon -1X | xmllint --xpath \'count(//nodes/node[@name=\\\\\\\"\'${current_owner}\'\\\\\\\" and @online=\\\\\\\"false\\\\\\\" and @unclean=\\\\\\\"false\\\\\\\"])\' -)\\\\n                    if [ \\\\\\\"${owner_stopped}\\\\\\\" = \\\\\\\"1\\\\\\\" ]; then\\\\n                        log \\\\\\\"Shutdown lock held by stopped node \'${current_owner}\', lock can be released\\\\\\\"\\\\n                        /var/lib/container-config-scripts/pacemaker_resource_lock.sh --release $lockname $current_owner\\\\n                        continue\\\\n                    fi\\\\n                fi\\\\n                log \\\\\\\"Shutdown lock held by another node (rc: $rc), retrying\\\\\\\"\\\\n                sleep 10\\\\n            fi\\\\n        fi\\\\n    done\\\\n    log \\\\\\\"Shutdown lock acquired\\\\\\\"\\\\n    return 0\\\\n}\\\\n\\\\n\\\\n# Release the lock if we still own it. Not owning it anymore is not fatal\\\\nshutdown_lock_release() {\\\\n    local lockname=$1\\\\n    local requester=$2\\\\n    local rc\\\\n\\\\n    log \\\\\\\"Releasing the shutdown lock\\\\\\\"\\\\n    /var/lib/container-config-scripts/pacemaker_resource_lock.sh --release $lockname $requester\\\\n    rc=$?\\\\n    if [ $rc -ne 0 ]; then\\\\n        if [ $rc -gt 1 ]; then\\\\n            error \\\\\\\"Could not release the shutdown lock due to unrecoverable error (rc: $rc), bailing out\\\\\\\"\\\\n        else\\\\n            log \\\\\\\"Shutdown lock no longer held, nothing to do\\\\\\\"\\\\n        fi\\\\n    else\\\\n        log \\\\\\\"Shutdown lock released\\\\\\\"\\\\n    fi\\\\n    return 0\\\\n}\\\\n\\\\n\\\\nACTION=$1\\\\nif [ -z \\\\\\\"$ACTION\\\\\\\" ]; then\\\\n    error \\\\\\\"Action must be specified\\\\\\\"\\\\nfi\\\\n\\\\nLOCK_NAME=tripleo-shutdown-lock\\\\nLOCK_OWNER=$(crm_node -n 2>/dev/null)\\\\nrc=$?\\\\nif [ $rc -ne 0 ]; then\\\\n    if [ $rc -eq 102 ]; then\\\\n        log \\\\\\\"Cluster is not running locally, no need to aquire the shutdown lock\\\\\\\"\\\\n        exit 0\\\\n    else\\\\n        error \\\\\\\"Unexpected error while connecting to the cluster (rc: $rc), bailing out\\\\\\\"\\\\n    fi\\\\nfi\\\\n\\\\n# We start with a very high TTL, that long enough to accomodate a cluster stop.\\\\n# As soon as the node will get offline, the other competing node will be entitled\\\\n# to steal the lock, so they should never wait that long in practice.\\\\nLOCK_TTL=600\\\\n\\\\n\\\\ncase $ACTION in\\\\n    --help) usage; exit 0;;\\\\n    --acquire|-a) shutdown_lock_acquire ${LOCK_NAME} ${LOCK_OWNER} ${LOCK_TTL};;\\\\n    --release|-r) shutdown_lock_release ${LOCK_NAME} ${LOCK_OWNER};;\\\\n    *) error \\\\\\\"Invalid action\\\\\\\";;\\\\nesac\\\\nexit $?\\\\n\\\"}, \\\"collectd_check_health.py\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/python3\\\\n#\\\\n# Copyright 2022 Red Hat Inc.\\\\n#\\\\n# Licensed under the Apache License, Version 2.0 (the \\\\\\\"License\\\\\\\"); you may\\\\n# not use this file except in compliance with the License. You may obtain\\\\n# a copy of the License at\\\\n#\\\\n#      http://www.apache.org/licenses/LICENSE-2.0\\\\n#\\\\n# Unless required by applicable law or agreed to in writing, software\\\\n# distributed under the License is distributed on an \\\\\\\"AS IS\\\\\\\" BASIS, WITHOUT\\\\n# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the\\\\n# License for the specific language governing permissions and limitations\\\\n# under the License.\\\\n\\\\nimport json\\\\nimport os\\\\nimport re\\\\nimport shutil\\\\nimport subprocess\\\\nimport sys\\\\n\\\\nfrom pkg_resources import packaging\\\\n\\\\n\\\\nSOCKET = \\\\\\\"unix:/run/podman/podman.sock\\\\\\\"\\\\nPS_FORMAT = (\'{\\\\\\\"service\\\\\\\": \\\\\\\"{{.Names}}\\\\\\\", \\\\\\\"container\\\\\\\": \\\\\\\"{{.ID}}\\\\\\\", \'\\\\n             \'\\\\\\\"status\\\\\\\": \\\\\\\"{{.State}}\\\\\\\", \\\\\\\"healthy\\\\\\\": \\\\\\\"{{.Status}}\\\\\\\"},\')\\\\nBASE_FORMAT = \\\\\\\"{service: .Name, container: .Id, status: .State.Running, \\\\\\\"\\\\nRUNNING_REX = re.compile(r\\\\\\\"Up .*(?P<health>\\\\\\\\(u?n?healthy\\\\\\\\))\\\\\\\")\\\\nSKIP_LIST = [\'.*_bootstrap\', \'container-puppet-.*\', \'.*_db_sync\',\\\\n             \'.*_cron\', \'create_.*_wrapper\', \'.*_wait_bundle\',\\\\n             \'configure_.*\', \'.*_fix_perms\', \'.*_init_logs?\',\\\\n             \'.*_init_perm\', \'(nova|placement)_wait_for_.*\', \'nova_.*ensure_\',\\\\n             \'(swift_)?setup_.*\', \'mysql_data_ownership\', \'swift_copy_rings\',\\\\n             \'nova_statedir_owner\']\\\\n\\\\n\\\\nclass ExecuteError(Exception):\\\\n    def __init__(self, rc, msg):\\\\n        self.rc = rc\\\\n        self.msg = msg\\\\n        super().__init__()\\\\n\\\\n\\\\ndef execute(cmd, workdir: str = None,\\\\n            prev_proc: subprocess.Popen = None) -> subprocess.Popen:\\\\n    # Note(mmagr): When this script is executed by collectd-sensubility started\\\\n    #              via collectd the script has non-root permission but inherits\\\\n    #              environment from collectd with root permission. We need\\\\n    #              to avoid sensubility access /root when using podman-remote.\\\\n    #              See https://bugzilla.redhat.com/show_bug.cgi?id=2091076 for\\\\n    #              more info.\\\\n    proc_env = os.environ.copy()\\\\n    proc_env[\\\\\\\"HOME\\\\\\\"] = \\\\\\\"/tmp\\\\\\\"\\\\n    if type(cmd[0]) is list:  # multiple piped commands\\\\n        last = prev_proc\\\\n        for c in cmd:\\\\n            last = execute(c, workdir, last)\\\\n        return last\\\\n    else:  # single command\\\\n        inpipe = prev_proc.stdout if prev_proc is not None else None\\\\n        proc = subprocess.Popen(cmd, cwd=workdir, env=proc_env, stdin=inpipe,\\\\n                                stdout=subprocess.PIPE, stderr=subprocess.PIPE)\\\\n        if prev_proc is not None:\\\\n            prev_proc.stdout.close()\\\\n            prev_proc.stderr.close()\\\\n        return proc\\\\n\\\\n\\\\ndef get_health_from_status(status):\\\\n    healthy = status in (\'healthy\', \'running\')\\\\n    return int(healthy)\\\\n\\\\n\\\\ndef fetch_state_from_inspect(cont, fmt):\\\\n    proc = execute([\\\\n        [shutil.which(\'podman-remote\'),\\\\n           \'--url\', SOCKET, \'inspect\', cont[\\\\\\\"container\\\\\\\"]],\\\\n        [shutil.which(\'jq\'), \'.[] | %s\' % fmt]\\\\n    ])\\\\n    o, e = proc.communicate()\\\\n    if proc.returncode != 0:\\\\n        msg = \\\\\\\"Failed to fetch status of %s: %s\\\\\\\" % (cont, e.decode())\\\\n        raise ExecuteError(proc.returncode, msg)\\\\n\\\\n    item = json.loads(o.decode())\\\\n    item[\'status\'] = \'running\' if item[\'status\'] else \'stopped\'\\\\n    if len(item[\'healthy\']) > 0 and item[\'status\'] != \'stopped\':\\\\n        item[\'status\'] = item[\'healthy\']\\\\n\\\\n    item[\'healthy\'] = get_health_from_status(item[\'status\'])\\\\n    return item\\\\n\\\\n\\\\ndef fetch_state(item):\\\\n    if \'up \' in item[\'status\'].lower():\\\\n        item[\'status\'] = \'running\'\\\\n    if item[\'status\'] != \'running\':\\\\n        item[\'status\'] = \'stopped\'\\\\n\\\\n    match = RUNNING_REX.match(item[\'healthy\'])\\\\n    if match:\\\\n        health = match.group(\'health\')\\\\n    else:\\\\n        health = \'\'\\\\n    if health:\\\\n        item[\'status\'] = health.strip(\\\\\\\"()\\\\\\\")\\\\n\\\\n    item[\'healthy\'] = get_health_from_status(item[\'status\'])\\\\n    return item\\\\n\\\\n\\\\ndef fetch_container_health(ps_result, inspect_fmt):\\\\n\\\\n    def container_filter(item):\\\\n        for rx in [re.compile(i) for i in SKIP_LIST]:\\\\n            if rx.match(item[\\\\\\\"service\\\\\\\"]):\\\\n                return False\\\\n        return True\\\\n    try:\\\\n        containers = filter(container_filter, json.loads(ps_result))\\\\n    except json.decoder.JSONDecodeError:\\\\n        return 1, \\\\\\\"%s\\\\\\\\nFailed to parse above output.\\\\\\\" % ps_result\\\\n\\\\n    out = []\\\\n    for cont in containers:\\\\n        try:\\\\n            out.append(fetch_state(cont))\\\\n        except Exception:\\\\n            # fallback to slow inspect way in case of any error\\\\n            try:\\\\n                out.append(fetch_state_from_inspect(cont, inspect_fmt))\\\\n            except ExecuteError as ex:\\\\n                return ex.rc, ex.msg\\\\n    return 0, out\\\\n\\\\n\\\\nif __name__ == \\\\\\\"__main__\\\\\\\":\\\\n    proc = execute([shutil.which(\'podman-remote\'),\\\\n                    \'--url\', SOCKET, \'version\',\\\\n                    \'--format\', r\'{{.Server.Version}}\'])\\\\n    o, e = proc.communicate()\\\\n    try:\\\\n        if packaging.version.parse(o.decode().strip()) >= packaging.version.parse(\\\\\\\"4.0.0\\\\\\\"):\\\\n            inspect_fmt = BASE_FORMAT + \\\\\\\"healthy: .State.Health.Status}\\\\\\\"\\\\n        else:\\\\n            inspect_fmt = BASE_FORMAT + \\\\\\\"healthy: .State.Healthcheck.Status}\\\\\\\"\\\\n    except Exception:\\\\n        # keep podman-4.0.0+ format in case of version decoding error\\\\n        inspect_fmt = BASE_FORMAT + \\\\\\\"healthy: .State.Health.Status}\\\\\\\"\\\\n\\\\n    proc = execute([shutil.which(\'podman-remote\'), \'--url\', SOCKET,\\\\n                    \'ps\', \'--all\', \'--format\', PS_FORMAT])\\\\n    o, e = proc.communicate()\\\\n    if proc.returncode != 0:\\\\n        print(\\\\\\\"Failed to list containers:\\\\\\\\n%s\\\\\\\\n%s\\\\\\\" % (o.decode(), e.decode()))\\\\n        sys.exit(1)\\\\n\\\\n    rc, status = fetch_container_health(\\\\\\\"[%s]\\\\\\\" % o.decode().strip(\\\\\\\"\\\\\\\\n,\\\\\\\"), inspect_fmt)\\\\n    if rc != 0:\\\\n        print(\\\\\\\"Failed to inspect containers:\\\\\\\\n%s\\\\\\\" % status)\\\\n        sys.exit(rc)\\\\n    print(json.dumps(status))\\\\n\\\"}}, \\\"docker_config\\\": {\\\"step_3\\\": {\\\"collectd\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\\\", \\\"net\\\": \\\"host\\\", \\\"pid\\\": \\\"host\\\", \\\"user\\\": \\\"root\\\", \\\"restart\\\": \\\"always\\\", \\\"memory\\\": \\\"512m\\\", \\\"cap_add\\\": [\\\"IPC_LOCK\\\"], \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/lib/kolla/config_files/collectd.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/containers/storage/overlay-containers:/var/lib/containers/storage/overlay-containers:ro\\\", \\\"/var/lib/config-data/puppet-generated/collectd:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/log/containers/collectd:/var/log/collectd:rw,z\\\", \\\"/var/lib/container-config-scripts:/config-scripts:ro\\\", \\\"/var/lib/container-user-scripts:/scripts:z\\\", \\\"/run:/run:rw\\\", \\\"/sys/fs/cgroup:/sys/fs/cgroup:ro\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/collectd\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}, {\\\"path\\\": \\\"/var/lib/container-user-scripts/\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0755\\\"}]}, {\\\"name\\\": \\\"import provision_mcelog\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_provision_mcelog\\\"}, \\\"when\\\": false}], \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"set enable_sensubility fact\\\", \\\"set_fact\\\": {\\\"enable_sensubility\\\": false}}, {\\\"name\\\": \\\"create podman socket for sensubility purposes\\\", \\\"block\\\": [{\\\"name\\\": \\\"create podman socket and appropriate systemd service\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_podman\\\", \\\"tasks_from\\\": \\\"tripleo_podman_service\\\"}, \\\"vars\\\": {\\\"tripleo_podman_socket_path\\\": \\\"/var/lib/tripleo-podman/collectd/podman.sock\\\"}}, {\\\"name\\\": \\\"create systemd service for ensuring socket file ACL contains collectd\\\", \\\"become\\\": true, \\\"ansible.builtin.copy\\\": {\\\"content\\\": \\\"[Unit]\\\\nDescription=ACL setting for /var/lib/tripleo-podman/collectd/podman.sock\\\\nRequires=tripleo_collectd.service\\\\nAfter=tripleo_podman.service\\\\nAfter=tripleo_collectd.service\\\\n\\\\n[Service]\\\\nType=oneshot\\\\nExecStart=/usr/bin/podman exec -it collectd setfacl -m m:rwx /run/podman/podman.sock\\\\nExecStart=/usr/bin/podman exec -it collectd setfacl -R -m u:collectd:rwx /run/podman\\\\nExecStart=/usr/bin/podman exec -it collectd setfacl -d -m u:collectd:rwx /run/podman\\\\n\\\\n[Install]\\\\nWantedBy=multi-user.target\\\\n\\\", \\\"dest\\\": \\\"/etc/systemd/system/tripleo_podman_collectd_acl.service\\\", \\\"mode\\\": 420}}, {\\\"name\\\": \\\"enable podman.sock ACL service\\\", \\\"ansible.builtin.service\\\": {\\\"name\\\": \\\"tripleo_podman_collectd_acl.service\\\", \\\"enabled\\\": true}}, {\\\"name\\\": \\\"create directory for downloads of users\' scripts\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/lib/container-user-scripts\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0755\\\"}}, {\\\"name\\\": \\\"download exec scripts\\\", \\\"ansible.builtin.get_url\\\": {\\\"url\\\": \\\"{{ item.source }}\\\", \\\"checksum\\\": \\\"{{ item.checksum }}\\\", \\\"dest\\\": \\\"/var/lib/container-user-scripts/{{ item.name }}\\\", \\\"mode\\\": \\\"0755\\\"}, \\\"with_items\\\": []}], \\\"when\\\": [\\\"enable_sensubility|bool\\\", \\\"step|int == 1\\\"]}], \\\"update_tasks\\\": [{\\\"name\\\": \\\"remove rsyslog configuration for podman healthcheck log\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_podman\\\", \\\"tasks_from\\\": \\\"tripleo_podman_rsyslog_cleanup\\\"}}], \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"remove rsyslog configuration for podman healthcheck log\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_podman\\\", \\\"tasks_from\\\": \\\"tripleo_podman_rsyslog_cleanup\\\"}}, {\\\"name\\\": \\\"Force pull image collectd\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade\\\", \\\"system_upgrade_run\\\"], \\\"when\\\": [\\\"step|int == 3\\\"], \\\"containers.podman.podman_image\\\": {\\\"name\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\\\", \\\"force\\\": true}}, {\\\"name\\\": \\\"UBI8 to UBI9 switch of collectd\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade\\\", \\\"system_upgrade_run\\\"], \\\"when\\\": [\\\"step|int == 5\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Update collectd to UBI9\\\", \\\"tripleo_container_manage\\\": {\\\"config_dir\\\": \\\"/var/lib/tripleo-config/container-startup-config/step_3\\\", \\\"config_patterns\\\": \\\"collectd.json\\\", \\\"config_id\\\": [\\\"tripleo_step3\\\"], \\\"log_base_path\\\": \\\"{{ container_log_stdout_path }}\\\", \\\"debug\\\": \\\"{{ enable_debug | bool }}\\\", \\\"config_overrides\\\": {\\\"collectd\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\\\"}}}}]}]}, {\\\"service_name\\\": \\\"ceilometer_agent_compute\\\", \\\"monitoring_subscription\\\": \\\"overcloud-ceilometer-agent-compute\\\", \\\"config_settings\\\": {\\\"ceilometer::logging::debug\\\": true, \\\"ceilometer::agent::polling::manage_polling\\\": false, \\\"ceilometer::agent::service_credentials::password\\\": \\\"6GBzmfESOACPjM70aXaIF8M8d\\\", \\\"ceilometer::agent::service_credentials::auth_url\\\": \\\"https://overcloud.internalapi.ooo.test:5000\\\", \\\"ceilometer::agent::service_credentials::region_name\\\": \\\"regionOne\\\", \\\"ceilometer::agent::service_credentials::project_name\\\": \\\"service\\\", \\\"ceilometer::agent::service_credentials::user_domain_name\\\": \\\"Default\\\", \\\"ceilometer::agent::service_credentials::auth_project_domain_name\\\": \\\"Default\\\", \\\"ceilometer::agent::service_credentials::interface\\\": \\\"internalURL\\\", \\\"ceilometer::notification_driver\\\": [\\\"noop\\\"], \\\"ceilometer::amqp_rpc_address_prefix\\\": \\\"\\\", \\\"ceilometer::amqp_notify_address_prefix\\\": \\\"\\\", \\\"ceilometer::telemetry_secret\\\": \\\"jRuRaXv8Ar7kg4X44CLZE5d2r\\\", \\\"ceilometer::snmpd_readonly_username\\\": \\\"ro_snmp_user\\\", \\\"ceilometer::snmpd_readonly_user_password\\\": \\\"IUqJgJKOidh20dco1DYKnuQ1\\\", \\\"ceilometer::host\\\": \\\"%{hiera(\'fqdn_canonical\')}\\\", \\\"ceilometer::rabbit_heartbeat_in_pthread\\\": false, \\\"ceilometer::cache::enabled\\\": true, \\\"ceilometer::cache::tls_enabled\\\": true, \\\"ceilometer::cache::backend\\\": \\\"dogpile.cache.pymemcache\\\", \\\"ceilometer::cache::enable_socket_keepalive\\\": true, \\\"ceilometer::agent::polling::instance_discovery_method\\\": \\\"libvirt_metadata\\\", \\\"ceilometer_redis_password\\\": \\\"Qw5poqjrA95kbXlQw5cMcjZDa\\\", \\\"compute_namespace\\\": true, \\\"ceilometer::agent::polling::tenant_name_discovery\\\": false}, \\\"service_config_settings\\\": {\\\"keystone\\\": {\\\"tripleo::profile::base::keystone::ceilometer_notification_topics\\\": [\\\"notifications\\\"]}}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"ceilometer\\\", \\\"puppet_tags\\\": \\\"ceilometer_config\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::ceilometer::agent::polling\\\", \\\"config_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\\\"}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/ceilometer_agent_compute.json\\\": {\\\"command\\\": \\\"/usr/bin/ceilometer-polling --polling-namespaces compute --logfile /var/log/ceilometer/compute.log\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}]}}, \\\"docker_config\\\": {\\\"step_4\\\": {\\\"ceilometer_agent_compute\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\\\", \\\"net\\\": \\\"host\\\", \\\"privileged\\\": false, \\\"restart\\\": \\\"always\\\", \\\"depends_on\\\": [\\\"tripleo_nova_libvirt.target\\\"], \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/lib/kolla/config_files/ceilometer_agent_compute.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\\\", \\\"/run/libvirt:/run/libvirt:shared,z\\\", \\\"/var/log/containers/ceilometer:/var/log/ceilometer:z\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/ceilometer\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}]}, {\\\"name\\\": \\\"enable virt_sandbox_use_netlink for healthcheck\\\", \\\"seboolean\\\": {\\\"name\\\": \\\"virt_sandbox_use_netlink\\\", \\\"persistent\\\": true, \\\"state\\\": true}, \\\"when\\\": [\\\"ansible_facts.selinux is defined\\\", \\\"ansible_facts.selinux.status == \\\\\\\"enabled\\\\\\\"\\\"]}]}, {\\\"service_name\\\": \\\"ceilometer_agent_ipmi\\\", \\\"monitoring_subscription\\\": \\\"overcloud-ceilometer-agent-ipmi\\\", \\\"config_settings\\\": {\\\"ceilometer::logging::debug\\\": true, \\\"ceilometer::agent::polling::manage_polling\\\": false, \\\"ceilometer::agent::service_credentials::password\\\": \\\"6GBzmfESOACPjM70aXaIF8M8d\\\", \\\"ceilometer::agent::service_credentials::auth_url\\\": \\\"https://overcloud.internalapi.ooo.test:5000\\\", \\\"ceilometer::agent::service_credentials::region_name\\\": \\\"regionOne\\\", \\\"ceilometer::agent::service_credentials::project_name\\\": \\\"service\\\", \\\"ceilometer::agent::service_credentials::user_domain_name\\\": \\\"Default\\\", \\\"ceilometer::agent::service_credentials::auth_project_domain_name\\\": \\\"Default\\\", \\\"ceilometer::agent::service_credentials::interface\\\": \\\"internalURL\\\", \\\"ceilometer::notification_driver\\\": [\\\"noop\\\"], \\\"ceilometer::amqp_rpc_address_prefix\\\": \\\"\\\", \\\"ceilometer::amqp_notify_address_prefix\\\": \\\"\\\", \\\"ceilometer::telemetry_secret\\\": \\\"jRuRaXv8Ar7kg4X44CLZE5d2r\\\", \\\"ceilometer::snmpd_readonly_username\\\": \\\"ro_snmp_user\\\", \\\"ceilometer::snmpd_readonly_user_password\\\": \\\"IUqJgJKOidh20dco1DYKnuQ1\\\", \\\"ceilometer::host\\\": \\\"%{hiera(\'fqdn_canonical\')}\\\", \\\"ceilometer::rabbit_heartbeat_in_pthread\\\": false, \\\"ceilometer::cache::enabled\\\": true, \\\"ceilometer::cache::tls_enabled\\\": true, \\\"ceilometer::cache::backend\\\": \\\"dogpile.cache.pymemcache\\\", \\\"ceilometer::cache::enable_socket_keepalive\\\": true, \\\"ceilometer_redis_password\\\": \\\"Qw5poqjrA95kbXlQw5cMcjZDa\\\", \\\"ipmi_namespace\\\": true}, \\\"service_config_settings\\\": {\\\"rsyslog\\\": {\\\"tripleo_logging_sources_ceilometer_agent_ipmi\\\": [{\\\"tag\\\": \\\"openstack.ceilometer.agent.ipmi\\\", \\\"file\\\": \\\"/var/log/containers/ceilometer/ipmi.log\\\"}]}}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"ceilometer\\\", \\\"puppet_tags\\\": \\\"ceilometer_config\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::ceilometer::agent::polling\\\\n\\\", \\\"config_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\\\"}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/ceilometer-agent-ipmi.json\\\": {\\\"command\\\": \\\"/usr/bin/ceilometer-polling --polling-namespaces ipmi --logfile /var/log/ceilometer/ipmi.log\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}]}}, \\\"docker_config\\\": {\\\"step_3\\\": {\\\"ceilometer_init_log\\\": {\\\"start_order\\\": 0, \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\\\", \\\"net\\\": \\\"none\\\", \\\"user\\\": \\\"root\\\", \\\"command\\\": [\\\"/bin/bash\\\", \\\"-c\\\", \\\"chown -R ceilometer:ceilometer /var/log/ceilometer\\\"], \\\"volumes\\\": [\\\"/var/log/containers/ceilometer:/var/log/ceilometer:z\\\"]}}, \\\"step_4\\\": {\\\"ceilometer_agent_ipmi\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\\\", \\\"net\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/lib/kolla/config_files/ceilometer-agent-ipmi.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/ceilometer:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/log/containers/ceilometer:/var/log/ceilometer:z\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/ceilometer\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}]}]}, {\\\"service_name\\\": \\\"ipaservice\\\", \\\"upgrade_tasks\\\": [], \\\"step_config\\\": \\\"\\\", \\\"ipa_registration_tasks\\\": [{\\\"name\\\": \\\"Get undercloud FQDN\\\", \\\"delegate_to\\\": \\\"{{ groups[\'Undercloud\'] | first }}\\\", \\\"set_fact\\\": {\\\"undercloud_fqdn\\\": \\\"{{ ansible_facts[\'fqdn\'] }}\\\"}}, {\\\"include_role\\\": {\\\"name\\\": \\\"tripleo_ipa_registration\\\", \\\"apply\\\": {\\\"delegate_to\\\": \\\"{{ groups[\'Undercloud\'] | first }}\\\", \\\"environment\\\": {\\\"IPA_USER\\\": \\\"nova/{{ undercloud_fqdn }}\\\", \\\"KRB5_CLIENT_KTNAME\\\": \\\"FILE:/etc/novajoin/krb5.keytab\\\", \\\"KRB5CCNAME\\\": \\\"/etc/novajoin/krb5.cache\\\", \\\"IPA_HOST\\\": \\\"ipa.ooo.test\\\"}}}, \\\"vars\\\": {\\\"tripleo_ipa_enroll_base_server\\\": true, \\\"tripleo_ipa_delegate_server\\\": \\\"{{ inventory_hostname }}\\\", \\\"tripleo_ipa_base_server_fqdn\\\": \\\"{{ fqdn_canonical }}\\\", \\\"tripleo_ipa_server_metadata\\\": \\\"{{ service_metadata_settings | to_json }}\\\"}, \\\"when\\\": \\\"\'ipaservice\' in group_names and \'excluded_overcloud\' not in group_names\\\"}, {\\\"name\\\": \\\"Enroll the node as an ipa client\\\", \\\"vars\\\": {\\\"ipaclient_install_packages\\\": false, \\\"idm_enroll_base_server\\\": true}, \\\"block\\\": [{\\\"name\\\": \\\"check if default.conf exists\\\", \\\"stat\\\": {\\\"path\\\": \\\"/etc/ipa/default.conf\\\"}, \\\"register\\\": \\\"ipa_conf_exists\\\"}, {\\\"name\\\": \\\"install openssl-perl\\\", \\\"become\\\": true, \\\"package\\\": {\\\"name\\\": \\\"openssl-perl\\\", \\\"state\\\": \\\"present\\\"}, \\\"when\\\": [\\\"ipaclient_install_packages|bool\\\"]}, {\\\"name\\\": \\\"register as an ipa client\\\", \\\"include_role\\\": {\\\"name\\\": \\\"ipaclient\\\", \\\"apply\\\": {\\\"become\\\": true}}, \\\"vars\\\": {\\\"state\\\": \\\"present\\\", \\\"ipaclient_otp\\\": \\\"{{ ipa_host_otp }}\\\", \\\"ipaclient_mkhomedir\\\": false, \\\"ipaclient_no_ntp\\\": false, \\\"ipaclient_force\\\": true, \\\"ipaclient_hostname\\\": \\\"{{ fqdn_canonical }}\\\", \\\"ansible_fqdn\\\": \\\"{{ ipaclient_hostname }}\\\", \\\"ipaclients\\\": [\\\"ipaclient_hostname\\\"], \\\"ansible_distribution\\\": \\\"{{ ansible_facts[\'distribution\'] }}\\\", \\\"ansible_distribution_major_version\\\": \\\"{{ ansible_facts[\'distribution_major_version\'] }}\\\", \\\"ansible_distribution_release\\\": \\\"{{ ansible_facts[\'distribution_release\'] }}\\\", \\\"ansible_distribution_version\\\": \\\"{{ ansible_facts[\'distribution_version\'] }}\\\", \\\"ansible_os_family\\\": \\\"{{ ansible_facts[\'os_family\'] }}\\\", \\\"ipaclient_servers\\\": [\\\"ipa.ooo.test\\\"], \\\"ipaclient_domain\\\": \\\"ooo.test\\\"}, \\\"when\\\": [\\\"idm_enroll_base_server|bool\\\", \\\"not ipa_conf_exists.stat.exists\\\"]}, {\\\"name\\\": \\\"restart certmonger service\\\", \\\"become\\\": true, \\\"systemd\\\": {\\\"state\\\": \\\"restarted\\\", \\\"daemon_reload\\\": true, \\\"name\\\": \\\"certmonger.service\\\"}, \\\"when\\\": [\\\"idm_enroll_base_server|bool\\\", \\\"not ipa_conf_exists.stat.exists\\\"]}, {\\\"name\\\": \\\"set discovered ipa realm\\\", \\\"set_fact\\\": {\\\"idm_realm\\\": \\\"{{ lookup(\'ini\', \'realm default=OOO.TEST section=global file=/etc/ipa/default.conf\')}}\\\"}}], \\\"when\\\": \\\"\'ipaservice\' in group_names and \'excluded_overcloud\' not in group_names\\\"}], \\\"external_deploy_tasks\\\": [{\\\"name\\\": \\\"add the DNS entries into IPA in step 1\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"include_role\\\": {\\\"name\\\": \\\"tripleo_ipa_dns\\\"}, \\\"vars\\\": {\\\"tripleo_ipa_ptr_zone_split_ipv4\\\": \\\"1\\\", \\\"tripleo_ipa_ptr_zone_split_ipv6\\\": \\\"1\\\"}, \\\"when\\\": true}], \\\"environment\\\": {\\\"IPA_USER\\\": \\\"nova/{{ ansible_facts[\'fqdn\'] }}\\\", \\\"KRB5_CLIENT_KTNAME\\\": \\\"FILE:/etc/novajoin/krb5.keytab\\\", \\\"KRB5CCNAME\\\": \\\"/etc/novajoin/krb5.cache\\\", \\\"IPA_HOST\\\": \\\"ipa.ooo.test\\\"}}], \\\"scale_tasks\\\": [{\\\"when\\\": \\\"step|int == 1\\\", \\\"tags\\\": \\\"down\\\", \\\"block\\\": [{\\\"name\\\": \\\"unregister node from ipa server\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_ipa_cleanup\\\"}, \\\"delegate_to\\\": \\\"{{ groups[\'Undercloud\'] | first }}\\\", \\\"vars\\\": {\\\"tripleo_ipa_keytab\\\": \\\"FILE:/etc/novajoin/krb5.keytab\\\", \\\"tripleo_ipa_hosts_to_delete\\\": [\\\"{{ fqdn_canonical }}\\\"]}}]}], \\\"external_upgrade_tasks\\\": [{\\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"check if ipa server has required permissions\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tls_everywhere\\\", \\\"tasks_from\\\": \\\"ipa-server-check\\\"}, \\\"tags\\\": [\\\"opendev-validation\\\", \\\"opendev-validation-tls-everywhere\\\"]}]}]}, {\\\"service_name\\\": \\\"iscsid\\\", \\\"config_settings\\\": {\\\"tripleo::profile::base::iscsid::chap_algs\\\": \\\"SHA3-256,SHA256,SHA1,MD5\\\"}, \\\"service_config_settings\\\": {}, \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"Run lvmfilter role\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_lvmfilter\\\"}, \\\"when\\\": [\\\"step|int == 1\\\"]}], \\\"ansible_group_vars\\\": {\\\"tripleo_tripleo_lvmfilter_enabled\\\": false, \\\"tripleo_tripleo_lvmfilter_devices_allowlist\\\": [], \\\"tripleo_tripleo_lvmfilter_devices_denylist\\\": [\\\".*\\\"], \\\"ContainerIscsidImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\\\", \\\"ContainerIscsidConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\\\"}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"iscsid\\\", \\\"puppet_tags\\\": \\\"iscsid_config\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::iscsid\\\\n\\\", \\\"config_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\\\", \\\"volumes\\\": [\\\"/etc/iscsi:/tmp/iscsi.host:z\\\"]}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/iscsid.json\\\": {\\\"command\\\": \\\"/usr/sbin/iscsid -f\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src-iscsid/\\\", \\\"dest\\\": \\\"/etc/iscsi/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}]}}, \\\"docker_config\\\": {\\\"step_3\\\": {\\\"iscsid\\\": {\\\"start_order\\\": 2, \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\\\", \\\"net\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/lib/kolla/config_files/iscsid.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/dev:/dev\\\", \\\"/run:/run\\\", \\\"/sys:/sys\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\\\", \\\"/etc/target:/etc/target:z\\\", \\\"/var/lib/iscsi:/var/lib/iscsi:z\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create fcontext entry for iscsi\\\", \\\"community.general.sefcontext\\\": {\\\"target\\\": \\\"{{ item.path }}(/.*)?\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"state\\\": \\\"present\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/etc/iscsi\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/etc/target\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/var/lib/iscsi\\\", \\\"setype\\\": \\\"container_file_t\\\"}]}, {\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/etc/iscsi\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/etc/target\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/var/lib/iscsi\\\", \\\"setype\\\": \\\"container_file_t\\\"}]}, {\\\"name\\\": \\\"stat /lib/systemd/system/iscsid.socket\\\", \\\"stat\\\": \\\"path=/lib/systemd/system/iscsid.socket\\\", \\\"register\\\": \\\"stat_iscsid_socket\\\"}, {\\\"name\\\": \\\"Stop and disable iscsid.socket service\\\", \\\"service\\\": \\\"name=iscsid.socket state=stopped enabled=no\\\", \\\"when\\\": \\\"stat_iscsid_socket.stat.exists\\\"}, {\\\"name\\\": \\\"Check if iscsi.service is enabled\\\", \\\"command\\\": \\\"systemctl is-enabled --quiet iscsi.service\\\", \\\"failed_when\\\": false, \\\"register\\\": \\\"iscsi_service_enabled_result\\\"}, {\\\"name\\\": \\\"Stop iscsi.service\\\", \\\"service\\\": \\\"name=iscsi.service state=stopped enabled=no\\\", \\\"when\\\": [\\\"iscsi_service_enabled_result is changed\\\", \\\"iscsi_service_enabled_result.rc == 0\\\"]}], \\\"upgrade_tasks\\\": []}, {\\\"service_name\\\": \\\"kernel\\\", \\\"host_prep_tasks\\\": [{\\\"include_role\\\": {\\\"name\\\": \\\"tripleo_kernel\\\"}}], \\\"ansible_group_vars\\\": {\\\"hieradata_localhost_address\\\": \\\"localhost\\\", \\\"tripleo_kernel_extra_modules\\\": {}, \\\"tripleo_kernel_extra_packages\\\": {}, \\\"tripleo_kernel_sysctl_extra_settings\\\": {\\\"net.ipv6.conf.default.disable_ipv6\\\": {\\\"value\\\": 0}, \\\"net.ipv4.ip_local_reserved_ports\\\": {\\\"value\\\": \\\"35357,49000-49001\\\"}, \\\"net.ipv6.conf.all.disable_ipv6\\\": {\\\"value\\\": 0}, \\\"net.ipv6.conf.lo.disable_ipv6\\\": {\\\"value\\\": 0}, \\\"net.ipv4.ip_forward\\\": {\\\"value\\\": 1}, \\\"net.ipv4.conf.all.rp_filter\\\": {\\\"value\\\": 1}, \\\"net.ipv6.conf.all.forwarding\\\": {\\\"value\\\": 0}, \\\"net.ipv4.ip_nonlocal_bind\\\": {\\\"value\\\": 1}, \\\"net.ipv6.ip_nonlocal_bind\\\": {\\\"value\\\": 1}, \\\"kernel.pid_max\\\": {\\\"value\\\": 1048576}, \\\"net.ipv4.neigh.default.gc_thresh1\\\": {\\\"value\\\": 1024}, \\\"net.ipv4.neigh.default.gc_thresh2\\\": {\\\"value\\\": 2048}, \\\"net.ipv4.neigh.default.gc_thresh3\\\": {\\\"value\\\": 4096}, \\\"net.bridge.bridge-nf-call-arptables\\\": {\\\"value\\\": 1}, \\\"net.bridge.bridge-nf-call-iptables\\\": {\\\"value\\\": 1}, \\\"net.bridge.bridge-nf-call-ip6tables\\\": {\\\"value\\\": 1}, \\\"fs.inotify.max_user_instances\\\": {\\\"value\\\": 1024}, \\\"fs.aio-max-nr\\\": {\\\"value\\\": 1048576}}}}, {\\\"service_name\\\": \\\"metrics_qdr\\\", \\\"firewall_rules\\\": {\\\"109 metrics qdr\\\": {\\\"dport\\\": [5666]}, \\\"109 accept internal metrics qdr ctlplane subnet 192.168.122.0/24\\\": {\\\"dport\\\": [5667, 5668]}}, \\\"monitoring_subscription\\\": \\\"overcloud-qdr\\\", \\\"service_config_settings\\\": {\\\"rsyslog\\\": {\\\"tripleo_logging_sources_metrics_qdr\\\": [{\\\"tag\\\": \\\"openstack.nova.consoleauth\\\", \\\"file\\\": \\\"/var/log/containers/metrics_qdr/metrics_qdr.log\\\", \\\"startmsg.regex\\\": \\\"^[0-9]{4}-[0-9]{2}-[0-9]{2} [0-9]{2}:[0-9]{2}:[0-9]{2}(.[0-9]+ \\\\\\\\\\\\\\\\+[0-9]+)? [A-Z]+ \\\\\\\\\\\\\\\\([a-z]+\\\\\\\\\\\\\\\\) \\\"}]}}, \\\"config_settings\\\": {\\\"tripleo::profile::base::metrics::qdr::listener_addr\\\": \\\"%{hiera(\'internal_api\')}\\\", \\\"tripleo::haproxy::metrics_qdr\\\": false, \\\"tripleo::profile::base::metrics::qdr::listener_port\\\": 5666, \\\"tripleo::profile::base::metrics::qdr::username\\\": \\\"guest\\\", \\\"tripleo::profile::base::metrics::qdr::password\\\": \\\"guest\\\", \\\"tripleo::profile::base::metrics::qdr::connectors\\\": [], \\\"tripleo::profile::base::metrics::qdr::addresses\\\": [{\\\"prefix\\\": \\\"collectd\\\", \\\"distribution\\\": \\\"multicast\\\"}, {\\\"prefix\\\": \\\"ceilometer/metering.sample\\\", \\\"distribution\\\": \\\"multicast\\\"}, {\\\"prefix\\\": \\\"ceilometer/event.sample\\\", \\\"distribution\\\": \\\"multicast\\\"}], \\\"tripleo::profile::base::metrics::qdr::autolink_addresses\\\": [], \\\"tripleo::profile::base::metrics::qdr::listener_require_ssl\\\": false, \\\"tripleo::profile::base::metrics::qdr::listener_require_encrypt\\\": false, \\\"tripleo::profile::base::metrics::qdr::listener_sasl_mech\\\": \\\"ANONYMOUS\\\", \\\"tripleo::profile::base::metrics::qdr::listener_ssl_cert_db\\\": \\\"/etc/ipa/ca.crt\\\", \\\"tripleo::profile::base::metrics::qdr::listener_ssl_cert_file\\\": \\\"/etc/pki/tls/certs/metrics_qdr.crt\\\", \\\"tripleo::profile::base::metrics::qdr::listener_ssl_key_file\\\": \\\"/etc/pki/tls/private/metrics_qdr.key\\\", \\\"tripleo::profile::base::metrics::qdr::listener_ssl_pw_file\\\": \\\"\\\", \\\"tripleo::profile::base::metrics::qdr::listener_ssl_password\\\": \\\"\\\", \\\"tripleo::profile::base::metrics::qdr::listener_trusted_certs\\\": \\\"\\\", \\\"qdr::log_enable\\\": \\\"info+\\\", \\\"qdr::log_output\\\": \\\"/var/log/qdrouterd/metrics_qdr.log\\\", \\\"qdr::listener_auth_peer\\\": false, \\\"tripleo::profile::base::metrics::qdr::ssl_profiles\\\": [{\\\"name\\\": \\\"sslProfile\\\"}, {\\\"name\\\": \\\"tlsProfile\\\", \\\"certFile\\\": \\\"/etc/pki/tls/certs/metrics_qdr.crt\\\", \\\"keyFile\\\": \\\"/etc/pki/tls/private/metrics_qdr.key\\\", \\\"caCertFile\\\": \\\"/etc/ipa/ca.crt\\\"}]}, \\\"metadata_settings\\\": [{\\\"service\\\": \\\"metrics_qdr\\\", \\\"network\\\": \\\"internal_api\\\", \\\"type\\\": \\\"node\\\"}], \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"metrics_qdr\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::metrics::qdr\\\\n\\\", \\\"config_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\\\"}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/metrics_qdr.json\\\": {\\\"command\\\": \\\"/usr/sbin/qdrouterd -c /etc/qpid-dispatch/qdrouterd.conf\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-tls/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true, \\\"optional\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/lib/qdrouterd\\\", \\\"owner\\\": \\\"qdrouterd:qdrouterd\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/etc/pki/tls/certs/metrics_qdr.crt\\\", \\\"owner\\\": \\\"qdrouterd:qdrouterd\\\", \\\"optional\\\": true}, {\\\"path\\\": \\\"/etc/pki/tls/private/metrics_qdr.key\\\", \\\"owner\\\": \\\"qdrouterd:qdrouterd\\\", \\\"optional\\\": true}]}}, \\\"docker_config\\\": {\\\"step_1\\\": {\\\"metrics_qdr_init_logs\\\": {\\\"start_order\\\": 0, \\\"detach\\\": false, \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\\\", \\\"net\\\": \\\"none\\\", \\\"privileged\\\": false, \\\"user\\\": \\\"root\\\", \\\"volumes\\\": [\\\"/var/log/containers/metrics_qdr:/var/log/qdrouterd:z\\\"], \\\"command\\\": [\\\"/bin/bash\\\", \\\"-c\\\", \\\"chown -R qdrouterd:qdrouterd /var/log/qdrouterd\\\"]}, \\\"metrics_qdr\\\": {\\\"start_order\\\": 1, \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\\\", \\\"net\\\": \\\"host\\\", \\\"user\\\": \\\"qdrouterd\\\", \\\"privileged\\\": false, \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/lib/kolla/config_files/metrics_qdr.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/metrics_qdr:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/lib/metrics_qdr:/var/lib/qdrouterd:z\\\", \\\"/var/log/containers/metrics_qdr:/var/log/qdrouterd:z\\\", \\\"/etc/pki/tls/certs/metrics_qdr.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/metrics_qdr.crt:ro\\\", \\\"/etc/pki/tls/private/metrics_qdr.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/metrics_qdr.key:ro\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"Certificate generation\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"enable_internal_tls\\\"], \\\"block\\\": [{\\\"include_role\\\": {\\\"name\\\": \\\"linux-system-roles.certificate\\\"}, \\\"vars\\\": {\\\"certificate_requests\\\": [{\\\"name\\\": \\\"metrics_qdr\\\", \\\"dns\\\": \\\"{{fqdn_internal_api}}\\\", \\\"principal\\\": \\\"metrics_qdr/{{fqdn_internal_api}}@{{idm_realm}}\\\", \\\"run_after\\\": \\\"container_name=$({{container_cli}} ps --format=\\\\\\\\{\\\\\\\\{.Names\\\\\\\\}\\\\\\\\} | grep metrics_qdr)\\\\nservice_crt=\\\\\\\"/etc/pki/tls/certs/metrics_qdr.crt\\\\\\\"\\\\nservice_key=\\\\\\\"/etc/pki/tls/private/metrics_qdr.key\\\\n# Copy the new cert from the mount-point to the real path\\\\n{{container_cli}} exec \\\\\\\"$container_name\\\\\\\" cp \\\\\\\"/var/lib/kolla/config_files/src-tls$service_crt\\\\\\\" \\\\\\\"$service_crt\\\\\\\"\\\\n# Copy the new key from the mount-point to the real path\\\\n{{container_cli}} exec \\\\\\\"$container_name\\\\\\\" cp \\\\\\\"/var/lib/kolla/config_files/src-tls$service_key\\\\\\\" \\\\\\\"$service_key\\\\\\\"\\\\n# Set appropriate permissions\\\\n{{container_cli}} exec \\\\\\\"$container_name\\\\\\\" chown qdrouterd:qdrouterd \\\\\\\"$service_crt\\\\\\\"\\\\n{{container_cli}} exec \\\\\\\"$container_name\\\\\\\" chown qdrouterd:qdrouterd \\\\\\\"$service_key\\\\\\\"\\\\n# Trigger a container restart to read the new certificate\\\\n{{container_cli}} restart \\\\\\\"$container_name\\\\\\\"\\\\n\\\", \\\"key_size\\\": \\\"2048\\\", \\\"ca\\\": \\\"ipa\\\"}]}}]}], \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create persistent logs directory\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode|default(omit) }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/metrics_qdr\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}, {\\\"path\\\": \\\"/var/lib/metrics_qdr\\\", \\\"setype\\\": \\\"container_file_t\\\"}]}]}, {\\\"service_name\\\": \\\"mysql_client\\\", \\\"config_settings\\\": {\\\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\\\": \\\"%{hiera(\'internal_api\')}\\\", \\\"tripleo::profile::base::database::mysql::client::enable_ssl\\\": true, \\\"tripleo::profile::base::database::mysql::client::ssl_ca\\\": \\\"/etc/ipa/ca.crt\\\"}, \\\"step_config\\\": \\\"include tripleo::profile::base::database::mysql::client\\\"}, {\\\"service_name\\\": \\\"nova_compute\\\", \\\"monitoring_subscription\\\": \\\"overcloud-nova-compute\\\", \\\"config_settings\\\": {\\\"nova::my_ip\\\": \\\"%{hiera(\'internal_api\')}\\\", \\\"nova::rabbit_use_ssl\\\": \\\"True\\\", \\\"nova::keystone::service_user::send_service_user_token\\\": true, \\\"nova::keystone::service_user::project_name\\\": \\\"service\\\", \\\"nova::keystone::service_user::password\\\": \\\"E43sBALvNAsJYgcBpWfsAoz9C\\\", \\\"nova::keystone::service_user::auth_url\\\": \\\"https://overcloud.internalapi.ooo.test:5000\\\", \\\"nova::keystone::service_user::region_name\\\": \\\"regionOne\\\", \\\"nova::placement::project_name\\\": \\\"service\\\", \\\"nova::placement::password\\\": \\\"qMFVkTRvhZKx21tsfFHzUpJTe\\\", \\\"nova::placement::auth_url\\\": \\\"https://overcloud.internalapi.ooo.test:5000\\\", \\\"nova::placement::region_name\\\": \\\"regionOne\\\", \\\"nova::placement::valid_interfaces\\\": \\\"internal\\\", \\\"nova::os_region_name\\\": \\\"regionOne\\\", \\\"nova::logging::debug\\\": true, \\\"nova::purge_config\\\": false, \\\"nova::network::neutron::project_name\\\": \\\"service\\\", \\\"nova::network::neutron::username\\\": \\\"neutron\\\", \\\"nova::network::neutron::region_name\\\": \\\"regionOne\\\", \\\"nova::dhcp_domain\\\": \\\"\\\", \\\"nova::network::neutron::password\\\": \\\"qzvItA1K3MLllVvkiCWVVbIpy\\\", \\\"nova::network::neutron::auth_url\\\": \\\"https://overcloud.internalapi.ooo.test:5000/v3\\\", \\\"nova::network::neutron::valid_interfaces\\\": \\\"internal\\\", \\\"nova::glance::valid_interfaces\\\": \\\"internal\\\", \\\"nova::rabbit_heartbeat_timeout_threshold\\\": 60, \\\"nova::cinder_catalog_info\\\": \\\"volumev3:cinderv3:internalURL\\\", \\\"nova::host\\\": \\\"%{hiera(\'fqdn_canonical\')}\\\", \\\"nova::notify_on_state_change\\\": \\\"vm_and_task_state\\\", \\\"nova::notification_driver\\\": [\\\"noop\\\"], \\\"nova::notification_format\\\": \\\"unversioned\\\", \\\"nova::network::neutron::auth_type\\\": \\\"v3password\\\", \\\"nova::db::database_db_max_retries\\\": -1, \\\"nova::db::database_max_retries\\\": -1, \\\"nova::network::neutron::ovs_bridge\\\": \\\"br-int\\\", \\\"nova::compute::sync_power_state_interval\\\": 600, \\\"nova_is_additional_cell\\\": false, \\\"nova::cross_az_attach\\\": true, \\\"nova::cache::enabled\\\": true, \\\"nova::cache::tls_enabled\\\": true, \\\"nova::cache::backend\\\": \\\"dogpile.cache.pymemcache\\\", \\\"nova::rabbit_heartbeat_in_pthread\\\": false, \\\"nova::ovsdb_connection\\\": \\\"\\\", \\\"nova::compute::vcpu_pin_set\\\": [], \\\"nova::compute::cpu_shared_set\\\": [], \\\"nova::compute::cpu_dedicated_set\\\": [], \\\"nova::compute::reserved_host_memory\\\": 512, \\\"nova::compute::reserved_huge_pages\\\": [], \\\"nova::compute::neutron_physnets_numa_nodes_mapping\\\": {}, \\\"nova::compute::neutron_tunnel_numa_nodes\\\": [], \\\"nova::compute::resume_guests_state_on_host_boot\\\": false, \\\"nova::compute::libvirt::rx_queue_size\\\": 512, \\\"nova::compute::libvirt::tx_queue_size\\\": 512, \\\"nova::compute::libvirt::file_backed_memory\\\": 0, \\\"nova::compute::libvirt::volume_use_multipath\\\": false, \\\"nova::compute::libvirt::hw_machine_type\\\": \\\"x86_64=pc-q35-rhel9.0.0\\\", \\\"nova::compute::mkisofs_cmd\\\": \\\"mkisofs\\\", \\\"compute_enable_ksm\\\": false, \\\"nova::compute::rbd::libvirt_images_rbd_pool\\\": \\\"vms\\\", \\\"tripleo::profile::base::nova::compute::nova_nfs_enabled\\\": false, \\\"nfs_backend_enable\\\": false, \\\"nfs_share\\\": \\\"\\\", \\\"nfs_options\\\": \\\"context=system_u:object_r:nfs_t:s0\\\", \\\"nfs_vers\\\": \\\"4.2\\\", \\\"nova::compute::libvirt::num_pcie_ports\\\": 16, \\\"nova::compute::libvirt::mem_stats_period_seconds\\\": 10, \\\"nova::compute::rbd::ephemeral_storage\\\": false, \\\"resume_guests_state_on_host_boot\\\": false, \\\"nova::cpu_allocation_ratio\\\": 0.0, \\\"nova::ram_allocation_ratio\\\": 1.0, \\\"nova::disk_allocation_ratio\\\": 0.0, \\\"nova::compute::max_disk_devices_to_attach\\\": -1, \\\"nova::compute::libvirt::pmem_namespaces\\\": \\\"\\\", \\\"nova_pmem_namespaces\\\": \\\"\\\", \\\"nova::compute::image_cache::remove_unused_original_minimum_age_seconds\\\": 86400, \\\"nova::compute::libvirt::swtpm_enabled\\\": false, \\\"nova::compute::vgpu::vgpu_types_device_addresses_mapping\\\": {}, \\\"compute_disable_irqbalance\\\": false, \\\"nova::compute::libvirt::cpu_mode\\\": \\\"host-model\\\", \\\"nova::compute::libvirt::cpu_models\\\": [], \\\"nova::compute::libvirt::cpu_model_extra_flags\\\": \\\"\\\", \\\"nova_compute_opt_volumes\\\": [], \\\"nova_compute_startup_delay\\\": 0, \\\"nova_compute_opt_env_vars\\\": {}, \\\"nova::workarounds::never_download_image_if_on_rbd\\\": false, \\\"nova::compute::image_type_exclude_list\\\": [], \\\"nova_permit_post_copy\\\": true, \\\"nova_permit_auto_converge\\\": true, \\\"nova_libvirt_max_queues\\\": 0, \\\"nova_glance_enable_rbd_download\\\": false, \\\"nova_glance_rbd_download_multistore_id\\\": \\\"\\\", \\\"nova::compute::force_raw_images\\\": true, \\\"nova::compute::use_cow_images\\\": true, \\\"nova::compute::libvirt::preallocate_images\\\": \\\"none\\\", \\\"nova::compute::image_cache::manager_interval\\\": 2400, \\\"nova::compute::image_cache::remove_unused_base_images\\\": true, \\\"nova::compute::image_cache::remove_unused_resized_minimum_age_seconds\\\": 3600, \\\"nova::compute::image_cache::precache_concurrency\\\": 1, \\\"nova::compute::provider::custom_inventories\\\": {}, \\\"nova::compute::rbd::libvirt_images_rbd_glance_copy_poll_interval\\\": 15, \\\"nova::compute::rbd::libvirt_images_rbd_glance_copy_timeout\\\": 600, \\\"ContainerNovaComputeImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\\\", \\\"ContainerNovaLibvirtConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\", \\\"nova::compute::libvirt::manage_libvirt_services\\\": false, \\\"nova::compute::pci::passthrough\\\": \\\"\\\", \\\"nova::compute::libvirt::migration_support\\\": false, \\\"tripleo::profile::base::nova::migration::client::nova_compute_enabled\\\": true, \\\"tripleo::profile::base::nova::migration::client::ssh_private_key\\\": \\\"-----BEGIN RSA PRIVATE KEY-----\\\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\\\n-----END RSA PRIVATE KEY-----\\\\n\\\", \\\"tripleo::profile::base::nova::migration::client::ssh_port\\\": 2022, \\\"nova::compute::rbd::libvirt_images_rbd_glance_store_name\\\": \\\"default_backend\\\", \\\"nova::compute::rbd::libvirt_images_rbd_ceph_conf\\\": \\\"/etc/ceph/ceph.conf\\\", \\\"nova::compute::rbd::libvirt_rbd_user\\\": \\\"openstack\\\", \\\"nova::compute::rbd::rbd_keyring\\\": \\\"client.openstack\\\", \\\"tripleo::profile::base::nova::compute::cinder_nfs_backend\\\": false, \\\"rbd_persistent_storage\\\": false, \\\"rbd_disk_cachemodes\\\": [\\\"network=writeback\\\"], \\\"nova::cinder::username\\\": \\\"cinder\\\", \\\"nova::cinder::auth_type\\\": \\\"v3password\\\", \\\"nova::cinder::project_name\\\": \\\"service\\\", \\\"nova::cinder::password\\\": \\\"1qmMnIFxlEBPP6HhUjwy6zBNn\\\", \\\"nova::cinder::auth_url\\\": \\\"https://overcloud.internalapi.ooo.test:5000/v3\\\", \\\"nova::cinder::region_name\\\": \\\"regionOne\\\", \\\"nova::compute::rbd::libvirt_rbd_secret_key\\\": \\\"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\\\", \\\"nova::compute::rbd::libvirt_rbd_secret_uuid\\\": \\\"141c0b27-2417-411f-ad72-876254cd4eac\\\", \\\"nova::compute::instance_usage_audit\\\": true, \\\"nova::compute::instance_usage_audit_period\\\": \\\"hour\\\", \\\"nova::compute::consecutive_build_service_disable_threshold\\\": \\\"10\\\", \\\"nova::compute::live_migration_wait_for_vif_plug\\\": true, \\\"nova::migration::libvirt::live_migration_permit_post_copy\\\": true, \\\"nova::migration::libvirt::live_migration_permit_auto_converge\\\": true, \\\"nova::migration::libvirt::live_migration_tunnelled\\\": false, \\\"nova::compute::vncserver_proxyclient_address\\\": \\\"%{hiera(\'internal_api\')}\\\", \\\"nova::compute::vncproxy_host\\\": \\\"overcloud.ooo.test\\\", \\\"nova::vncproxy::common::vncproxy_protocol\\\": \\\"https\\\", \\\"nova::vncproxy::common::vncproxy_host\\\": \\\"overcloud.ooo.test\\\", \\\"nova::vncproxy::common::vncproxy_port\\\": \\\"13080\\\", \\\"nova::compute::verify_glance_signatures\\\": false, \\\"nova::workarounds::disable_compute_service_check_for_ffu\\\": false}, \\\"service_config_settings\\\": {\\\"rsyslog\\\": {\\\"tripleo_logging_sources_nova_compute\\\": [{\\\"tag\\\": \\\"openstack.nova.compute\\\", \\\"file\\\": \\\"/var/log/containers/nova/nova-compute.log\\\"}]}, \\\"collectd\\\": {\\\"tripleo.collectd.plugins.nova_compute\\\": [\\\"virt\\\"], \\\"collectd::plugin::virt::connection\\\": \\\"qemu:///system\\\"}}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"nova_libvirt\\\", \\\"puppet_tags\\\": \\\"nova_config\\\", \\\"step_config\\\": \\\"# TODO(emilien): figure how to deal with libvirt profile.\\\\n# We\'ll probably treat it like we do with Neutron plugins.\\\\n# Until then, just include it in the default nova-compute role.\\\\ninclude tripleo::profile::base::nova::compute::libvirt\\\\n\\\", \\\"config_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\"}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/nova_compute.json\\\": {\\\"command\\\": \\\"/usr/bin/nova-compute \\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-iscsid/*\\\", \\\"dest\\\": \\\"/etc/iscsi/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-ceph/\\\", \\\"dest\\\": \\\"/etc/ceph/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/nova\\\", \\\"owner\\\": \\\"nova:nova\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/etc/ceph/ceph.client.openstack.keyring\\\", \\\"owner\\\": \\\"nova:nova\\\", \\\"perm\\\": \\\"0600\\\"}]}, \\\"/var/lib/kolla/config_files/nova_compute_wait_for_compute_service.json\\\": {\\\"command\\\": \\\"/container-config-scripts/pyshim.sh /container-config-scripts/nova_wait_for_compute_service.py\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/nova\\\", \\\"owner\\\": \\\"nova:nova\\\", \\\"recurse\\\": true}]}}, \\\"container_config_scripts\\\": {\\\"container_puppet_apply.sh\\\": {\\\"mode\\\": \\\"0700\\\", \\\"content\\\": \\\"#!/bin/bash\\\\nset -eux\\\\nSTEP=$1\\\\nTAGS=$2\\\\nCONFIG=$3\\\\nEXTRA_ARGS=${4:-\'\'}\\\\nif [ -d /tmp/puppet-etc ]; then\\\\n  # ignore copy failures as these may be the same file depending on docker mounts\\\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\\\nfi\\\\necho \\\\\\\"{\\\\\\\\\\\\\\\"step\\\\\\\\\\\\\\\": ${STEP}}\\\\\\\" > /etc/puppet/hieradata/docker_puppet.json\\\\n# $::deployment_type in puppet-tripleo\\\\nexport FACTER_deployment_type=containers\\\\nset +e\\\\npuppet apply $EXTRA_ARGS \\\\\\\\\\\\n    --verbose \\\\\\\\\\\\n    --detailed-exitcodes \\\\\\\\\\\\n    --summarize \\\\\\\\\\\\n    --color=false \\\\\\\\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\\\\\\\n    --tags $TAGS \\\\\\\\\\\\n    -e \\\\\\\"noop_resource(\'package\'); ${CONFIG}\\\\\\\"\\\\nrc=$?\\\\nset -e\\\\nset +ux\\\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\\\n    exit 0\\\\nfi\\\\nexit $rc\\\\n\\\"}, \\\"pyshim.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n# Copyright 2018 Red Hat Inc.\\\\n#\\\\n# Licensed under the Apache License, Version 2.0 (the \\\\\\\"License\\\\\\\"); you may\\\\n# not use this file except in compliance with the License. You may obtain\\\\n# a copy of the License at\\\\n#\\\\n#      http://www.apache.org/licenses/LICENSE-2.0\\\\n#\\\\n# Unless required by applicable law or agreed to in writing, software\\\\n# distributed under the License is distributed on an \\\\\\\"AS IS\\\\\\\" BASIS, WITHOUT\\\\n# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the\\\\n# License for the specific language governing permissions and limitations\\\\n# under the License.\\\\n#\\\\n# Usage: pyshim.sh <script and/or arguments>\\\\n#\\\\n# Unfortunately THT doesn\'t know which version of python might be in a\\\\n# container so we need this script to be able to try python3 or python2\\\\n# depending on availability.  Since this is a temporary shim until we\'ve\\\\n# fully cut over to python3, we check for the existence of python3 first\\\\n# before falling back to python2. This will help in the transition from\\\\n# python2 based containers to python3.\\\\n\\\\nshow_usage() {\\\\n    echo \\\\\\\"Usage: pyshim.sh <script and/or arguments>\\\\\\\"\\\\n}\\\\n\\\\nif [ $# -lt 1 ]\\\\nthen\\\\n    show_usage\\\\n    exit 1\\\\nfi\\\\n\\\\nset -x\\\\nif command -v python3 >/dev/null; then\\\\n    python3 \\\\\\\"$@\\\\\\\"\\\\nelif command -v python2 >/dev/null; then\\\\n    python2 \\\\\\\"$@\\\\\\\"\\\\nelif command -v python >/dev/null; then\\\\n    python \\\\\\\"$@\\\\\\\"\\\\nelse\\\\n    echo \\\\\\\"ERROR: python is not available!\\\\\\\"\\\\n    exit 1\\\\nfi\\\\n\\\"}, \\\"pacemaker_restart_bundle.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\nset -u\\\\n\\\\n# ./pacemaker_restart_bundle.sh mysql galera galera-bundle Master _\\\\n# ./pacemaker_restart_bundle.sh redis redis redis-bundle Slave Master\\\\n# ./pacemaker_restart_bundle.sh ovn_dbs ovndb_servers ovn-dbs-bundle Slave Master\\\\nRESTART_SCRIPTS_DIR=$(dirname $0)\\\\nTRIPLEO_SERVICE=$1\\\\nRESOURCE_NAME=$2\\\\nBUNDLE_NAME=$3\\\\nWAIT_TARGET_LOCAL=$4\\\\nWAIT_TARGET_ANYWHERE=${5:-_}\\\\nTRIPLEO_MINOR_UPDATE=\\\\\\\"${TRIPLEO_MINOR_UPDATE:-false}\\\\\\\"\\\\nTRIPLEO_HA_WRAPPER_RESOURCE_EXISTS=\\\\\\\"${TRIPLEO_HA_WRAPPER_RESOURCE_EXISTS:-false}\\\\\\\"\\\\n\\\\nbundle_can_be_restarted() {\\\\n    local bundle=$1\\\\n    # As long as the resource bundle is managed by pacemaker and is\\\\n    # not meant to stay stopped, no matter the state of any inner\\\\n    # pcmk_remote or ocf resource, we should restart it to give it a\\\\n    # chance to read the new config.\\\\n    [ \\\\\\\"$(crm_resource --meta -r $1 -g is-managed 2>/dev/null)\\\\\\\" != \\\\\\\"false\\\\\\\" ] && \\\\\\\\\\\\n    [ \\\\\\\"$(crm_resource --meta -r $1 -g target-role 2>/dev/null)\\\\\\\" != \\\\\\\"Stopped\\\\\\\" ]\\\\n}\\\\n\\\\nlog() {\\\\n    local msg=$1\\\\n    logger -t pcmkrestart \\\\\\\"$1\\\\\\\"\\\\n}\\\\n\\\\nHOSTNAME=$(/bin/hostname -s)\\\\nif [ x\\\\\\\"${TRIPLEO_MINOR_UPDATE,,}\\\\\\\" != x\\\\\\\"true\\\\\\\" ]; then\\\\n    if [ x\\\\\\\"${TRIPLEO_HA_WRAPPER_RESOURCE_EXISTS,,}\\\\\\\" = x\\\\\\\"false\\\\\\\" ]; then\\\\n        # Do not restart during initial deployment, as the resource\\\\n        # has just been created.\\\\n        SERVICE_NODEID=$(/bin/hiera -c /etc/puppet/hiera.yaml \\\\\\\"${TRIPLEO_SERVICE}_short_bootstrap_node_name\\\\\\\")\\\\n        if [[ \\\\\\\"${HOSTNAME,,}\\\\\\\" == \\\\\\\"${SERVICE_NODEID,,}\\\\\\\" ]]; then\\\\n            log \\\\\\\"Initial deployment, skipping the restart of ${BUNDLE_NAME}\\\\\\\"\\\\n\\\\tfi\\\\n        exit 0\\\\n    else\\\\n        # During a stack update, this script is called in parallel on\\\\n        # every node the resource runs on, after the service\'s configs\\\\n        # have been updated on all nodes. So we need to run pcs only\\\\n        # once (e.g. on the service\'s boostrap node).\\\\n        if bundle_can_be_restarted ${BUNDLE_NAME}; then\\\\n            SERVICE_NODEID=$(/bin/hiera -c /etc/puppet/hiera.yaml \\\\\\\"${TRIPLEO_SERVICE}_short_bootstrap_node_name\\\\\\\")\\\\n            if [[ \\\\\\\"${HOSTNAME,,}\\\\\\\" == \\\\\\\"${SERVICE_NODEID,,}\\\\\\\" ]]; then\\\\n                replicas_running=$(crm_resource -Q -r $BUNDLE_NAME --locate 2>&1 | wc -l)\\\\n                if [ \\\\\\\"$replicas_running\\\\\\\" != \\\\\\\"0\\\\\\\" ]; then\\\\n                    log \\\\\\\"Restarting ${BUNDLE_NAME} globally. Stopping:\\\\\\\"\\\\n                    /sbin/pcs resource disable --wait=600 $BUNDLE_NAME\\\\n                    log \\\\\\\"Restarting ${BUNDLE_NAME} globally. Starting:\\\\\\\"\\\\n                    /sbin/pcs resource enable --wait=600 $BUNDLE_NAME\\\\n                else\\\\n                    log \\\\\\\"${BUNDLE_NAME} is not running anywhere,\\\\\\\" \\\\\\\\\\\\n                         \\\\\\\"cleaning up to restart it globally if necessary\\\\\\\"\\\\n                    /sbin/pcs resource cleanup $BUNDLE_NAME\\\\n                fi\\\\n            else\\\\n                log \\\\\\\"Skipping global restart of ${BUNDLE_NAME} on ${HOSTNAME} it will be restarted by node ${SERVICE_NODEID}\\\\\\\"\\\\n            fi\\\\n\\\\n        else\\\\n            log \\\\\\\"No global restart needed for ${BUNDLE_NAME}.\\\\\\\"\\\\n        fi\\\\n    fi\\\\nelse\\\\n    # During a minor update workflow however, a host gets fully\\\\n    # updated before updating the next one. So unlike stack\\\\n    # update, at the time this script is called, the service\'s\\\\n    # configs aren\'t updated on all nodes yet. So only restart the\\\\n    # resource locally, where it\'s guaranteed that the config is\\\\n    # up to date.\\\\n    HOST=$(facter hostname)\\\\n\\\\n    if bundle_can_be_restarted ${BUNDLE_NAME}; then\\\\n\\\\t# if the resource is running locally, restart it\\\\n\\\\tif crm_resource -r $BUNDLE_NAME --locate 2>&1 | grep -w -q \\\\\\\"${HOST}\\\\\\\"; then\\\\n            log \\\\\\\"Restarting ${BUNDLE_NAME} locally on \'${HOST}\'\\\\\\\"\\\\n            /sbin/pcs resource restart $BUNDLE_NAME \\\\\\\"${HOST}\\\\\\\"\\\\n\\\\n\\\\telse\\\\n\\\\t    # At this point, if no resource is running locally, it\'s\\\\n\\\\t    # either because a) it has failed previously, or b) because\\\\n\\\\t    # it\'s an A/P resource running elsewhere.\\\\n\\\\t    # By cleaning up resource, we ensure that a) it will try to\\\\n\\\\t    # restart, or b) it won\'t do anything if the resource is\\\\n\\\\t    # already running elsewhere.\\\\n            log \\\\\\\"${BUNDLE_NAME} is currently not running on \'${HOST}\',\\\\\\\" \\\\\\\\\\\\n                 \\\\\\\"cleaning up its state to restart it if necessary\\\\\\\"\\\\n            /sbin/pcs resource cleanup $BUNDLE_NAME node=\\\\\\\"${HOST}\\\\\\\"\\\\n\\\\tfi\\\\n\\\\n\\\\t# Wait until the resource is in the expected target state\\\\n\\\\t$RESTART_SCRIPTS_DIR/pacemaker_wait_bundle.sh \\\\\\\\\\\\n            $RESOURCE_NAME $BUNDLE_NAME \\\\\\\\\\\\n            \\\\\\\"$WAIT_TARGET_LOCAL\\\\\\\" \\\\\\\"$WAIT_TARGET_ANYWHERE\\\\\\\" \\\\\\\\\\\\n\\\\t    \\\\\\\"${HOST}\\\\\\\" 600\\\\n    else\\\\n        log \\\\\\\"No restart needed for ${BUNDLE_NAME}.\\\\\\\"\\\\n    fi\\\\nfi\\\\n\\\"}, \\\"pacemaker_wait_bundle.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\n# ----\\\\n# Wait for an OCF resource or a bundle to be restarted\\\\n# ----\\\\n# e.g.:\\\\n# M/S OCF:      $0 galera galera-bundle Master\\\\n# clone OCF:    $0 rabbitmq rabbitmq-bundle Started\\\\n# A/P M/S OCF:  $0 redis redis-bundle Slave Master\\\\n# A/P bundle:   $0 openstack-cinder-volume openstack-cinder-volume _ Started\\\\n# clone bundle: $0 haproxy-bundle haproxy-bundle Started\\\\n\\\\n# design note 1:\\\\n#  - this script is called during a minor update; it is called\\\\n#    once per node that hosts a service replica.\\\\n#  - the purpose of this script is to ensure that restarting the\\\\n#    service replica locally won\'t disrupt the service availability\\\\n#    for the end user. To reach that goal, the script waits until the\\\\n#    service is restarted locally or globallu and reaches a given\\\\n#    target state (i.e. Started, Slave or Master).\\\\n# design note 2:\\\\n#   - we don\'t want to track restart error: our only job is to ensure\\\\n#     service restart synchronization, not service health.\\\\n#   - In particular, we don\'t want to error out in case the resource\\\\n#     cannot be restarted locally, because that would make the minor\\\\n#     update fail, even if potentially other replicas still provide\\\\n#     the service.\\\\n# design note 3:\\\\n#   - we can bail out early if we determine that the resource can\'t\\\\n#     be restarted automatically by pacemaker (e.g. its \\\\\\\"blocked\\\\\\\",\\\\n#     unmanaged or disabled).\\\\n\\\\nlog() {\\\\n    local msg=$1\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\"\\\\n}\\\\n\\\\nusage() {\\\\n    echo 2>&1 \\\\\\\"Usage: $0 NAME BUNDLE_NAME ROLE_LOCAL [ROLE_ANYWHERE] [HOST] [TIMEOUT]\\\\\\\"\\\\n    exit 1\\\\n}\\\\n\\\\npacemaker_supports_promoted() {\\\\n    # The Promoted token is only matched in recent pacemaker versions\\\\n    grep -wq \\\\\\\"<value>Promoted</value>\\\\\\\" /usr/share/pacemaker/resources-*.rng\\\\n}\\\\n\\\\n#\\\\n# Utility functions to detect stuck resources\\\\n#\\\\n\\\\nbundle_failures_locally() {\\\\n    local engine=$BUNDLE_CONTAINER_ENGINE\\\\n    local replicas=$BUNDLE_REPLICAS\\\\n    local last=$(($replicas - 1))\\\\n    local replica_name\\\\n    for i in $(seq 0 $last); do\\\\n\\\\treplica_name=${BUNDLE_NAME}-${engine}-${i}\\\\n\\\\tcrm_failcount -q -G -r $replica_name -N $HOST\\\\n    done\\\\n}\\\\n\\\\nbundle_failures_globally() {\\\\n    local engine=$BUNDLE_CONTAINER_ENGINE\\\\n    local replicas=$BUNDLE_REPLICAS\\\\n    local last=$(($replicas - 1))\\\\n    for i in $(seq 0 $last); do\\\\n\\\\tcrm_failcount -q -G -r ${BUNDLE_NAME}-${engine}-${i}\\\\n    done\\\\n}\\\\n\\\\nbundle_running_globally() {\\\\n    local engine=$BUNDLE_CONTAINER_ENGINE\\\\n    # return the number of running bundles replica, i.e. the number of\\\\n    # docker/podman resource replicas currently running in the cluster\\\\n    crm_mon --as-xml | xmllint --xpath \\\\\\\"count(//resources/bundle[@id=\'${BUNDLE_NAME}\']/replica/resource[@resource_agent=\'${OCF}:heartbeat:${engine}\']/node)\\\\\\\" -\\\\n}\\\\n\\\\nocf_failures_globally() {\\\\n    local replicas=$BUNDLE_REPLICAS\\\\n    local last=$(($replicas - 1))\\\\n    local bundle_node\\\\n    for i in $(seq 0 $last); do\\\\n\\\\tbundle_node=${BUNDLE_NAME}-${i}\\\\n\\\\tcrm_failcount -q -G -r $NAME -N $bundle_node\\\\n    done\\\\n}\\\\n\\\\ndid_resource_failed_locally() {\\\\n    local failures\\\\n    local running\\\\n    local remotehost\\\\n    if [ \\\\\\\"${NAME}\\\\\\\" != \\\\\\\"${BUNDLE_NAME}\\\\\\\" ]; then\\\\n\\\\t# if we\'re dealing with an ocf resource, it is running on a\\\\n\\\\t# pacemaker_remote rather that on the real host, and the\\\\n\\\\t# failcounts are thus associated to the pcmk remote. Replace\\\\n\\\\t# the host\'s name with the pcmk remote\'s name.\\\\n        remotehost=$(crm_mon --as-xml | xmllint --xpath \\\\\\\"string(//resources/bundle[@id=\'${BUNDLE_NAME}\']/replica/resource/node[@name=\'${HOST}\']/../../resource[@resource_agent=\'${OCF}:pacemaker:remote\']/@id)\\\\\\\" -)\\\\n\\\\tif [ -n \\\\\\\"${remotehost}\\\\\\\" ]; then\\\\n\\\\t    crm_failcount -q -G -r $NAME -N $remotehost | grep -q -w INFINITY\\\\n\\\\t    return $?\\\\n\\\\tfi\\\\n\\\\t# If no pcmk remote is currently running, the failcount from\\\\n\\\\t# the ocf resource is useless, compute the failcount from the\\\\n\\\\t# bundle case instead (computed below).\\\\n    fi\\\\n\\\\n    # for bundles, pacemaker can run any bundle replica locally\\\\n    # (e.g. galera-bundle-docker-{0,1,2}), and a failure happens when\\\\n    # there are no more replica to try.\\\\n    # That is, when _at least_ one replica failed locally, and all the\\\\n    # others either failed or are currently running elsewhere.\\\\n    failures=$(bundle_failures_locally $HOST | grep -c -w INFINITY)\\\\n    running=$(bundle_running_globally)\\\\n    test $failures -gt 0 && \\\\\\\\\\\\n    test $(( $failures + $running )) -ge $BUNDLE_REPLICAS\\\\n}\\\\n\\\\ndid_resource_failed_globally() {\\\\n    local remotecount\\\\n    local failures\\\\n    if [ \\\\\\\"${NAME}\\\\\\\" != \\\\\\\"${BUNDLE_NAME}\\\\\\\" ]; then\\\\n\\\\t# we check the state of an ocf resource only if the\\\\n\\\\t# pcmkremotes are started\\\\n        remotecount=$(crm_mon --as-xml | xmllint --xpath \\\\\\\"count(//resources/bundle[@id=\'${BUNDLE_NAME}\']/replica/resource[@resource_agent=\'${OCF}:pacemaker:remote\']/node)\\\\\\\" -)\\\\n\\\\tif [ \\\\\\\"${remotecount}\\\\\\\" = \\\\\\\"0\\\\\\\" ]; then\\\\n\\\\t    # no pcmkremote is running, so check the bundle state\\\\n\\\\t    # instead of checking the ocf resource\\\\n\\\\t    # bundle failed if all ${BUNDLE_REPLICAS} replicas failed\\\\n\\\\t    failures=$(bundle_failures_globally | grep -c -w INFINITY)\\\\n\\\\t    test $failures -eq $BUNDLE_REPLICAS\\\\n\\\\telse\\\\n\\\\t    # ocf resource failed if it failed to start on\\\\n\\\\t    # all $BUNDLE_REPLICAS bundle nodes\\\\n\\\\t    failures=$(ocf_failures_globally | grep -c -w INFINITY)\\\\n\\\\t    test $failures -eq $BUNDLE_REPLICAS\\\\n\\\\tfi\\\\n    else\\\\n\\\\t# bundle failed if all ${BUNDLE_REPLICAS} replicas failed\\\\n\\\\tfailures=$(bundle_failures_globally | grep -c -w INFINITY)\\\\n\\\\ttest $failures -eq $BUNDLE_REPLICAS\\\\n    fi\\\\n}\\\\n\\\\n\\\\n# Input validation\\\\n#\\\\n\\\\nNAME=$1\\\\nif [ -z \\\\\\\"${NAME}\\\\\\\" ]; then\\\\n    echo 2>&1 \\\\\\\"Error: argument NAME must not be empty\\\\\\\"\\\\n    exit 1\\\\nfi\\\\n\\\\nBUNDLE_NAME=$2\\\\nif [ -z \\\\\\\"${BUNDLE_NAME}\\\\\\\" ]; then\\\\n    echo 2>&1 \\\\\\\"Error: argument BUNDLE_NAME must not be empty\\\\\\\"\\\\n    exit 1\\\\nfi\\\\n\\\\nROLE_LOCAL=$3\\\\nif [ \\\\\\\"${ROLE_LOCAL}\\\\\\\" = \\\\\\\"_\\\\\\\" ]; then\\\\n    ROLE_LOCAL=\\\\\\\"\\\\\\\"\\\\nfi\\\\n\\\\nROLE_ANYWHERE=$4\\\\nif [ \\\\\\\"${ROLE_ANYWHERE}\\\\\\\" = \\\\\\\"_\\\\\\\" ]; then\\\\n    ROLE_ANYWHERE=\\\\\\\"\\\\\\\"\\\\nfi\\\\n\\\\nif [ -z \\\\\\\"${ROLE_LOCAL}\\\\\\\" ]; then\\\\n    if [ -z \\\\\\\"${ROLE_ANYWHERE}\\\\\\\" ]; then\\\\n        echo 2>&1 \\\\\\\"Error: either ROLE_LOCAL or ROLE_ANYWHERE must be non empty\\\\\\\"\\\\n        exit 1\\\\n    fi\\\\nelse\\\\n    if !(echo \\\\\\\"${ROLE_LOCAL}\\\\\\\" | grep -q -x -E \\\\\\\"(Started|Slave|Master|Unpromoted|Promoted)\\\\\\\"); then\\\\n        echo 2>&1 \\\\\\\"Error: argument ROLE_LOCAL must be either \'Started\' \'Slave\' \'Master\' \'Unpromoted\' or \'Promoted\'\\\\\\\"\\\\n        exit 1\\\\n    fi\\\\nfi\\\\n\\\\nif [ -n \\\\\\\"${ROLE_ANYWHERE}\\\\\\\" ] && !(echo \\\\\\\"${ROLE_ANYWHERE}\\\\\\\" | grep -q -x -E \\\\\\\"(Started|Slave|Master|Unpromoted|Promoted)\\\\\\\"); then\\\\n    echo 2>&1 \\\\\\\"Error: argument ROLE_ANYWHERE must be either \'Started\' \'Slave\' \'Master\' \'Unpromoted\' or \'Promoted\'\\\\\\\"\\\\n    exit 1\\\\nfi\\\\n\\\\n# Ensure compatibility with pacemaker 2.1\\\\nif pacemaker_supports_promoted; then\\\\n    ROLE_LOCAL=$(echo \\\\\\\"$ROLE_LOCAL\\\\\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\\\n    ROLE_ANYWHERE=$(echo \\\\\\\"$ROLE_ANYWHERE\\\\\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\\\n    OCF=\\\\\\\"ocf\\\\\\\"\\\\nelse\\\\n    OCF=\\\\\\\"ocf:\\\\\\\"\\\\nfi\\\\n\\\\nHOST=${5:-$(facter hostname)}\\\\nTIMEOUT=${6:-600}\\\\n\\\\n\\\\n# Configure the search\\\\n# ----\\\\n# Note: we can\'t use crm_resource in all searches because we can\'t\\\\n# easily extract the host the OCF resources run on (crm_resource\\\\n# returns the pcmk-remote nodes rather than the hosts)\\\\n# So instead, we implement various searches with XPath directly.\\\\n\\\\nif [ \\\\\\\"${BUNDLE_NAME}\\\\\\\" != \\\\\\\"${NAME}\\\\\\\" ]; then\\\\n# ocf resource\\\\nlocal_resource_xpath=\\\\\\\"//bundle/replica/resource[@resource_agent=\'${OCF}:pacemaker:remote\']/node[@name=\'${HOST}\']/../../resource[@id=\'${NAME}\']\\\\\\\"\\\\nany_resource_xpath=\\\\\\\"//bundle//resource[@id=\'${NAME}\']\\\\\\\"\\\\nreplicas_xpath=\\\\\\\"//bundle/primitive[@id=\'${BUNDLE_NAME}\']/../*[boolean(@image) and boolean(@replicas)]\\\\\\\"\\\\nelse\\\\n# bundle resource\\\\nlocal_resource_xpath=\\\\\\\"//bundle[@id=\'${NAME}\']/replica/resource/node[@name=\'${HOST}\']/../../resource\\\\\\\"\\\\nany_resource_xpath=\\\\\\\"//bundle[@id=\'${NAME}\']//resource\\\\\\\"\\\\nreplicas_xpath=\\\\\\\"//bundle[@id=\'${BUNDLE_NAME}\']/*[boolean(@image) and boolean(@replicas)]\\\\\\\"\\\\nfi\\\\n\\\\nbundle_def_xpath=\\\\\\\"//bundle[@id=\'${BUNDLE_NAME}\']/*[boolean(@image) and boolean(@replicas)]\\\\\\\"\\\\nBUNDLE_CONTAINER_ENGINE=$(cibadmin -Q | xmllint --xpath \\\\\\\"name(${bundle_def_xpath})\\\\\\\" -)\\\\nBUNDLE_REPLICAS=$(cibadmin -Q | xmllint --xpath \\\\\\\"string(${bundle_def_xpath}/@replicas)\\\\\\\" -)\\\\n\\\\n\\\\n# The wait algorithm follows a two-stage approach\\\\n#  1. Depending on how the script is called, we first check whether\\\\n#     the resource is restarted locally. An A/P resource may be\\\\n#     restarted elsewhere in the cluster.\\\\n#  2. If needed, check whether the A/P resource has restarted\\\\n#     elsewhere. For A/P M/S resources, in case the resource is\\\\n#     restarted as Slave locally, ensure a Master is available.\\\\n\\\\nsuccess=1\\\\nbailout=1\\\\ntimeout=$TIMEOUT\\\\nrole=\\\\\\\"\\\\\\\"\\\\n\\\\n# Stage 1: local check\\\\nif [ -n \\\\\\\"$ROLE_LOCAL\\\\\\\" ]; then\\\\n    log \\\\\\\"Waiting until ${NAME} has restarted on ${HOST} and is in state ${ROLE_LOCAL}\\\\\\\"\\\\n    log \\\\\\\"Will probe resource state with the following XPath pattern: ${local_resource_xpath}\\\\\\\"\\\\n\\\\n    while [ $timeout -gt 0 ] && [ $bailout -ne 0 ] && [ $success -ne 0 ]; do\\\\n        resource=$(crm_mon -r --as-xml | xmllint --xpath \\\\\\\"${local_resource_xpath}\\\\\\\" - 2>/dev/null)\\\\n        role=$(echo \\\\\\\"${resource}\\\\\\\" | sed -ne \'s/.*\\\\\\\\Wrole=\\\\\\\"\\\\\\\\([^\\\\\\\"]*\\\\\\\\)\\\\\\\".*/\\\\\\\\1/p\')\\\\n\\\\n\\\\tif [ \\\\\\\"$(crm_resource --meta -r ${NAME} -g is-managed 2>/dev/null)\\\\\\\" = \\\\\\\"false\\\\\\\" ]; then\\\\n            log \\\\\\\"${NAME} is unmanaged, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n\\\\telif [ \\\\\\\"$(crm_resource --meta -r ${NAME} -g target-role 2>/dev/null)\\\\\\\" = \\\\\\\"Stopped\\\\\\\" ]; then\\\\n            log \\\\\\\"${NAME} is disabled, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n        elif echo \\\\\\\"${resource}\\\\\\\" | grep -q -w \\\\\\\"\\\\\\\\Wblocked=\\\\\\\\\\\\\\\"true\\\\\\\\\\\\\\\"\\\\\\\"; then\\\\n            log \\\\\\\"${NAME} is blocked, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n\\\\telif did_resource_failed_locally; then\\\\n            log \\\\\\\"${NAME} is in failed state, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n        elif [ \\\\\\\"$role\\\\\\\" = \\\\\\\"$ROLE_LOCAL\\\\\\\" ]; then\\\\n            success=0\\\\n            continue\\\\n        elif [ -n \\\\\\\"$ROLE_ANYWHERE\\\\\\\" ] && [ \\\\\\\"$role\\\\\\\" = \\\\\\\"$ROLE_ANYWHERE\\\\\\\" ]; then\\\\n            # A/P: we are restarted in the expected state\\\\n            success=0\\\\n            continue\\\\n        else\\\\n            log \\\\\\\"Waiting for ${NAME} to transition to role ${ROLE_LOCAL} on ${HOST}\\\\\\\"\\\\n        fi\\\\n\\\\n        if [ $bailout -ne 0 ] && [ $success -ne 0 ]; then\\\\n            sleep 4\\\\n            timeout=$((timeout-4))\\\\n        fi\\\\n    done\\\\nfi\\\\n\\\\n# Stage 2: global check\\\\nif [ $timeout -gt 0 ] && [ -n \\\\\\\"$ROLE_ANYWHERE\\\\\\\" ] && [ \\\\\\\"$role\\\\\\\" != \\\\\\\"$ROLE_ANYWHERE\\\\\\\" ]; then\\\\n    log \\\\\\\"Wait until ${NAME} is restarted anywhere in the cluster in state ${ROLE_ANYWHERE}\\\\\\\"\\\\n    log \\\\\\\"Will probe resource state with the following XPath pattern: ${any_resource_xpath}\\\\\\\"\\\\n\\\\n    success=1\\\\n    bailout=1\\\\n    while [ $timeout -gt 0 ] && [ $bailout -ne 0 ] && [ $success -ne 0 ]; do\\\\n        resources=$(crm_mon -r --as-xml | xmllint --xpath \\\\\\\"${any_resource_xpath}\\\\\\\" - 2>/dev/null)\\\\n\\\\tif [ \\\\\\\"$(crm_resource --meta -r ${NAME} -g is-managed 2>/dev/null)\\\\\\\" = \\\\\\\"false\\\\\\\" ]; then\\\\n            log \\\\\\\"${NAME} is unmanaged, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n\\\\telif [ \\\\\\\"$(crm_resource --meta -r ${NAME} -g target-role 2>/dev/null)\\\\\\\" = \\\\\\\"Stopped\\\\\\\" ]; then\\\\n            log \\\\\\\"${NAME} is disabled, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n        elif ! (echo \\\\\\\"${resources}\\\\\\\" | grep -q -w \\\\\\\"\\\\\\\\Wblocked=\\\\\\\\\\\\\\\"false\\\\\\\\\\\\\\\"\\\\\\\"); then\\\\n            log \\\\\\\"${NAME} blocked, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n\\\\telif did_resource_failed_globally; then\\\\n            log \\\\\\\"${NAME} is in failed state, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n        elif echo \\\\\\\"${resources}\\\\\\\" | grep -q -w \\\\\\\"\\\\\\\\Wrole=\\\\\\\\\\\\\\\"${ROLE_ANYWHERE}\\\\\\\\\\\\\\\"\\\\\\\"; then\\\\n            success=0\\\\n            continue\\\\n        else\\\\n            log \\\\\\\"Waiting for ${NAME} to transition to role ${ROLE_ANYWHERE} anywhere in the cluster\\\\\\\"\\\\n        fi\\\\n\\\\n        if [ $bailout -ne 0 ] && [ $success -ne 0 ]; then\\\\n            sleep 4\\\\n            timeout=$((timeout-4))\\\\n        fi\\\\n    done\\\\nfi\\\\n\\\\nif [ $timeout -le 0 ]; then\\\\n    log \\\\\\\"Timeout reached after ${TIMEOUT}s while waiting for ${NAME} to be restarted\\\\\\\"\\\\nelif [ $bailout -le 0 ]; then\\\\n    log \\\\\\\"Restart monitoring for ${NAME} cancelled\\\\\\\"\\\\nfi\\\\n\\\\nif [ $success -eq 0 ]; then\\\\n    log \\\\\\\"${NAME} successfully restarted\\\\\\\"\\\\nelse\\\\n    log \\\\\\\"${NAME} was not restarted properly\\\\\\\"\\\\nfi\\\\n\\\\n# Don\'t block minor update or stack update if the wait was unsuccessful\\\\nexit 0\\\\n\\\"}, \\\"wait-port-and-run.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\nset -eu\\\\n\\\\nHOST=$1\\\\nPORT=$2\\\\n\\\\necho \\\\\\\"$(date -u): Checking whether we can bind to ${HOST}:${PORT}\\\\\\\"\\\\nwhile (ss -Htnl src \\\\\\\"${HOST}\\\\\\\" \\\\\\\"sport = :${PORT}\\\\\\\" | grep -wq \\\\\\\"${PORT}\\\\\\\"); do\\\\n    echo \\\\\\\"$(date -u): ${HOST}:${PORT} still in use, waiting...\\\\\\\";\\\\n    sleep 10;\\\\ndone\\\\n\\\\nshift 2\\\\nCOMMAND=\\\\\\\"$*\\\\\\\"\\\\nif [ -z \\\\\\\"${COMMAND}\\\\\\\" ]; then\\\\n    COMMAND=\\\\\\\"true\\\\\\\"\\\\nfi\\\\nexec $COMMAND\\\\n\\\"}, \\\"pacemaker_resource_lock.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\nMAX_RETRIES=10\\\\nCIB_ENOTFOUND=105\\\\n\\\\nusage() {\\\\n   echo \\\\\\\"Set a global property in the cluster with a validity timestamp.\\\\\\\"\\\\n   echo \\\\\\\"Usage:\\\\\\\"\\\\n   echo \\\\\\\"   $0 --acquire <lock_name> <lock_owner> <lock_ttl_in_seconds>\\\\\\\"\\\\n   echo \\\\\\\"   $0 --release <lock_name> <lock_owner>\\\\\\\"\\\\n   echo\\\\n}\\\\n\\\\nlog() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\" 1>&2\\\\n}\\\\n\\\\nerror() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\" 1>&2\\\\n    exit 1\\\\n}\\\\n\\\\nlock_create() {\\\\n    local name=$1\\\\n    local data=$2\\\\n    # cibadmin won\'t overwrite a key if someone else succeeded to create it concurrently\\\\n    cibadmin --sync-call --scope crm_config --create --xml-text \\\\\\\"<cluster_property_set id=\'${name}\'><nvpair id=\'${name}-pair\' name=\'${name}\' value=\'${data}\'/></cluster_property_set>\\\\\\\" &>/dev/null\\\\n    return $?\\\\n}\\\\n\\\\nlock_update() {\\\\n    local name=$1\\\\n    local expected_data=$2\\\\n    local new_data=$3\\\\n    # we only update the lock we expect to see, so we can\'t update someone else\'s lock\\\\n    cibadmin --sync-call --scope crm_config --modify --xpath \\\\\\\"//cluster_property_set/nvpair[@name=\'${name}\' and @value=\'${expected_data}\']/..\\\\\\\" --xml-text \\\\\\\"<nvpair id=\'${name}-pair\' name=\'${name}\' value=\'${new_data}\'/>\\\\\\\" &>/dev/null\\\\n    return $?\\\\n}\\\\n\\\\nlock_delete() {\\\\n    local name=$1\\\\n    local expected_data=$2\\\\n    # we only delete the lock we expect to see, so we can\'t delete someone else\'s lock\\\\n    cibadmin --sync-call --scope crm_config --delete --xpath \\\\\\\"//cluster_property_set/nvpair[@name=\'${name}\' and @value=\'${expected_data}\']/..\\\\\\\" &>/dev/null\\\\n    return $?\\\\n}\\\\n\\\\nlock_get() {\\\\n    local lockname=$1\\\\n    local res\\\\n    local rc\\\\n    res=$(cibadmin --query --scope crm_config --xpath \\\\\\\"//cluster_property_set/nvpair[@name=\'$lockname\']\\\\\\\" 2>/dev/null)\\\\n    rc=$?\\\\n    if [ $rc -eq 0 ]; then\\\\n        echo \\\\\\\"$res\\\\\\\" | sed -n \'s/.*value=\\\\\\\"\\\\\\\\([^\\\\\\\"]*\\\\\\\\)\\\\\\\".*/\\\\\\\\1/p\'\\\\n    fi\\\\n    return $rc\\\\n}\\\\n\\\\nlock_owner() {\\\\n    local lock=$1\\\\n    echo \\\\\\\"$lock\\\\\\\" | cut -d\':\' -f1\\\\n}\\\\n\\\\nlock_has_expired() {\\\\n    local lock=$1\\\\n    local expiry=$(echo \\\\\\\"$lock\\\\\\\" | cut -d\':\' -f2)\\\\n    local now=$(date +%s)\\\\n    test $now -ge $expiry\\\\n}\\\\n\\\\n\\\\n# Perform a lock action and restart if the CIB has been modified before\\\\n# committing the lock action\\\\ntry_action() {\\\\n    local fun=$1\\\\n    local lock=$2\\\\n    local requester=$3\\\\n    local args=${4:-}\\\\n    local tries=$MAX_RETRIES\\\\n    local rc=1\\\\n    if [ \\\\\\\"$fun\\\\\\\" = \\\\\\\"lock_acquire\\\\\\\" ] || [ \\\\\\\"$fun\\\\\\\" = \\\\\\\"lock_release\\\\\\\" ]; then\\\\n        log \\\\\\\"Try running $fun\\\\\\\"\\\\n    else\\\\n        return 2\\\\n    fi\\\\n    while [ $rc -ne 0 ]; do\\\\n        $fun $lock $requester $args\\\\n        rc=$?\\\\n        if [ $rc -eq 0 ]; then\\\\n            log \\\\\\\"Operation $1 succeeded\\\\\\\"\\\\n            return 0\\\\n        elif [ $rc -eq 3 ]; then\\\\n            # rc == 3 -> CIB changed before push\\\\n            if [ $tries -eq 0 ]; then\\\\n                log \\\\\\\"Failed to commit after $MAX_RETRIES retries. Bailing out.\\\\\\\"\\\\n                return 2\\\\n            else\\\\n                log \\\\\\\"Failed to commit. Retrying operation.\\\\\\\"\\\\n                tries=$(($tries - 1))\\\\n            fi\\\\n        elif [ $rc -eq 2 ]; then\\\\n            # rc == 2 -> unrecoverable cib error (e.g. pacemaker down)\\\\n            log \\\\\\\"Unexpected failure. Bailing out\\\\\\\"\\\\n            return $rc\\\\n        else\\\\n            # rc == 1 -> lock error (not owner, lock doesn\'t exists)\\\\n            return $rc\\\\n        fi\\\\n    done\\\\n}\\\\n\\\\n# The lock mechanism uses cibadmin\'s atomic creation so cluster-wide\\\\n# state coherency is guaranteed by pacemaker\\\\nlock_acquire() {\\\\n    local lockname=$1\\\\n    local requester=$2\\\\n    local ttl=$3\\\\n    local rc\\\\n    local lock\\\\n    local expiry\\\\n    local owner\\\\n\\\\n    log \\\\\\\"Check whether the lock is already held in the CIB\\\\\\\"\\\\n    lock=$(lock_get $lockname)\\\\n    rc=$?\\\\n    if [ $rc -ne 0 ] && [ $rc -ne $CIB_ENOTFOUND ]; then\\\\n        log \\\\\\\"Could not retrieve info from the CIB\\\\\\\"\\\\n        return 2\\\\n    fi\\\\n\\\\n    if [ -n \\\\\\\"$lock\\\\\\\" ]; then\\\\n        lock_has_expired $lock\\\\n        rc=$?\\\\n        if [ $rc -eq 0 ]; then\\\\n            log \\\\\\\"Lock has expired, now available for being held\\\\\\\"\\\\n        else\\\\n            # lock is still held. check whether we\'re the owner\\\\n            owner=$(lock_owner $lock)\\\\n            if [ \\\\\\\"$owner\\\\\\\" = \\\\\\\"$requester\\\\\\\" ];then\\\\n                log \\\\\\\"Requester already owns the lock, acquiring attempt will just reconfigure the TTL\\\\\\\"\\\\n            else\\\\n                log \\\\\\\"Lock is held by someone else ($owner)\\\\\\\"\\\\n                return 1\\\\n            fi\\\\n        fi\\\\n    else\\\\n        log \\\\\\\"Lock is not held yet\\\\\\\"\\\\n    fi\\\\n\\\\n    # prepare the lock info\\\\n    expiry=$(($(date +%s) + $ttl))\\\\n\\\\n    if [ -n \\\\\\\"$lock\\\\\\\" ]; then\\\\n        log \\\\\\\"Attempting to update the lock\\\\\\\"\\\\n        lock_update $lockname \\\\\\\"$lock\\\\\\\" \\\\\\\"$requester:$expiry\\\\\\\"\\\\n        rc=$?\\\\n    else\\\\n        log \\\\\\\"Attempting to acquire the lock\\\\\\\"\\\\n        lock_create $lockname \\\\\\\"$requester:$expiry\\\\\\\"\\\\n        rc=$?\\\\n    fi\\\\n\\\\n    if [ $rc -eq 0 ]; then\\\\n        log \\\\\\\"Lock \'$lockname\' acquired by \'$requester\', valid until $(date -d @$expiry)\\\\\\\"\\\\n        return 0\\\\n    else\\\\n        log \\\\\\\"CIB changed, lock cannot be acquired\\\\\\\"\\\\n        return 3\\\\n    fi\\\\n}\\\\n\\\\n\\\\n# The lock mechanism uses the CIB\'s num_updates tag to implement\\\\n# a conditional store. Cluster-wide locking is guaranteed by pacemaker\\\\nlock_release() {\\\\n    local lockname=$1\\\\n    local requester=$2\\\\n    local rc\\\\n    local lock\\\\n    local owner\\\\n\\\\n    log \\\\\\\"Check whether the lock is already held in the CIB\\\\\\\"\\\\n    lock=$(lock_get $lockname)\\\\n    rc=$?\\\\n    if [ $rc -ne 0 ] && [ $rc -ne $CIB_ENOTFOUND ]; then\\\\n        log \\\\\\\"Could not retrieve info from the CIB\\\\\\\"\\\\n        return 2\\\\n    fi\\\\n\\\\n    if [ -z \\\\\\\"$lock\\\\\\\" ]; then\\\\n        log \\\\\\\"Lock doesn\'t exist. Nothing to release\\\\\\\"\\\\n        return 0\\\\n    else\\\\n        log \\\\\\\"Lock exists, check whether we\'re the owner\\\\\\\"\\\\n        owner=$(lock_owner $lock)\\\\n        if [ \\\\\\\"$owner\\\\\\\" != \\\\\\\"$requester\\\\\\\" ];then\\\\n            log \\\\\\\"Lock is held by someone else ($owner), will not unlock\\\\\\\"\\\\n            return 1\\\\n        fi\\\\n    fi\\\\n\\\\n    lock_delete $lockname \\\\\\\"$lock\\\\\\\"\\\\n    rc=$?\\\\n\\\\n    if [ $rc -eq 0 ]; then\\\\n        log \\\\\\\"Lock \'$lockname\' released by \'$requester\'\\\\\\\"\\\\n        return 0\\\\n    else\\\\n        log \\\\\\\"CIB deletion error, lock cannot be released\\\\\\\"\\\\n        return 3\\\\n    fi\\\\n}\\\\n\\\\n\\\\n# Retrieve the owner of a lock from the CIB\\\\n# this is a read-only operation, so no need to log debug info\\\\nlock_get_owner() {\\\\n    local lockname=$1\\\\n    local rc\\\\n    local lock\\\\n    local owner\\\\n\\\\n    lock=$(lock_get $lockname)\\\\n    rc=$?\\\\n    if [ $rc -ne 0 ] && [ $rc -ne $CIB_ENOTFOUND ]; then\\\\n        return 2\\\\n    fi\\\\n\\\\n    if [ -z \\\\\\\"$lock\\\\\\\" ]; then\\\\n        return 1\\\\n    else\\\\n        lock_owner $lock\\\\n        return 0\\\\n    fi\\\\n}\\\\n\\\\n\\\\nACTION=$1\\\\nLOCKNAME=$2\\\\nREQUESTER=$3\\\\nTTL=${4:-60}\\\\n\\\\nif [ -z \\\\\\\"$ACTION\\\\\\\" ]; then\\\\n    error \\\\\\\"Action must be specified\\\\\\\"\\\\nfi\\\\n\\\\nif [ $ACTION != \\\\\\\"--help\\\\\\\" ]; then\\\\n    if [ -z \\\\\\\"$LOCKNAME\\\\\\\" ]; then\\\\n        error \\\\\\\"You must specific a lock name\\\\\\\"\\\\n    fi\\\\n    if [ $ACTION != \\\\\\\"--owner\\\\\\\" ] && [ $ACTION != \\\\\\\"-o\\\\\\\" ]; then\\\\n        if [ -z \\\\\\\"$REQUESTER\\\\\\\" ]; then\\\\n            error \\\\\\\"You must specific a lock requester\\\\\\\"\\\\n        fi\\\\n    fi\\\\nfi\\\\n\\\\ncase $ACTION in\\\\n    --help) usage; exit 0;;\\\\n    --acquire|-a) try_action lock_acquire $LOCKNAME $REQUESTER $TTL;;\\\\n    --release|-r) try_action lock_release $LOCKNAME $REQUESTER;;\\\\n    --acquire-once|-A) lock_acquire $LOCKNAME $REQUESTER $TTL;;\\\\n    --owner|-o) lock_get_owner $LOCKNAME;;\\\\n    *) error \\\\\\\"Invalid action\\\\\\\";;\\\\nesac\\\\nexit $?\\\\n\\\"}, \\\"pacemaker_mutex_restart_bundle.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\n# pacemaker_mutex_restart_bundle.sh --lock mysql galera galera-bundle Master _\\\\n# pacemaker_mutex_restart_bundle.sh --lock ovn_dbs ovndb_servers ovn-dbs-bundle Slave Master\\\\n\\\\nset -u\\\\n\\\\nusage() {\\\\n    echo \\\\\\\"Restart a clustered resource in a coordinated way across the cluster\\\\\\\"\\\\n    echo \\\\\\\"Usage:\\\\\\\"\\\\n    echo \\\\\\\"   $0 --lock <tripleo-service> <pcmk-resource> <pcmk-bundle> <target-state-local> <target-state-cluster>\\\\\\\"\\\\n    echo\\\\n}\\\\n\\\\nlog() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\"\\\\n}\\\\n\\\\nerror() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\" 1>&2\\\\n    exit 1\\\\n}\\\\n\\\\npacemaker_supports_promoted() {\\\\n    # The Promoted token is only matched in recent pacemaker versions\\\\n    grep -wq \\\\\\\"<value>Promoted</value>\\\\\\\" /usr/share/pacemaker/resources-*.rng\\\\n}\\\\n\\\\nACTION=$1\\\\ncase $ACTION in\\\\n    --help) usage; exit 0;;\\\\n    --lock) ;;\\\\n    *) error \\\\\\\"Unknown action \'$ACTION\'\\\\\\\";;\\\\nesac\\\\n\\\\nTRIPLEO_SERVICE=$2\\\\nLOCK_NAME=${TRIPLEO_SERVICE}-restart-lock\\\\nLOCK_OWNER=$(crm_node -n 2>/dev/null)\\\\nrc=$?\\\\nif [ $rc -ne 0 ]; then\\\\n    if [ $rc -eq 102 ]; then\\\\n        log \\\\\\\"Cluster is not running locally, no need to restart resource $TRIPLEO_SERVICE\\\\\\\"\\\\n        exit 0\\\\n    else\\\\n        error \\\\\\\"Unexpected error while connecting to the cluster (rc: $rc), bailing out\\\\\\\"\\\\n    fi\\\\nfi\\\\n\\\\nRESOURCE_NAME=$3\\\\nBUNDLE_NAME=$4\\\\nWAIT_TARGET_LOCAL=$5\\\\nWAIT_TARGET_ANYWHERE=${6:-_}\\\\n\\\\nif pacemaker_supports_promoted; then\\\\n    WAIT_TARGET_LOCAL=$(echo \\\\\\\"$5\\\\\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\\\n    WAIT_TARGET_ANYWHERE=$(echo \\\\\\\"${6:-_}\\\\\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\\\n    promoted_role=\\\\\\\"Promoted\\\\\\\"\\\\nelse\\\\n    promoted_role=\\\\\\\"Master\\\\\\\"\\\\nfi\\\\n\\\\n# The lock TTL should accomodate for the resource start/promote timeout\\\\nif [ \\\\\\\"$RESOURCE_NAME\\\\\\\" != \\\\\\\"$BUNDLE_NAME\\\\\\\" ]; then\\\\n    if [ \\\\\\\"$WAIT_TARGET_LOCAL\\\\\\\" = \\\\\\\"$promoted_role\\\\\\\" ] || [ \\\\\\\"$WAIT_TARGET_ANYWHERE\\\\\\\" = \\\\\\\"$promoted_role\\\\\\\" ]; then\\\\n        rsc_op=\\\\\\\"promote\\\\\\\"\\\\n    else\\\\n        rsc_op=\\\\\\\"start\\\\\\\"\\\\n    fi\\\\n    # <op id=\\\\\\\"galera-promote-interval-0s\\\\\\\" interval=\\\\\\\"0s\\\\\\\" name=\\\\\\\"promote\\\\\\\" on-fail=\\\\\\\"block\\\\\\\" timeout=\\\\\\\"300s\\\\\\\"/>\\\\n    PCMK_TTL=$(cibadmin -Q | xmllint -xpath \\\\\\\"string(//primitive[@id=\'${RESOURCE_NAME}\']/operations/op[@name=\'${rsc_op}\']/@timeout)\\\\\\\" - | sed \'s/s$//\')\\\\n    LOCK_TTL=$((PCMK_TTL + 30))\\\\nelse\\\\n    # The podman RA\'s default start timeout\\\\n    LOCK_TTL=90\\\\nfi\\\\n\\\\nlog \\\\\\\"Acquire a ${LOCK_TTL}s restart lock for service $TRIPLEO_SERVICE before restarting it\\\\\\\"\\\\n# Loop until we hold the lock. The lock has a TTL, so we\'re guaranteed to get it eventually\\\\nrc=1\\\\nwhile [ $rc -ne 0 ]; do\\\\n    /var/lib/container-config-scripts/pacemaker_resource_lock.sh --acquire $LOCK_NAME $LOCK_OWNER $LOCK_TTL\\\\n    rc=$?\\\\n    if [ $rc != 0 ]; then\\\\n        if [ $rc -gt 1 ]; then\\\\n            error \\\\\\\"Could not acquire lock due to unrecoverable error (rc: $rc), bailing out\\\\\\\"\\\\n        else\\\\n            log \\\\\\\"Could not acquire lock, retrying\\\\\\\"\\\\n            sleep 10\\\\n        fi\\\\n    fi\\\\ndone\\\\n\\\\nlog \\\\\\\"Restart the service $TRIPLEO_SERVICE locally\\\\\\\"\\\\n# Reuse the local restart script in t-h-t (driven by env var TRIPLEO_MINOR_UPDATE)\\\\nTRIPLEO_MINOR_UPDATE=true /var/lib/container-config-scripts/pacemaker_restart_bundle.sh $TRIPLEO_SERVICE $RESOURCE_NAME $BUNDLE_NAME $WAIT_TARGET_LOCAL $WAIT_TARGET_ANYWHERE\\\\n\\\\n# If we reached this point, always try to release the lock\\\\nlog \\\\\\\"Release the restart lock for service $TRIPLEO_SERVICE\\\\\\\"\\\\n/var/lib/container-config-scripts/pacemaker_resource_lock.sh --release $LOCK_NAME $LOCK_OWNER\\\\nrc=$?\\\\nif [ $rc -ne 0 ] && [ $rc -ne 1 ]; then\\\\n    error \\\\\\\"Could not release held lock (rc: $rc)\\\\\\\"\\\\nfi\\\\n\\\"}, \\\"pacemaker_mutex_shutdown.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\n# pacemaker_mutex_shutdown.sh --acquire\\\\n# pacemaker_mutex_shutdown.sh --release\\\\n\\\\nset -u\\\\n\\\\nusage() {\\\\n    echo \\\\\\\"Shutdown a cluster node in a coordinated way across the cluster\\\\\\\"\\\\n    echo \\\\\\\"Usage:\\\\\\\"\\\\n    echo \\\\\\\"   $0 --acquire # prevent other node from shutting down until we hold the lock\\\\\\\"\\\\n    echo \\\\\\\"   $0 --release # release the lock, other node can compete for the shutdown lock\\\\\\\"\\\\n    echo\\\\n}\\\\n\\\\nlog() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\"\\\\n}\\\\n\\\\nerror() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\" 1>&2\\\\n    exit 1\\\\n}\\\\n\\\\n# Loop until we hold the lock. The lock has a TTL, so we\'re guaranteed to get it eventually\\\\nshutdown_lock_acquire() {\\\\n    local lockname=$1\\\\n    local requester=$2\\\\n    local ttl=$3\\\\n    local rc=1\\\\n    local current_owner\\\\n    local owner_stopped\\\\n    local owner_rc\\\\n\\\\n    log \\\\\\\"Acquiring the shutdown lock\\\\\\\"\\\\n    while [ $rc -ne 0 ]; do\\\\n        /var/lib/container-config-scripts/pacemaker_resource_lock.sh --acquire-once $lockname $requester $ttl\\\\n        rc=$?\\\\n        if [ $rc -ne 0 ]; then\\\\n            if [ $rc -eq 2 ]; then\\\\n                error \\\\\\\"Could not acquire the shutdown lock due to unrecoverable error (rc: $rc), bailing out\\\\\\\"\\\\n            else\\\\n                # The lock is held by another node.\\\\n                current_owner=$(/var/lib/container-config-scripts/pacemaker_resource_lock.sh --owner $lockname)\\\\n                owner_rc=$?\\\\n                if [ $owner_rc -eq 2 ]; then\\\\n                    error \\\\\\\"Could not get the shutdown lock owner due to unrecoverable error (rc: $owner_rc), bailing out\\\\\\\"\\\\n                fi\\\\n                if [ $owner_rc -eq 0 ]; then\\\\n                    # If the owner is marked as offline, that means it has shutdown and\\\\n                    # we can clean the lock preemptively and try to acquire it.\\\\n                    owner_stopped=$(crm_mon -1X | xmllint --xpath \'count(//nodes/node[@name=\\\\\\\"\'${current_owner}\'\\\\\\\" and @online=\\\\\\\"false\\\\\\\" and @unclean=\\\\\\\"false\\\\\\\"])\' -)\\\\n                    if [ \\\\\\\"${owner_stopped}\\\\\\\" = \\\\\\\"1\\\\\\\" ]; then\\\\n                        log \\\\\\\"Shutdown lock held by stopped node \'${current_owner}\', lock can be released\\\\\\\"\\\\n                        /var/lib/container-config-scripts/pacemaker_resource_lock.sh --release $lockname $current_owner\\\\n                        continue\\\\n                    fi\\\\n                fi\\\\n                log \\\\\\\"Shutdown lock held by another node (rc: $rc), retrying\\\\\\\"\\\\n                sleep 10\\\\n            fi\\\\n        fi\\\\n    done\\\\n    log \\\\\\\"Shutdown lock acquired\\\\\\\"\\\\n    return 0\\\\n}\\\\n\\\\n\\\\n# Release the lock if we still own it. Not owning it anymore is not fatal\\\\nshutdown_lock_release() {\\\\n    local lockname=$1\\\\n    local requester=$2\\\\n    local rc\\\\n\\\\n    log \\\\\\\"Releasing the shutdown lock\\\\\\\"\\\\n    /var/lib/container-config-scripts/pacemaker_resource_lock.sh --release $lockname $requester\\\\n    rc=$?\\\\n    if [ $rc -ne 0 ]; then\\\\n        if [ $rc -gt 1 ]; then\\\\n            error \\\\\\\"Could not release the shutdown lock due to unrecoverable error (rc: $rc), bailing out\\\\\\\"\\\\n        else\\\\n            log \\\\\\\"Shutdown lock no longer held, nothing to do\\\\\\\"\\\\n        fi\\\\n    else\\\\n        log \\\\\\\"Shutdown lock released\\\\\\\"\\\\n    fi\\\\n    return 0\\\\n}\\\\n\\\\n\\\\nACTION=$1\\\\nif [ -z \\\\\\\"$ACTION\\\\\\\" ]; then\\\\n    error \\\\\\\"Action must be specified\\\\\\\"\\\\nfi\\\\n\\\\nLOCK_NAME=tripleo-shutdown-lock\\\\nLOCK_OWNER=$(crm_node -n 2>/dev/null)\\\\nrc=$?\\\\nif [ $rc -ne 0 ]; then\\\\n    if [ $rc -eq 102 ]; then\\\\n        log \\\\\\\"Cluster is not running locally, no need to aquire the shutdown lock\\\\\\\"\\\\n        exit 0\\\\n    else\\\\n        error \\\\\\\"Unexpected error while connecting to the cluster (rc: $rc), bailing out\\\\\\\"\\\\n    fi\\\\nfi\\\\n\\\\n# We start with a very high TTL, that long enough to accomodate a cluster stop.\\\\n# As soon as the node will get offline, the other competing node will be entitled\\\\n# to steal the lock, so they should never wait that long in practice.\\\\nLOCK_TTL=600\\\\n\\\\n\\\\ncase $ACTION in\\\\n    --help) usage; exit 0;;\\\\n    --acquire|-a) shutdown_lock_acquire ${LOCK_NAME} ${LOCK_OWNER} ${LOCK_TTL};;\\\\n    --release|-r) shutdown_lock_release ${LOCK_NAME} ${LOCK_OWNER};;\\\\n    *) error \\\\\\\"Invalid action\\\\\\\";;\\\\nesac\\\\nexit $?\\\\n\\\"}, \\\"nova_statedir_ownership.py\\\": {\\\"mode\\\": \\\"0700\\\", \\\"content\\\": \\\"#!/usr/bin/python3\\\\n#\\\\n# Copyright 2018 Red Hat Inc.\\\\n#\\\\n# Licensed under the Apache License, Version 2.0 (the \\\\\\\"License\\\\\\\"); you may\\\\n# not use this file except in compliance with the License. You may obtain\\\\n# a copy of the License at\\\\n#\\\\n#      http://www.apache.org/licenses/LICENSE-2.0\\\\n#\\\\n# Unless required by applicable law or agreed to in writing, software\\\\n# distributed under the License is distributed on an \\\\\\\"AS IS\\\\\\\" BASIS, WITHOUT\\\\n# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the\\\\n# License for the specific language governing permissions and limitations\\\\n# under the License.\\\\nimport logging\\\\nimport os\\\\nimport pwd\\\\nimport selinux\\\\nimport stat\\\\nimport sys\\\\n\\\\ndebug = os.getenv(\'__OS_DEBUG\', \'false\')\\\\n\\\\nif debug.lower() == \'true\':\\\\n    loglevel = logging.DEBUG\\\\nelse:\\\\n    loglevel = logging.INFO\\\\n\\\\nlogging.basicConfig(stream=sys.stdout, level=loglevel)\\\\nLOG = logging.getLogger(\'nova_statedir\')\\\\n\\\\n\\\\nclass PathManager(object):\\\\n    \\\\\\\"\\\\\\\"\\\\\\\"Helper class to manipulate ownership of a given path\\\\\\\"\\\\\\\"\\\\\\\"\\\\n    def __init__(self, path):\\\\n        self.path = path\\\\n        self.uid = None\\\\n        self.gid = None\\\\n        self.is_dir = None\\\\n        self.secontext = None\\\\n        self._update()\\\\n\\\\n    def _update(self):\\\\n        try:\\\\n            statinfo = os.stat(self.path)\\\\n            self.is_dir = stat.S_ISDIR(statinfo.st_mode)\\\\n            self.uid = statinfo.st_uid\\\\n            self.gid = statinfo.st_gid\\\\n            self.secontext = selinux.lgetfilecon(self.path)[1]\\\\n        except Exception:\\\\n            LOG.exception(\'Could not update metadata for %s\', self.path)\\\\n            raise\\\\n\\\\n    def __str__(self):\\\\n        return \\\\\\\"uid: {} gid: {} path: {}{}\\\\\\\".format(\\\\n            self.uid,\\\\n            self.gid,\\\\n            self.path,\\\\n            \'/\' if self.is_dir else \'\'\\\\n        )\\\\n\\\\n    def has_owner(self, uid, gid):\\\\n        return self.uid == uid and self.gid == gid\\\\n\\\\n    def has_either(self, uid, gid):\\\\n        return self.uid == uid or self.gid == gid\\\\n\\\\n    def chown(self, uid, gid):\\\\n        target_uid = -1\\\\n        target_gid = -1\\\\n        if self.uid != uid:\\\\n            target_uid = uid\\\\n        if self.gid != gid:\\\\n            target_gid = gid\\\\n        if (target_uid, target_gid) != (-1, -1):\\\\n            LOG.info(\'Changing ownership of %s from %d:%d to %d:%d\',\\\\n                     self.path,\\\\n                     self.uid,\\\\n                     self.gid,\\\\n                     self.uid if target_uid == -1 else target_uid,\\\\n                     self.gid if target_gid == -1 else target_gid)\\\\n            try:\\\\n                os.chown(self.path, target_uid, target_gid)\\\\n                self._update()\\\\n            except Exception:\\\\n                LOG.exception(\'Could not change ownership of %s: \',\\\\n                              self.path)\\\\n                raise\\\\n        else:\\\\n            LOG.info(\'Ownership of %s already %d:%d\',\\\\n                     self.path,\\\\n                     uid,\\\\n                     gid)\\\\n\\\\n    def chcon(self, context):\\\\n        # If dir returns whether to recusively set context\\\\n        try:\\\\n            try:\\\\n                selinux.lsetfilecon(self.path, context)\\\\n                LOG.info(\'Setting selinux context of %s to %s\',\\\\n                     self.path, context)\\\\n                return True\\\\n            except OSError as e:\\\\n                if self.is_dir and e.errno == 95:\\\\n                    # Operation not supported, assume NFS mount and skip\\\\n                    LOG.info(\'Setting selinux context not supported for %s\',\\\\n                             self.path)\\\\n                    return False\\\\n                else:\\\\n                    raise\\\\n        except Exception:\\\\n            LOG.exception(\'Could not set selinux context of %s to %s:\',\\\\n                          self.path, context)\\\\n            raise\\\\n\\\\n\\\\nclass NovaStatedirOwnershipManager(object):\\\\n    \\\\\\\"\\\\\\\"\\\\\\\"Class to manipulate the ownership of the nova statedir (/var/lib/nova).\\\\n\\\\n       The nova uid/gid differ on the host and container images. An upgrade\\\\n       that switches from host systemd services to docker requires a change in\\\\n       ownership. Previously this was a naive recursive chown, however this\\\\n       causes issues if nova instance are shared via an NFS mount: any open\\\\n       filehandles in qemu/libvirt fail with an I/O error (LP1778465).\\\\n\\\\n       Instead the upgrade/FFU ansible tasks now lay down a marker file when\\\\n       stopping and disabling the host systemd services. We use this file to\\\\n       determine the host nova uid/gid. We then walk the tree and update any\\\\n       files that have the host uid/gid to the docker nova uid/gid. As files\\\\n       owned by root/qemu etc... are ignored this avoids the issues with open\\\\n       filehandles. The marker is removed once the tree has been walked.\\\\n\\\\n       For subsequent runs, or for a new deployment, we simply ensure that the\\\\n       docker nova user/group owns all directories. This is required as the\\\\n       directories are created with root ownership in host_prep_tasks (the\\\\n       docker nova uid/gid is not known in this context).\\\\n    \\\\\\\"\\\\\\\"\\\\\\\"\\\\n    def __init__(self, statedir, upgrade_marker=\'upgrade_marker\',\\\\n                 nova_user=\'nova\', secontext_marker=\'../_nova_secontext\',\\\\n                 exclude_paths=None):\\\\n        self.statedir = statedir\\\\n        self.nova_user = nova_user\\\\n\\\\n        self.upgrade_marker_path = os.path.join(statedir, upgrade_marker)\\\\n        self.secontext_marker_path = os.path.normpath(os.path.join(statedir, secontext_marker))\\\\n        self.upgrade = os.path.exists(self.upgrade_marker_path)\\\\n\\\\n        self.exclude_paths = [self.upgrade_marker_path]\\\\n        if exclude_paths is not None:\\\\n            for p in exclude_paths:\\\\n                if not p.startswith(os.path.sep):\\\\n                    p = os.path.join(self.statedir, p)\\\\n                self.exclude_paths.append(p)\\\\n\\\\n        self.target_uid, self.target_gid = self._get_nova_ids()\\\\n        self.previous_uid, self.previous_gid = self._get_previous_nova_ids()\\\\n        self.id_change = (self.target_uid, self.target_gid) != \\\\\\\\\\\\n            (self.previous_uid, self.previous_gid)\\\\n        self.target_secontext = self._get_secontext()\\\\n\\\\n    def _get_nova_ids(self):\\\\n        nova_uid, nova_gid = pwd.getpwnam(self.nova_user)[2:4]\\\\n        return nova_uid, nova_gid\\\\n\\\\n    def _get_previous_nova_ids(self):\\\\n        if self.upgrade:\\\\n            statinfo = os.stat(self.upgrade_marker_path)\\\\n            return statinfo.st_uid, statinfo.st_gid\\\\n        else:\\\\n            return self._get_nova_ids()\\\\n\\\\n    def _get_secontext(self):\\\\n        if os.path.exists(self.secontext_marker_path):\\\\n            return selinux.lgetfilecon(self.secontext_marker_path)[1]\\\\n        else:\\\\n            return None\\\\n\\\\n    def _walk(self, top, chcon=True):\\\\n        for f in os.listdir(top):\\\\n            pathname = os.path.join(top, f)\\\\n\\\\n            if pathname in self.exclude_paths:\\\\n                continue\\\\n\\\\n            try:\\\\n                pathinfo = PathManager(pathname)\\\\n                LOG.info(\\\\\\\"Checking %s\\\\\\\", pathinfo)\\\\n                if pathinfo.is_dir:\\\\n                    # Always chown the directories\\\\n                    pathinfo.chown(self.target_uid, self.target_gid)\\\\n                    chcon_r = chcon\\\\n                    if chcon:\\\\n                        chcon_r = pathinfo.chcon(self.target_secontext)\\\\n                    self._walk(pathname, chcon_r)\\\\n                elif self.id_change:\\\\n                    # Only chown files if it\'s an upgrade and the file is owned by\\\\n                    # the host nova uid/gid\\\\n                    pathinfo.chown(\\\\n                        self.target_uid if pathinfo.uid == self.previous_uid\\\\n                        else pathinfo.uid,\\\\n                        self.target_gid if pathinfo.gid == self.previous_gid\\\\n                        else pathinfo.gid\\\\n                    )\\\\n                    if chcon:\\\\n                        pathinfo.chcon(self.target_secontext)\\\\n            except Exception:\\\\n                # Likely to have been caused by external systems\\\\n                # interacting with this directory tree,\\\\n                # especially on NFS e.g snapshot dirs.\\\\n                # Just ignore it and continue on to the next entry\\\\n                continue\\\\n\\\\n    def run(self):\\\\n        LOG.info(\'Applying nova statedir ownership\')\\\\n        LOG.info(\'Target ownership for %s: %d:%d\',\\\\n                 self.statedir,\\\\n                 self.target_uid,\\\\n                 self.target_gid)\\\\n\\\\n        pathinfo = PathManager(self.statedir)\\\\n        LOG.info(\\\\\\\"Checking %s\\\\\\\", pathinfo)\\\\n        pathinfo.chown(self.target_uid, self.target_gid)\\\\n        chcon = self.target_secontext is not None\\\\n\\\\n        if chcon:\\\\n            pathinfo.chcon(self.target_secontext)\\\\n\\\\n        self._walk(self.statedir, chcon)\\\\n\\\\n        if self.upgrade:\\\\n            LOG.info(\'Removing upgrade_marker %s\',\\\\n                     self.upgrade_marker_path)\\\\n            os.unlink(self.upgrade_marker_path)\\\\n\\\\n        LOG.info(\'Nova statedir ownership complete\')\\\\n\\\\n\\\\ndef get_exclude_paths():\\\\n    exclude_paths = os.environ.get(\'NOVA_STATEDIR_OWNERSHIP_SKIP\')\\\\n    if exclude_paths is not None:\\\\n        exclude_paths = exclude_paths.split(os.pathsep)\\\\n    return exclude_paths\\\\n\\\\n\\\\nif __name__ == \'__main__\':\\\\n    NovaStatedirOwnershipManager(\'/var/lib/nova\', exclude_paths=get_exclude_paths()).run()\\\\n\\\"}, \\\"nova_wait_for_compute_service.py\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/python3\\\\n#\\\\n# Copyright 2018 Red Hat Inc.\\\\n#\\\\n# Licensed under the Apache License, Version 2.0 (the \\\\\\\"License\\\\\\\"); you may\\\\n# not use this file except in compliance with the License. You may obtain\\\\n# a copy of the License at\\\\n#\\\\n#      http://www.apache.org/licenses/LICENSE-2.0\\\\n#\\\\n# Unless required by applicable law or agreed to in writing, software\\\\n# distributed under the License is distributed on an \\\\\\\"AS IS\\\\\\\" BASIS, WITHOUT\\\\n# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the\\\\n# License for the specific language governing permissions and limitations\\\\n# under the License.\\\\nimport argparse\\\\nimport logging\\\\nimport os\\\\nimport six\\\\nimport socket\\\\nimport sys\\\\nimport time\\\\n\\\\n\\\\nfrom keystoneauth1 import loading\\\\nfrom keystoneauth1 import session\\\\n\\\\nfrom novaclient import client\\\\n\\\\n# In python3 SafeConfigParser was renamed to ConfigParser and the default\\\\n# for duplicate options default to true. In case of nova it is valid to\\\\n# have duplicate option lines, e.g. passthrough_whitelist which leads to\\\\n# issues reading the nova.conf\\\\n# https://bugs.launchpad.net/tripleo/+bug/1827775\\\\nif six.PY3:\\\\n    from six.moves.configparser import ConfigParser\\\\n    config = ConfigParser(strict=False)\\\\nelse:\\\\n    from six.moves.configparser import SafeConfigParser\\\\n    config = SafeConfigParser()\\\\n\\\\ndebug = os.getenv(\'__OS_DEBUG\', \'false\')\\\\n\\\\nif debug.lower() == \'true\':\\\\n    loglevel = logging.DEBUG\\\\nelse:\\\\n    loglevel = logging.INFO\\\\n\\\\nlogging.basicConfig(stream=sys.stdout, level=loglevel)\\\\nLOG = logging.getLogger(\'nova_wait_for_compute_service\')\\\\n\\\\niterations = 60\\\\ntimeout = 10\\\\nnova_cfg = \'/etc/nova/nova.conf\'\\\\n\\\\nif __name__ == \'__main__\':\\\\n    parser = argparse.ArgumentParser(usage=\'%(prog)s [options]\')\\\\n    parser.add_argument(\'-k\', \'--insecure\',\\\\n                        action=\\\\\\\"store_false\\\\\\\",\\\\n                        dest=\'insecure\',\\\\n                        default=True,\\\\n                        help=\'Allow insecure connection when using SSL\')\\\\n\\\\n    args = parser.parse_args()\\\\n    LOG.debug(\'Running with parameter insecure = %s\',\\\\n              args.insecure)\\\\n\\\\n    if os.path.isfile(nova_cfg):\\\\n        try:\\\\n            config.read(nova_cfg)\\\\n        except Exception:\\\\n            LOG.exception(\'Error while reading nova.conf:\')\\\\n    else:\\\\n        LOG.error(\'Nova configuration file %s does not exist\', nova_cfg)\\\\n        sys.exit(1)\\\\n\\\\n    my_host = config.get(\'DEFAULT\', \'host\')\\\\n    if not my_host:\\\\n        # If host isn\'t set nova defaults to this\\\\n        my_host = socket.gethostname()\\\\n\\\\n    loader = loading.get_plugin_loader(\'password\')\\\\n    auth = loader.load_from_options(\\\\n        auth_url=config.get(\'neutron\',\\\\n                            \'auth_url\'),\\\\n        username=config.get(\'neutron\',\\\\n                            \'username\'),\\\\n        password=config.get(\'neutron\',\\\\n                            \'password\'),\\\\n        project_name=config.get(\'neutron\',\\\\n                                \'project_name\'),\\\\n        project_domain_name=config.get(\'neutron\',\\\\n                                       \'project_domain_name\'),\\\\n        user_domain_name=config.get(\'neutron\',\\\\n                                    \'user_domain_name\'))\\\\n    sess = session.Session(auth=auth, verify=args.insecure)\\\\n    nova = client.Client(\'2.11\', session=sess, endpoint_type=\'internal\',\\\\n                         region_name=config.get(\'neutron\', \'region_name\'))\\\\n\\\\n    # Wait until this host is listed in the service list\\\\n    for i in range(iterations):\\\\n        try:\\\\n            service_list = nova.services.list(binary=\'nova-compute\')\\\\n            for entry in service_list:\\\\n                host = getattr(entry, \'host\', \'\')\\\\n                zone = getattr(entry, \'zone\', \'\')\\\\n                if host == my_host and zone != \'internal\':\\\\n                    LOG.info(\'Nova-compute service registered\')\\\\n                    sys.exit(0)\\\\n            LOG.info(\'Waiting for nova-compute service to register\')\\\\n        except Exception:\\\\n            LOG.exception(\\\\n                \'Error while waiting for nova-compute service to register\')\\\\n        time.sleep(timeout)\\\\nsys.exit(1)\\\\n\\\\n# vim: set et ts=4 sw=4 :\\\\n\\\"}}, \\\"docker_config\\\": {\\\"step_2\\\": {\\\"nova_compute_init_log\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\\\", \\\"net\\\": \\\"none\\\", \\\"privileged\\\": false, \\\"user\\\": \\\"root\\\", \\\"volumes\\\": [\\\"/var/log/containers/nova:/var/log/nova:z\\\"], \\\"command\\\": [\\\"/bin/bash\\\", \\\"-c\\\", \\\"chown -R nova:nova /var/log/nova\\\"], \\\"environment\\\": {\\\"TRIPLEO_DEPLOY_IDENTIFIER\\\": \\\"1780992067\\\"}}}, \\\"step_3\\\": {\\\"nova_statedir_owner\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\\\", \\\"net\\\": \\\"none\\\", \\\"user\\\": \\\"root\\\", \\\"security_opt\\\": [\\\"label=disable\\\"], \\\"privileged\\\": false, \\\"detach\\\": false, \\\"volumes\\\": [\\\"/var/lib/nova:/var/lib/nova:shared\\\", \\\"/var/lib/_nova_secontext:/var/lib/_nova_secontext:shared,z\\\", \\\"/var/lib/container-config-scripts:/container-config-scripts:z\\\"], \\\"command\\\": \\\"/container-config-scripts/pyshim.sh /container-config-scripts/nova_statedir_ownership.py\\\", \\\"environment\\\": {\\\"TRIPLEO_DEPLOY_IDENTIFIER\\\": \\\"1780992067\\\", \\\"__OS_DEBUG\\\": \\\"true\\\", \\\"NOVA_STATEDIR_OWNERSHIP_SKIP\\\": \\\"triliovault-mounts\\\"}}}, \\\"step_5\\\": {\\\"nova_compute\\\": {\\\"start_order\\\": 3, \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\\\", \\\"ulimit\\\": [\\\"nofile=131072\\\", \\\"memlock=67108864\\\"], \\\"ipc\\\": \\\"host\\\", \\\"net\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"user\\\": \\\"nova\\\", \\\"restart\\\": \\\"always\\\", \\\"depends_on\\\": [\\\"tripleo_nova_libvirt.target\\\"], \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck 5672\\\"}, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/log/containers/nova:/var/log/nova\\\", \\\"/etc/ssh/ssh_known_hosts:/etc/ssh/ssh_known_hosts:ro\\\", \\\"/var/lib/kolla/config_files/nova_compute.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/lib/config-data/puppet-generated/iscsid/etc/iscsi:/var/lib/kolla/config_files/src-iscsid:ro\\\", \\\"/var/lib/tripleo-config/ceph:/var/lib/kolla/config_files/src-ceph:z\\\", \\\"/dev:/dev\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/run:/run\\\", \\\"/run/nova:/run/nova:z\\\", \\\"/var/lib/iscsi:/var/lib/iscsi:z\\\", \\\"/var/lib/libvirt:/var/lib/libvirt:shared\\\", \\\"/sys/class/net:/sys/class/net\\\", \\\"/sys/bus/pci:/sys/bus/pci\\\", \\\"/boot:/boot:ro\\\", \\\"/var/lib/nova:/var/lib/nova:shared\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\", \\\"LIBGUESTFS_BACKEND\\\": \\\"direct\\\"}}, \\\"nova_wait_for_compute_service\\\": {\\\"start_order\\\": 4, \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\\\", \\\"net\\\": \\\"host\\\", \\\"detach\\\": false, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/lib/kolla/config_files/nova_compute_wait_for_compute_service.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/log/containers/nova:/var/log/nova\\\", \\\"/var/lib/container-config-scripts:/container-config-scripts\\\"], \\\"user\\\": \\\"nova\\\", \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\", \\\"__OS_DEBUG\\\": \\\"true\\\"}}}}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"state\\\": \\\"directory\\\", \\\"mode\\\": \\\"{{ item.mode }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/nova\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}]}, {\\\"name\\\": \\\"Check for /var/lib/nova/instances directory exitance\\\", \\\"stat\\\": {\\\"path\\\": \\\"/var/lib/nova/instances\\\"}, \\\"register\\\": \\\"check_nova_instances_result\\\"}, {\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype | default(omit) }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/lib/nova\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/var/lib/_nova_secontext\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/var/lib/nova/instances\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/var/lib/libvirt\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/etc/tmpfiles.d\\\"}]}, {\\\"name\\\": \\\"ensure /run/nova is present upon reboot\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/tmpfiles.d/run-nova.conf\\\", \\\"content\\\": \\\"d /run/nova 0777 root root - -\\\\n\\\"}}, {\\\"name\\\": \\\"create tempfiles\\\", \\\"command\\\": \\\"systemd-tmpfiles --create\\\"}, {\\\"name\\\": \\\"Mount Nova NFS Share\\\", \\\"vars\\\": {\\\"nfs_backend_enable\\\": false, \\\"nfs_share\\\": \\\"\\\", \\\"nfs_options\\\": \\\"context=system_u:object_r:nfs_t:s0\\\", \\\"nfs_vers\\\": \\\"4.2\\\"}, \\\"mount\\\": {\\\"name\\\": \\\"/var/lib/nova/instances\\\", \\\"state\\\": \\\"mounted\\\", \\\"fstype\\\": \\\"nfs4\\\", \\\"src\\\": \\\"{{nfs_share}}\\\", \\\"opts\\\": \\\"_netdev,bg,{{nfs_options}},nfsvers={{nfs_vers}}\\\"}, \\\"when\\\": \\\"nfs_backend_enable|bool\\\"}, {\\\"name\\\": \\\"delay installation of systemd-container\\\", \\\"when\\\": \\\"check_nova_instances_result.stat.exists\\\", \\\"block\\\": [{\\\"name\\\": \\\"check systemd-container package installed or not\\\", \\\"package\\\": {\\\"name\\\": \\\"systemd-container\\\", \\\"state\\\": \\\"present\\\"}, \\\"check_mode\\\": true, \\\"register\\\": \\\"is_systemd_container_package\\\", \\\"failed_when\\\": false}, {\\\"name\\\": \\\"get latest package from downloaded package versions\\\", \\\"shell\\\": \\\"ls -1t /var/tmp/systemd-container* | head -1\\\", \\\"register\\\": \\\"latest_systemd_container_package\\\", \\\"when\\\": [\\\"is_systemd_container_package is defined\\\", \\\"(\'changed\' in is_systemd_container_package)\\\", \\\"is_systemd_container_package.changed\\\"], \\\"failed_when\\\": false}, {\\\"name\\\": \\\"Install systemd-container package on boot\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/systemd/system/install-systemd-container.service\\\", \\\"content\\\": \\\"[Unit]\\\\nDescription=Install systemd container package on system boot\\\\nBefore=tripleo_nova_virtqemud.service\\\\n\\\\n[Service]\\\\nType=oneshot\\\\nExecStart=/usr/bin/rpm -ivh {{ latest_systemd_container_package.stdout }}\\\\nExecStartPost=rm -f /var/tmp/systemd-container*\\\\n\\\\n[Install]\\\\nWantedBy=multi-user.target\\\\n\\\"}, \\\"when\\\": [\\\"latest_systemd_container_package is defined\\\", \\\"(\'stdout\' in latest_systemd_container_package)\\\", \\\"is_systemd_container_package is defined\\\", \\\"(\'changed\' in is_systemd_container_package)\\\", \\\"is_systemd_container_package.changed\\\"]}, {\\\"name\\\": \\\"enable install-systemd-container on compute boot\\\", \\\"systemd\\\": {\\\"name\\\": \\\"install-systemd-container\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": true, \\\"daemon_reload\\\": true}, \\\"when\\\": [\\\"is_systemd_container_package is defined\\\", \\\"(\'changed\' in is_systemd_container_package)\\\", \\\"is_systemd_container_package.changed\\\"]}, {\\\"name\\\": \\\"check if install-systemd-container service exists\\\", \\\"stat\\\": {\\\"path\\\": \\\"/etc/systemd/system/install-systemd-container.service\\\"}, \\\"register\\\": \\\"install_systemd_container_result\\\"}, {\\\"name\\\": \\\"disable and mask install-systemd-container on compute boot\\\", \\\"systemd\\\": {\\\"name\\\": \\\"install-systemd-container\\\", \\\"enabled\\\": false, \\\"masked\\\": true, \\\"daemon_reload\\\": true}, \\\"when\\\": [\\\"is_systemd_container_package is defined\\\", \\\"(\'changed\' in is_systemd_container_package)\\\", \\\"not is_systemd_container_package.changed\\\", \\\"install_systemd_container_result.stat.exists\\\"]}]}, {\\\"name\\\": \\\"is Nova Resume Guests State On Host Boot enabled\\\", \\\"set_fact\\\": {\\\"resume_guests_state_on_host_boot_enabled\\\": false}}, {\\\"name\\\": \\\"install libvirt-guests systemd unit file (docker)\\\", \\\"when\\\": [\\\"resume_guests_state_on_host_boot_enabled|bool\\\", \\\"container_cli == \'docker\'\\\"], \\\"block\\\": [{\\\"name\\\": \\\"libvirt-guests unit to stop nova_compute container before shutdown VMs\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/systemd/system/libvirt-guests.service\\\", \\\"content\\\": \\\"[Unit]\\\\nDescription=Suspend/Resume Running libvirt Guests\\\\nAfter=network.target\\\\nAfter=time-sync.target\\\\nAfter=virt-guest-shutdown.target\\\\nAfter=docker.service\\\\nAfter=tripleo-container-shutdown.service\\\\nAfter=rhel-push-plugin.service\\\\nDocumentation=man:libvirtd(8)\\\\nDocumentation=https://libvirt.org\\\\n\\\\n[Service]\\\\nEnvironmentFile=-/var/lib/config-data/puppet-generated/nova_libvirt/etc/sysconfig/libvirt-guests\\\\n# Hack just call traditional service until we factor\\\\n# out the code\\\\nExecStart=/bin/{{container_cli}} exec nova_libvirt /bin/sh -x /usr/libexec/libvirt-guests.sh start\\\\nExecStop=/bin/{{container_cli}} stop nova_compute\\\\nExecStop=/bin/{{container_cli}}  exec nova_libvirt /bin/sh -x /usr/libexec/libvirt-guests.sh stop\\\\nType=oneshot\\\\nRemainAfterExit=yes\\\\nStandardOutput=journal+console\\\\nTimeoutStopSec=0\\\\n\\\\n[Install]\\\\nWantedBy=multi-user.target\\\\n\\\"}}, {\\\"name\\\": \\\"Making sure virt-guest-shutdown.target is present\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/systemd/system/virt-guest-shutdown.target\\\", \\\"content\\\": \\\"[Unit]\\\\nDescription=Libvirt guests shutdown\\\\nDocumentation=https://libvirt.org\\\\nAfter=systemd-machined.service\\\\nAfter=network-online.target\\\\nAfter=tripleo_nova_libvirt.target\\\\nBefore=tripleo_nova_compute.service\\\\n\\\"}}, {\\\"name\\\": \\\"libvirt-guests enable VM shutdown on compute reboot/shutdown\\\", \\\"systemd\\\": {\\\"name\\\": \\\"libvirt-guests\\\", \\\"enabled\\\": true, \\\"daemon_reload\\\": true}}]}, {\\\"name\\\": \\\"install tripleo_nova_libvirt_guests systemd unit file (podman)\\\", \\\"when\\\": [\\\"resume_guests_state_on_host_boot_enabled|bool\\\", \\\"container_cli == \'podman\'\\\"], \\\"block\\\": [{\\\"name\\\": \\\"libvirt-guests unit to stop nova_compute container before shutdown VMs (monolithic libvirt)\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/systemd/system/tripleo_nova_libvirt_guests.service\\\", \\\"content\\\": \\\"[Unit]\\\\nDescription=Suspend libvirt Guests in tripleo\\\\nRequires=virt-guest-shutdown.target\\\\nAfter=systemd-machined.service\\\\nAfter=network-online.target\\\\nAfter=tripleo_nova_libvirt.target\\\\nBefore=tripleo_nova_compute.service\\\\nDocumentation=man:libvirtd(8)\\\\nDocumentation=https://libvirt.org\\\\n\\\\n[Service]\\\\nEnvironmentFile=-/etc/sysconfig/libvirt-guests\\\\nExecStart=/bin/podman exec nova_libvirt /bin/rm -f /var/lib/libvirt/libvirt-guests\\\\nExecStop=/bin/podman exec nova_libvirt /bin/sh -x /usr/libexec/libvirt-guests.sh shutdown\\\\nType=oneshot\\\\nRemainAfterExit=yes\\\\nStandardOutput=journal+console\\\\nTimeoutStopSec=0\\\\n\\\\n[Install]\\\\nWantedBy=multi-user.target\\\\n\\\"}, \\\"when\\\": \\\"tripleo_nova_libvirt_virsh_container | default(\'nova_libvirt\') == \'nova_libvirt\'\\\"}, {\\\"name\\\": \\\"libvirt-guests unit to stop nova_compute container before shutdown VMs (modular libvirt)\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/systemd/system/tripleo_nova_libvirt_guests.service\\\", \\\"content\\\": \\\"[Unit]\\\\nDescription=Suspend libvirt Guests in tripleo\\\\nRequires=virt-guest-shutdown.target\\\\nAfter=systemd-machined.service\\\\nAfter=network-online.target\\\\nAfter=tripleo_nova_libvirt.target\\\\nBefore=tripleo_nova_compute.service\\\\nDocumentation=man:libvirtd(8)\\\\nDocumentation=https://libvirt.org\\\\n\\\\n[Service]\\\\nEnvironmentFile=-/etc/sysconfig/libvirt-guests\\\\nExecStart=/bin/podman exec nova_virtproxyd /bin/rm -f /var/lib/libvirt/libvirt-guests\\\\nExecStop=/bin/podman exec nova_virtproxyd /bin/sh -x /usr/libexec/libvirt-guests.sh shutdown\\\\nType=oneshot\\\\nRemainAfterExit=yes\\\\nStandardOutput=journal+console\\\\nTimeoutStopSec=0\\\\n\\\\n[Install]\\\\nWantedBy=multi-user.target\\\\n\\\"}, \\\"when\\\": \\\"tripleo_nova_libvirt_virsh_container | default(\'nova_libvirt\') != \'nova_libvirt\'\\\"}, {\\\"name\\\": \\\"Making sure virt-guest-shutdown.target is present\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/systemd/system/virt-guest-shutdown.target\\\", \\\"content\\\": \\\"[Unit]\\\\nDescription=Libvirt guests shutdown\\\\nDocumentation=https://libvirt.org\\\\nAfter=systemd-machined.service\\\\nAfter=network-online.target\\\\nAfter=tripleo_nova_libvirt.target\\\\nBefore=tripleo_nova_compute.service\\\\n\\\"}}, {\\\"name\\\": \\\"tripleo_nova_libvirt_guests enable VM shutdown on compute reboot/shutdown\\\", \\\"systemd\\\": {\\\"name\\\": \\\"tripleo_nova_libvirt_guests\\\", \\\"enabled\\\": true, \\\"daemon_reload\\\": true}}]}, {\\\"name\\\": \\\"ensure ceph configurations exist\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/lib/tripleo-config/ceph\\\", \\\"state\\\": \\\"directory\\\"}}, {\\\"name\\\": \\\"enable virt_sandbox_use_netlink for healthcheck\\\", \\\"seboolean\\\": {\\\"name\\\": \\\"virt_sandbox_use_netlink\\\", \\\"persistent\\\": true, \\\"state\\\": true}, \\\"when\\\": [\\\"ansible_facts.selinux is defined\\\", \\\"ansible_facts.selinux.status == \\\\\\\"enabled\\\\\\\"\\\"]}, {\\\"name\\\": \\\"Do we prepend nova startup with a delay\\\", \\\"set_fact\\\": {\\\"nova_compute_delay\\\": 0}}, {\\\"name\\\": \\\"install nova-compute delay wrapper script\\\", \\\"copy\\\": {\\\"content\\\": \\\"#!/usr/libexec/platform-python\\\\n\\\\\\\"\\\\\\\"\\\\\\\"\\\\nThis wrapper was created to add an optional delay to the startup of nova-compute.\\\\nWe know that instances will fail to boot, after a compute reboot, if ceph is not\\\\nhealthy.\\\\n\\\\nIdeally, we would poll ceph to get its health, but it\'s not guaranteed that the\\\\ncompute node will have access to the keys.\\\\n\\\\\\\"\\\\\\\"\\\\\\\"\\\\n\\\\nimport os\\\\nimport sys\\\\nimport time\\\\nimport logging\\\\nimport argparse\\\\n\\\\nparser = argparse.ArgumentParser(description=\'Process some integers.\')\\\\nparser.add_argument(\'--config-file\', dest=\'nova_config\', action=\'store\',\\\\n                    default=\\\\\\\"/etc/nova/nova.conf\\\\\\\",\\\\n                    help=\'path to nova configuration (default: /etc/nova/nova.conf)\')\\\\nparser.add_argument(\'--nova-binary\', dest=\'nova_binary\', action=\'store\',\\\\n                    default=\\\\\\\"/usr/bin/nova-compute\\\\\\\",\\\\n                    help=\'path to nova compute binary (default: /usr/bin/nova-compute)\')\\\\nparser.add_argument(\'--delay\', dest=\'delay\', action=\'store\',\\\\n                    default=120, type=int,\\\\n                    help=\'Number of seconds to wait until nova-compute is started\')\\\\nparser.add_argument(\'--state-dir\', dest=\'state_dir\', action=\'store\',\\\\n                    default=\\\\\\\"/run/nova/startup\\\\\\\", help=\'state-file directory\')\\\\nparser.add_argument(\'--state-file\', dest=\'state_file\', action=\'store\',\\\\n                    default=\\\\\\\"nova-compute-delayed\\\\\\\",\\\\n                    help=\'file exists if we already delayed nova-compute startup\')\\\\n\\\\n\\\\nsections = {}\\\\n(args, remaining) = parser.parse_known_args(sys.argv)\\\\n\\\\nreal_args = [args.nova_binary, \'--config-file\', args.nova_config]\\\\nreal_args.extend(remaining[1:])\\\\n\\\\nif not os.path.isdir(args.state_dir):\\\\n  os.makedirs(args.state_dir, mode = 0o751)\\\\n\\\\nstate_file_name = os.path.join(args.state_dir, args.state_file)\\\\n\\\\nif not os.path.isfile(state_file_name):\\\\n    logging.info(\\\\\\\"Delaying nova-compute startup by %s seconds\\\\\\\" % args.delay)\\\\n    time.sleep(args.delay)\\\\n    open(state_file_name, \'a\').close()\\\\n\\\\nlogging.info(\\\\\\\"Executing %s\\\\\\\" % real_args)\\\\nos.execv(args.nova_binary, real_args)\\\\n\\\", \\\"dest\\\": \\\"/var/lib/nova/delay-nova-compute\\\", \\\"mode\\\": 493}, \\\"when\\\": \\\"nova_compute_delay|int > 0\\\"}, {\\\"name\\\": \\\"Is irqbalance enabled\\\", \\\"set_fact\\\": {\\\"compute_irqbalance_disabled\\\": false}}, {\\\"name\\\": \\\"disable irqbalance service on compute\\\", \\\"when\\\": \\\"compute_irqbalance_disabled|bool\\\", \\\"service\\\": {\\\"name\\\": \\\"irqbalance.service\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": false}}], \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"install systemd-container for a greenfield\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"not check_nova_instances_result.stat.exists\\\"], \\\"package\\\": {\\\"name\\\": \\\"systemd-container\\\", \\\"state\\\": \\\"present\\\"}}, {\\\"name\\\": \\\"validate nova-compute container state\\\", \\\"containers.podman.podman_container_info\\\": {\\\"name\\\": \\\"nova_compute\\\"}, \\\"register\\\": \\\"nova_compute_infos\\\", \\\"failed_when\\\": [\\\"nova_compute_infos.containers.0.Healthcheck.Status is defined\\\", \\\"\'healthy\' not in nova_compute_infos.containers.0.Healthcheck.Status\\\"], \\\"retries\\\": 10, \\\"delay\\\": 30, \\\"tags\\\": [\\\"opendev-validation\\\", \\\"opendev-validation-nova\\\"], \\\"when\\\": [\\\"container_cli == \'podman\'\\\", \\\"not container_healthcheck_disabled\\\", \\\"step|int == 6\\\"]}, {\\\"name\\\": \\\"manage PMEM namespaces for vPMEM\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_nvdimm\\\"}, \\\"vars\\\": {\\\"tripleo_nvdimm_pmem_namespaces\\\": \\\"\\\"}, \\\"when\\\": [\\\"step|int == 1\\\", \\\"tripleo_nvdimm_pmem_namespaces != \'\'\\\"]}, {\\\"name\\\": \\\"manage OS version 9 specific sysctls\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"ansible_facts[\'os_family\'] == \'RedHat\'\\\", \\\"ansible_facts[\'distribution_major_version\'] is version(\'9\', \'==\')\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Enable post-copy by setting unprivileged_userfaultfd\\\", \\\"sysctl\\\": {\\\"name\\\": \\\"vm.unprivileged_userfaultfd\\\", \\\"value\\\": 1, \\\"sysctl_set\\\": true, \\\"sysctl_file\\\": \\\"/etc/sysctl.d/99-tripleo-postcopy.conf\\\", \\\"state\\\": \\\"present\\\", \\\"reload\\\": true}}]}, {\\\"name\\\": \\\"enable/disable ksm\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"is KSM enabled\\\", \\\"set_fact\\\": {\\\"compute_ksm_enabled\\\": false}}, {\\\"name\\\": \\\"disable KSM on compute\\\", \\\"when\\\": \\\"not compute_ksm_enabled|bool\\\", \\\"block\\\": [{\\\"name\\\": \\\"Check for ksm\\\", \\\"shell\\\": \\\"systemctl is-active ksm.service || systemctl is-enabled ksm.service\\\", \\\"become\\\": true, \\\"failed_when\\\": false, \\\"register\\\": \\\"ksm_service_check\\\"}, {\\\"name\\\": \\\"disable KSM services\\\", \\\"service\\\": {\\\"name\\\": \\\"{{ item }}\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": false}, \\\"with_items\\\": [\\\"ksm.service\\\", \\\"ksmtuned.service\\\"], \\\"when\\\": [\\\"ksm_service_check.rc is defined\\\", \\\"ksm_service_check.rc == 0\\\"], \\\"register\\\": \\\"ksmdisabled\\\"}, {\\\"name\\\": \\\"delete PageKSM after disable ksm on compute\\\", \\\"command\\\": \\\"echo 2 >/sys/kernel/mm/ksm/run\\\", \\\"when\\\": [\\\"ksm_service_check.rc is defined\\\", \\\"ksm_service_check.rc == 0\\\", \\\"ksmdisabled is changed\\\"]}]}, {\\\"name\\\": \\\"enable KSM on compute\\\", \\\"when\\\": \\\"compute_ksm_enabled|bool\\\", \\\"block\\\": [{\\\"name\\\": \\\"make sure package providing ksmtuned is installed (RHEL8 or CentOS8)\\\", \\\"package\\\": {\\\"name\\\": \\\"qemu-kvm-common\\\", \\\"state\\\": \\\"present\\\"}, \\\"when\\\": [\\\"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\\\"]}, {\\\"name\\\": \\\"make sure package providing ksmtuned is installed (RHEL9 or CentOS9)\\\", \\\"package\\\": {\\\"name\\\": \\\"ksmtuned\\\", \\\"state\\\": \\\"present\\\"}, \\\"when\\\": [\\\"ansible_facts[\'distribution_major_version\'] is version(\'9\', \'==\')\\\"]}, {\\\"name\\\": \\\"enable ksmtunded\\\", \\\"service\\\": {\\\"name\\\": \\\"{{ item }}\\\", \\\"state\\\": \\\"started\\\", \\\"enabled\\\": true}, \\\"with_items\\\": [\\\"ksm.service\\\", \\\"ksmtuned.service\\\"]}]}]}], \\\"external_post_deploy_tasks\\\": [{\\\"block\\\": [{\\\"name\\\": \\\"is additonal Cell?\\\", \\\"set_fact\\\": {\\\"nova_additional_cell\\\": false}}, {\\\"name\\\": \\\"check if discover hosts is required\\\", \\\"when\\\": [\\\"not nova_additional_cell|bool\\\", \\\"nova_cellv2_discovery_done is not defined\\\"], \\\"block\\\": [{\\\"name\\\": \\\"discover via nova_manager?\\\", \\\"set_fact\\\": {\\\"nova_cellv2_discovery_delegate_host\\\": \\\"{{ groups[\'nova_manager\'][0] }}\\\", \\\"nova_cellv2_discovery_container\\\": \\\"nova_manager\\\"}, \\\"when\\\": [\\\"groups[\'nova_manager\'] is defined and (groups[\'nova_manager\']|length>0)\\\"]}, {\\\"name\\\": \\\"discover via nova_api?\\\", \\\"set_fact\\\": {\\\"nova_cellv2_discovery_delegate_host\\\": \\\"{{ groups[\'nova_api\'][0] }}\\\", \\\"nova_cellv2_discovery_container\\\": \\\"nova_api\\\"}, \\\"when\\\": [\\\"nova_cellv2_discovery_delegate_host is not defined\\\", \\\"groups[\'nova_api\'] is defined and (groups[\'nova_api\']|length>0)\\\"]}, {\\\"name\\\": \\\"Warn if no discovery host available\\\", \\\"fail\\\": {\\\"msg\\\": \\\"No hosts available to run nova cell_v2 host discovery.\\\"}, \\\"ignore_errors\\\": true, \\\"when\\\": [\\\"nova_cellv2_discovery_delegate_host is not defined\\\"]}, {\\\"name\\\": \\\"Discovering nova hosts\\\", \\\"command\\\": \\\"{{ container_cli }} exec {{ nova_cellv2_discovery_container }} nova-manage cell_v2 discover_hosts --by-service\\\", \\\"become\\\": true, \\\"changed_when\\\": false, \\\"delegate_to\\\": \\\"{{ nova_cellv2_discovery_delegate_host }}\\\", \\\"when\\\": [\\\"nova_cellv2_discovery_delegate_host is defined\\\"]}, {\\\"set_fact\\\": {\\\"nova_cellv2_discovery_done\\\": true}}]}]}], \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"Remove openstack-nova-compute and python-nova package during upgrade\\\", \\\"package\\\": {\\\"name\\\": [\\\"openstack-nova-compute\\\", \\\"python-nova\\\"], \\\"state\\\": \\\"removed\\\"}, \\\"failed_when\\\": false, \\\"when\\\": \\\"step|int == 2\\\"}, {\\\"name\\\": \\\"nova_compute pre system_upgrade tasks\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade\\\", \\\"system_upgrade_run\\\", \\\"system_upgrade_nfsmounts\\\"], \\\"when\\\": [\\\"step|int == 3\\\", \\\"upgrade_leapp_enabled\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Unmount Nova NFS Share\\\", \\\"vars\\\": {\\\"nfs_backend_enable\\\": false}, \\\"mount\\\": {\\\"name\\\": \\\"/var/lib/nova/instances\\\", \\\"state\\\": \\\"absent\\\", \\\"fstype\\\": \\\"nfs4\\\"}, \\\"when\\\": \\\"nfs_backend_enable|bool\\\"}]}, {\\\"name\\\": \\\"nova_compute post system_upgrade tasks\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade\\\", \\\"system_upgrade_run\\\", \\\"system_upgrade_nfsmounts\\\"], \\\"when\\\": [\\\"step|int == 5\\\", \\\"upgrade_leapp_enabled\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Mount Nova NFS Share\\\", \\\"vars\\\": {\\\"nfs_backend_enable\\\": false, \\\"nfs_share\\\": \\\"\\\", \\\"nfs_options\\\": \\\"context=system_u:object_r:nfs_t:s0\\\", \\\"nfs_vers\\\": \\\"4.2\\\"}, \\\"mount\\\": {\\\"name\\\": \\\"/var/lib/nova/instances\\\", \\\"state\\\": \\\"mounted\\\", \\\"fstype\\\": \\\"nfs4\\\", \\\"src\\\": \\\"{{nfs_share}}\\\", \\\"opts\\\": \\\"_netdev,bg,{{nfs_options}},nfsvers={{nfs_vers}}\\\"}, \\\"when\\\": \\\"nfs_backend_enable|bool\\\"}]}], \\\"update_tasks\\\": [{\\\"name\\\": \\\"Remove openstack-nova-compute and python-nova package during upgrade\\\", \\\"package\\\": {\\\"name\\\": [\\\"openstack-nova-compute\\\", \\\"python-nova\\\"], \\\"state\\\": \\\"removed\\\"}, \\\"failed_when\\\": false, \\\"when\\\": \\\"step|int == 2\\\"}], \\\"post_update_tasks\\\": [{\\\"name\\\": \\\"Ensure instanceha directory is purged\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"become\\\": true, \\\"file\\\": {\\\"path\\\": \\\"/var/lib/nova/instanceha\\\", \\\"state\\\": \\\"absent\\\"}}], \\\"post_upgrade_tasks\\\": [{\\\"name\\\": \\\"Ensure instanceha directory is purged\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"become\\\": true, \\\"file\\\": {\\\"path\\\": \\\"/var/lib/nova/instanceha\\\", \\\"state\\\": \\\"absent\\\"}}], \\\"scale_tasks\\\": [{\\\"when\\\": [\\\"step|int == 1\\\", \\\"container_cli == \'podman\'\\\"], \\\"tags\\\": \\\"down\\\", \\\"become\\\": true, \\\"environment\\\": {\\\"OS_CLOUD\\\": \\\"overcloud\\\"}, \\\"block\\\": [{\\\"name\\\": \\\"Get nova-compute service ID\\\", \\\"command\\\": \\\"openstack compute service list --service nova-compute --column ID --column Host --format yaml\\\", \\\"register\\\": \\\"nova_compute_service_result\\\", \\\"delegate_to\\\": \\\"{{ groups[\'Undercloud\'] | first }}\\\", \\\"check_mode\\\": false, \\\"changed_when\\\": false}, {\\\"name\\\": \\\"is additional Cell?\\\", \\\"set_fact\\\": {\\\"is_additional_cell\\\": false}}, {\\\"name\\\": \\\"Set fact for nova_compute services\\\", \\\"set_fact\\\": {\\\"nova_compute_service\\\": \\\"{{ nova_compute_service_result.stdout | from_yaml | selectattr(\'Host\', \'match\', ansible_facts[\'fqdn\'] ~ \'.*\') | list }}\\\"}, \\\"delegate_to\\\": \\\"{{ groups[\'Undercloud\'] | first }}\\\", \\\"check_mode\\\": false}, {\\\"name\\\": \\\"Check search output\\\", \\\"fail\\\": {\\\"msg\\\": \\\"Found multiple `{{ ansible_facts[\'fqdn\'] }}`, which is unexpected. This means that the FQDN of the selected device to disable is either wrong or is sharing a name with another host, which is also wrong. Please correct this issue before continuing. Nova service list return data can be found here -> {{ nova_compute_service }}.\\\"}, \\\"when\\\": [\\\"(nova_compute_service | length) > 1\\\"]}, {\\\"name\\\": \\\"Disable nova services\\\", \\\"when\\\": [\\\"(nova_compute_service | length) == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Disable nova-compute service\\\", \\\"command\\\": \\\"openstack compute service set {{ nova_compute_service[0].Host }} nova-compute --disable\\\", \\\"delegate_to\\\": \\\"{{ groups[\'Undercloud\'] | first }}\\\", \\\"check_mode\\\": false, \\\"when\\\": [\\\"not is_additional_cell|bool\\\"]}, {\\\"name\\\": \\\"Stop nova-compute container\\\", \\\"service\\\": {\\\"name\\\": \\\"tripleo_nova_compute\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": false}, \\\"become\\\": true, \\\"register\\\": \\\"stop_nova_compute\\\", \\\"failed_when\\\": \\\"(\'msg\' in stop_nova_compute and \'Could not find the requested service tripleo_nova_compute\' not in stop_nova_compute.msg) or (\'rc\' in stop_nova_compute and stop_nova_compute.rc != 0)\\\"}, {\\\"name\\\": \\\"Delete nova-compute service\\\", \\\"command\\\": \\\"openstack compute service delete {{ nova_compute_service[0].ID }}\\\", \\\"delegate_to\\\": \\\"{{ groups[\'Undercloud\'] | first }}\\\", \\\"check_mode\\\": false}]}]}]}, {\\\"service_name\\\": \\\"nova_libvirt\\\", \\\"firewall_rules\\\": {\\\"200 nova_libvirt\\\": {\\\"dport\\\": [16514, \\\"61152-61215\\\", \\\"5900-6923\\\"]}}, \\\"ansible_group_vars\\\": {\\\"tripleo_nova_libvirt_virsh_container\\\": \\\"nova_virtproxyd\\\"}, \\\"monitoring_subscription\\\": \\\"overcloud-nova-libvirt\\\", \\\"config_settings\\\": {\\\"nova::my_ip\\\": \\\"%{hiera(\'internal_api\')}\\\", \\\"nova::rabbit_use_ssl\\\": \\\"True\\\", \\\"nova::keystone::service_user::send_service_user_token\\\": true, \\\"nova::keystone::service_user::project_name\\\": \\\"service\\\", \\\"nova::keystone::service_user::password\\\": \\\"E43sBALvNAsJYgcBpWfsAoz9C\\\", \\\"nova::keystone::service_user::auth_url\\\": \\\"https://overcloud.internalapi.ooo.test:5000\\\", \\\"nova::keystone::service_user::region_name\\\": \\\"regionOne\\\", \\\"nova::placement::project_name\\\": \\\"service\\\", \\\"nova::placement::password\\\": \\\"qMFVkTRvhZKx21tsfFHzUpJTe\\\", \\\"nova::placement::auth_url\\\": \\\"https://overcloud.internalapi.ooo.test:5000\\\", \\\"nova::placement::region_name\\\": \\\"regionOne\\\", \\\"nova::placement::valid_interfaces\\\": \\\"internal\\\", \\\"nova::os_region_name\\\": \\\"regionOne\\\", \\\"nova::logging::debug\\\": true, \\\"nova::purge_config\\\": false, \\\"nova::network::neutron::project_name\\\": \\\"service\\\", \\\"nova::network::neutron::username\\\": \\\"neutron\\\", \\\"nova::network::neutron::region_name\\\": \\\"regionOne\\\", \\\"nova::dhcp_domain\\\": \\\"\\\", \\\"nova::network::neutron::password\\\": \\\"qzvItA1K3MLllVvkiCWVVbIpy\\\", \\\"nova::network::neutron::auth_url\\\": \\\"https://overcloud.internalapi.ooo.test:5000/v3\\\", \\\"nova::network::neutron::valid_interfaces\\\": \\\"internal\\\", \\\"nova::glance::valid_interfaces\\\": \\\"internal\\\", \\\"nova::rabbit_heartbeat_timeout_threshold\\\": 60, \\\"nova::cinder_catalog_info\\\": \\\"volumev3:cinderv3:internalURL\\\", \\\"nova::host\\\": \\\"%{hiera(\'fqdn_canonical\')}\\\", \\\"nova::notify_on_state_change\\\": \\\"vm_and_task_state\\\", \\\"nova::notification_driver\\\": [\\\"noop\\\"], \\\"nova::notification_format\\\": \\\"unversioned\\\", \\\"nova::network::neutron::auth_type\\\": \\\"v3password\\\", \\\"nova::db::database_db_max_retries\\\": -1, \\\"nova::db::database_max_retries\\\": -1, \\\"nova::network::neutron::ovs_bridge\\\": \\\"br-int\\\", \\\"nova::compute::sync_power_state_interval\\\": 600, \\\"nova_is_additional_cell\\\": false, \\\"nova::cross_az_attach\\\": true, \\\"nova::cache::enabled\\\": true, \\\"nova::cache::tls_enabled\\\": true, \\\"nova::cache::backend\\\": \\\"dogpile.cache.pymemcache\\\", \\\"nova::rabbit_heartbeat_in_pthread\\\": false, \\\"nova::ovsdb_connection\\\": \\\"\\\", \\\"vhostuser_socket_group\\\": \\\"qemu\\\", \\\"nova_libvirt_opt_volumes\\\": [], \\\"ContainerNovaLibvirtImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\", \\\"ContainerNovaLibvirtConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\", \\\"nova::compute::libvirt::log_outputs\\\": \\\"1:file:/var/log/libvirt/libvirtd.log\\\", \\\"nova::compute::libvirt::virtlogd::log_outputs\\\": \\\"1:file:/var/log/libvirt/virtlogd.log\\\", \\\"nova::compute::libvirt::virtsecretd::log_outputs\\\": \\\"1:file:/var/log/libvirt/virtsecretd.log\\\", \\\"nova::compute::libvirt::virtnodedevd::log_outputs\\\": \\\"1:file:/var/log/libvirt/virtnodedevd.log\\\", \\\"nova::compute::libvirt::virtqemud::log_outputs\\\": \\\"1:file:/var/log/libvirt/virtqemud.log\\\", \\\"nova::compute::libvirt::virtproxyd::log_outputs\\\": \\\"1:file:/var/log/libvirt/virtproxyd.log\\\", \\\"nova::compute::libvirt::virtstoraged::log_outputs\\\": \\\"1:file:/var/log/libvirt/virtstoraged.log\\\", \\\"nova::compute::libvirt::qemu::memory_backing_dir\\\": \\\"\\\", \\\"nova::compute::libvirt::manage_libvirt_services\\\": false, \\\"tripleo::profile::base::nova::virtlogd_wrapper::enable_wrapper\\\": true, \\\"tripleo::profile::base::nova::virtlogd_wrapper::virtlogd_process_wrapper\\\": \\\"/var/lib/container-config-scripts/virtlogd_wrapper\\\", \\\"tripleo::profile::base::nova::virtlogd_wrapper::virtlogd_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\", \\\"tripleo::profile::base::nova::virtlogd_wrapper::debug\\\": true, \\\"nova::compute::libvirt::migration_support\\\": false, \\\"nova::compute::rbd::libvirt_images_rbd_ceph_conf\\\": \\\"/etc/ceph/ceph.conf\\\", \\\"nova::compute::rbd::libvirt_rbd_user\\\": \\\"openstack\\\", \\\"tripleo::profile::base::nova::compute_libvirt_shared::nova_rbd_ceph_conf_path\\\": \\\"/var/lib/tripleo-config/ceph\\\", \\\"nova::compute::rbd::rbd_keyring\\\": \\\"client.openstack\\\", \\\"nova::compute::rbd::libvirt_rbd_secret_key\\\": \\\"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\\\", \\\"nova::compute::rbd::libvirt_rbd_secret_uuid\\\": \\\"141c0b27-2417-411f-ad72-876254cd4eac\\\", \\\"tripleo::profile::base::nova::migration::client::libvirt_enabled\\\": true, \\\"tripleo::profile::base::nova::migration::client::ssh_private_key\\\": \\\"-----BEGIN RSA PRIVATE KEY-----\\\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\\\n-----END RSA PRIVATE KEY-----\\\\n\\\", \\\"tripleo::profile::base::nova::migration::client::ssh_port\\\": 2022, \\\"nova::compute::libvirt::services::libvirt_virt_type\\\": \\\"qemu\\\", \\\"nova::compute::libvirt::virt_type\\\": \\\"qemu\\\", \\\"nova::compute::libvirt::enabled_perf_events\\\": [], \\\"nova::compute::libvirt::qemu::configure_qemu\\\": true, \\\"nova::compute::libvirt::qemu::max_files\\\": 32768, \\\"nova::compute::libvirt::qemu::max_processes\\\": 131072, \\\"nova::migration::qemu::configure_qemu\\\": true, \\\"nova::migration::qemu::migration_port_min\\\": 61152, \\\"nova::migration::qemu::migration_port_max\\\": 61215, \\\"nova::compute::libvirt::vncserver_listen\\\": \\\"%{hiera(\'internal_api\')}\\\", \\\"nova::compute::libvirt::log_filters\\\": \\\"1:libvirt 1:qemu 1:conf 1:security 3:event 3:json 3:file 3:object 1:util\\\", \\\"nova::compute::libvirt::virtlogd::log_filters\\\": \\\"1:logging 4:object 4:json 4:event 1:util\\\", \\\"rbd_persistent_storage\\\": false, \\\"rbd_disk_cachemodes\\\": [\\\"network=writeback\\\"], \\\"nova::compute::libvirt::virtsecretd::log_filters\\\": \\\"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\\\", \\\"nova::compute::libvirt::virtnodedevd::log_filters\\\": \\\"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\\\", \\\"nova::compute::libvirt::virtstoraged::log_filters\\\": \\\"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\\\", \\\"nova::compute::libvirt::virtqemud::log_filters\\\": \\\"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\\\", \\\"nova::compute::libvirt::virtproxyd::log_filters\\\": \\\"1:qemu 1:libvirt 4:object 4:json 4:event 1:util\\\", \\\"tripleo::profile::base::nova::libvirt::modular_libvirt\\\": true, \\\"nova::compute::libvirt::services::modular_libvirt\\\": true, \\\"nova::compute::libvirt::modular_libvirt\\\": true, \\\"nova::migration::libvirt::modular_libvirt\\\": true, \\\"tripleo::profile::base::nova::migration::client::libvirt_tls\\\": true, \\\"tripleo::profile::base::nova::libvirt::tls_password\\\": \\\"bkbQ5iHPPbgRmMbCp8YibZ8gy\\\", \\\"nova::compute::libvirt::qemu::default_tls_verify\\\": true, \\\"nova::compute::libvirt::tls_priority\\\": \\\"NORMAL:-VERS-SSL3.0:-VERS-TLS-ALL:+VERS-TLS1.2\\\", \\\"nova::migration::libvirt::listen_address\\\": \\\"%{hiera(\'internal_api\')}\\\", \\\"nova::migration::libvirt::live_migration_inbound_addr\\\": \\\"%{hiera(\'fqdn_internal_api\')}\\\", \\\"nova::compute::libvirt::qemu::vnc_tls\\\": true, \\\"nova::compute::libvirt::qemu::vnc_tls_verify\\\": true, \\\"nova::compute::libvirt::qemu::nbd_tls\\\": true, \\\"nova::migration::libvirt::live_migration_with_native_tls\\\": true}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"nova_libvirt\\\", \\\"puppet_tags\\\": \\\"libvirtd_config,virtlogd_config,virtproxyd_config,virtqemud_config,virtnodedevd_config,virtsecretd_config,virtstoraged_config,nova_config,file,libvirt_tls_password\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::nova::libvirt\\\\n\\\", \\\"config_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\"}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/nova_virtlogd.json\\\": {\\\"command\\\": \\\"/usr/local/bin/virtlogd_wrapper\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-ceph/\\\", \\\"dest\\\": \\\"/etc/ceph/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/etc/ceph/ceph.client.openstack.keyring\\\", \\\"owner\\\": \\\"nova:nova\\\", \\\"perm\\\": \\\"0600\\\"}]}, \\\"/var/lib/kolla/config_files/nova_virtsecretd.json\\\": {\\\"command\\\": \\\"/usr/sbin/virtsecretd --config /etc/libvirt/virtsecretd.conf\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-ceph/\\\", \\\"dest\\\": \\\"/etc/ceph/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/etc/ceph/ceph.client.openstack.keyring\\\", \\\"owner\\\": \\\"nova:nova\\\", \\\"perm\\\": \\\"0600\\\"}]}, \\\"/var/lib/kolla/config_files/nova_virtnodedevd.json\\\": {\\\"command\\\": \\\"/usr/sbin/virtnodedevd --config /etc/libvirt/virtnodedevd.conf\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-ceph/\\\", \\\"dest\\\": \\\"/etc/ceph/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/etc/ceph/ceph.client.openstack.keyring\\\", \\\"owner\\\": \\\"nova:nova\\\", \\\"perm\\\": \\\"0600\\\"}]}, \\\"/var/lib/kolla/config_files/nova_virtstoraged.json\\\": {\\\"command\\\": \\\"/usr/sbin/virtstoraged --config /etc/libvirt/virtstoraged.conf\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-ceph/\\\", \\\"dest\\\": \\\"/etc/ceph/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/etc/ceph/ceph.client.openstack.keyring\\\", \\\"owner\\\": \\\"nova:nova\\\", \\\"perm\\\": \\\"0600\\\"}]}, \\\"/var/lib/kolla/config_files/nova_virtqemud.json\\\": {\\\"command\\\": \\\"/usr/sbin/virtqemud --config /etc/libvirt/virtqemud.conf\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-ceph/\\\", \\\"dest\\\": \\\"/etc/ceph/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/etc/ceph/ceph.client.openstack.keyring\\\", \\\"owner\\\": \\\"nova:nova\\\", \\\"perm\\\": \\\"0600\\\"}]}, \\\"/var/lib/kolla/config_files/nova_virtproxyd.json\\\": {\\\"command\\\": \\\"/usr/sbin/virtproxyd --config /etc/libvirt/virtproxyd.conf\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/var/lib/kolla/config_files/src-ceph/\\\", \\\"dest\\\": \\\"/etc/ceph/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/etc/ceph/ceph.client.openstack.keyring\\\", \\\"owner\\\": \\\"nova:nova\\\", \\\"perm\\\": \\\"0600\\\"}]}}, \\\"container_config_scripts\\\": {\\\"nova_libvirt_init_secret.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\nset -e\\\\n\\\\nCEPH_INFO=($*)\\\\n\\\\nif [ -z \\\\\\\"$CEPH_INFO\\\\\\\" ]; then\\\\n    echo \\\\\\\"error: At least one CLUSTER:CLIENT tuple must be specified\\\\\\\"\\\\n    exit 1\\\\nfi\\\\n\\\\necho \\\\\\\"------------------------------------------------\\\\\\\"\\\\necho \\\\\\\"Initializing virsh secrets for: ${CEPH_INFO[@]}\\\\\\\"\\\\n\\\\nfor INFO in ${CEPH_INFO[@]}; do\\\\n    IFS=: read CLUSTER CLIENT <<< $INFO\\\\n    if [ ! -f /etc/ceph/${CLUSTER}.conf ]; then\\\\n        echo \\\\\\\"Error: /etc/ceph/${CLUSTER}.conf was not found\\\\\\\"\\\\n        echo \\\\\\\"Path to nova_libvirt_init_secret was ${CEPH_INFO}\\\\\\\"\\\\n        exit 1\\\\n    fi\\\\n    FSID=$(awk \'$1 == \\\\\\\"fsid\\\\\\\" {print $3}\' /etc/ceph/${CLUSTER}.conf)\\\\n    if [ -z \\\\\\\"${FSID}\\\\\\\" ]; then\\\\n        echo \\\\\\\"Error: /etc/ceph/${CLUSTER}.conf contained an empty fsid definition\\\\\\\"\\\\n        echo \\\\\\\"Check your ceph configuration\\\\\\\"\\\\n        exit 1\\\\n    fi\\\\n\\\\n    echo \\\\\\\"--------\\\\\\\"\\\\n    echo \\\\\\\"Initializing the virsh secret for \'$CLUSTER\' cluster ($FSID) \'$CLIENT\' client\\\\\\\"\\\\n\\\\n    # Ensure the secret XML file exists. Puppet should have created a secret.xml\\\\n    # file for the first cluster\'s secret, so detect when to use that file.\\\\n    if grep -q $FSID /etc/nova/secret.xml; then\\\\n        SECRET_FILE=\\\\\\\"/etc/nova/secret.xml\\\\\\\"\\\\n        SECRET_NAME=\\\\\\\"client.${CLIENT} secret\\\\\\\"\\\\n    else\\\\n        SECRET_FILE=\\\\\\\"/etc/nova/${CLUSTER}-secret.xml\\\\\\\"\\\\n        SECRET_NAME=\\\\\\\"${CLUSTER}.client.${CLIENT} secret\\\\\\\"\\\\n    fi\\\\n\\\\n    if [ ! -f $SECRET_FILE ]; then\\\\n        echo \\\\\\\"Creating $SECRET_FILE\\\\\\\"\\\\n        cat <<EOF > $SECRET_FILE\\\\n<secret ephemeral=\'no\' private=\'no\'>\\\\n  <usage type=\'ceph\'>\\\\n    <name>${SECRET_NAME}</name>\\\\n  </usage>\\\\n  <uuid>${FSID}</uuid>\\\\n</secret>\\\\nEOF\\\\n    else\\\\n        echo \\\\\\\"The $SECRET_FILE file already exists\\\\\\\"\\\\n    fi\\\\n\\\\n    # Ensure the libvirt secret is defined\\\\n    if /usr/bin/virsh secret-list | grep -q $FSID; then\\\\n        echo \\\\\\\"The virsh secret for $FSID has already been defined\\\\\\\"\\\\n    else\\\\n        /usr/bin/virsh secret-define --file $SECRET_FILE\\\\n    fi\\\\n\\\\n    # Fetch the key from the keyring and ensure the secret is set\\\\n    KEY=$(awk \'$1 == \\\\\\\"key\\\\\\\" {print $3}\' /etc/ceph/${CLUSTER}.client.${CLIENT}.keyring)\\\\n    if /usr/bin/virsh secret-get-value $FSID 2>/dev/null | grep -q $KEY; then\\\\n        echo \\\\\\\"The virsh secret for $FSID has already been set\\\\\\\"\\\\n    else\\\\n        /usr/bin/virsh secret-set-value --secret $FSID --base64 $KEY\\\\n    fi\\\\ndone\\\\n\\\"}}, \\\"docker_config\\\": {\\\"step_2\\\": {\\\"nova_virtqemud_init_logs\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\", \\\"net\\\": \\\"none\\\", \\\"privileged\\\": true, \\\"security_opt\\\": [\\\"label=level:s0\\\", \\\"label=type:spc_t\\\", \\\"label=filetype:container_file_t\\\"], \\\"user\\\": \\\"root\\\", \\\"volumes\\\": [\\\"/var/log/containers/libvirt/swtpm:/var/log/swtpm:shared,z\\\"], \\\"command\\\": [\\\"/bin/bash\\\", \\\"-c\\\", \\\"chown -R tss:tss /var/log/swtpm\\\"], \\\"environment\\\": {\\\"TRIPLEO_DEPLOY_IDENTIFIER\\\": \\\"1780992067\\\"}}, \\\"create_virtlogd_wrapper\\\": {\\\"start_order\\\": 1, \\\"detach\\\": false, \\\"cgroupns\\\": \\\"host\\\", \\\"net\\\": \\\"host\\\", \\\"pid\\\": \\\"host\\\", \\\"user\\\": \\\"root\\\", \\\"command\\\": [\\\"/container_puppet_apply.sh\\\", \\\"4\\\", \\\"file\\\", \\\"include ::tripleo::profile::base::nova::virtlogd_wrapper\\\"], \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\", \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\\\", \\\"/etc/puppet:/tmp/puppet-etc:ro\\\", \\\"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\\\", \\\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:shared,z\\\"], \\\"environment\\\": {\\\"TRIPLEO_DEPLOY_IDENTIFIER\\\": \\\"1780992067\\\"}}}, \\\"step_3\\\": {\\\"nova_virtlogd_wrapper\\\": {\\\"start_order\\\": 0, \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\", \\\"ulimit\\\": [\\\"nofile=131072\\\", \\\"nproc=126960\\\"], \\\"cgroupns\\\": \\\"host\\\", \\\"net\\\": \\\"host\\\", \\\"pid\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"security_opt\\\": [\\\"label=level:s0\\\", \\\"label=type:spc_t\\\", \\\"label=filetype:container_file_t\\\"], \\\"restart\\\": \\\"always\\\", \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/log/containers/libvirt:/var/log/libvirt:shared,z\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/dev:/dev\\\", \\\"/run:/run\\\", \\\"/sys/fs/cgroup:/sys/fs/cgroup\\\", \\\"/sys/fs/selinux:/sys/fs/selinux\\\", \\\"/etc/selinux/config:/etc/selinux/config:ro\\\", \\\"/etc/libvirt:/etc/libvirt:shared\\\", \\\"/etc/ssh/ssh_known_hosts:/etc/ssh/ssh_known_hosts:ro\\\", \\\"/run/libvirt:/run/libvirt:shared,z\\\", \\\"/var/lib/nova:/var/lib/nova:shared\\\", \\\"/var/lib/libvirt:/var/lib/libvirt:shared\\\", \\\"/var/cache/libvirt:/var/cache/libvirt:shared\\\", \\\"/var/lib/vhost_sockets:/var/lib/vhost_sockets\\\", \\\"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/lib/tripleo-config/ceph:/var/lib/kolla/config_files/src-ceph:z\\\", \\\"/etc/pki/CA/cacert.pem:/etc/pki/CA/cacert.pem:ro\\\", \\\"/etc/pki/libvirt:/etc/pki/libvirt:ro\\\", \\\"/etc/pki/qemu:/etc/pki/qemu:ro\\\", \\\"/var/lib/kolla/config_files/nova_virtlogd.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/container-config-scripts/virtlogd_wrapper:/usr/local/bin/virtlogd_wrapper:ro\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}, \\\"nova_virtsecretd\\\": {\\\"start_order\\\": 1, \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\", \\\"ulimit\\\": [\\\"nofile=131072\\\", \\\"nproc=126960\\\"], \\\"cgroupns\\\": \\\"host\\\", \\\"net\\\": \\\"host\\\", \\\"pid\\\": \\\"host\\\", \\\"pids_limit\\\": 65536, \\\"privileged\\\": true, \\\"security_opt\\\": [\\\"label=level:s0\\\", \\\"label=type:spc_t\\\", \\\"label=filetype:container_file_t\\\"], \\\"restart\\\": \\\"always\\\", \\\"depends_on\\\": [\\\"tripleo_nova_virtlogd_wrapper.service\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/log/containers/libvirt:/var/log/libvirt:shared,z\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/dev:/dev\\\", \\\"/run:/run\\\", \\\"/sys/fs/cgroup:/sys/fs/cgroup\\\", \\\"/sys/fs/selinux:/sys/fs/selinux\\\", \\\"/etc/selinux/config:/etc/selinux/config:ro\\\", \\\"/etc/libvirt:/etc/libvirt:shared\\\", \\\"/etc/ssh/ssh_known_hosts:/etc/ssh/ssh_known_hosts:ro\\\", \\\"/run/libvirt:/run/libvirt:shared,z\\\", \\\"/var/lib/nova:/var/lib/nova:shared\\\", \\\"/var/lib/libvirt:/var/lib/libvirt:shared\\\", \\\"/var/cache/libvirt:/var/cache/libvirt:shared\\\", \\\"/var/lib/vhost_sockets:/var/lib/vhost_sockets\\\", \\\"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/lib/tripleo-config/ceph:/var/lib/kolla/config_files/src-ceph:z\\\", \\\"/etc/pki/CA/cacert.pem:/etc/pki/CA/cacert.pem:ro\\\", \\\"/etc/pki/libvirt:/etc/pki/libvirt:ro\\\", \\\"/etc/pki/qemu:/etc/pki/qemu:ro\\\", \\\"/var/lib/kolla/config_files/nova_virtsecretd.json:/var/lib/kolla/config_files/config.json:ro\\\"]}, \\\"nova_virtnodedevd\\\": {\\\"start_order\\\": 2, \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\", \\\"ulimit\\\": [\\\"nofile=131072\\\", \\\"nproc=126960\\\"], \\\"cgroupns\\\": \\\"host\\\", \\\"net\\\": \\\"host\\\", \\\"pid\\\": \\\"host\\\", \\\"pids_limit\\\": 65536, \\\"privileged\\\": true, \\\"security_opt\\\": [\\\"label=level:s0\\\", \\\"label=type:spc_t\\\", \\\"label=filetype:container_file_t\\\"], \\\"restart\\\": \\\"always\\\", \\\"depends_on\\\": [\\\"tripleo_nova_virtlogd_wrapper.service\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/log/containers/libvirt:/var/log/libvirt:shared,z\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/dev:/dev\\\", \\\"/run:/run\\\", \\\"/sys/fs/cgroup:/sys/fs/cgroup\\\", \\\"/sys/fs/selinux:/sys/fs/selinux\\\", \\\"/etc/selinux/config:/etc/selinux/config:ro\\\", \\\"/etc/libvirt:/etc/libvirt:shared\\\", \\\"/etc/ssh/ssh_known_hosts:/etc/ssh/ssh_known_hosts:ro\\\", \\\"/run/libvirt:/run/libvirt:shared,z\\\", \\\"/var/lib/nova:/var/lib/nova:shared\\\", \\\"/var/lib/libvirt:/var/lib/libvirt:shared\\\", \\\"/var/cache/libvirt:/var/cache/libvirt:shared\\\", \\\"/var/lib/vhost_sockets:/var/lib/vhost_sockets\\\", \\\"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/lib/tripleo-config/ceph:/var/lib/kolla/config_files/src-ceph:z\\\", \\\"/etc/pki/CA/cacert.pem:/etc/pki/CA/cacert.pem:ro\\\", \\\"/etc/pki/libvirt:/etc/pki/libvirt:ro\\\", \\\"/etc/pki/qemu:/etc/pki/qemu:ro\\\", \\\"/var/lib/kolla/config_files/nova_virtnodedevd.json:/var/lib/kolla/config_files/config.json:ro\\\"]}, \\\"nova_virtstoraged\\\": {\\\"start_order\\\": 3, \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\", \\\"ulimit\\\": [\\\"nofile=131072\\\", \\\"nproc=126960\\\"], \\\"cgroupns\\\": \\\"host\\\", \\\"net\\\": \\\"host\\\", \\\"pid\\\": \\\"host\\\", \\\"pids_limit\\\": 65536, \\\"privileged\\\": true, \\\"security_opt\\\": [\\\"label=level:s0\\\", \\\"label=type:spc_t\\\", \\\"label=filetype:container_file_t\\\"], \\\"restart\\\": \\\"always\\\", \\\"depends_on\\\": [\\\"tripleo_nova_virtlogd_wrapper.service\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/log/containers/libvirt:/var/log/libvirt:shared,z\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/dev:/dev\\\", \\\"/run:/run\\\", \\\"/sys/fs/cgroup:/sys/fs/cgroup\\\", \\\"/sys/fs/selinux:/sys/fs/selinux\\\", \\\"/etc/selinux/config:/etc/selinux/config:ro\\\", \\\"/etc/libvirt:/etc/libvirt:shared\\\", \\\"/etc/ssh/ssh_known_hosts:/etc/ssh/ssh_known_hosts:ro\\\", \\\"/run/libvirt:/run/libvirt:shared,z\\\", \\\"/var/lib/nova:/var/lib/nova:shared\\\", \\\"/var/lib/libvirt:/var/lib/libvirt:shared\\\", \\\"/var/cache/libvirt:/var/cache/libvirt:shared\\\", \\\"/var/lib/vhost_sockets:/var/lib/vhost_sockets\\\", \\\"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/lib/tripleo-config/ceph:/var/lib/kolla/config_files/src-ceph:z\\\", \\\"/etc/pki/CA/cacert.pem:/etc/pki/CA/cacert.pem:ro\\\", \\\"/etc/pki/libvirt:/etc/pki/libvirt:ro\\\", \\\"/etc/pki/qemu:/etc/pki/qemu:ro\\\", \\\"/var/lib/kolla/config_files/nova_virtstoraged.json:/var/lib/kolla/config_files/config.json:ro\\\"]}, \\\"nova_virtqemud\\\": {\\\"start_order\\\": 4, \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\", \\\"ulimit\\\": [\\\"nofile=131072\\\", \\\"nproc=126960\\\"], \\\"cgroupns\\\": \\\"host\\\", \\\"net\\\": \\\"host\\\", \\\"pid\\\": \\\"host\\\", \\\"pids_limit\\\": 65536, \\\"privileged\\\": true, \\\"security_opt\\\": [\\\"label=level:s0\\\", \\\"label=type:spc_t\\\", \\\"label=filetype:container_file_t\\\"], \\\"restart\\\": \\\"always\\\", \\\"depends_on\\\": [\\\"tripleo_nova_virtlogd_wrapper.service\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/log/containers/libvirt:/var/log/libvirt:shared,z\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/dev:/dev\\\", \\\"/run:/run\\\", \\\"/sys/fs/cgroup:/sys/fs/cgroup\\\", \\\"/sys/fs/selinux:/sys/fs/selinux\\\", \\\"/etc/selinux/config:/etc/selinux/config:ro\\\", \\\"/etc/libvirt:/etc/libvirt:shared\\\", \\\"/etc/ssh/ssh_known_hosts:/etc/ssh/ssh_known_hosts:ro\\\", \\\"/run/libvirt:/run/libvirt:shared,z\\\", \\\"/var/lib/nova:/var/lib/nova:shared\\\", \\\"/var/lib/libvirt:/var/lib/libvirt:shared\\\", \\\"/var/cache/libvirt:/var/cache/libvirt:shared\\\", \\\"/var/lib/vhost_sockets:/var/lib/vhost_sockets\\\", \\\"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/lib/tripleo-config/ceph:/var/lib/kolla/config_files/src-ceph:z\\\", \\\"/etc/pki/CA/cacert.pem:/etc/pki/CA/cacert.pem:ro\\\", \\\"/etc/pki/libvirt:/etc/pki/libvirt:ro\\\", \\\"/etc/pki/qemu:/etc/pki/qemu:ro\\\", \\\"/var/lib/kolla/config_files/nova_virtqemud.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/log/containers/libvirt/swtpm:/var/log/swtpm:z\\\"]}, \\\"nova_virtproxyd\\\": {\\\"start_order\\\": 5, \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\", \\\"ulimit\\\": [\\\"nofile=131072\\\", \\\"nproc=126960\\\"], \\\"cgroupns\\\": \\\"host\\\", \\\"net\\\": \\\"host\\\", \\\"pid\\\": \\\"host\\\", \\\"pids_limit\\\": 65536, \\\"privileged\\\": true, \\\"security_opt\\\": [\\\"label=level:s0\\\", \\\"label=type:spc_t\\\", \\\"label=filetype:container_file_t\\\"], \\\"restart\\\": \\\"always\\\", \\\"depends_on\\\": [\\\"tripleo_nova_virtlogd_wrapper.service\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/log/containers/libvirt:/var/log/libvirt:shared,z\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/dev:/dev\\\", \\\"/run:/run\\\", \\\"/sys/fs/cgroup:/sys/fs/cgroup\\\", \\\"/sys/fs/selinux:/sys/fs/selinux\\\", \\\"/etc/selinux/config:/etc/selinux/config:ro\\\", \\\"/etc/libvirt:/etc/libvirt:shared\\\", \\\"/etc/ssh/ssh_known_hosts:/etc/ssh/ssh_known_hosts:ro\\\", \\\"/run/libvirt:/run/libvirt:shared,z\\\", \\\"/var/lib/nova:/var/lib/nova:shared\\\", \\\"/var/lib/libvirt:/var/lib/libvirt:shared\\\", \\\"/var/cache/libvirt:/var/cache/libvirt:shared\\\", \\\"/var/lib/vhost_sockets:/var/lib/vhost_sockets\\\", \\\"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/lib/tripleo-config/ceph:/var/lib/kolla/config_files/src-ceph:z\\\", \\\"/etc/pki/CA/cacert.pem:/etc/pki/CA/cacert.pem:ro\\\", \\\"/etc/pki/libvirt:/etc/pki/libvirt:ro\\\", \\\"/etc/pki/qemu:/etc/pki/qemu:ro\\\", \\\"/var/lib/kolla/config_files/nova_virtproxyd.json:/var/lib/kolla/config_files/config.json:ro\\\"]}}}, \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"Ensure recovery of containerized virtqemud\\\", \\\"when\\\": \\\"step|int == 4\\\", \\\"become\\\": true, \\\"block\\\": [{\\\"name\\\": \\\"Create virtqemud recovery script\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/usr/libexec/recover_tripleo_nova_virtqemud.sh\\\", \\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/bin/bash\\\\npgrep -f /sbin/virtqemud\\\\n[ $? -eq 0 ] && exit 0\\\\nkill -9 $(cat /run/nova_virtqemud.pid)\\\\n\\\"}}, {\\\"name\\\": \\\"Create virtqemud recovery trigger service\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/systemd/system/tripleo_nova_virtqemud_recover.service\\\", \\\"mode\\\": \\\"0644\\\", \\\"content\\\": \\\"[Unit]\\\\nDescription=Check and recover tripleo_nova_virtqemud\\\\nAfter=tripleo_nova_virtqemud.service\\\\nRequisite=tripleo_nova_virtqemud.service\\\\n[Service]\\\\nType=oneshot\\\\nExecStart=bash /usr/libexec/recover_tripleo_nova_virtqemud.sh\\\\nSyslogIdentifier=recover_tripleo_nova_virtqemud\\\\n[Install]\\\\nWantedBy=multi-user.target\\\\n\\\"}}, {\\\"name\\\": \\\"Create virtqemud recovery trigger timer\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/systemd/system/tripleo_nova_virtqemud_recover.timer\\\", \\\"mode\\\": \\\"0644\\\", \\\"content\\\": \\\"[Unit]\\\\nDescription=Check and recover tripleo_nova_virtqemud every 10m\\\\nPartOf=tripleo_nova_virtqemud.service\\\\n[Timer]\\\\nOnCalendar=*:5/10\\\\nOnActiveSec=120\\\\nOnUnitActiveSec=60\\\\nRandomizedDelaySec=1m\\\\n[Install]\\\\nWantedBy=timers.target\\\\n\\\"}}, {\\\"name\\\": \\\"Enable virtqemud recovery trigger service\\\", \\\"systemd\\\": {\\\"name\\\": \\\"tripleo_nova_virtqemud_recover.service\\\", \\\"enabled\\\": true, \\\"daemon_reload\\\": true}}, {\\\"name\\\": \\\"Enable virtqemud recovery trigger timer\\\", \\\"systemd\\\": {\\\"name\\\": \\\"tripleo_nova_virtqemud_recover.timer\\\", \\\"enabled\\\": true, \\\"state\\\": \\\"restarted\\\", \\\"daemon_reload\\\": true}, \\\"register\\\": \\\"virtqemud_recover_timer_result\\\"}, {\\\"name\\\": \\\"Really enable virtqemud recovery trigger timer\\\", \\\"shell\\\": {\\\"cmd\\\": \\\"systemctl enable --now tripleo_nova_virtqemud_recover.timer\\\"}, \\\"when\\\": \\\"virtqemud_recover_timer_result.status.UnitFileState != \\\\\\\"enabled\\\\\\\"\\\"}]}, {\\\"name\\\": \\\"Certificate generation\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"Create dirs for certificates and keys\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item }}\\\", \\\"state\\\": \\\"directory\\\", \\\"serole\\\": \\\"object_r\\\", \\\"setype\\\": \\\"cert_t\\\", \\\"seuser\\\": \\\"system_u\\\"}, \\\"with_items\\\": [\\\"/etc/pki/libvirt\\\", \\\"/etc/pki/libvirt/private\\\", \\\"/etc/pki/qemu\\\"]}, {\\\"include_role\\\": {\\\"name\\\": \\\"linux-system-roles.certificate\\\"}, \\\"vars\\\": {\\\"certificate_requests\\\": [{\\\"name\\\": \\\"libvirt-server-cert\\\", \\\"dns\\\": \\\"{{fqdn_internal_api}}\\\", \\\"principal\\\": \\\"libvirt/{{fqdn_internal_api}}@{{idm_realm}}\\\", \\\"run_after\\\": \\\"# Copy cert and key to libvirt dirs\\\\ncp /etc/ipa/ca.crt /etc/pki/CA/cacert.pem\\\\nchown root:root /etc/pki/CA/cacert.pem\\\\nchmod 644 /etc/pki/CA/cacert.pem\\\\ncp /etc/pki/tls/certs/libvirt-server-cert.crt /etc/pki/libvirt/servercert.pem\\\\ncp /etc/pki/tls/private/libvirt-server-cert.key /etc/pki/libvirt/private/serverkey.pem\\\\npodman exec nova_virtproxyd virt-admin server-update-tls virtproxyd || systemctl reload tripleo_nova_virtproxyd\\\\n\\\", \\\"key_size\\\": \\\"2048\\\", \\\"ca\\\": \\\"ipa\\\"}, {\\\"name\\\": \\\"libvirt-client-cert\\\", \\\"dns\\\": \\\"{{fqdn_internal_api}}\\\", \\\"principal\\\": \\\"libvirt/{{fqdn_internal_api}}@{{idm_realm}}\\\", \\\"run_after\\\": \\\"# Copy cert and key to libvirt dirs\\\\ncp /etc/pki/tls/certs/libvirt-client-cert.crt /etc/pki/libvirt/clientcert.pem\\\\ncp /etc/pki/tls/private/libvirt-client-cert.key /etc/pki/libvirt/private/clientkey.pem\\\\npodman exec nova_virtproxyd virt-admin server-update-tls virtproxyd || systemctl reload tripleo_nova_virtproxyd\\\\n\\\", \\\"key_size\\\": \\\"2048\\\", \\\"ca\\\": \\\"ipa\\\"}, {\\\"name\\\": \\\"qemu-server-cert\\\", \\\"owner\\\": \\\"root\\\", \\\"group\\\": \\\"qemu\\\", \\\"dns\\\": \\\"{{fqdn_internal_api}}\\\", \\\"principal\\\": \\\"qemu/{{fqdn_internal_api}}@{{idm_realm}}\\\", \\\"run_after\\\": \\\"# Copy cert and key to qemu dir\\\\ncp /etc/ipa/ca.crt /etc/pki/qemu/ca-cert.pem\\\\nchown root:root /etc/pki/qemu/ca-cert.pem\\\\nchmod 644 /etc/pki/qemu/ca-cert.pem\\\\ncp -a /etc/pki/tls/certs/qemu-server-cert.crt /etc/pki/qemu/server-cert.pem\\\\ncp -a /etc/pki/tls/private/qemu-server-cert.key /etc/pki/qemu/server-key.pem\\\\nchgrp qemu /etc/pki/qemu/server-*\\\\nchmod 0640 /etc/pki/qemu/server-cert.pem\\\\nchmod 0640 /etc/pki/qemu/server-key.pem\\\\n\\\", \\\"key_size\\\": \\\"2048\\\", \\\"ca\\\": \\\"ipa\\\"}, {\\\"name\\\": \\\"qemu-client-cert\\\", \\\"owner\\\": \\\"root\\\", \\\"group\\\": \\\"qemu\\\", \\\"dns\\\": \\\"{{fqdn_internal_api}}\\\", \\\"principal\\\": \\\"qemu/{{fqdn_internal_api}}@{{idm_realm}}\\\", \\\"run_after\\\": \\\"# Copy cert and key to qemu dir\\\\ncp -a /etc/pki/tls/certs/qemu-client-cert.crt /etc/pki/qemu/client-cert.pem\\\\ncp -a /etc/pki/tls/private/qemu-client-cert.key /etc/pki/qemu/client-key.pem\\\\nchgrp qemu /etc/pki/qemu/client-*\\\\nchmod 0640 /etc/pki/qemu/client-cert.pem\\\\nchmod 0640 /etc/pki/qemu/client-key.pem\\\\n\\\", \\\"key_size\\\": \\\"2048\\\", \\\"ca\\\": \\\"ipa\\\"}]}}]}, {\\\"name\\\": \\\"Set up systemd target for libvirt services\\\", \\\"when\\\": \\\"step|int == 4\\\", \\\"block\\\": [{\\\"name\\\": \\\"Create systemd file\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/systemd/system/tripleo_nova_libvirt.target\\\", \\\"mode\\\": \\\"0644\\\", \\\"owner\\\": \\\"root\\\", \\\"group\\\": \\\"root\\\", \\\"content\\\": \\\"[Unit]\\\\nWants=tripleo_nova_virtsecretd.service\\\\nWants=tripleo_nova_virtnodedevd.service\\\\nWants=tripleo_nova_virtstoraged.service\\\\nWants=tripleo_nova_virtproxyd.service\\\\nWants=tripleo_nova_virtqemud.service\\\\nAfter=tripleo_nova_virtsecretd.service\\\\nAfter=tripleo_nova_virtnodedevd.service\\\\nAfter=tripleo_nova_virtstoraged.service\\\\nAfter=tripleo_nova_virtproxyd.service\\\\nAfter=tripleo_nova_virtqemud.service\\\\n\\\"}, \\\"become\\\": true, \\\"register\\\": \\\"libvirt_target_result\\\"}, {\\\"name\\\": \\\"Reload systemd\\\", \\\"systemd\\\": {\\\"name\\\": \\\"tripleo_nova_libvirt.target\\\", \\\"enabled\\\": true, \\\"state\\\": \\\"restarted\\\", \\\"daemon_reload\\\": true}, \\\"become\\\": true, \\\"when\\\": \\\"libvirt_target_result.changed\\\"}]}], \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"state\\\": \\\"directory\\\", \\\"mode\\\": \\\"{{ item.mode }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/libvirt\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}]}, {\\\"name\\\": \\\"create libvirt persistent data directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype | default(omit) }}\\\", \\\"mode\\\": \\\"{{ item.mode | default(omit) }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/etc/libvirt\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/etc/libvirt/secrets\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/etc/libvirt/qemu\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/var/lib/libvirt\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/var/cache/libvirt\\\"}, {\\\"path\\\": \\\"/var/lib/nova\\\", \\\"setype\\\": \\\"container_file_t\\\"}, {\\\"path\\\": \\\"/run/libvirt\\\"}, {\\\"path\\\": \\\"/var/log/containers/libvirt/swtpm\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0770\\\"}]}, {\\\"name\\\": \\\"ensure qemu group is present on the host\\\", \\\"group\\\": {\\\"name\\\": \\\"qemu\\\", \\\"gid\\\": 107, \\\"state\\\": \\\"present\\\"}}, {\\\"name\\\": \\\"ensure qemu user is present on the host\\\", \\\"user\\\": {\\\"name\\\": \\\"qemu\\\", \\\"uid\\\": 107, \\\"group\\\": \\\"qemu\\\", \\\"state\\\": \\\"present\\\", \\\"shell\\\": \\\"/sbin/nologin\\\", \\\"comment\\\": \\\"qemu user\\\"}}, {\\\"name\\\": \\\"create directory for vhost-user sockets with qemu ownership\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/lib/vhost_sockets\\\", \\\"state\\\": \\\"directory\\\", \\\"owner\\\": \\\"qemu\\\", \\\"group\\\": \\\"qemu\\\", \\\"setype\\\": \\\"virt_cache_t\\\", \\\"seuser\\\": \\\"system_u\\\"}}, {\\\"name\\\": \\\"ensure ceph configurations exist\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/lib/tripleo-config/ceph\\\", \\\"state\\\": \\\"directory\\\"}}, {\\\"name\\\": \\\"check if libvirt is installed\\\", \\\"command\\\": \\\"/usr/bin/rpm -q libvirt-daemon\\\", \\\"failed_when\\\": false, \\\"register\\\": \\\"libvirt_installed\\\", \\\"check_mode\\\": false}, {\\\"name\\\": \\\"make sure libvirt services are disabled and masked\\\", \\\"service\\\": {\\\"name\\\": \\\"{{ item }}\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": false, \\\"masked\\\": true, \\\"daemon_reload\\\": true}, \\\"with_items\\\": [\\\"libvirtd.service\\\", \\\"virtlogd.socket\\\"], \\\"when\\\": \\\"libvirt_installed.rc == 0\\\"}, {\\\"name\\\": \\\"ensure /run/libvirt is present upon reboot\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/tmpfiles.d/run-libvirt.conf\\\", \\\"content\\\": \\\"d /run/libvirt 0755 root root - -\\\\n\\\"}}, {\\\"name\\\": \\\"Enable os_enable_vtpm SELinux boolean for vTPM\\\", \\\"seboolean\\\": {\\\"name\\\": \\\"os_enable_vtpm\\\", \\\"persistent\\\": true, \\\"state\\\": true}, \\\"when\\\": [\\\"ansible_facts.selinux is defined\\\", \\\"ansible_facts.selinux.status == \\\\\\\"enabled\\\\\\\"\\\"]}, [{\\\"name\\\": \\\"remove gnutls-qemu.config\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/crypto-policies/local.d/gnutls-qemu.config\\\", \\\"state\\\": \\\"absent\\\"}, \\\"register\\\": \\\"update_gnutls_config\\\"}], {\\\"name\\\": \\\"update crypto policies\\\", \\\"command\\\": \\\"update-crypto-policies\\\", \\\"when\\\": \\\"update_gnutls_config.changed\\\"}], \\\"metadata_settings\\\": [{\\\"service\\\": \\\"libvirt\\\", \\\"network\\\": \\\"internal_api\\\", \\\"type\\\": \\\"node\\\"}, {\\\"service\\\": \\\"qemu\\\", \\\"network\\\": \\\"internal_api\\\", \\\"type\\\": \\\"node\\\"}, {\\\"service\\\": \\\"libvirt-vnc\\\", \\\"network\\\": \\\"internal_api\\\", \\\"type\\\": \\\"node\\\"}], \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"Fail if we are on RHEL8 as this is monolithic libvirt deployment\\\", \\\"when\\\": [\\\"step|int == 0\\\", \\\"\'system_upgrade\' not in ansible_run_tags\\\", \\\"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\\\"], \\\"fail\\\": {\\\"msg\\\": \\\"Use of the Modular Libvirt deployment on RHEL8 results in loss of workloads. Use NovaLibvirtLegacy in roles data.\\\"}}, {\\\"name\\\": \\\"nova_libvirt_container_tmpfile_cleanup\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"Remove old tmpfiles.d config\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/tmpfiles.d/var-run-libvirt.conf\\\", \\\"state\\\": \\\"absent\\\"}}]}, {\\\"name\\\": \\\"Get container virtlogd image\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"tags\\\": \\\"always\\\", \\\"set_fact\\\": {\\\"virtlogd_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\"}}, {\\\"name\\\": \\\"Force pull image novalibvirt\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"containers.podman.podman_image\\\": {\\\"name\\\": \\\"{{ virtlogd_image }}\\\", \\\"force\\\": true}}, {\\\"name\\\": \\\"Diff OS release in container image and baremetal\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"shell\\\": \\\"diff /etc/redhat-release <(podman run {{ virtlogd_image }} cat /etc/redhat-release)\\\\n\\\", \\\"args\\\": {\\\"executable\\\": \\\"/bin/bash\\\"}, \\\"failed_when\\\": false, \\\"register\\\": \\\"libvirt_ubi_diff\\\"}, {\\\"name\\\": \\\"Fail if UBI of the container does not match RHEL of running host\\\", \\\"when\\\": [\\\"\'system_upgrade\' not in ansible_run_tags\\\", \\\"step|int == 1\\\", \\\"libvirt_ubi_diff.rc == 1\\\"], \\\"fail\\\": {\\\"msg\\\": \\\"The host operating system versus container UBI does not match.\\\\n{{ libvirt_ubi_diff.stdout }}\\\\nMost likely container passed to NovaLibvirt was EL8 one.\\\\nYou have to pass the correct container for container-image-prepare.\\\\nIf you would continue all running workloads would get destroyed.\\\\n\\\"}}, {\\\"name\\\": \\\"Switch virtlogd image before system upgrade\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Get running image version\\\", \\\"shell\\\": \\\"podman ps --filter name=^nova_virtlogd$ --format \\\\\\\"{% raw %}{{ .Image }}{% endraw %}\\\\\\\"\\\\n\\\", \\\"register\\\": \\\"old_virtlogd_image\\\"}, {\\\"name\\\": \\\"Switch running image to new image in wrapper script\\\", \\\"shell\\\": \\\"set -o pipefail\\\\nsed -i -e \'s|{{ old_virtlogd_image.stdout }}|{{ virtlogd_image }}|\' /var/lib/container-config-scripts/virtlogd_wrapper\\\\n\\\", \\\"when\\\": [\\\"old_virtlogd_image.stdout != virtlogd_image\\\", \\\"old_virtlogd_image.stdout != \'\'\\\"]}]}], \\\"update_tasks\\\": [{\\\"name\\\": \\\"check systemd-container package present or not\\\", \\\"package\\\": {\\\"name\\\": \\\"systemd-container\\\", \\\"state\\\": \\\"present\\\"}, \\\"check_mode\\\": true, \\\"register\\\": \\\"is_systemd_container_package\\\"}, {\\\"name\\\": \\\"download systemd-container package if not present\\\", \\\"yum\\\": {\\\"name\\\": \\\"systemd-container\\\", \\\"state\\\": \\\"present\\\", \\\"download_only\\\": true, \\\"download_dir\\\": \\\"/var/tmp/\\\"}, \\\"when\\\": \\\"is_systemd_container_package.changed\\\"}, {\\\"name\\\": \\\"nova_libvirt_container_tmpfile_cleanup\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"Remove old tmpfiles.d config\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/tmpfiles.d/var-run-libvirt.conf\\\", \\\"state\\\": \\\"absent\\\"}}]}]}, {\\\"service_name\\\": \\\"nova_libvirt_guests\\\", \\\"config_settings\\\": {\\\"tripleo::profile::base::nova::compute::libvirt_guests::enabled\\\": false, \\\"nova::compute::libvirt_guests::shutdown_timeout\\\": \\\"300\\\", \\\"ContainerNovaLibvirtConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\"}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"nova_libvirt\\\", \\\"puppet_tags\\\": \\\"libvirtd_config,nova_config,file,libvirt_tls_password\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::nova::compute::libvirt_guests\\\\n\\\", \\\"config_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\"}}, {\\\"service_name\\\": \\\"nova_migration_target\\\", \\\"firewall_rules\\\": {\\\"113 nova_migration_target accept libvirt subnet 172.17.0.0/24\\\": {\\\"source\\\": \\\"172.17.0.0/24\\\", \\\"proto\\\": \\\"tcp\\\", \\\"dport\\\": 2022}, \\\"113 nova_migration_target accept api subnet 172.17.0.0/24\\\": {\\\"source\\\": \\\"172.17.0.0/24\\\", \\\"proto\\\": \\\"tcp\\\", \\\"dport\\\": 2022}}, \\\"config_settings\\\": {\\\"tripleo::profile::base::sshd::bannertext\\\": \\\"\\\", \\\"tripleo::profile::base::sshd::motd\\\": \\\"\\\", \\\"tripleo::profile::base::sshd::options\\\": {\\\"HostKey\\\": [\\\"/etc/ssh/ssh_host_rsa_key\\\", \\\"/etc/ssh/ssh_host_ecdsa_key\\\", \\\"/etc/ssh/ssh_host_ed25519_key\\\"], \\\"SyslogFacility\\\": \\\"AUTHPRIV\\\", \\\"AuthorizedKeysFile\\\": \\\".ssh/authorized_keys\\\", \\\"ChallengeResponseAuthentication\\\": \\\"no\\\", \\\"GSSAPIAuthentication\\\": \\\"no\\\", \\\"GSSAPICleanupCredentials\\\": \\\"no\\\", \\\"UsePAM\\\": \\\"yes\\\", \\\"UseDNS\\\": \\\"no\\\", \\\"PrintMotd\\\": \\\"no\\\", \\\"X11Forwarding\\\": \\\"yes\\\", \\\"AcceptEnv\\\": [\\\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\\\", \\\"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\\\", \\\"LC_IDENTIFICATION LC_ALL LANGUAGE\\\", \\\"XMODIFIERS\\\"], \\\"Subsystem\\\": \\\"sftp  /usr/libexec/openssh/sftp-server\\\"}, \\\"tripleo::profile::base::sshd::password_authentication\\\": \\\"yes\\\", \\\"tripleo::profile::base::nova::migration::target::ssh_authorized_keys\\\": [\\\"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\\\"], \\\"tripleo::profile::base::nova::migration::target::ssh_localaddrs\\\": [\\\"%{hiera(\'cold_migration_ssh_inbound_addr\')}\\\", \\\"%{hiera(\'live_migration_ssh_inbound_addr\')}\\\"], \\\"live_migration_ssh_inbound_addr\\\": \\\"%{hiera(\'internal_api\')}\\\", \\\"cold_migration_ssh_inbound_addr\\\": \\\"%{hiera(\'internal_api\')}\\\", \\\"tripleo::profile::base::sshd::port\\\": [22]}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"nova_libvirt\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::sshd\\\\ninclude tripleo::profile::base::nova::migration::target\\\", \\\"config_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\\\"}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/nova-migration-target.json\\\": {\\\"command\\\": \\\"dumb-init --single-child -- /usr/sbin/sshd -D -p 2022\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}, {\\\"source\\\": \\\"/host-ssh/ssh_host_*_key\\\", \\\"dest\\\": \\\"/etc/ssh/\\\", \\\"owner\\\": \\\"root\\\", \\\"perm\\\": \\\"0600\\\"}]}}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"Create libvirt persistent data directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\"}, \\\"loop\\\": [{\\\"path\\\": \\\"/run/libvirt\\\", \\\"setype\\\": \\\"virt_var_run_t\\\"}]}, {\\\"name\\\": \\\"ensure /run/libvirt is present upon reboot\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/tmpfiles.d/run-libvirt.conf\\\", \\\"content\\\": \\\"d /run/libvirt 0755 root root - -\\\\n\\\"}}], \\\"docker_config\\\": {\\\"step_4\\\": {\\\"nova_migration_target\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\\\", \\\"net\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"user\\\": \\\"root\\\", \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/lib/kolla/config_files/nova-migration-target.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/nova_libvirt:/var/lib/kolla/config_files/src:ro\\\", \\\"/etc/ssh:/host-ssh:ro\\\", \\\"/run/libvirt:/run/libvirt:shared,z\\\", \\\"/var/lib/nova:/var/lib/nova:shared\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"validate nova-migration-target container state\\\", \\\"containers.podman.podman_container_info\\\": {\\\"name\\\": \\\"nova_migration_target\\\"}, \\\"register\\\": \\\"nova_migration_target_infos\\\", \\\"failed_when\\\": [\\\"nova_migration_target_infos.containers.0.Healthcheck.Status is defined\\\", \\\"\'healthy\' not in nova_migration_target_infos.containers.0.Healthcheck.Status\\\"], \\\"retries\\\": 10, \\\"delay\\\": 30, \\\"tags\\\": [\\\"opendev-validation\\\", \\\"opendev-validation-nova\\\"], \\\"when\\\": [\\\"container_cli == \'podman\'\\\", \\\"not container_healthcheck_disabled\\\", \\\"step|int == 5\\\"]}], \\\"update_tasks\\\": [{\\\"name\\\": \\\"nova_migration_target_tmpfile_cleanup\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"Remove old tmpfiles.d config\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/tmpfiles.d/var-run-libvirt.conf\\\", \\\"state\\\": \\\"absent\\\"}}]}], \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"nova_migration_target_tmpfile_cleanup\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"block\\\": [{\\\"name\\\": \\\"Remove old tmpfiles.d config\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/tmpfiles.d/var-run-libvirt.conf\\\", \\\"state\\\": \\\"absent\\\"}}]}]}, {\\\"service_name\\\": \\\"logrotate_crond\\\", \\\"config_settings\\\": {\\\"tripleo::profile::base::logging::logrotate::maxsize\\\": \\\"10M\\\", \\\"tripleo::profile::base::logging::logrotate::rotation\\\": \\\"daily\\\", \\\"tripleo::profile::base::logging::logrotate::rotate\\\": \\\"14\\\", \\\"tripleo::profile::base::logging::logrotate::purge_after_days\\\": \\\"14\\\", \\\"tripleo::profile::base::logging::logrotate::dateext\\\": false}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"allow logrotate to read inside containers\\\", \\\"seboolean\\\": {\\\"name\\\": \\\"logrotate_read_inside_containers\\\", \\\"persistent\\\": true, \\\"state\\\": true}, \\\"when\\\": [\\\"ansible_facts.selinux is defined\\\", \\\"ansible_facts.selinux.status == \\\\\\\"enabled\\\\\\\"\\\"]}], \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"configure tmpwatch on the host\\\", \\\"when\\\": \\\"step|int == 2\\\", \\\"block\\\": [{\\\"name\\\": \\\"Push script\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/usr/local/sbin/containers-tmpwatch\\\", \\\"owner\\\": \\\"root\\\", \\\"group\\\": \\\"root\\\", \\\"mode\\\": 493, \\\"content\\\": \\\"#!/bin/sh\\\\ntmpwatch --nodirs \\\\\\\\\\\\n  -X \\\\\\\"/var/log/containers/*/*log\\\\\\\" \\\\\\\\\\\\n  -X \\\\\\\"/var/log/containers/*/*/*log\\\\\\\" \\\\\\\\\\\\n  -X \\\\\\\"/var/log/containers/*/*err\\\\\\\" \\\\\\\\\\\\n  {{ LogrotatePurgeAfterDays|int +1 }}d \\\\\\\\\\\\n  /var/log/containers/ 2>&1 | logger -t container-tmpwatch\\\\n\\\"}, \\\"vars\\\": {\\\"LogrotatePurgeAfterDays\\\": \\\"14\\\"}}, {\\\"name\\\": \\\"Insert cronjob in root crontab\\\", \\\"cron\\\": {\\\"name\\\": \\\"Remove old logs\\\", \\\"special_time\\\": \\\"daily\\\", \\\"user\\\": \\\"root\\\", \\\"job\\\": \\\"/usr/local/sbin/containers-tmpwatch\\\"}}]}], \\\"update_tasks\\\": [{\\\"name\\\": \\\"Ensure old cron.daily is absent\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/cron.daily/containers-tmpwatch\\\", \\\"state\\\": \\\"absent\\\"}}], \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"Ensure old cron.daily is absent\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/cron.daily/containers-tmpwatch\\\", \\\"state\\\": \\\"absent\\\"}}], \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"crond\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::logging::logrotate\\\", \\\"config_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\\\"}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/logrotate-crond.json\\\": {\\\"command\\\": \\\"/usr/sbin/crond -s -n\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}]}}, \\\"docker_config\\\": {\\\"step_4\\\": {\\\"logrotate_crond\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\\\", \\\"net\\\": \\\"none\\\", \\\"pid\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"user\\\": \\\"root\\\", \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/usr/share/openstack-tripleo-common/healthcheck/cron\\\"}, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/lib/kolla/config_files/logrotate-crond.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/crond:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/log/containers:/var/log/containers:z\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"external_upgrade_tasks\\\": [{\\\"when\\\": [\\\"step|int == 1\\\"], \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade_transfer_data\\\", \\\"system_upgrade_stop_services\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Stop logrotate container\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_stop\\\"}, \\\"vars\\\": {\\\"tripleo_containers_to_stop\\\": [\\\"logrotate_crond\\\"], \\\"tripleo_delegate_to\\\": \\\"{{ groups[\'logrotate_crond\'] | difference(groups[\'excluded_overcloud\']) }}\\\"}}]}]}, {\\\"service_name\\\": \\\"podman\\\", \\\"config_settings\\\": {}, \\\"step_config\\\": \\\"\\\", \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"Install and configure Podman\\\", \\\"block\\\": [{\\\"name\\\": \\\"Set login facts\\\", \\\"no_log\\\": true, \\\"set_fact\\\": {\\\"container_registry_insecure_registries\\\": [], \\\"container_registry_login\\\": false, \\\"container_registry_logins\\\": {}, \\\"container_registry_logins_json\\\": {}, \\\"container_default_pids_limit\\\": 4096, \\\"container_events_logger_mechanism\\\": \\\"journald\\\"}}, {\\\"name\\\": \\\"Convert logins json to dict\\\", \\\"no_log\\\": true, \\\"set_fact\\\": {\\\"container_registry_logins\\\": \\\"{{ container_registry_logins_json | from_json }}\\\"}, \\\"when\\\": [\\\"container_registry_logins_json is string\\\", \\\"container_registry_login | bool\\\", \\\"(container_registry_logins_json | length) > 0\\\"]}, {\\\"name\\\": \\\"Set registry logins\\\", \\\"no_log\\\": true, \\\"set_fact\\\": {\\\"container_registry_logins\\\": \\\"{{ container_registry_logins_json }}\\\"}, \\\"when\\\": [\\\"container_registry_logins_json is mapping\\\", \\\"container_registry_login | bool\\\", \\\"(container_registry_logins_json | length) > 0\\\"]}, {\\\"name\\\": \\\"Run podman install\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_podman\\\", \\\"tasks_from\\\": \\\"tripleo_podman_install.yml\\\"}, \\\"vars\\\": {\\\"tripleo_container_registry_insecure_registries\\\": \\\"{{ container_registry_insecure_registries }}\\\", \\\"tripleo_container_default_pids_limit\\\": \\\"{{ container_default_pids_limit }}\\\", \\\"tripleo_container_events_logger_mechanism\\\": \\\"{{ container_events_logger_mechanism }}\\\"}}, {\\\"name\\\": \\\"Run podman login\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_podman\\\", \\\"tasks_from\\\": \\\"tripleo_podman_login.yml\\\"}, \\\"vars\\\": {\\\"tripleo_container_registry_logins\\\": \\\"{{ container_registry_logins }}\\\", \\\"tripleo_container_registry_login\\\": \\\"{{ container_registry_login | bool }}\\\"}}]}, [{\\\"name\\\": \\\"Configure tripleo_container_manage to generate systemd drop-in dependencies\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/etc/sysconfig/podman_drop_in\\\", \\\"content\\\": \\\"This file makes tripleo_container_manage generate additional systemd\\\\ndependencies for containers that have special\\\\nstart/stop ordering constraints. It ensures that\\\\nthose constraints are enforced on reboot/shutdown.\\\\n\\\"}}]], \\\"deploy_steps_tasks\\\": [{\\\"when\\\": [\\\"(step|int) == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Pre-fetch all the containers\\\", \\\"become\\\": true, \\\"containers.podman.podman_image\\\": {\\\"name\\\": \\\"{{ prefetch_image }}\\\", \\\"validate_certs\\\": false, \\\"force\\\": true}, \\\"register\\\": \\\"result\\\", \\\"until\\\": \\\"result is succeeded\\\", \\\"retries\\\": 5, \\\"delay\\\": 5, \\\"loop_control\\\": {\\\"loop_var\\\": \\\"prefetch_image\\\"}, \\\"loop\\\": \\\"{{ lookup(\'template\', tripleo_role_name + \'/docker_config.yaml\', errors=\'ignore\') | default(\'{}\', True) | from_yaml | recursive_get_key_from_dict(key=\'image\') | unique }}\\\"}]}], \\\"service_config_settings\\\": {}, \\\"workaround_upgrade_tasks\\\": [{\\\"name\\\": \\\"Configure Podman registry\\\", \\\"when\\\": [\\\"step|int == 0\\\"], \\\"tags\\\": [\\\"setup_packages\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Make sure the Undercloud hostname is included in /etc/hosts\\\", \\\"when\\\": [\\\"undercloud_hosts_entries is defined\\\"], \\\"lineinfile\\\": {\\\"dest\\\": \\\"/etc/hosts\\\", \\\"line\\\": \\\"{{ undercloud_hosts_entries | join(\'\') }}\\\", \\\"state\\\": \\\"present\\\"}}]}, {\\\"name\\\": \\\"Run podman install\\\", \\\"tags\\\": [\\\"system_upgrade\\\", \\\"system_upgrade_run\\\", \\\"setup_packages\\\"], \\\"when\\\": [\\\"step|int == 0\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Set login facts\\\", \\\"no_log\\\": true, \\\"set_fact\\\": {\\\"container_registry_insecure_registries\\\": [], \\\"container_registry_login\\\": false, \\\"container_registry_logins\\\": {}, \\\"container_registry_logins_json\\\": {}, \\\"container_default_pids_limit\\\": 4096, \\\"container_events_logger_mechanism\\\": \\\"journald\\\"}}, {\\\"name\\\": \\\"Convert logins json to dict\\\", \\\"no_log\\\": true, \\\"set_fact\\\": {\\\"container_registry_logins\\\": \\\"{{ container_registry_logins_json | from_json }}\\\"}, \\\"when\\\": [\\\"container_registry_logins_json is string\\\", \\\"container_registry_login | bool\\\", \\\"(container_registry_logins_json | length) > 0\\\"]}, {\\\"name\\\": \\\"Set registry logins\\\", \\\"no_log\\\": true, \\\"set_fact\\\": {\\\"container_registry_logins\\\": \\\"{{ container_registry_logins_json }}\\\"}, \\\"when\\\": [\\\"container_registry_logins_json is mapping\\\", \\\"container_registry_login | bool\\\", \\\"(container_registry_logins_json | length) > 0\\\"]}, {\\\"name\\\": \\\"Run podman install\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_podman\\\", \\\"tasks_from\\\": \\\"tripleo_podman_install.yml\\\"}, \\\"vars\\\": {\\\"tripleo_container_registry_insecure_registries\\\": \\\"{{ container_registry_insecure_registries }}\\\", \\\"tripleo_container_default_pids_limit\\\": \\\"{{ container_default_pids_limit }}\\\", \\\"tripleo_container_events_logger_mechanism\\\": \\\"{{ container_events_logger_mechanism }}\\\"}}, {\\\"name\\\": \\\"Run podman login\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_podman\\\", \\\"tasks_from\\\": \\\"tripleo_podman_login.yml\\\"}, \\\"vars\\\": {\\\"tripleo_container_registry_logins\\\": \\\"{{ container_registry_logins }}\\\", \\\"tripleo_container_registry_login\\\": \\\"{{ container_registry_login | bool }}\\\"}}]}, {\\\"name\\\": \\\"Comment infra_image in container.conf\\\", \\\"lineinfile\\\": {\\\"dest\\\": \\\"/usr/share/containers/containers.conf\\\", \\\"regexp\\\": \\\"(?i)^(infra_image.*)\\\", \\\"line\\\": \\\"#\\\\\\\\1\\\", \\\"backrefs\\\": true, \\\"state\\\": \\\"present\\\"}, \\\"tags\\\": [\\\"setup_packages\\\"], \\\"when\\\": [\\\"step|int == 0\\\"]}], \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"Configure Podman registry\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Make sure the Undercloud hostname is included in /etc/hosts\\\", \\\"when\\\": [\\\"undercloud_hosts_entries is defined\\\"], \\\"lineinfile\\\": {\\\"dest\\\": \\\"/etc/hosts\\\", \\\"line\\\": \\\"{{ undercloud_hosts_entries | join(\'\') }}\\\", \\\"state\\\": \\\"present\\\"}}]}, {\\\"name\\\": \\\"Run podman install\\\", \\\"tags\\\": [\\\"system_upgrade\\\", \\\"system_upgrade_run\\\"], \\\"when\\\": [\\\"step|int == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Set login facts\\\", \\\"no_log\\\": true, \\\"set_fact\\\": {\\\"container_registry_insecure_registries\\\": [], \\\"container_registry_login\\\": false, \\\"container_registry_logins\\\": {}, \\\"container_registry_logins_json\\\": {}, \\\"container_default_pids_limit\\\": 4096, \\\"container_events_logger_mechanism\\\": \\\"journald\\\"}}, {\\\"name\\\": \\\"Convert logins json to dict\\\", \\\"no_log\\\": true, \\\"set_fact\\\": {\\\"container_registry_logins\\\": \\\"{{ container_registry_logins_json | from_json }}\\\"}, \\\"when\\\": [\\\"container_registry_logins_json is string\\\", \\\"container_registry_login | bool\\\", \\\"(container_registry_logins_json | length) > 0\\\"]}, {\\\"name\\\": \\\"Set registry logins\\\", \\\"no_log\\\": true, \\\"set_fact\\\": {\\\"container_registry_logins\\\": \\\"{{ container_registry_logins_json }}\\\"}, \\\"when\\\": [\\\"container_registry_logins_json is mapping\\\", \\\"container_registry_login | bool\\\", \\\"(container_registry_logins_json | length) > 0\\\"]}, {\\\"name\\\": \\\"Run podman install\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_podman\\\", \\\"tasks_from\\\": \\\"tripleo_podman_install.yml\\\"}, \\\"vars\\\": {\\\"tripleo_container_registry_insecure_registries\\\": \\\"{{ container_registry_insecure_registries }}\\\", \\\"tripleo_container_default_pids_limit\\\": \\\"{{ container_default_pids_limit }}\\\", \\\"tripleo_container_events_logger_mechanism\\\": \\\"{{ container_events_logger_mechanism }}\\\"}}, {\\\"name\\\": \\\"Run podman login\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_podman\\\", \\\"tasks_from\\\": \\\"tripleo_podman_login.yml\\\"}, \\\"vars\\\": {\\\"tripleo_container_registry_logins\\\": \\\"{{ container_registry_logins }}\\\", \\\"tripleo_container_registry_login\\\": \\\"{{ container_registry_login | bool }}\\\"}}]}], \\\"update_tasks\\\": [{\\\"name\\\": \\\"Force pre-fetch of container images\\\", \\\"when\\\": [\\\"(step|int) == 5\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Pre-fetch all the containers\\\", \\\"become\\\": true, \\\"containers.podman.podman_image\\\": {\\\"name\\\": \\\"{{ prefetch_image }}\\\", \\\"validate_certs\\\": false, \\\"force\\\": true}, \\\"register\\\": \\\"result\\\", \\\"until\\\": \\\"result is succeeded\\\", \\\"retries\\\": 5, \\\"delay\\\": 5, \\\"loop_control\\\": {\\\"loop_var\\\": \\\"prefetch_image\\\"}, \\\"loop\\\": \\\"{{ lookup(\'template\', tripleo_role_name + \'/docker_config.yaml\', errors=\'ignore\') | default(\'{}\', True) | from_yaml | recursive_get_key_from_dict(key=\'image\') | unique }}\\\"}]}], \\\"post_upgrade_tasks\\\": [{\\\"name\\\": \\\"Purge Podman\\\", \\\"when\\\": [\\\"(step | int) == 3\\\", \\\"container_cli == \'podman\'\\\", \\\"deployment_source_hosts not in group_names\\\"], \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_podman\\\", \\\"tasks_from\\\": \\\"tripleo_podman_purge.yml\\\"}, \\\"vars\\\": {\\\"deployment_source_hosts\\\": \\\"Undercloud\\\"}}], \\\"post_update_tasks\\\": [{\\\"name\\\": \\\"Purge Podman\\\", \\\"when\\\": [\\\"(step | int) == 3\\\", \\\"container_cli == \'podman\'\\\", \\\"deployment_source_hosts not in group_names\\\"], \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_podman\\\", \\\"tasks_from\\\": \\\"tripleo_podman_purge.yml\\\"}, \\\"vars\\\": {\\\"deployment_source_hosts\\\": \\\"Undercloud\\\"}}]}, {\\\"service_name\\\": \\\"rsyslog\\\", \\\"config_settings\\\": {\\\"rsyslog::server::global_config\\\": {\\\"WorkDirectory\\\": {\\\"type\\\": \\\"legacy\\\", \\\"target\\\": \\\"00_rsyslog.conf\\\", \\\"value\\\": \\\"/var/lib/rsyslog\\\"}, \\\"MaxMessageSize\\\": {\\\"type\\\": \\\"legacy\\\", \\\"target\\\": \\\"00_rsyslog.conf\\\", \\\"value\\\": \\\"32k\\\"}}, \\\"rsyslog::confdir\\\": \\\"/etc/rsyslog.d\\\", \\\"rsyslog::package_name\\\": \\\"rsyslog\\\", \\\"rsyslog::package_version\\\": \\\"installed\\\", \\\"rsyslog::manage_package\\\": true, \\\"rsyslog::manage_confdir\\\": true, \\\"rsyslog::purge_config_files\\\": true, \\\"rsyslog::override_default_config\\\": true, \\\"rsyslog::config_file\\\": \\\"/etc/rsyslog.conf\\\", \\\"rsyslog::manage_service\\\": true, \\\"rsyslog::service_name\\\": \\\"rsyslog\\\", \\\"rsyslog::service_status\\\": \\\"running\\\", \\\"rsyslog::service_enabled\\\": true, \\\"rsyslog::external_service\\\": false, \\\"rsyslog::use_upstream_repo\\\": false, \\\"rsyslog::feature_packages\\\": [\\\"rsyslog-elasticsearch\\\", \\\"rsyslog-mmnormalize\\\"], \\\"rsyslog::global_config_priority\\\": 10, \\\"rsyslog::module_load_priority\\\": 20, \\\"rsyslog::input_priority\\\": 30, \\\"rsyslog::main_queue_priority\\\": 40, \\\"rsyslog::parser_priority\\\": 45, \\\"rsyslog::template_priority\\\": 50, \\\"rsyslog::filter_priority\\\": 55, \\\"rsyslog::action_priority\\\": 60, \\\"rsyslog::ruleset_priority\\\": 65, \\\"rsyslog::lookup_table_priority\\\": 70, \\\"rsyslog::legacy_config_priority\\\": 80, \\\"rsyslog::custom_priority\\\": 90, \\\"rsyslog::target_file\\\": \\\"50_openstack_logs.conf\\\", \\\"rsyslog::server::modules\\\": {\\\"imfile\\\": {}, \\\"omelasticsearch\\\": {}, \\\"omamqp1\\\": {}}, \\\"rsyslog::server::templates\\\": {\\\"rsyslog-node-index\\\": {\\\"type\\\": \\\"list\\\", \\\"list_descriptions\\\": [{\\\"constant\\\": {\\\"value\\\": \\\"%{hiera(\'fqdn_canonical\')}-\\\"}}, {\\\"property\\\": {\\\"name\\\": \\\"timereported\\\", \\\"dateFormat\\\": \\\"year\\\"}}, {\\\"constant\\\": {\\\"value\\\": \\\".\\\"}}, {\\\"property\\\": {\\\"name\\\": \\\"timereported\\\", \\\"dateFormat\\\": \\\"month\\\"}}, {\\\"constant\\\": {\\\"value\\\": \\\".\\\"}}, {\\\"property\\\": {\\\"name\\\": \\\"timereported\\\", \\\"dateFormat\\\": \\\"day\\\"}}]}, \\\"rsyslog-record\\\": {\\\"type\\\": \\\"list\\\", \\\"options\\\": {\\\"jsonf\\\": \\\"on\\\"}, \\\"list_descriptions\\\": [{\\\"property\\\": {\\\"outname\\\": \\\"@timestamp\\\", \\\"name\\\": \\\"timereported\\\", \\\"dateFormat\\\": \\\"rfc3339\\\", \\\"format\\\": \\\"jsonf\\\"}}, {\\\"property\\\": {\\\"outname\\\": \\\"host\\\", \\\"name\\\": \\\"hostname\\\", \\\"format\\\": \\\"jsonf\\\"}}, {\\\"property\\\": {\\\"outname\\\": \\\"severity\\\", \\\"name\\\": \\\"syslogseverity\\\", \\\"format\\\": \\\"jsonf\\\"}}, {\\\"property\\\": {\\\"outname\\\": \\\"facility\\\", \\\"name\\\": \\\"syslogfacility-text\\\", \\\"format\\\": \\\"jsonf\\\"}}, {\\\"property\\\": {\\\"outname\\\": \\\"tag\\\", \\\"name\\\": \\\"syslogtag\\\", \\\"format\\\": \\\"jsonf\\\"}}, {\\\"property\\\": {\\\"outname\\\": \\\"source\\\", \\\"name\\\": \\\"app-name\\\", \\\"format\\\": \\\"jsonf\\\"}}, {\\\"property\\\": {\\\"outname\\\": \\\"message\\\", \\\"name\\\": \\\"msg\\\", \\\"format\\\": \\\"jsonf\\\"}}, {\\\"property\\\": {\\\"outname\\\": \\\"file\\\", \\\"name\\\": \\\"$!metadata!filename\\\", \\\"format\\\": \\\"jsonf\\\"}}, {\\\"constant\\\": {\\\"outname\\\": \\\"cloud\\\", \\\"value\\\": \\\"overcloud.ooo.test\\\", \\\"format\\\": \\\"jsonf\\\"}}, {\\\"constant\\\": {\\\"outname\\\": \\\"region\\\", \\\"value\\\": \\\"regionOne\\\", \\\"format\\\": \\\"jsonf\\\"}}]}}, \\\"tripleo::profile::base::logging::rsyslog::reopen_on_truncate\\\": \\\"on\\\"}, \\\"puppet_config\\\": {\\\"config_volume\\\": \\\"rsyslog\\\", \\\"puppet_tags\\\": \\\"rsyslog::generate_concat,concat::fragment\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::logging::rsyslog\\\", \\\"config_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\\\"}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/rsyslog.json\\\": {\\\"command\\\": \\\"/usr/sbin/rsyslogd -n -iNONE\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/lib/rsyslog\\\", \\\"owner\\\": \\\"root:root\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/var/log/rsyslog\\\", \\\"owner\\\": \\\"root:root\\\", \\\"recurse\\\": true}]}}, \\\"docker_config\\\": {\\\"step_3\\\": {\\\"rsyslog\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\\\", \\\"net\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"user\\\": \\\"root\\\", \\\"restart\\\": \\\"always\\\", \\\"security_opt\\\": [\\\"label=disable\\\"], \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/lib/kolla/config_files/rsyslog.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/rsyslog:/var/lib/kolla/config_files/src:ro\\\", \\\"/var/log/containers:/var/log/containers:ro\\\", \\\"/var/log/containers/rsyslog:/var/log/rsyslog:rw,z\\\", \\\"/var/log:/var/log/host:ro\\\", \\\"/var/lib/rsyslog.container:/var/lib/rsyslog:rw,z\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create persistent logs directory for rsyslog\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/log/containers/rsyslog\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}}, {\\\"name\\\": \\\"create persistent state directory for rsyslog\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/lib/rsyslog.container\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"container_file_t\\\"}}]}, {\\\"service_name\\\": \\\"snmp\\\", \\\"firewall_rules\\\": {\\\"124 snmp 192.168.122.0/24\\\": {\\\"dport\\\": 161, \\\"proto\\\": \\\"udp\\\", \\\"source\\\": \\\"192.168.122.0/24\\\"}}, \\\"config_settings\\\": {\\\"tripleo::profile::base::snmp::snmpd_user\\\": \\\"ro_snmp_user\\\", \\\"tripleo::profile::base::snmp::snmpd_password\\\": \\\"IUqJgJKOidh20dco1DYKnuQ1\\\", \\\"snmp::agentaddress\\\": [\\\"udp:161\\\", \\\"udp6:[::1]:161\\\"], \\\"snmp::snmpd_options\\\": \\\"-LS0-5d\\\"}, \\\"step_config\\\": \\\"include tripleo::profile::base::snmp\\\\n\\\", \\\"upgrade_tasks\\\": [{\\\"when\\\": \\\"step|int == 0\\\", \\\"block\\\": [{\\\"name\\\": \\\"Check if snmpd is enabled\\\", \\\"command\\\": \\\"systemctl is-enabled --quiet snmpd\\\", \\\"failed_when\\\": false, \\\"register\\\": \\\"snmpd_enabled_result\\\"}, {\\\"name\\\": \\\"Set fact snmpd_enabled\\\", \\\"set_fact\\\": {\\\"snmpd_enabled\\\": \\\"{{ snmpd_enabled_result.rc == 0 }}\\\"}}]}, {\\\"name\\\": \\\"Stop snmp service\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"snmpd_enabled|bool\\\"], \\\"service\\\": \\\"name=snmpd state=stopped\\\"}]}, {\\\"service_name\\\": \\\"sshd\\\", \\\"firewall_rules\\\": {\\\"003 accept ssh from all\\\": {\\\"proto\\\": \\\"tcp\\\", \\\"dport\\\": 22, \\\"extras\\\": {\\\"ensure\\\": \\\"present\\\"}}}, \\\"host_prep_tasks\\\": [{\\\"include_role\\\": {\\\"name\\\": \\\"tripleo_sshd\\\"}, \\\"vars\\\": {\\\"tripleo_sshd_server_options\\\": {\\\"HostKey\\\": [\\\"/etc/ssh/ssh_host_rsa_key\\\", \\\"/etc/ssh/ssh_host_ecdsa_key\\\", \\\"/etc/ssh/ssh_host_ed25519_key\\\"], \\\"SyslogFacility\\\": \\\"AUTHPRIV\\\", \\\"AuthorizedKeysFile\\\": \\\".ssh/authorized_keys\\\", \\\"ChallengeResponseAuthentication\\\": \\\"no\\\", \\\"GSSAPIAuthentication\\\": \\\"no\\\", \\\"GSSAPICleanupCredentials\\\": \\\"no\\\", \\\"UsePAM\\\": \\\"yes\\\", \\\"UseDNS\\\": \\\"no\\\", \\\"PrintMotd\\\": \\\"no\\\", \\\"X11Forwarding\\\": \\\"yes\\\", \\\"AcceptEnv\\\": [\\\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\\\", \\\"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\\\", \\\"LC_IDENTIFICATION LC_ALL LANGUAGE\\\", \\\"XMODIFIERS\\\"], \\\"Subsystem\\\": \\\"sftp  /usr/libexec/openssh/sftp-server\\\"}, \\\"tripleo_sshd_password_authentication\\\": \\\"yes\\\", \\\"tripleo_sshd_banner_enabled\\\": false, \\\"tripleo_sshd_banner_text\\\": \\\"\\\", \\\"tripleo_sshd_motd_enabled\\\": false, \\\"tripleo_sshd_message_of_the_day\\\": \\\"\\\"}}]}, {\\\"service_name\\\": \\\"chrony\\\", \\\"firewall_rules\\\": {\\\"105 ntp\\\": {\\\"dport\\\": 123, \\\"proto\\\": \\\"udp\\\"}}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"Check for NTP service\\\", \\\"shell\\\": \\\"systemctl is-active ntpd.service || systemctl is-enabled ntpd.service\\\", \\\"failed_when\\\": false, \\\"become\\\": true, \\\"register\\\": \\\"ntp_service_check\\\"}, {\\\"name\\\": \\\"Disable NTP before configuring Chrony\\\", \\\"service\\\": {\\\"name\\\": \\\"ntpd\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": false}, \\\"when\\\": [\\\"ntp_service_check.rc is defined\\\", \\\"ntp_service_check.rc == 0\\\"]}, {\\\"name\\\": \\\"Install, Configure and Run Chrony\\\", \\\"include_role\\\": {\\\"name\\\": \\\"chrony\\\"}}, {\\\"name\\\": \\\"Force NTP sync\\\", \\\"command\\\": \\\"chronyc makestep\\\"}, {\\\"name\\\": \\\"Ensure system is NTP time synced\\\", \\\"command\\\": \\\"chronyc waitsync 30\\\"}], \\\"ansible_group_vars\\\": {\\\"chrony_role_action\\\": \\\"all\\\", \\\"chrony_ntp_servers\\\": [\\\"pool.ntp.org\\\"], \\\"chrony_ntp_pools\\\": [], \\\"chrony_global_server_settings\\\": \\\"iburst minpoll 6 maxpoll 10\\\", \\\"chrony_global_pool_settings\\\": \\\"iburst minpoll 6 maxpoll 10\\\", \\\"chrony_manage_package\\\": true, \\\"chrony_acl_rules\\\": [\\\"deny all\\\"]}}, {\\\"service_name\\\": \\\"timezone\\\", \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"Run timezone role\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_timezone\\\"}, \\\"vars\\\": {\\\"tripleo_timezone\\\": \\\"UTC\\\"}}]}, {\\\"service_name\\\": \\\"tripleo_firewall\\\", \\\"config_settings\\\": {\\\"tripleo::firewall::manage_firewall\\\": false, \\\"tripleo::firewall::purge_firewall_rules\\\": false}, \\\"ansible_group_vars\\\": {\\\"tripleo_nftables_debug\\\": true}, \\\"firewall_rules\\\": {\\\"003 accept ssh from ctlplane subnet 192.168.122.0/24\\\": {\\\"source\\\": \\\"192.168.122.0/24\\\", \\\"proto\\\": \\\"tcp\\\", \\\"dport\\\": 22}}, \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"Notice - ctlplane subnet is set\\\", \\\"debug\\\": {\\\"msg\\\": \\\"CIDRs found in the ctlplane network tags.\\\\n\\\"}}], \\\"host_firewall_tasks\\\": [{\\\"name\\\": \\\"Run firewall role\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_firewall\\\"}}], \\\"update_tasks\\\": [{\\\"name\\\": \\\"Cleanup tripleo-iptables services\\\", \\\"when\\\": [\\\"(step | int) == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Disable tripleo-iptables.service\\\", \\\"systemd\\\": {\\\"name\\\": \\\"tripleo-iptables.service\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": false}, \\\"register\\\": \\\"systemd_tripleo_iptables\\\", \\\"failed_when\\\": false}, {\\\"name\\\": \\\"Cleanup tripleo-iptables.services\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/systemd/system/tripleo-iptables.service\\\", \\\"state\\\": \\\"absent\\\"}}, {\\\"name\\\": \\\"Disable tripleo-ip6tables.service\\\", \\\"systemd\\\": {\\\"name\\\": \\\"tripleo-ip6tables.service\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": false}, \\\"register\\\": \\\"systemd_tripleo_ip6tables\\\", \\\"failed_when\\\": false}, {\\\"name\\\": \\\"Cleanup tripleo-ip6tables.services\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/systemd/system/tripleo-ip6tables.service\\\", \\\"state\\\": \\\"absent\\\"}}, {\\\"name\\\": \\\"Reload systemd\\\", \\\"systemd\\\": {\\\"daemon_reload\\\": true}, \\\"when\\\": [\\\"(systemd_tripleo_iptables is changed or systemd_tripleo_ip6tables is changed)\\\"]}]}], \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"Cleanup tripleo-iptables services\\\", \\\"when\\\": [\\\"(step | int) == 1\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Disable tripleo-iptables.service\\\", \\\"systemd\\\": {\\\"name\\\": \\\"tripleo-iptables.service\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": false}, \\\"register\\\": \\\"systemd_tripleo_iptables\\\", \\\"failed_when\\\": false}, {\\\"name\\\": \\\"Cleanup tripleo-iptables.services\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/systemd/system/tripleo-iptables.service\\\", \\\"state\\\": \\\"absent\\\"}}, {\\\"name\\\": \\\"Disable tripleo-ip6tables.service\\\", \\\"systemd\\\": {\\\"name\\\": \\\"tripleo-ip6tables.service\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": false}, \\\"register\\\": \\\"systemd_tripleo_ip6tables\\\", \\\"failed_when\\\": false}, {\\\"name\\\": \\\"Cleanup tripleo-ip6tables.services\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/systemd/system/tripleo-ip6tables.service\\\", \\\"state\\\": \\\"absent\\\"}}, {\\\"name\\\": \\\"Reload systemd\\\", \\\"systemd\\\": {\\\"daemon_reload\\\": true}, \\\"when\\\": [\\\"(systemd_tripleo_iptables is changed or systemd_tripleo_ip6tables is changed)\\\"]}]}, {\\\"when\\\": [\\\"(step | int) == 3\\\"], \\\"block\\\": [{\\\"name\\\": \\\"blank ipv6 rule before activating ipv6 firewall.\\\", \\\"shell\\\": \\\"cat /etc/sysconfig/ip6tables > /etc/sysconfig/ip6tables.n-o-upgrade; cat</dev/null>/etc/sysconfig/ip6tables\\\", \\\"args\\\": {\\\"creates\\\": \\\"/etc/sysconfig/ip6tables.n-o-upgrade\\\"}}, {\\\"name\\\": \\\"cleanup unmanaged rules pushed by iptables-services\\\", \\\"shell\\\": \\\"iptables -C INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT &>/dev/null && \\\\\\\\\\\\n  iptables -D INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT\\\\niptables -C INPUT -p icmp -j ACCEPT &>/dev/null && \\\\\\\\\\\\n  iptables -D INPUT -p icmp -j ACCEPT\\\\niptables -C INPUT -i lo -j ACCEPT &>/dev/null && \\\\\\\\\\\\n  iptables -D INPUT -i lo -j ACCEPT\\\\niptables -C INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT &>/dev/null && \\\\\\\\\\\\n  iptables -D INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT\\\\niptables -C INPUT -j REJECT --reject-with icmp-host-prohibited &>/dev/null && \\\\\\\\\\\\n  iptables -D INPUT -j REJECT --reject-with icmp-host-prohibited\\\\niptables -C FORWARD -j REJECT --reject-with icmp-host-prohibited &>/dev/null && \\\\\\\\\\\\n  iptables -D FORWARD -j REJECT --reject-with icmp-host-prohibited\\\\n\\\\nsed -i \'/^-A INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT$/d\' /etc/sysconfig/iptables\\\\nsed -i \'/^-A INPUT -p icmp -j ACCEPT$/d\' /etc/sysconfig/iptables\\\\nsed -i \'/^-A INPUT -i lo -j ACCEPT$/d\' /etc/sysconfig/iptables\\\\nsed -i \'/^-A INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT$/d\' /etc/sysconfig/iptables\\\\nsed -i \'/^-A INPUT -j REJECT --reject-with icmp-host-prohibited$/d\' /etc/sysconfig/iptables\\\\nsed -i \'/^-A FORWARD -j REJECT --reject-with icmp-host-prohibited$/d\' /etc/sysconfig/iptables\\\\n\\\\nip6tables -C INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT &>/dev/null && \\\\\\\\\\\\n  ip6tables -D INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT\\\\nip6tables -C INPUT -p ipv6-icmp -j ACCEPT &>/dev/null && \\\\\\\\\\\\n  ip6tables -D INPUT -p ipv6-icmp -j ACCEPT\\\\nip6tables -C INPUT -i lo -j ACCEPT &>/dev/null && \\\\\\\\\\\\n  ip6tables -D INPUT -i lo -j ACCEPT\\\\nip6tables -C INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT &>/dev/null && \\\\\\\\\\\\n  ip6tables -D INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT\\\\nip6tables -C INPUT -d fe80::/64 -p udp -m udp --dport 546 -m state --state NEW -j ACCEPT &>/dev/null && \\\\\\\\\\\\n  ip6tables -D INPUT -d fe80::/64 -p udp -m udp --dport 546 -m state --state NEW -j ACCEPT\\\\nip6tables -C INPUT -j REJECT --reject-with icmp6-adm-prohibited &>/dev/null && \\\\\\\\\\\\n  ip6tables -D INPUT -j REJECT --reject-with icmp6-adm-prohibited\\\\nip6tables -C FORWARD -j REJECT --reject-with icmp6-adm-prohibited &>/dev/null && \\\\\\\\\\\\n  ip6tables -D FORWARD -j REJECT --reject-with icmp6-adm-prohibited\\\\n\\\\nsed -i \'/^-A INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\\\nsed -i \'/^-A INPUT -p ipv6-icmp -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\\\nsed -i \'/^-A INPUT -i lo -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\\\nsed -i \'/^-A INPUT -p tcp -m state --state NEW -m tcp --dport 22 -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\\\nsed -i \'/^-A INPUT -d fe80::\\\\\\\\/64 -p udp -m udp --dport 546 -m state --state NEW -j ACCEPT$/d\' /etc/sysconfig/ip6tables\\\\nsed -i \'/^-A INPUT -j REJECT --reject-with icmp6-adm-prohibited$/d\' /etc/sysconfig/ip6tables\\\\nsed -i \'/^-A FORWARD -j REJECT --reject-with icmp6-adm-prohibited$/d\' /etc/sysconfig/ip6tables\\\"}]}]}, {\\\"service_name\\\": \\\"tripleo_packages\\\", \\\"config_settings\\\": {\\\"tripleo::packages::enable_install\\\": true}, \\\"step_config\\\": \\\"include ::tripleo::packages\\\\n\\\", \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"Gather missing facts\\\", \\\"setup\\\": {\\\"gather_subset\\\": [\\\"!all\\\", \\\"!min\\\", \\\"distribution\\\"]}, \\\"tags\\\": [\\\"always\\\"]}, {\\\"name\\\": \\\"Set leapp facts\\\", \\\"set_fact\\\": {\\\"upgrade_leapp_enabled\\\": \\\"{{ _upgradeLeappEnabled | bool and\\\\n   ansible_facts[\'distribution\'] == \'RedHat\' and\\\\n   ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\') }}\\\", \\\"upgrade_leapp_debug\\\": false, \\\"upgrade_leapp_devel_skip\\\": \\\"\\\", \\\"upgrade_leapp_command_options\\\": \\\"\\\", \\\"upgrade_leapp_reboot_timeout\\\": 3600, \\\"upgrade_leapp_post_reboot_delay\\\": 120}, \\\"vars\\\": {\\\"_upgradeLeappEnabled\\\": false}, \\\"tags\\\": [\\\"always\\\"]}, {\\\"name\\\": \\\"system_upgrade_prepare step 3\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade\\\", \\\"system_upgrade_prepare\\\"], \\\"when\\\": [\\\"step|int == 3\\\", \\\"upgrade_leapp_enabled\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Run LeappRepoInitCommand\\\", \\\"shell\\\": \\\"#!/bin/bash\\\\n\\\\n\\\"}, {\\\"name\\\": \\\"Remove firewalld bindings\\\", \\\"package\\\": {\\\"name\\\": \\\"python3-firewall\\\", \\\"state\\\": \\\"absent\\\"}}, {\\\"name\\\": \\\"install leapp\\\", \\\"package\\\": {\\\"name\\\": \\\"leapp-repository-openstack\\\", \\\"state\\\": \\\"latest\\\"}}, {\\\"name\\\": \\\"Run LeappInitCommand\\\", \\\"shell\\\": \\\"#!/bin/bash\\\\n\\\\n\\\"}, {\\\"name\\\": \\\"Remove vdo\\\", \\\"package\\\": {\\\"name\\\": \\\"vdo\\\", \\\"state\\\": \\\"absent\\\"}}, {\\\"name\\\": \\\"add packages into Leapp\'s to_remove file\\\", \\\"vars\\\": {\\\"pkg_to_remove\\\": []}, \\\"lineinfile\\\": {\\\"path\\\": \\\"/etc/leapp/transaction/to_remove\\\", \\\"line\\\": \\\"{{ item }}\\\"}, \\\"loop\\\": \\\"{{ pkg_to_remove }}\\\"}, {\\\"name\\\": \\\"add packages into Leapp\'s to_install file\\\", \\\"vars\\\": {\\\"pkg_to_install\\\": []}, \\\"lineinfile\\\": {\\\"path\\\": \\\"/etc/leapp/transaction/to_install\\\", \\\"line\\\": \\\"{{ item }}\\\"}, \\\"loop\\\": \\\"{{ pkg_to_install }}\\\"}, {\\\"name\\\": \\\"check sshd_config file\\\", \\\"stat\\\": {\\\"path\\\": \\\"/etc/ssh/sshd_config\\\"}, \\\"register\\\": \\\"sshd_config_result\\\"}, {\\\"name\\\": \\\"add PermitRootLogin option for leapp\\\", \\\"lineinfile\\\": {\\\"path\\\": \\\"/etc/ssh/sshd_config\\\", \\\"regexp\\\": \\\"^(# *)?PermitRootLogin\\\", \\\"line\\\": \\\"PermitRootLogin without-password\\\"}}, {\\\"name\\\": \\\"Remove paunch-services\\\", \\\"package\\\": {\\\"name\\\": \\\"paunch-services\\\", \\\"state\\\": \\\"absent\\\"}}, {\\\"name\\\": \\\"tripleo_container_manage reconfiguration\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_container_manage\\\", \\\"tasks_from\\\": \\\"shutdown.yml\\\"}}]}, {\\\"name\\\": \\\"system_upgrade_prepare step 4\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade\\\", \\\"system_upgrade_prepare\\\"], \\\"when\\\": [\\\"step|int == 4\\\", \\\"upgrade_leapp_enabled\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Delete the kernel modules in Leapp database (device_driver_deprecation_data.json)\\\", \\\"vars\\\": {\\\"modules_to_unload\\\": []}, \\\"shell\\\": \\\"set -o pipefail && jq \'. | del(.data[] | select(.driver_name == \\\\\\\"{{ item }}\\\\\\\"))\' /etc/leapp/files/device_driver_deprecation_data.json > /etc/leapp/files/device_driver_deprecation_data.json_modified && mv /etc/leapp/files/device_driver_deprecation_data.json_modified /etc/leapp/files/device_driver_deprecation_data.json\\\\n\\\", \\\"loop\\\": \\\"{{ modules_to_unload }}\\\"}, {\\\"name\\\": \\\"Remove leapp actors to prevent them inhibiting the upgrade\\\", \\\"vars\\\": {\\\"actors_to_remove\\\": []}, \\\"command\\\": {\\\"cmd\\\": \\\"find /usr/share/leapp-repository/repositories/ -name {{ item }} -type d -print -exec rm -rf \\\\\\\"{}\\\\\\\" +\\\"}, \\\"loop\\\": \\\"{{ actors_to_remove }}\\\"}, {\\\"name\\\": \\\"set leapp required answers\\\", \\\"shell\\\": \\\"leapp answer --add --section check_vdo.confirm=True\\\\n\\\"}, {\\\"name\\\": \\\"Replace EFI grub.cfg with redirect to /boot/grub2/grub.cfg\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_kernel\\\", \\\"tasks_from\\\": \\\"efigrub.yml\\\"}}, {\\\"name\\\": \\\"Keep nics with prefix in NICsPrefixesToUdev from renaming\\\", \\\"vars\\\": {\\\"nics_prefixes_to_keep\\\": []}, \\\"shell\\\": \\\"ip -j link show | \\\\\\\\ jq -r --arg prefix \\\\\\\"{{ item }}\\\\\\\" \'.[] |\\\\n  select((.ifname | startswith($prefix)) and\\\\n  (.ifname | test(\\\\\\\"^.*v[0-9]*$\\\\\\\") | not) and\\\\n  (.ifname | test(\\\\\\\"^.*_[0-9]*$\\\\\\\") | not) and\\\\n  (.ifname | test(\\\\\\\"^.*\\\\\\\\\\\\\\\\..*$\\\\\\\") | not)) |\\\\n  if .permaddr? then .address=.permaddr else . end |\\\\n  \\\\\\\"SUBSYSTEM==\\\\\\\\\\\\\\\"net\\\\\\\\\\\\\\\",ACTION==\\\\\\\\\\\\\\\"add\\\\\\\\\\\\\\\",DRIVERS==\\\\\\\\\\\\\\\"?*\\\\\\\\\\\\\\\",\\\\\\\" + \\\\\\\"NAME=\\\\\\\\\\\\\\\"\\\\\\\" + .ifname +\\\\\\\"\\\\\\\\\\\\\\\" ,ATTR{address}==\\\\\\\\\\\\\\\"\\\\\\\" + .address + \\\\\\\"\\\\\\\\\\\\\\\"\\\\\\\"\' >> /etc/udev/rules.d/70-rhosp-persistent-net.rules\\\\n\\\", \\\"loop\\\": \\\"{{ nics_prefixes_to_keep|list }}\\\"}, {\\\"name\\\": \\\"run leapp upgrade (download packages)\\\", \\\"shell\\\": \\\"{% if upgrade_leapp_devel_skip|default(false) %}{{ upgrade_leapp_devel_skip }}{% endif %} leapp upgrade {% if upgrade_leapp_debug|default(true) %}--debug{% endif %} {% if upgrade_leapp_command_options|default(false) %}{{ upgrade_leapp_command_options }}{% endif %}\\\\n\\\", \\\"when\\\": \\\"upgrade_leapp_enabled\\\"}]}, {\\\"name\\\": \\\"system_upgrade_run step 4\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade\\\", \\\"system_upgrade_run\\\", \\\"system_upgrade_reboot\\\"], \\\"when\\\": [\\\"step|int == 4\\\", \\\"upgrade_leapp_enabled\\\", \\\"\'Undercloud\' not in group_names\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Run LeappPreRebootCommand\\\", \\\"shell\\\": \\\"#!/bin/bash\\\\n\\\\n\\\"}, {\\\"name\\\": \\\"Check that nova_libvirt is running\\\", \\\"shell\\\": \\\"podman ps --filter name=^nova_virtlogd$ --format \\\\\\\"{% raw %}{{ .Image }}{% endraw %}\\\\\\\"\\\\n\\\", \\\"register\\\": \\\"is_virtlogd_image_running\\\"}, {\\\"name\\\": \\\"Remove systemd files to disable them\\\", \\\"file\\\": {\\\"path\\\": \\\"/etc/systemd/system/{{ item }}\\\", \\\"state\\\": \\\"absent\\\"}, \\\"with_items\\\": [\\\"tripleo_nova_libvirt.service\\\", \\\"tripleo_nova_virtlogd_wrapper.service\\\", \\\"tripleo_nova_libvirt.target\\\"], \\\"when\\\": \\\"is_virtlogd_image_running.stdout != \'\'\\\"}, {\\\"name\\\": \\\"reboot to perform the upgrade\\\", \\\"reboot\\\": {\\\"reboot_timeout\\\": \\\"{{upgrade_leapp_reboot_timeout}}\\\", \\\"test_command\\\": \\\"source /etc/os-release; [ \\\\\\\"${VERSION_ID%.*}\\\\\\\" -ge \\\\\\\"8\\\\\\\" ] && systemctl is-system-running | grep -qE \\\\\\\"running|degraded\\\\\\\" || exit 1\\\", \\\"post_reboot_delay\\\": \\\"{{ upgrade_leapp_post_reboot_delay }}\\\"}}, {\\\"name\\\": \\\"Set selinux back to enforcing after leapp reboot\\\", \\\"selinux\\\": {\\\"policy\\\": \\\"targeted\\\", \\\"state\\\": \\\"enforcing\\\"}}, {\\\"name\\\": \\\"Run LeappPostRebootCommand\\\", \\\"shell\\\": \\\"#!/bin/bash\\\\n\\\\n\\\"}]}, {\\\"name\\\": \\\"Host packages setup step0\\\", \\\"tags\\\": \\\"setup_packages\\\", \\\"when\\\": \\\"step|int == 0\\\", \\\"block\\\": [{\\\"name\\\": \\\"Package and repo update tasks\\\", \\\"block\\\": [{\\\"name\\\": \\\"Run UpgradeInitCommand\\\", \\\"shell\\\": \\\"#!/bin/bash\\\\n\\\\nif [[ -f /etc/resolv.conf.save ]] ; then rm /etc/resolv.conf.save; fi\\\\n\\\\n\\\"}, {\\\"name\\\": \\\"Run UpgradeInitCommonCommand\\\", \\\"shell\\\": \\\"#!/bin/bash\\\\n\\\\n\\\"}, {\\\"name\\\": \\\"Ensure DNF modules have the right stream\\\", \\\"vars\\\": {\\\"dnf_module_list\\\": []}, \\\"dnf\\\": {\\\"name\\\": \\\"@{{ item.module }}:{{ item.stream }}/{{ item.profile|default(\'common\') }}\\\", \\\"state\\\": \\\"present\\\"}, \\\"loop\\\": \\\"{{ dnf_module_list|list }}\\\", \\\"when\\\": [\\\"dnf_module_list|length > 0\\\", \\\"item.distribution_version is defined\\\", \\\"ansible_facts[\'distribution_major_version\'] is version(item.distribution_version, \'==\')\\\"]}, {\\\"name\\\": \\\"Ensure TripleO prerequisite packages are installed\\\", \\\"package\\\": {\\\"name\\\": [\\\"jq\\\", \\\"lvm2\\\", \\\"openstack-selinux\\\", \\\"os-net-config\\\", \\\"puppet-tripleo\\\", \\\"python3-heat-agent*\\\", \\\"rsync\\\"], \\\"state\\\": \\\"present\\\"}, \\\"when\\\": \\\"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\\\"}, {\\\"name\\\": \\\"Ensure TripleO prerequisite packages are installed and use role based heat variable to provide specific list of packages\\\", \\\"vars\\\": {\\\"base_tripleo_packages\\\": []}, \\\"package\\\": {\\\"name\\\": \\\"{{ base_tripleo_packages }}\\\", \\\"state\\\": \\\"present\\\"}, \\\"when\\\": [\\\"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\\\", \\\"base_tripleo_packages|length > 0\\\"]}, {\\\"name\\\": \\\"WA for 2240185 - If the image is schema 1 and lacks signatures than add empty signatures\\\", \\\"shell\\\": \\\"for manifest_file in `find /var/lib/containers/storage/overlay-images/ -name \'manifest\'`\\\\ndo\\\\n    cat <<< $( jq  \'if .schemaVersion == 1 then if has(\\\\\\\"signatures\\\\\\\") then . else .signatures=[] end else . end\' $manifest_file ) > $manifest_file\\\\ndone\\\\n\\\", \\\"when\\\": \\\"ansible_facts[\'distribution_major_version\'] is version(\'8\', \'==\')\\\"}]}, {\\\"name\\\": \\\"check if libvirt is installed\\\", \\\"command\\\": \\\"/usr/bin/rpm -q libvirt-daemon\\\", \\\"failed_when\\\": false, \\\"register\\\": \\\"libvirt_installed\\\", \\\"check_mode\\\": false}, {\\\"name\\\": \\\"make sure libvirt services are disabled and masked\\\", \\\"service\\\": {\\\"name\\\": \\\"{{ item }}\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": false, \\\"masked\\\": true, \\\"daemon_reload\\\": true}, \\\"loop\\\": [\\\"libvirtd.service\\\", \\\"virtlogd.socket\\\"], \\\"when\\\": [\\\"libvirt_installed.rc == 0\\\"]}]}, {\\\"name\\\": \\\"Host packages setup step2\\\", \\\"tags\\\": \\\"setup_packages\\\", \\\"when\\\": \\\"step|int == 2\\\", \\\"block\\\": [{\\\"name\\\": \\\"Special treatment for OpenvSwitch\\\", \\\"tripleo_ovs_upgrade\\\": null, \\\"register\\\": \\\"ovs_upgrade\\\"}, {\\\"name\\\": \\\"Always ensure the openvswitch service is enabled and running after upgrades\\\", \\\"service\\\": {\\\"name\\\": \\\"openvswitch\\\", \\\"enabled\\\": true, \\\"state\\\": \\\"started\\\"}, \\\"when\\\": [\\\"ovs_upgrade.changed|bool\\\"]}]}, {\\\"name\\\": \\\"Host packages setup step3\\\", \\\"tags\\\": \\\"setup_packages\\\", \\\"when\\\": \\\"step|int == 3\\\", \\\"block\\\": [{\\\"name\\\": \\\"Check for os-net-config upgrade\\\", \\\"shell\\\": \\\"yum check-upgrade | awk \'/os-net-config/{print}\'\\\", \\\"register\\\": \\\"os_net_config_need_upgrade\\\"}, {\\\"name\\\": \\\"Check that os-net-config has legacy configuration\\\", \\\"stat\\\": {\\\"path\\\": \\\"/etc/os-net-config/config.json\\\", \\\"get_attributes\\\": false, \\\"get_checksum\\\": false, \\\"get_mime\\\": false}, \\\"register\\\": \\\"stat_config_json\\\"}, {\\\"name\\\": \\\"Check that os-net-config has new configuration\\\", \\\"stat\\\": {\\\"path\\\": \\\"/etc/os-net-config/config.yaml\\\", \\\"get_attributes\\\": false, \\\"get_checksum\\\": false, \\\"get_mime\\\": false}, \\\"register\\\": \\\"stat_config_yaml\\\"}, {\\\"name\\\": \\\"Slurp the os-net-config config.json\\\", \\\"slurp\\\": {\\\"src\\\": \\\"/etc/os-net-config/config.json\\\"}, \\\"register\\\": \\\"os_config_json\\\", \\\"when\\\": [\\\"stat_config_json.stat.exists\\\", \\\"not stat_config_yaml.stat.exists\\\"]}, {\\\"name\\\": \\\"Write updated /etc/os-net-config/config.yaml\\\", \\\"copy\\\": {\\\"content\\\": \\\"{{ os_config_json.content | b64decode | from_json | to_yaml }}\\\", \\\"dest\\\": \\\"/etc/os-net-config/config.yaml\\\"}, \\\"when\\\": [\\\"stat_config_json.stat.exists\\\", \\\"not stat_config_yaml.stat.exists\\\"]}, {\\\"name\\\": \\\"Remove legacy os-net-config configuration\\\", \\\"command\\\": \\\"mv /etc/os-net-config/config.json /etc/os-net-config/deprecated_config.json\\\", \\\"when\\\": [\\\"stat_config_json.stat.exists\\\"]}, {\\\"block\\\": [{\\\"name\\\": \\\"Upgrade os-net-config\\\", \\\"package\\\": \\\"name=os-net-config state=latest\\\"}, {\\\"name\\\": \\\"take new os-net-config parameters into account now\\\", \\\"command\\\": \\\"os-net-config --no-activate -c /etc/os-net-config/config.yaml -v --detailed-exit-codes\\\", \\\"register\\\": \\\"os_net_config_upgrade\\\", \\\"failed_when\\\": \\\"os_net_config_upgrade.rc not in [0,2]\\\", \\\"changed_when\\\": \\\"os_net_config_upgrade.rc == 2\\\"}], \\\"when\\\": [\\\"os_net_config_need_upgrade.stdout\\\", \\\"stat_config_yaml.stat.exists or stat_config_json.stat.exists\\\"]}, {\\\"name\\\": \\\"Update all packages\\\", \\\"when\\\": [\\\"not skip_package_update|bool\\\"], \\\"yum\\\": {\\\"name\\\": \\\"*\\\", \\\"state\\\": \\\"latest\\\", \\\"exclude\\\": \\\"ansible-core\\\"}, \\\"vars\\\": {\\\"skip_package_update\\\": false}}, {\\\"name\\\": \\\"Check whether openvswitch exits\\\", \\\"command\\\": \\\"systemctl status openvswitch.service\\\", \\\"register\\\": \\\"ovs_service\\\", \\\"ignore_errors\\\": true}, {\\\"name\\\": \\\"Always ensure the openvswitch service is enabled and running after upgrades rhbz#2329821\\\", \\\"service\\\": {\\\"name\\\": \\\"openvswitch\\\", \\\"enabled\\\": true, \\\"state\\\": \\\"started\\\"}, \\\"when\\\": [\\\"ovs_service.stderr != \\\\\\\"Unit openvswitch.service could not be found.\\\\\\\"\\\"]}]}], \\\"external_upgrade_tasks\\\": [{\\\"name\\\": \\\"Clean up upgrade artifacts\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"tags\\\": [\\\"never\\\", \\\"system_upgrade_cleanup\\\"], \\\"block\\\": [{\\\"name\\\": \\\"cleanup tripleo_persist\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_persist\\\", \\\"tasks_from\\\": \\\"cleanup.yml\\\"}}]}], \\\"update_tasks\\\": [{\\\"name\\\": \\\"Enforce RHOSP rules regarding subscription.\\\", \\\"include_role\\\": {\\\"name\\\": \\\"tripleo_redhat_enforce\\\"}, \\\"vars\\\": {\\\"skip_rhel_enforcement\\\": false}, \\\"when\\\": [\\\"step|int == 0\\\", \\\"ansible_facts[\'distribution\'] == \'RedHat\'\\\", \\\"not (skip_rhel_enforcement | bool)\\\"]}, {\\\"name\\\": \\\"Ensure DNF modules have the right stream enabled\\\", \\\"vars\\\": {\\\"dnf_module_list\\\": []}, \\\"tripleo_dnf_stream\\\": {\\\"name\\\": \\\"{{ item.module }}:{{ item.stream }}\\\", \\\"state\\\": \\\"enabled\\\"}, \\\"loop\\\": \\\"{{ dnf_module_list|list }}\\\", \\\"when\\\": [\\\"step|int == 0\\\", \\\"dnf_module_list|length > 0\\\", \\\"item.distribution_version is defined\\\", \\\"ansible_facts[\'distribution_major_version\'] is version(item.distribution_version, \'==\')\\\"]}, {\\\"name\\\": \\\"Check for existing yum.pid\\\", \\\"stat\\\": \\\"path=/run/yum.pid\\\", \\\"register\\\": \\\"yum_pid_file\\\", \\\"when\\\": \\\"step|int == 0 or step|int == 3\\\"}, {\\\"name\\\": \\\"Exit if existing yum process\\\", \\\"fail\\\": \\\"msg=\\\\\\\"ERROR existing yum.pid detected - can\'t continue! Please ensure there is no other package update process for the duration of the minor update worfklow. Exiting.\\\\\\\"\\\", \\\"when\\\": \\\"(step|int == 0 or step|int == 3) and yum_pid_file.stat.exists\\\"}, {\\\"name\\\": \\\"Special treatment for OpenvSwitch\\\", \\\"tripleo_ovs_upgrade\\\": null, \\\"when\\\": [\\\"step|int == 2\\\"], \\\"register\\\": \\\"ovs_upgrade\\\"}, {\\\"name\\\": \\\"Always ensure the openvswitch service is enabled and running after upgrades\\\", \\\"service\\\": {\\\"name\\\": \\\"openvswitch\\\", \\\"enabled\\\": true, \\\"state\\\": \\\"started\\\"}, \\\"when\\\": [\\\"step|int == 2\\\", \\\"ovs_upgrade.changed|bool\\\"]}, {\\\"name\\\": \\\"Update packages and EFI grub.cfg\\\", \\\"when\\\": [\\\"step|int == 3\\\", \\\"not skip_package_update|bool\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Update all packages\\\", \\\"yum\\\": {\\\"name\\\": \\\"*\\\", \\\"state\\\": \\\"latest\\\", \\\"exclude\\\": \\\"ansible-core\\\"}}, {\\\"name\\\": \\\"Replace EFI grub.cfg with redirect to /boot/grub2/grub.cfg\\\", \\\"import_role\\\": {\\\"name\\\": \\\"tripleo_kernel\\\", \\\"tasks_from\\\": \\\"efigrub.yml\\\"}}], \\\"vars\\\": {\\\"skip_package_update\\\": false}}, {\\\"name\\\": \\\"Ensure openvswitch is running after update\\\", \\\"when\\\": \\\"step|int == 3\\\", \\\"service\\\": {\\\"name\\\": \\\"openvswitch\\\", \\\"enabled\\\": true, \\\"state\\\": \\\"started\\\"}, \\\"ignore_errors\\\": true}]}, {\\\"service_name\\\": \\\"tuned\\\", \\\"host_prep_tasks\\\": [{\\\"include_role\\\": {\\\"name\\\": \\\"tuned\\\"}}], \\\"ansible_group_vars\\\": {\\\"tuned_profile\\\": \\\"throughput-performance\\\", \\\"tuned_custom_profile\\\": \\\"\\\"}}, {\\\"service_name\\\": \\\"ovn_controller\\\", \\\"firewall_rules\\\": {\\\"118 neutron vxlan networks\\\": {\\\"proto\\\": \\\"udp\\\", \\\"dport\\\": 4789, \\\"state\\\": []}, \\\"119 neutron geneve networks\\\": {\\\"proto\\\": \\\"udp\\\", \\\"dport\\\": 6081, \\\"state\\\": []}, \\\"120 neutron geneve networks no conntrack\\\": {\\\"proto\\\": \\\"udp\\\", \\\"dport\\\": 6081, \\\"table\\\": \\\"raw\\\", \\\"chain\\\": \\\"OUTPUT\\\", \\\"jump\\\": \\\"NOTRACK\\\", \\\"action\\\": \\\"append\\\", \\\"state\\\": [\\\"INVALID\\\"]}, \\\"121 neutron geneve networks no conntrack\\\": {\\\"proto\\\": \\\"udp\\\", \\\"dport\\\": 6081, \\\"table\\\": \\\"raw\\\", \\\"chain\\\": \\\"PREROUTING\\\", \\\"jump\\\": \\\"NOTRACK\\\", \\\"action\\\": \\\"append\\\", \\\"state\\\": [\\\"INVALID\\\"]}}, \\\"config_settings\\\": {\\\"ovn::controller::ovn_bridge_mappings\\\": [\\\"datacentre:br-ex\\\"], \\\"ovn::controller::ovn_cms_options\\\": \\\"\\\", \\\"ovn::controller::ovn_encap_tos\\\": \\\"0\\\", \\\"vswitch::ovs::enable_hw_offload\\\": false, \\\"container_cpuset_cpus\\\": \\\"\\\", \\\"ContainerOvnControllerImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\\\", \\\"ContainerOvnControllerConfigImage\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\\\", \\\"ovn::southbound::port\\\": 6642, \\\"ovn::controller::ovn_encap_ip\\\": \\\"%{hiera(\'tenant\')}\\\", \\\"ovn::controller::ovn_encap_type\\\": \\\"geneve\\\", \\\"ovn::controller::ovn_bridge\\\": \\\"br-int\\\", \\\"ovn::controller::hostname\\\": \\\"%{hiera(\'fqdn_canonical\')}\\\", \\\"ovn::controller::ovn_remote_probe_interval\\\": 60000, \\\"ovn::controller::ovn_openflow_probe_interval\\\": 60, \\\"ovn::controller::ovn_ofctrl_wait_before_clear\\\": 8000, \\\"ovn::controller::garp_max_timeout_sec\\\": 0, \\\"ovn::controller::ovn_monitor_all\\\": true, \\\"tripleo::profile::base::neutron::agents::ovn::protocol\\\": \\\"ssl\\\"}, \\\"service_config_settings\\\": {}, \\\"puppet_config\\\": {\\\"puppet_tags\\\": \\\"vs_config,exec\\\", \\\"config_volume\\\": \\\"ovn_controller\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::neutron::agents::ovn\\\\n\\\", \\\"config_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\\\", \\\"volumes\\\": [\\\"/lib/modules:/lib/modules:ro\\\", \\\"/run/openvswitch:/run/openvswitch:shared,z\\\", \\\"/etc/sysconfig/modules:/etc/sysconfig/modules\\\"]}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/ovn_controller.json\\\": {\\\"command\\\": \\\"/usr/bin/ovn-controller --pidfile --log-file unix:/run/openvswitch/db.sock -p /etc/pki/tls/private/ovn_controller.key -c /etc/pki/tls/certs/ovn_controller.crt -C /etc/ipa/ca.crt\\\", \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/openvswitch\\\", \\\"owner\\\": \\\"root:root\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/var/log/ovn\\\", \\\"owner\\\": \\\"root:root\\\", \\\"recurse\\\": true}]}}, \\\"metadata_settings\\\": [{\\\"service\\\": \\\"ovn_controller\\\", \\\"network\\\": \\\"internal_api\\\", \\\"type\\\": \\\"node\\\"}], \\\"docker_config\\\": {\\\"step_4\\\": {\\\"configure_cms_options\\\": {\\\"start_order\\\": 0, \\\"detach\\\": false, \\\"net\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"user\\\": \\\"root\\\", \\\"command\\\": [\\\"/bin/bash\\\", \\\"-c\\\", \\\"CMS_OPTS=$(hiera ovn::controller::ovn_cms_options -c /etc/puppet/hiera.yaml);  if [ X\\\\\\\"$CMS_OPTS\\\\\\\" !=  X ]; then ovs-vsctl set open . external_ids:ovn-cms-options=$CMS_OPTS;else ovs-vsctl remove open . external_ids ovn-cms-options; fi\\\"], \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\\\", \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/run/openvswitch:/run/openvswitch:shared,z\\\"], \\\"environment\\\": {\\\"TRIPLEO_DEPLOY_IDENTIFIER\\\": \\\"1780992067\\\"}}, \\\"ovn_controller\\\": {\\\"start_order\\\": 1, \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\\\", \\\"net\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"user\\\": \\\"root\\\", \\\"restart\\\": \\\"always\\\", \\\"depends_on\\\": [\\\"openvswitch.service\\\"], \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck 6642\\\"}, \\\"volumes\\\": [\\\"/var/lib/kolla/config_files/ovn_controller.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/run:/run\\\", \\\"/var/lib/openvswitch/ovn:/run/ovn:shared,z\\\", \\\"/var/log/containers/openvswitch:/var/log/openvswitch:z\\\", \\\"/var/log/containers/openvswitch:/var/log/ovn:z\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/pki/tls/certs/ovn_controller.crt:/etc/pki/tls/certs/ovn_controller.crt\\\", \\\"/etc/pki/tls/private/ovn_controller.key:/etc/pki/tls/private/ovn_controller.key\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"Certificate generation\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"enable_internal_tls\\\"], \\\"block\\\": [{\\\"include_role\\\": {\\\"name\\\": \\\"linux-system-roles.certificate\\\"}, \\\"vars\\\": {\\\"certificate_requests\\\": [{\\\"name\\\": \\\"ovn_controller\\\", \\\"dns\\\": \\\"{{fqdn_internal_api}}\\\", \\\"principal\\\": \\\"ovn_controller/{{fqdn_internal_api}}@{{idm_realm}}\\\", \\\"run_after\\\": \\\"systemctl restart tripleo_ovn_controller\\\\n\\\", \\\"key_size\\\": \\\"2048\\\", \\\"ca\\\": \\\"ipa\\\"}]}}]}], \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode|default(omit) }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/openvswitch\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}, {\\\"path\\\": \\\"/var/lib/openvswitch/ovn\\\", \\\"setype\\\": \\\"container_file_t\\\"}]}, {\\\"name\\\": \\\"enable virt_sandbox_use_netlink for healthcheck\\\", \\\"seboolean\\\": {\\\"name\\\": \\\"virt_sandbox_use_netlink\\\", \\\"persistent\\\": true, \\\"state\\\": true}, \\\"when\\\": [\\\"ansible_facts.selinux is defined\\\", \\\"ansible_facts.selinux.status == \\\\\\\"enabled\\\\\\\"\\\"]}, {\\\"name\\\": \\\"Copy in cleanup script\\\", \\\"copy\\\": {\\\"content\\\": \\\"#!/usr/bin/bash\\\\n# Cleanup neutron OVS bridges. To be called on startup to avoid\\\\n# \\\\\\\"difficult-to-debug\\\\\\\" issues with partially configured resources.\\\\n\\\\nNEUTRON_OVS_CONF=/var/lib/config-data/puppet-generated/neutron/etc/neutron/plugins/ml2/openvswitch_agent.ini\\\\n\\\\nif [ -e ${NEUTRON_OVS_CONF} ];\\\\nthen\\\\n    INT_BRIDGE=`crudini --get ${NEUTRON_OVS_CONF} ovs integration_bridge`\\\\n    TUN_BRIDGE=`crudini --get ${NEUTRON_OVS_CONF} ovs tunnel_bridge`\\\\nfi\\\\n\\\\nfor port in `ovs-vsctl list-ports ${INT_BRIDGE:-\\\\\\\"br-int\\\\\\\"}`;\\\\ndo\\\\n    skip_cleanup=`ovs-vsctl --if-exists get Interface $port external_ids:skip_cleanup`\\\\n    if ! [[ \\\\\\\"x$skip_cleanup\\\\\\\" == \\\\\\\"x\\\\\\\\\\\\\\\"true\\\\\\\\\\\\\\\"\\\\\\\" ]];\\\\n    then\\\\n        ovs-vsctl del-port ${INT_BRIDGE:-\\\\\\\"br-int\\\\\\\"} $port\\\\n    fi\\\\ndone\\\\n\\\\novs-vsctl --if-exists del-br ${TUN_BRIDGE:-\\\\\\\"br-tun\\\\\\\"}\\\\n\\\\n# Clean up trunk port bridges\\\\nfor br in $(ovs-vsctl list-br | egrep \'tbr-[0-9a-f\\\\\\\\-]+\'); do\\\\n    ovs-vsctl --if-exists del-br $br\\\\ndone\\\\n\\\", \\\"dest\\\": \\\"/usr/libexec/neutron-cleanup\\\", \\\"force\\\": true, \\\"mode\\\": \\\"0755\\\"}}, {\\\"name\\\": \\\"Copy in cleanup service\\\", \\\"copy\\\": {\\\"content\\\": \\\"[Unit]\\\\nDescription=Neutron cleanup on startup\\\\nAfter=openvswitch.service network.target\\\\nBefore=tripleo_neutron_ovs_agent.service tripleo_neutron_dhcp.service tripleo_neutron_l3_agent.service tripleo_nova_compute.service\\\\nRefuseManualStop=yes\\\\n\\\\n[Service]\\\\nType=oneshot\\\\nExecStart=/usr/libexec/neutron-cleanup\\\\n\\\\n[Install]\\\\nWantedBy=multi-user.target\\\\n\\\", \\\"dest\\\": \\\"/usr/lib/systemd/system/neutron-cleanup.service\\\", \\\"force\\\": true}}, {\\\"name\\\": \\\"Enabling the cleanup service\\\", \\\"service\\\": {\\\"name\\\": \\\"neutron-cleanup\\\", \\\"enabled\\\": true}, \\\"when\\\": \\\"not (ansible_check_mode|bool)\\\"}], \\\"external_deploy_tasks\\\": [{\\\"when\\\": [\\\"step|int == 0\\\"], \\\"name\\\": \\\"ovn_controller_external_deploy_init\\\", \\\"block\\\": [{\\\"name\\\": \\\"create ovn mac address for Compute role nodes\\\", \\\"tripleo_ovn_mac_addresses\\\": {\\\"playbook_dir\\\": \\\"{{ playbook_dir }}\\\", \\\"stack_name\\\": \\\"overcloud\\\", \\\"role_name\\\": \\\"Compute\\\", \\\"server_resource_names\\\": \\\"{{ groups[\\\\\\\"Compute\\\\\\\"] }}\\\", \\\"ovn_bridge_mappings\\\": [\\\"datacentre:br-ex\\\"], \\\"ovn_static_bridge_mac_mappings\\\": {}}}]}], \\\"external_update_tasks\\\": [{\\\"name\\\": \\\"Force pull image in case image name doesn\'t change.\\\", \\\"when\\\": \\\"step|int == 1\\\", \\\"tags\\\": [\\\"ovn\\\", \\\"ovn_image\\\"], \\\"become\\\": true, \\\"loop\\\": \\\"{{ groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) }}\\\", \\\"delegate_to\\\": \\\"{{ item }}\\\", \\\"async\\\": 600, \\\"poll\\\": 0, \\\"register\\\": \\\"ovn_controller_image_update\\\", \\\"containers.podman.podman_image\\\": {\\\"name\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\\\", \\\"validate_certs\\\": false, \\\"force\\\": true}}, {\\\"name\\\": \\\"Was the ovn_controller image pull successful.\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"\'results\' in ovn_controller_image_update\\\"], \\\"tags\\\": [\\\"ovn\\\", \\\"ovn_image\\\"], \\\"become\\\": true, \\\"delegate_to\\\": \\\"{{ async_result_item.item }}\\\", \\\"async_status\\\": {\\\"jid\\\": \\\"{{ async_result_item.ansible_job_id }}\\\"}, \\\"loop\\\": \\\"{{ovn_controller_image_update.results }}\\\", \\\"loop_control\\\": {\\\"loop_var\\\": \\\"async_result_item\\\"}, \\\"register\\\": \\\"async_poll_results\\\", \\\"until\\\": \\\"async_poll_results.finished\\\", \\\"retries\\\": 600, \\\"delay\\\": 1}, {\\\"name\\\": \\\"OVN Container image used\\\", \\\"debug\\\": {\\\"msg\\\": \\\"ovn container will be using {{ image }}\\\"}, \\\"vars\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\\\"}, \\\"when\\\": \\\"step|int == 1\\\", \\\"tags\\\": \\\"ovn\\\"}, {\\\"name\\\": \\\"Update OVN OVS related parameters before update.\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"tags\\\": [\\\"ovn\\\"], \\\"become\\\": true, \\\"vars\\\": {\\\"timeout\\\": 8000}, \\\"shell\\\": \\\"set -e\\\\novs-vsctl set Open_vSwitch . external_ids:ovn-ofctrl-wait-before-clear={{ timeout }}\\\\novs-vsctl set Open_vSwitch . external_ids:ovn-monitor-all=true\\\\novs-vsctl set Open_vSwitch . external_ids:ovn-match-northd-version=false\\\\n\\\", \\\"async\\\": 600, \\\"poll\\\": 0, \\\"register\\\": \\\"ovs_vsctl\\\", \\\"loop\\\": \\\"{{ groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) }}\\\", \\\"delegate_to\\\": \\\"{{ item }}\\\"}, {\\\"name\\\": \\\"Was the update of OVN OVS related parameter successful.\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"\'results\' in ovs_vsctl\\\"], \\\"become\\\": true, \\\"tags\\\": [\\\"ovn\\\"], \\\"delegate_to\\\": \\\"{{ async_result_item.item }}\\\", \\\"async_status\\\": {\\\"jid\\\": \\\"{{ async_result_item.ansible_job_id }}\\\"}, \\\"loop\\\": \\\"{{ovs_vsctl.results }}\\\", \\\"loop_control\\\": {\\\"loop_var\\\": \\\"async_result_item\\\"}, \\\"register\\\": \\\"async_poll_results\\\", \\\"until\\\": \\\"async_poll_results.finished\\\", \\\"retries\\\": 600, \\\"delay\\\": 1}, {\\\"set_fact\\\": {\\\"any_ovn_host\\\": \\\"{{groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) | first }}\\\"}, \\\"tags\\\": \\\"ovn\\\", \\\"when\\\": \\\"step|int == 1\\\"}, {\\\"name\\\": \\\"Find ovn_controller configs in container-startup-configs\\\", \\\"find\\\": {\\\"paths\\\": \\\"/var/lib/tripleo-config/container-startup-config/\\\", \\\"patterns\\\": \\\"*ovn_controller.json\\\", \\\"recurse\\\": true}, \\\"register\\\": \\\"ovn_cont_17_0\\\", \\\"delegate_to\\\": \\\"{{ any_ovn_host }}\\\", \\\"when\\\": \\\"(step|int == 1) and (any_ovn_host is defined) and (any_ovn_host|length > 0)\\\", \\\"tags\\\": [\\\"ovn\\\"], \\\"become\\\": true}, {\\\"name\\\": \\\"get directory path from the ovn_cont_17_0\\\", \\\"set_fact\\\": {\\\"ovn_config_path\\\": \\\"{{ ovn_cont_17_0.files.0.path | dirname }}\\\"}, \\\"when\\\": \\\"step|int == 1\\\", \\\"tags\\\": \\\"ovn\\\"}, {\\\"name\\\": \\\"Get PIDfile used by systemd on each ovn node\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"tags\\\": [\\\"ovn\\\"], \\\"become\\\": true, \\\"shell\\\": \\\"set -e\\\\ngrep PID /etc/systemd/system/tripleo_ovn_controller.service | cut -d= -f2\\\\n\\\", \\\"register\\\": \\\"pidfile\\\", \\\"loop\\\": \\\"{{ groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) }}\\\", \\\"delegate_to\\\": \\\"{{ item }}\\\"}, {\\\"name\\\": \\\"Update ovn_controller.\\\", \\\"vars\\\": {\\\"config_step\\\": \\\"{{ (\'step_4\' in ovn_config_path) | ternary(\'4\', \'3\')}}\\\", \\\"query\\\": \\\"results[?item == \'{{item}}\'].stdout\\\"}, \\\"when\\\": \\\"step|int == 1\\\", \\\"tags\\\": \\\"ovn\\\", \\\"become\\\": true, \\\"loop\\\": \\\"{{ groups[\'ovn_controller\'] | difference(groups[\'excluded_overcloud\']) }}\\\", \\\"delegate_to\\\": \\\"{{ item }}\\\", \\\"async\\\": 600, \\\"poll\\\": 0, \\\"register\\\": \\\"ovn_controller_update\\\", \\\"tripleo_container_manage\\\": {\\\"config_dir\\\": \\\"{{ ovn_config_path }}\\\", \\\"config_patterns\\\": \\\"*ovn_controller.json\\\", \\\"config_id\\\": [\\\"tripleo_step{{config_step}}\\\"], \\\"log_base_path\\\": \\\"{{ container_log_stdout_path }}\\\", \\\"debug\\\": \\\"{{ enable_debug | bool }}\\\", \\\"config_overrides\\\": {\\\".*ovn_controller\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\\\", \\\"conmon_pidfile\\\": \\\"{{ pidfile | json_query(query) | first }}\\\", \\\"name\\\": \\\"ovn_controller\\\"}}}}, {\\\"name\\\": \\\"Was the ovn_controller successful.\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"\'results\' in ovn_controller_update\\\"], \\\"tags\\\": \\\"ovn\\\", \\\"become\\\": true, \\\"delegate_to\\\": \\\"{{ async_result_item.item }}\\\", \\\"async_status\\\": {\\\"jid\\\": \\\"{{ async_result_item.ansible_job_id }}\\\"}, \\\"loop\\\": \\\"{{ovn_controller_update.results }}\\\", \\\"loop_control\\\": {\\\"loop_var\\\": \\\"async_result_item\\\"}, \\\"register\\\": \\\"async_poll_results\\\", \\\"until\\\": \\\"async_poll_results.finished\\\", \\\"retries\\\": 600, \\\"delay\\\": 1}, {\\\"name\\\": \\\"Pause for 30s to give ovn_controllers time to reconnect to dbs\\\", \\\"when\\\": [\\\"step|int == 1\\\"], \\\"tags\\\": \\\"ovn\\\", \\\"wait_for\\\": {\\\"timeout\\\": 30}}], \\\"upgrade_tasks\\\": [{\\\"name\\\": \\\"Fetch running ovn_controller image\\\", \\\"shell\\\": \\\"set -e\\\\npodman inspect --format \\\\\\\"{{\'{{\'}}.ImageName{{\'}}\'}}\\\\\\\" ovn_controller\\\\n\\\", \\\"register\\\": \\\"running_ovn_image\\\", \\\"when\\\": [\\\"step|int == 4\\\"], \\\"tags\\\": [\\\"ovn\\\", \\\"ovn_image\\\"]}, {\\\"name\\\": \\\"Run ovn_controller upgrade\\\", \\\"tags\\\": [\\\"ovn\\\", \\\"ovn_image\\\"], \\\"vars\\\": {\\\"ovn_controller_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\\\"}, \\\"when\\\": [\\\"step|int == 4\\\", \\\"running_ovn_image.stdout != ovn_controller_image\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Force pull image in case image name doesn\'t change.\\\", \\\"when\\\": \\\"step|int == 4\\\", \\\"tags\\\": [\\\"ovn\\\", \\\"ovn_image\\\"], \\\"containers.podman.podman_image\\\": {\\\"name\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\\\", \\\"validate_certs\\\": false, \\\"force\\\": true}}, {\\\"name\\\": \\\"Update OVN OVS related parameters before update.\\\", \\\"when\\\": [\\\"step|int == 4\\\"], \\\"tags\\\": [\\\"ovn\\\"], \\\"vars\\\": {\\\"timeout\\\": 8000}, \\\"shell\\\": \\\"set -e\\\\novs-vsctl set Open_vSwitch . external_ids:ovn-ofctrl-wait-before-clear={{ timeout }}\\\\novs-vsctl set Open_vSwitch . external_ids:ovn-monitor-all=true\\\\novs-vsctl set Open_vSwitch . external_ids:ovn-match-northd-version=false\\\\n\\\"}, {\\\"name\\\": \\\"Find ovn_controller configs in container-startup-configs\\\", \\\"find\\\": {\\\"paths\\\": \\\"/var/lib/tripleo-config/container-startup-config/\\\", \\\"patterns\\\": \\\"*ovn_controller.json\\\", \\\"recurse\\\": true}, \\\"register\\\": \\\"ovn_cont_17_0\\\", \\\"when\\\": [\\\"step|int == 4\\\"], \\\"tags\\\": [\\\"ovn\\\"]}, {\\\"name\\\": \\\"get directory path from the ovn_cont_17_0\\\", \\\"set_fact\\\": {\\\"ovn_config_path\\\": \\\"{{ ovn_cont_17_0.files.0.path | dirname }}\\\"}, \\\"when\\\": \\\"step|int == 4\\\", \\\"tags\\\": \\\"ovn\\\"}, {\\\"name\\\": \\\"Get PIDfile used by systemd on each ovn node\\\", \\\"when\\\": [\\\"step|int == 4\\\"], \\\"tags\\\": [\\\"ovn\\\"], \\\"shell\\\": \\\"set -e\\\\ngrep PID /etc/systemd/system/tripleo_ovn_controller.service | cut -d= -f2\\\\n\\\", \\\"register\\\": \\\"pidfile\\\"}, {\\\"name\\\": \\\"Update ovn_controller.\\\", \\\"vars\\\": {\\\"config_step\\\": \\\"{{ (\'step_4\' in ovn_config_path) | ternary(\'4\', \'3\')}}\\\"}, \\\"when\\\": \\\"step|int == 4\\\", \\\"tags\\\": \\\"ovn\\\", \\\"tripleo_container_manage\\\": {\\\"config_dir\\\": \\\"{{ ovn_config_path }}\\\", \\\"config_patterns\\\": \\\"*ovn_controller.json\\\", \\\"config_id\\\": [\\\"tripleo_step{{config_step}}\\\"], \\\"log_base_path\\\": \\\"{{ container_log_stdout_path }}\\\", \\\"debug\\\": \\\"{{ enable_debug | bool }}\\\", \\\"config_overrides\\\": {\\\".*ovn_controller\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\\\", \\\"conmon_pidfile\\\": \\\"{{ pidfile.stdout }}\\\", \\\"name\\\": \\\"ovn_controller\\\"}}}}, {\\\"name\\\": \\\"Pause for 30s to give ovn_controllers time to reconnect to dbs\\\", \\\"when\\\": [\\\"step|int == 4\\\"], \\\"tags\\\": \\\"ovn\\\", \\\"wait_for\\\": {\\\"timeout\\\": 30}}]}], \\\"scale_tasks\\\": [{\\\"when\\\": [\\\"step|int == 1\\\", \\\"container_cli == \'podman\'\\\"], \\\"tags\\\": \\\"down\\\", \\\"become\\\": true, \\\"environment\\\": {\\\"OS_CLOUD\\\": \\\"overcloud\\\"}, \\\"block\\\": [{\\\"name\\\": \\\"Get neutron agents ID\\\", \\\"command\\\": \\\"openstack network agent list --column ID --column Host --column Binary --format yaml\\\", \\\"register\\\": \\\"neutron_agents_result\\\", \\\"delegate_to\\\": \\\"{{ groups[\'Undercloud\'] | first }}\\\", \\\"check_mode\\\": false, \\\"changed_when\\\": false}, {\\\"name\\\": \\\"Filter only current host\\\", \\\"set_fact\\\": {\\\"neutron_agents\\\": \\\"{{ neutron_agents_result.stdout | from_yaml | selectattr(\'Host\', \'match\', ansible_facts[\'fqdn\'] ~ \'.*\') | list }}\\\"}, \\\"delegate_to\\\": \\\"{{ groups[\'Undercloud\'] | first }}\\\", \\\"check_mode\\\": false}, {\\\"name\\\": \\\"Deleting OVN agents\\\", \\\"block\\\": [{\\\"name\\\": \\\"Stop OVN containers\\\", \\\"loop\\\": [\\\"tripleo_ovn_controller\\\", \\\"tripleo_ovn_metadata_agent\\\"], \\\"service\\\": {\\\"name\\\": \\\"{{ item }}\\\", \\\"state\\\": \\\"stopped\\\", \\\"enabled\\\": false}, \\\"become\\\": true, \\\"register\\\": \\\"stop_containers\\\", \\\"failed_when\\\": \\\"(\'msg\' in stop_containers and \'Could not find the requested service\' not in stop_containers.msg) or (\'rc\' in stop_containers and stop_containers.rc != 0)\\\"}, {\\\"name\\\": \\\"Delete neutron agents\\\", \\\"loop\\\": \\\"{{ neutron_agents }}\\\", \\\"loop_control\\\": {\\\"loop_var\\\": \\\"agent\\\", \\\"label\\\": \\\"{{ agent.Host }}/{{ agent.Binary }}\\\"}, \\\"command\\\": \\\"openstack network agent delete {{ agent.ID }}\\\", \\\"delegate_to\\\": \\\"{{ groups[\'Undercloud\'] | first }}\\\", \\\"check_mode\\\": false}]}]}]}, {\\\"service_name\\\": \\\"ovn_metadata\\\", \\\"monitoring_subscription\\\": \\\"overcloud-ovn-metadata\\\", \\\"config_settings\\\": {\\\"neutron::notification_driver\\\": [\\\"noop\\\"], \\\"neutron::core_plugin\\\": \\\"ml2\\\", \\\"neutron::service_plugins\\\": [\\\"qos\\\", \\\"ovn-router\\\", \\\"trunk\\\", \\\"segments\\\", \\\"port_forwarding\\\", \\\"log\\\"], \\\"neutron::report_interval\\\": 300, \\\"neutron::logging::debug\\\": true, \\\"neutron::purge_config\\\": false, \\\"neutron::allow_overlapping_ips\\\": true, \\\"neutron::dhcp_agent_notification\\\": false, \\\"neutron::dns_domain\\\": \\\"ooo.test\\\", \\\"neutron::rabbit_heartbeat_timeout_threshold\\\": 60, \\\"neutron::host\\\": \\\"%{hiera(\'fqdn_canonical\')}\\\", \\\"neutron::db::database_db_max_retries\\\": -1, \\\"neutron::db::database_max_retries\\\": -1, \\\"neutron::db::sync::db_sync_timeout\\\": 900, \\\"neutron::global_physnet_mtu\\\": 1350, \\\"neutron::db::sync::extra_params\\\": \\\"\\\", \\\"neutron::vlan_transparent\\\": false, \\\"neutron::rabbit_heartbeat_in_pthread\\\": false, \\\"tripleo::profile::base::neutron::ovn_metadata_agent_wrappers::enable_haproxy_wrapper\\\": true, \\\"tripleo::profile::base::neutron::ovn_metadata_agent_wrappers::haproxy_process_wrapper\\\": \\\"/var/lib/neutron/ovn_metadata_haproxy_wrapper\\\", \\\"tripleo::profile::base::neutron::ovn_metadata_agent_wrappers::haproxy_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\\\", \\\"tripleo::profile::base::neutron::ovn_metadata_agent_wrappers::debug\\\": true, \\\"tripleo::profile::base::neutron::container_cli\\\": \\\"podman\\\", \\\"neutron::agents::ovn_metadata::shared_secret\\\": \\\"WlxpFDSY9t6h6Jb7QWOpi1RBB\\\", \\\"neutron::agents::ovn_metadata::auth_password\\\": \\\"qzvItA1K3MLllVvkiCWVVbIpy\\\", \\\"neutron::agents::ovn_metadata::auth_url\\\": \\\"https://overcloud.internalapi.ooo.test:5000\\\", \\\"neutron::agents::ovn_metadata::auth_tenant\\\": \\\"service\\\", \\\"neutron::agents::ovn_metadata::metadata_host\\\": \\\"overcloud.internalapi.ooo.test\\\", \\\"neutron::agents::ovn_metadata::ovsdb_connection_timeout\\\": 180, \\\"neutron::agents::ovn_metadata::ovsdb_probe_interval\\\": 60000, \\\"neutron::agents::ovn_metadata::hwol_qos_enabled\\\": false, \\\"ovn::northbound::port\\\": 6641, \\\"ovn::southbound::port\\\": 6642, \\\"neutron::agents::ovn_metadata::debug\\\": true, \\\"neutron::agents::ovn_metadata::metadata_protocol\\\": \\\"https\\\", \\\"neutron::agents::ovn_metadata::metadata_workers\\\": \\\"1\\\", \\\"tripleo::profile::base::neutron::ovn_metadata::ovn_nb_ca_cert\\\": \\\"/etc/ipa/ca.crt\\\", \\\"tripleo::profile::base::neutron::ovn_metadata::ovn_sb_ca_cert\\\": \\\"/etc/ipa/ca.crt\\\", \\\"tripleo::profile::base::neutron::ovn_metadata::protocol\\\": \\\"ssl\\\", \\\"tripleo::profile::base::neutron::ovn_metadata::ovn_nb_certificate\\\": \\\"/etc/pki/tls/certs/ovn_metadata.crt\\\", \\\"tripleo::profile::base::neutron::ovn_metadata::ovn_nb_private_key\\\": \\\"/etc/pki/tls/private/ovn_metadata.key\\\", \\\"tripleo::profile::base::neutron::ovn_metadata::ovn_sb_certificate\\\": \\\"/etc/pki/tls/certs/ovn_metadata.crt\\\", \\\"tripleo::profile::base::neutron::ovn_metadata::ovn_sb_private_key\\\": \\\"/etc/pki/tls/private/ovn_metadata.key\\\"}, \\\"puppet_config\\\": {\\\"puppet_tags\\\": \\\"neutron_config,ovn_metadata_agent_config\\\", \\\"config_volume\\\": \\\"neutron\\\", \\\"step_config\\\": \\\"include tripleo::profile::base::neutron::ovn_metadata\\\\n\\\", \\\"config_image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\\\", \\\"volumes\\\": [\\\"/lib/modules:/lib/modules:ro\\\", \\\"/run/openvswitch:/run/openvswitch:shared,z\\\"]}, \\\"kolla_config\\\": {\\\"/var/lib/kolla/config_files/ovn_metadata_agent.json\\\": {\\\"command\\\": \\\"/usr/bin/networking-ovn-metadata-agent --config-file /etc/neutron/neutron.conf --config-file /etc/neutron/plugins/networking-ovn/networking-ovn-metadata-agent.ini --log-file=/var/log/neutron/ovn-metadata-agent.log\\\", \\\"config_files\\\": [{\\\"source\\\": \\\"/var/lib/kolla/config_files/src/*\\\", \\\"dest\\\": \\\"/\\\", \\\"merge\\\": true, \\\"preserve_properties\\\": true}], \\\"permissions\\\": [{\\\"path\\\": \\\"/var/log/neutron\\\", \\\"owner\\\": \\\"neutron:neutron\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/var/lib/neutron\\\", \\\"owner\\\": \\\"neutron:neutron\\\", \\\"recurse\\\": true}, {\\\"path\\\": \\\"/etc/pki/tls/certs/ovn_metadata.crt\\\", \\\"owner\\\": \\\"neutron:neutron\\\", \\\"optional\\\": true, \\\"perm\\\": \\\"0644\\\"}, {\\\"path\\\": \\\"/etc/pki/tls/private/ovn_metadata.key\\\", \\\"owner\\\": \\\"neutron:neutron\\\", \\\"optional\\\": true, \\\"perm\\\": \\\"0644\\\"}]}}, \\\"container_config_scripts\\\": {\\\"container_puppet_apply.sh\\\": {\\\"mode\\\": \\\"0700\\\", \\\"content\\\": \\\"#!/bin/bash\\\\nset -eux\\\\nSTEP=$1\\\\nTAGS=$2\\\\nCONFIG=$3\\\\nEXTRA_ARGS=${4:-\'\'}\\\\nif [ -d /tmp/puppet-etc ]; then\\\\n  # ignore copy failures as these may be the same file depending on docker mounts\\\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\\\nfi\\\\necho \\\\\\\"{\\\\\\\\\\\\\\\"step\\\\\\\\\\\\\\\": ${STEP}}\\\\\\\" > /etc/puppet/hieradata/docker_puppet.json\\\\n# $::deployment_type in puppet-tripleo\\\\nexport FACTER_deployment_type=containers\\\\nset +e\\\\npuppet apply $EXTRA_ARGS \\\\\\\\\\\\n    --verbose \\\\\\\\\\\\n    --detailed-exitcodes \\\\\\\\\\\\n    --summarize \\\\\\\\\\\\n    --color=false \\\\\\\\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\\\\\\\n    --tags $TAGS \\\\\\\\\\\\n    -e \\\\\\\"noop_resource(\'package\'); ${CONFIG}\\\\\\\"\\\\nrc=$?\\\\nset -e\\\\nset +ux\\\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\\\n    exit 0\\\\nfi\\\\nexit $rc\\\\n\\\"}, \\\"pyshim.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n# Copyright 2018 Red Hat Inc.\\\\n#\\\\n# Licensed under the Apache License, Version 2.0 (the \\\\\\\"License\\\\\\\"); you may\\\\n# not use this file except in compliance with the License. You may obtain\\\\n# a copy of the License at\\\\n#\\\\n#      http://www.apache.org/licenses/LICENSE-2.0\\\\n#\\\\n# Unless required by applicable law or agreed to in writing, software\\\\n# distributed under the License is distributed on an \\\\\\\"AS IS\\\\\\\" BASIS, WITHOUT\\\\n# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the\\\\n# License for the specific language governing permissions and limitations\\\\n# under the License.\\\\n#\\\\n# Usage: pyshim.sh <script and/or arguments>\\\\n#\\\\n# Unfortunately THT doesn\'t know which version of python might be in a\\\\n# container so we need this script to be able to try python3 or python2\\\\n# depending on availability.  Since this is a temporary shim until we\'ve\\\\n# fully cut over to python3, we check for the existence of python3 first\\\\n# before falling back to python2. This will help in the transition from\\\\n# python2 based containers to python3.\\\\n\\\\nshow_usage() {\\\\n    echo \\\\\\\"Usage: pyshim.sh <script and/or arguments>\\\\\\\"\\\\n}\\\\n\\\\nif [ $# -lt 1 ]\\\\nthen\\\\n    show_usage\\\\n    exit 1\\\\nfi\\\\n\\\\nset -x\\\\nif command -v python3 >/dev/null; then\\\\n    python3 \\\\\\\"$@\\\\\\\"\\\\nelif command -v python2 >/dev/null; then\\\\n    python2 \\\\\\\"$@\\\\\\\"\\\\nelif command -v python >/dev/null; then\\\\n    python \\\\\\\"$@\\\\\\\"\\\\nelse\\\\n    echo \\\\\\\"ERROR: python is not available!\\\\\\\"\\\\n    exit 1\\\\nfi\\\\n\\\"}, \\\"pacemaker_restart_bundle.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\nset -u\\\\n\\\\n# ./pacemaker_restart_bundle.sh mysql galera galera-bundle Master _\\\\n# ./pacemaker_restart_bundle.sh redis redis redis-bundle Slave Master\\\\n# ./pacemaker_restart_bundle.sh ovn_dbs ovndb_servers ovn-dbs-bundle Slave Master\\\\nRESTART_SCRIPTS_DIR=$(dirname $0)\\\\nTRIPLEO_SERVICE=$1\\\\nRESOURCE_NAME=$2\\\\nBUNDLE_NAME=$3\\\\nWAIT_TARGET_LOCAL=$4\\\\nWAIT_TARGET_ANYWHERE=${5:-_}\\\\nTRIPLEO_MINOR_UPDATE=\\\\\\\"${TRIPLEO_MINOR_UPDATE:-false}\\\\\\\"\\\\nTRIPLEO_HA_WRAPPER_RESOURCE_EXISTS=\\\\\\\"${TRIPLEO_HA_WRAPPER_RESOURCE_EXISTS:-false}\\\\\\\"\\\\n\\\\nbundle_can_be_restarted() {\\\\n    local bundle=$1\\\\n    # As long as the resource bundle is managed by pacemaker and is\\\\n    # not meant to stay stopped, no matter the state of any inner\\\\n    # pcmk_remote or ocf resource, we should restart it to give it a\\\\n    # chance to read the new config.\\\\n    [ \\\\\\\"$(crm_resource --meta -r $1 -g is-managed 2>/dev/null)\\\\\\\" != \\\\\\\"false\\\\\\\" ] && \\\\\\\\\\\\n    [ \\\\\\\"$(crm_resource --meta -r $1 -g target-role 2>/dev/null)\\\\\\\" != \\\\\\\"Stopped\\\\\\\" ]\\\\n}\\\\n\\\\nlog() {\\\\n    local msg=$1\\\\n    logger -t pcmkrestart \\\\\\\"$1\\\\\\\"\\\\n}\\\\n\\\\nHOSTNAME=$(/bin/hostname -s)\\\\nif [ x\\\\\\\"${TRIPLEO_MINOR_UPDATE,,}\\\\\\\" != x\\\\\\\"true\\\\\\\" ]; then\\\\n    if [ x\\\\\\\"${TRIPLEO_HA_WRAPPER_RESOURCE_EXISTS,,}\\\\\\\" = x\\\\\\\"false\\\\\\\" ]; then\\\\n        # Do not restart during initial deployment, as the resource\\\\n        # has just been created.\\\\n        SERVICE_NODEID=$(/bin/hiera -c /etc/puppet/hiera.yaml \\\\\\\"${TRIPLEO_SERVICE}_short_bootstrap_node_name\\\\\\\")\\\\n        if [[ \\\\\\\"${HOSTNAME,,}\\\\\\\" == \\\\\\\"${SERVICE_NODEID,,}\\\\\\\" ]]; then\\\\n            log \\\\\\\"Initial deployment, skipping the restart of ${BUNDLE_NAME}\\\\\\\"\\\\n\\\\tfi\\\\n        exit 0\\\\n    else\\\\n        # During a stack update, this script is called in parallel on\\\\n        # every node the resource runs on, after the service\'s configs\\\\n        # have been updated on all nodes. So we need to run pcs only\\\\n        # once (e.g. on the service\'s boostrap node).\\\\n        if bundle_can_be_restarted ${BUNDLE_NAME}; then\\\\n            SERVICE_NODEID=$(/bin/hiera -c /etc/puppet/hiera.yaml \\\\\\\"${TRIPLEO_SERVICE}_short_bootstrap_node_name\\\\\\\")\\\\n            if [[ \\\\\\\"${HOSTNAME,,}\\\\\\\" == \\\\\\\"${SERVICE_NODEID,,}\\\\\\\" ]]; then\\\\n                replicas_running=$(crm_resource -Q -r $BUNDLE_NAME --locate 2>&1 | wc -l)\\\\n                if [ \\\\\\\"$replicas_running\\\\\\\" != \\\\\\\"0\\\\\\\" ]; then\\\\n                    log \\\\\\\"Restarting ${BUNDLE_NAME} globally. Stopping:\\\\\\\"\\\\n                    /sbin/pcs resource disable --wait=600 $BUNDLE_NAME\\\\n                    log \\\\\\\"Restarting ${BUNDLE_NAME} globally. Starting:\\\\\\\"\\\\n                    /sbin/pcs resource enable --wait=600 $BUNDLE_NAME\\\\n                else\\\\n                    log \\\\\\\"${BUNDLE_NAME} is not running anywhere,\\\\\\\" \\\\\\\\\\\\n                         \\\\\\\"cleaning up to restart it globally if necessary\\\\\\\"\\\\n                    /sbin/pcs resource cleanup $BUNDLE_NAME\\\\n                fi\\\\n            else\\\\n                log \\\\\\\"Skipping global restart of ${BUNDLE_NAME} on ${HOSTNAME} it will be restarted by node ${SERVICE_NODEID}\\\\\\\"\\\\n            fi\\\\n\\\\n        else\\\\n            log \\\\\\\"No global restart needed for ${BUNDLE_NAME}.\\\\\\\"\\\\n        fi\\\\n    fi\\\\nelse\\\\n    # During a minor update workflow however, a host gets fully\\\\n    # updated before updating the next one. So unlike stack\\\\n    # update, at the time this script is called, the service\'s\\\\n    # configs aren\'t updated on all nodes yet. So only restart the\\\\n    # resource locally, where it\'s guaranteed that the config is\\\\n    # up to date.\\\\n    HOST=$(facter hostname)\\\\n\\\\n    if bundle_can_be_restarted ${BUNDLE_NAME}; then\\\\n\\\\t# if the resource is running locally, restart it\\\\n\\\\tif crm_resource -r $BUNDLE_NAME --locate 2>&1 | grep -w -q \\\\\\\"${HOST}\\\\\\\"; then\\\\n            log \\\\\\\"Restarting ${BUNDLE_NAME} locally on \'${HOST}\'\\\\\\\"\\\\n            /sbin/pcs resource restart $BUNDLE_NAME \\\\\\\"${HOST}\\\\\\\"\\\\n\\\\n\\\\telse\\\\n\\\\t    # At this point, if no resource is running locally, it\'s\\\\n\\\\t    # either because a) it has failed previously, or b) because\\\\n\\\\t    # it\'s an A/P resource running elsewhere.\\\\n\\\\t    # By cleaning up resource, we ensure that a) it will try to\\\\n\\\\t    # restart, or b) it won\'t do anything if the resource is\\\\n\\\\t    # already running elsewhere.\\\\n            log \\\\\\\"${BUNDLE_NAME} is currently not running on \'${HOST}\',\\\\\\\" \\\\\\\\\\\\n                 \\\\\\\"cleaning up its state to restart it if necessary\\\\\\\"\\\\n            /sbin/pcs resource cleanup $BUNDLE_NAME node=\\\\\\\"${HOST}\\\\\\\"\\\\n\\\\tfi\\\\n\\\\n\\\\t# Wait until the resource is in the expected target state\\\\n\\\\t$RESTART_SCRIPTS_DIR/pacemaker_wait_bundle.sh \\\\\\\\\\\\n            $RESOURCE_NAME $BUNDLE_NAME \\\\\\\\\\\\n            \\\\\\\"$WAIT_TARGET_LOCAL\\\\\\\" \\\\\\\"$WAIT_TARGET_ANYWHERE\\\\\\\" \\\\\\\\\\\\n\\\\t    \\\\\\\"${HOST}\\\\\\\" 600\\\\n    else\\\\n        log \\\\\\\"No restart needed for ${BUNDLE_NAME}.\\\\\\\"\\\\n    fi\\\\nfi\\\\n\\\"}, \\\"pacemaker_wait_bundle.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\n# ----\\\\n# Wait for an OCF resource or a bundle to be restarted\\\\n# ----\\\\n# e.g.:\\\\n# M/S OCF:      $0 galera galera-bundle Master\\\\n# clone OCF:    $0 rabbitmq rabbitmq-bundle Started\\\\n# A/P M/S OCF:  $0 redis redis-bundle Slave Master\\\\n# A/P bundle:   $0 openstack-cinder-volume openstack-cinder-volume _ Started\\\\n# clone bundle: $0 haproxy-bundle haproxy-bundle Started\\\\n\\\\n# design note 1:\\\\n#  - this script is called during a minor update; it is called\\\\n#    once per node that hosts a service replica.\\\\n#  - the purpose of this script is to ensure that restarting the\\\\n#    service replica locally won\'t disrupt the service availability\\\\n#    for the end user. To reach that goal, the script waits until the\\\\n#    service is restarted locally or globallu and reaches a given\\\\n#    target state (i.e. Started, Slave or Master).\\\\n# design note 2:\\\\n#   - we don\'t want to track restart error: our only job is to ensure\\\\n#     service restart synchronization, not service health.\\\\n#   - In particular, we don\'t want to error out in case the resource\\\\n#     cannot be restarted locally, because that would make the minor\\\\n#     update fail, even if potentially other replicas still provide\\\\n#     the service.\\\\n# design note 3:\\\\n#   - we can bail out early if we determine that the resource can\'t\\\\n#     be restarted automatically by pacemaker (e.g. its \\\\\\\"blocked\\\\\\\",\\\\n#     unmanaged or disabled).\\\\n\\\\nlog() {\\\\n    local msg=$1\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\"\\\\n}\\\\n\\\\nusage() {\\\\n    echo 2>&1 \\\\\\\"Usage: $0 NAME BUNDLE_NAME ROLE_LOCAL [ROLE_ANYWHERE] [HOST] [TIMEOUT]\\\\\\\"\\\\n    exit 1\\\\n}\\\\n\\\\npacemaker_supports_promoted() {\\\\n    # The Promoted token is only matched in recent pacemaker versions\\\\n    grep -wq \\\\\\\"<value>Promoted</value>\\\\\\\" /usr/share/pacemaker/resources-*.rng\\\\n}\\\\n\\\\n#\\\\n# Utility functions to detect stuck resources\\\\n#\\\\n\\\\nbundle_failures_locally() {\\\\n    local engine=$BUNDLE_CONTAINER_ENGINE\\\\n    local replicas=$BUNDLE_REPLICAS\\\\n    local last=$(($replicas - 1))\\\\n    local replica_name\\\\n    for i in $(seq 0 $last); do\\\\n\\\\treplica_name=${BUNDLE_NAME}-${engine}-${i}\\\\n\\\\tcrm_failcount -q -G -r $replica_name -N $HOST\\\\n    done\\\\n}\\\\n\\\\nbundle_failures_globally() {\\\\n    local engine=$BUNDLE_CONTAINER_ENGINE\\\\n    local replicas=$BUNDLE_REPLICAS\\\\n    local last=$(($replicas - 1))\\\\n    for i in $(seq 0 $last); do\\\\n\\\\tcrm_failcount -q -G -r ${BUNDLE_NAME}-${engine}-${i}\\\\n    done\\\\n}\\\\n\\\\nbundle_running_globally() {\\\\n    local engine=$BUNDLE_CONTAINER_ENGINE\\\\n    # return the number of running bundles replica, i.e. the number of\\\\n    # docker/podman resource replicas currently running in the cluster\\\\n    crm_mon --as-xml | xmllint --xpath \\\\\\\"count(//resources/bundle[@id=\'${BUNDLE_NAME}\']/replica/resource[@resource_agent=\'${OCF}:heartbeat:${engine}\']/node)\\\\\\\" -\\\\n}\\\\n\\\\nocf_failures_globally() {\\\\n    local replicas=$BUNDLE_REPLICAS\\\\n    local last=$(($replicas - 1))\\\\n    local bundle_node\\\\n    for i in $(seq 0 $last); do\\\\n\\\\tbundle_node=${BUNDLE_NAME}-${i}\\\\n\\\\tcrm_failcount -q -G -r $NAME -N $bundle_node\\\\n    done\\\\n}\\\\n\\\\ndid_resource_failed_locally() {\\\\n    local failures\\\\n    local running\\\\n    local remotehost\\\\n    if [ \\\\\\\"${NAME}\\\\\\\" != \\\\\\\"${BUNDLE_NAME}\\\\\\\" ]; then\\\\n\\\\t# if we\'re dealing with an ocf resource, it is running on a\\\\n\\\\t# pacemaker_remote rather that on the real host, and the\\\\n\\\\t# failcounts are thus associated to the pcmk remote. Replace\\\\n\\\\t# the host\'s name with the pcmk remote\'s name.\\\\n        remotehost=$(crm_mon --as-xml | xmllint --xpath \\\\\\\"string(//resources/bundle[@id=\'${BUNDLE_NAME}\']/replica/resource/node[@name=\'${HOST}\']/../../resource[@resource_agent=\'${OCF}:pacemaker:remote\']/@id)\\\\\\\" -)\\\\n\\\\tif [ -n \\\\\\\"${remotehost}\\\\\\\" ]; then\\\\n\\\\t    crm_failcount -q -G -r $NAME -N $remotehost | grep -q -w INFINITY\\\\n\\\\t    return $?\\\\n\\\\tfi\\\\n\\\\t# If no pcmk remote is currently running, the failcount from\\\\n\\\\t# the ocf resource is useless, compute the failcount from the\\\\n\\\\t# bundle case instead (computed below).\\\\n    fi\\\\n\\\\n    # for bundles, pacemaker can run any bundle replica locally\\\\n    # (e.g. galera-bundle-docker-{0,1,2}), and a failure happens when\\\\n    # there are no more replica to try.\\\\n    # That is, when _at least_ one replica failed locally, and all the\\\\n    # others either failed or are currently running elsewhere.\\\\n    failures=$(bundle_failures_locally $HOST | grep -c -w INFINITY)\\\\n    running=$(bundle_running_globally)\\\\n    test $failures -gt 0 && \\\\\\\\\\\\n    test $(( $failures + $running )) -ge $BUNDLE_REPLICAS\\\\n}\\\\n\\\\ndid_resource_failed_globally() {\\\\n    local remotecount\\\\n    local failures\\\\n    if [ \\\\\\\"${NAME}\\\\\\\" != \\\\\\\"${BUNDLE_NAME}\\\\\\\" ]; then\\\\n\\\\t# we check the state of an ocf resource only if the\\\\n\\\\t# pcmkremotes are started\\\\n        remotecount=$(crm_mon --as-xml | xmllint --xpath \\\\\\\"count(//resources/bundle[@id=\'${BUNDLE_NAME}\']/replica/resource[@resource_agent=\'${OCF}:pacemaker:remote\']/node)\\\\\\\" -)\\\\n\\\\tif [ \\\\\\\"${remotecount}\\\\\\\" = \\\\\\\"0\\\\\\\" ]; then\\\\n\\\\t    # no pcmkremote is running, so check the bundle state\\\\n\\\\t    # instead of checking the ocf resource\\\\n\\\\t    # bundle failed if all ${BUNDLE_REPLICAS} replicas failed\\\\n\\\\t    failures=$(bundle_failures_globally | grep -c -w INFINITY)\\\\n\\\\t    test $failures -eq $BUNDLE_REPLICAS\\\\n\\\\telse\\\\n\\\\t    # ocf resource failed if it failed to start on\\\\n\\\\t    # all $BUNDLE_REPLICAS bundle nodes\\\\n\\\\t    failures=$(ocf_failures_globally | grep -c -w INFINITY)\\\\n\\\\t    test $failures -eq $BUNDLE_REPLICAS\\\\n\\\\tfi\\\\n    else\\\\n\\\\t# bundle failed if all ${BUNDLE_REPLICAS} replicas failed\\\\n\\\\tfailures=$(bundle_failures_globally | grep -c -w INFINITY)\\\\n\\\\ttest $failures -eq $BUNDLE_REPLICAS\\\\n    fi\\\\n}\\\\n\\\\n\\\\n# Input validation\\\\n#\\\\n\\\\nNAME=$1\\\\nif [ -z \\\\\\\"${NAME}\\\\\\\" ]; then\\\\n    echo 2>&1 \\\\\\\"Error: argument NAME must not be empty\\\\\\\"\\\\n    exit 1\\\\nfi\\\\n\\\\nBUNDLE_NAME=$2\\\\nif [ -z \\\\\\\"${BUNDLE_NAME}\\\\\\\" ]; then\\\\n    echo 2>&1 \\\\\\\"Error: argument BUNDLE_NAME must not be empty\\\\\\\"\\\\n    exit 1\\\\nfi\\\\n\\\\nROLE_LOCAL=$3\\\\nif [ \\\\\\\"${ROLE_LOCAL}\\\\\\\" = \\\\\\\"_\\\\\\\" ]; then\\\\n    ROLE_LOCAL=\\\\\\\"\\\\\\\"\\\\nfi\\\\n\\\\nROLE_ANYWHERE=$4\\\\nif [ \\\\\\\"${ROLE_ANYWHERE}\\\\\\\" = \\\\\\\"_\\\\\\\" ]; then\\\\n    ROLE_ANYWHERE=\\\\\\\"\\\\\\\"\\\\nfi\\\\n\\\\nif [ -z \\\\\\\"${ROLE_LOCAL}\\\\\\\" ]; then\\\\n    if [ -z \\\\\\\"${ROLE_ANYWHERE}\\\\\\\" ]; then\\\\n        echo 2>&1 \\\\\\\"Error: either ROLE_LOCAL or ROLE_ANYWHERE must be non empty\\\\\\\"\\\\n        exit 1\\\\n    fi\\\\nelse\\\\n    if !(echo \\\\\\\"${ROLE_LOCAL}\\\\\\\" | grep -q -x -E \\\\\\\"(Started|Slave|Master|Unpromoted|Promoted)\\\\\\\"); then\\\\n        echo 2>&1 \\\\\\\"Error: argument ROLE_LOCAL must be either \'Started\' \'Slave\' \'Master\' \'Unpromoted\' or \'Promoted\'\\\\\\\"\\\\n        exit 1\\\\n    fi\\\\nfi\\\\n\\\\nif [ -n \\\\\\\"${ROLE_ANYWHERE}\\\\\\\" ] && !(echo \\\\\\\"${ROLE_ANYWHERE}\\\\\\\" | grep -q -x -E \\\\\\\"(Started|Slave|Master|Unpromoted|Promoted)\\\\\\\"); then\\\\n    echo 2>&1 \\\\\\\"Error: argument ROLE_ANYWHERE must be either \'Started\' \'Slave\' \'Master\' \'Unpromoted\' or \'Promoted\'\\\\\\\"\\\\n    exit 1\\\\nfi\\\\n\\\\n# Ensure compatibility with pacemaker 2.1\\\\nif pacemaker_supports_promoted; then\\\\n    ROLE_LOCAL=$(echo \\\\\\\"$ROLE_LOCAL\\\\\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\\\n    ROLE_ANYWHERE=$(echo \\\\\\\"$ROLE_ANYWHERE\\\\\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\\\n    OCF=\\\\\\\"ocf\\\\\\\"\\\\nelse\\\\n    OCF=\\\\\\\"ocf:\\\\\\\"\\\\nfi\\\\n\\\\nHOST=${5:-$(facter hostname)}\\\\nTIMEOUT=${6:-600}\\\\n\\\\n\\\\n# Configure the search\\\\n# ----\\\\n# Note: we can\'t use crm_resource in all searches because we can\'t\\\\n# easily extract the host the OCF resources run on (crm_resource\\\\n# returns the pcmk-remote nodes rather than the hosts)\\\\n# So instead, we implement various searches with XPath directly.\\\\n\\\\nif [ \\\\\\\"${BUNDLE_NAME}\\\\\\\" != \\\\\\\"${NAME}\\\\\\\" ]; then\\\\n# ocf resource\\\\nlocal_resource_xpath=\\\\\\\"//bundle/replica/resource[@resource_agent=\'${OCF}:pacemaker:remote\']/node[@name=\'${HOST}\']/../../resource[@id=\'${NAME}\']\\\\\\\"\\\\nany_resource_xpath=\\\\\\\"//bundle//resource[@id=\'${NAME}\']\\\\\\\"\\\\nreplicas_xpath=\\\\\\\"//bundle/primitive[@id=\'${BUNDLE_NAME}\']/../*[boolean(@image) and boolean(@replicas)]\\\\\\\"\\\\nelse\\\\n# bundle resource\\\\nlocal_resource_xpath=\\\\\\\"//bundle[@id=\'${NAME}\']/replica/resource/node[@name=\'${HOST}\']/../../resource\\\\\\\"\\\\nany_resource_xpath=\\\\\\\"//bundle[@id=\'${NAME}\']//resource\\\\\\\"\\\\nreplicas_xpath=\\\\\\\"//bundle[@id=\'${BUNDLE_NAME}\']/*[boolean(@image) and boolean(@replicas)]\\\\\\\"\\\\nfi\\\\n\\\\nbundle_def_xpath=\\\\\\\"//bundle[@id=\'${BUNDLE_NAME}\']/*[boolean(@image) and boolean(@replicas)]\\\\\\\"\\\\nBUNDLE_CONTAINER_ENGINE=$(cibadmin -Q | xmllint --xpath \\\\\\\"name(${bundle_def_xpath})\\\\\\\" -)\\\\nBUNDLE_REPLICAS=$(cibadmin -Q | xmllint --xpath \\\\\\\"string(${bundle_def_xpath}/@replicas)\\\\\\\" -)\\\\n\\\\n\\\\n# The wait algorithm follows a two-stage approach\\\\n#  1. Depending on how the script is called, we first check whether\\\\n#     the resource is restarted locally. An A/P resource may be\\\\n#     restarted elsewhere in the cluster.\\\\n#  2. If needed, check whether the A/P resource has restarted\\\\n#     elsewhere. For A/P M/S resources, in case the resource is\\\\n#     restarted as Slave locally, ensure a Master is available.\\\\n\\\\nsuccess=1\\\\nbailout=1\\\\ntimeout=$TIMEOUT\\\\nrole=\\\\\\\"\\\\\\\"\\\\n\\\\n# Stage 1: local check\\\\nif [ -n \\\\\\\"$ROLE_LOCAL\\\\\\\" ]; then\\\\n    log \\\\\\\"Waiting until ${NAME} has restarted on ${HOST} and is in state ${ROLE_LOCAL}\\\\\\\"\\\\n    log \\\\\\\"Will probe resource state with the following XPath pattern: ${local_resource_xpath}\\\\\\\"\\\\n\\\\n    while [ $timeout -gt 0 ] && [ $bailout -ne 0 ] && [ $success -ne 0 ]; do\\\\n        resource=$(crm_mon -r --as-xml | xmllint --xpath \\\\\\\"${local_resource_xpath}\\\\\\\" - 2>/dev/null)\\\\n        role=$(echo \\\\\\\"${resource}\\\\\\\" | sed -ne \'s/.*\\\\\\\\Wrole=\\\\\\\"\\\\\\\\([^\\\\\\\"]*\\\\\\\\)\\\\\\\".*/\\\\\\\\1/p\')\\\\n\\\\n\\\\tif [ \\\\\\\"$(crm_resource --meta -r ${NAME} -g is-managed 2>/dev/null)\\\\\\\" = \\\\\\\"false\\\\\\\" ]; then\\\\n            log \\\\\\\"${NAME} is unmanaged, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n\\\\telif [ \\\\\\\"$(crm_resource --meta -r ${NAME} -g target-role 2>/dev/null)\\\\\\\" = \\\\\\\"Stopped\\\\\\\" ]; then\\\\n            log \\\\\\\"${NAME} is disabled, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n        elif echo \\\\\\\"${resource}\\\\\\\" | grep -q -w \\\\\\\"\\\\\\\\Wblocked=\\\\\\\\\\\\\\\"true\\\\\\\\\\\\\\\"\\\\\\\"; then\\\\n            log \\\\\\\"${NAME} is blocked, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n\\\\telif did_resource_failed_locally; then\\\\n            log \\\\\\\"${NAME} is in failed state, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n        elif [ \\\\\\\"$role\\\\\\\" = \\\\\\\"$ROLE_LOCAL\\\\\\\" ]; then\\\\n            success=0\\\\n            continue\\\\n        elif [ -n \\\\\\\"$ROLE_ANYWHERE\\\\\\\" ] && [ \\\\\\\"$role\\\\\\\" = \\\\\\\"$ROLE_ANYWHERE\\\\\\\" ]; then\\\\n            # A/P: we are restarted in the expected state\\\\n            success=0\\\\n            continue\\\\n        else\\\\n            log \\\\\\\"Waiting for ${NAME} to transition to role ${ROLE_LOCAL} on ${HOST}\\\\\\\"\\\\n        fi\\\\n\\\\n        if [ $bailout -ne 0 ] && [ $success -ne 0 ]; then\\\\n            sleep 4\\\\n            timeout=$((timeout-4))\\\\n        fi\\\\n    done\\\\nfi\\\\n\\\\n# Stage 2: global check\\\\nif [ $timeout -gt 0 ] && [ -n \\\\\\\"$ROLE_ANYWHERE\\\\\\\" ] && [ \\\\\\\"$role\\\\\\\" != \\\\\\\"$ROLE_ANYWHERE\\\\\\\" ]; then\\\\n    log \\\\\\\"Wait until ${NAME} is restarted anywhere in the cluster in state ${ROLE_ANYWHERE}\\\\\\\"\\\\n    log \\\\\\\"Will probe resource state with the following XPath pattern: ${any_resource_xpath}\\\\\\\"\\\\n\\\\n    success=1\\\\n    bailout=1\\\\n    while [ $timeout -gt 0 ] && [ $bailout -ne 0 ] && [ $success -ne 0 ]; do\\\\n        resources=$(crm_mon -r --as-xml | xmllint --xpath \\\\\\\"${any_resource_xpath}\\\\\\\" - 2>/dev/null)\\\\n\\\\tif [ \\\\\\\"$(crm_resource --meta -r ${NAME} -g is-managed 2>/dev/null)\\\\\\\" = \\\\\\\"false\\\\\\\" ]; then\\\\n            log \\\\\\\"${NAME} is unmanaged, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n\\\\telif [ \\\\\\\"$(crm_resource --meta -r ${NAME} -g target-role 2>/dev/null)\\\\\\\" = \\\\\\\"Stopped\\\\\\\" ]; then\\\\n            log \\\\\\\"${NAME} is disabled, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n        elif ! (echo \\\\\\\"${resources}\\\\\\\" | grep -q -w \\\\\\\"\\\\\\\\Wblocked=\\\\\\\\\\\\\\\"false\\\\\\\\\\\\\\\"\\\\\\\"); then\\\\n            log \\\\\\\"${NAME} blocked, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n\\\\telif did_resource_failed_globally; then\\\\n            log \\\\\\\"${NAME} is in failed state, will never reach target role. Bailing out\\\\\\\"\\\\n            bailout=0\\\\n            continue\\\\n        elif echo \\\\\\\"${resources}\\\\\\\" | grep -q -w \\\\\\\"\\\\\\\\Wrole=\\\\\\\\\\\\\\\"${ROLE_ANYWHERE}\\\\\\\\\\\\\\\"\\\\\\\"; then\\\\n            success=0\\\\n            continue\\\\n        else\\\\n            log \\\\\\\"Waiting for ${NAME} to transition to role ${ROLE_ANYWHERE} anywhere in the cluster\\\\\\\"\\\\n        fi\\\\n\\\\n        if [ $bailout -ne 0 ] && [ $success -ne 0 ]; then\\\\n            sleep 4\\\\n            timeout=$((timeout-4))\\\\n        fi\\\\n    done\\\\nfi\\\\n\\\\nif [ $timeout -le 0 ]; then\\\\n    log \\\\\\\"Timeout reached after ${TIMEOUT}s while waiting for ${NAME} to be restarted\\\\\\\"\\\\nelif [ $bailout -le 0 ]; then\\\\n    log \\\\\\\"Restart monitoring for ${NAME} cancelled\\\\\\\"\\\\nfi\\\\n\\\\nif [ $success -eq 0 ]; then\\\\n    log \\\\\\\"${NAME} successfully restarted\\\\\\\"\\\\nelse\\\\n    log \\\\\\\"${NAME} was not restarted properly\\\\\\\"\\\\nfi\\\\n\\\\n# Don\'t block minor update or stack update if the wait was unsuccessful\\\\nexit 0\\\\n\\\"}, \\\"wait-port-and-run.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\nset -eu\\\\n\\\\nHOST=$1\\\\nPORT=$2\\\\n\\\\necho \\\\\\\"$(date -u): Checking whether we can bind to ${HOST}:${PORT}\\\\\\\"\\\\nwhile (ss -Htnl src \\\\\\\"${HOST}\\\\\\\" \\\\\\\"sport = :${PORT}\\\\\\\" | grep -wq \\\\\\\"${PORT}\\\\\\\"); do\\\\n    echo \\\\\\\"$(date -u): ${HOST}:${PORT} still in use, waiting...\\\\\\\";\\\\n    sleep 10;\\\\ndone\\\\n\\\\nshift 2\\\\nCOMMAND=\\\\\\\"$*\\\\\\\"\\\\nif [ -z \\\\\\\"${COMMAND}\\\\\\\" ]; then\\\\n    COMMAND=\\\\\\\"true\\\\\\\"\\\\nfi\\\\nexec $COMMAND\\\\n\\\"}, \\\"pacemaker_resource_lock.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\nMAX_RETRIES=10\\\\nCIB_ENOTFOUND=105\\\\n\\\\nusage() {\\\\n   echo \\\\\\\"Set a global property in the cluster with a validity timestamp.\\\\\\\"\\\\n   echo \\\\\\\"Usage:\\\\\\\"\\\\n   echo \\\\\\\"   $0 --acquire <lock_name> <lock_owner> <lock_ttl_in_seconds>\\\\\\\"\\\\n   echo \\\\\\\"   $0 --release <lock_name> <lock_owner>\\\\\\\"\\\\n   echo\\\\n}\\\\n\\\\nlog() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\" 1>&2\\\\n}\\\\n\\\\nerror() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\" 1>&2\\\\n    exit 1\\\\n}\\\\n\\\\nlock_create() {\\\\n    local name=$1\\\\n    local data=$2\\\\n    # cibadmin won\'t overwrite a key if someone else succeeded to create it concurrently\\\\n    cibadmin --sync-call --scope crm_config --create --xml-text \\\\\\\"<cluster_property_set id=\'${name}\'><nvpair id=\'${name}-pair\' name=\'${name}\' value=\'${data}\'/></cluster_property_set>\\\\\\\" &>/dev/null\\\\n    return $?\\\\n}\\\\n\\\\nlock_update() {\\\\n    local name=$1\\\\n    local expected_data=$2\\\\n    local new_data=$3\\\\n    # we only update the lock we expect to see, so we can\'t update someone else\'s lock\\\\n    cibadmin --sync-call --scope crm_config --modify --xpath \\\\\\\"//cluster_property_set/nvpair[@name=\'${name}\' and @value=\'${expected_data}\']/..\\\\\\\" --xml-text \\\\\\\"<nvpair id=\'${name}-pair\' name=\'${name}\' value=\'${new_data}\'/>\\\\\\\" &>/dev/null\\\\n    return $?\\\\n}\\\\n\\\\nlock_delete() {\\\\n    local name=$1\\\\n    local expected_data=$2\\\\n    # we only delete the lock we expect to see, so we can\'t delete someone else\'s lock\\\\n    cibadmin --sync-call --scope crm_config --delete --xpath \\\\\\\"//cluster_property_set/nvpair[@name=\'${name}\' and @value=\'${expected_data}\']/..\\\\\\\" &>/dev/null\\\\n    return $?\\\\n}\\\\n\\\\nlock_get() {\\\\n    local lockname=$1\\\\n    local res\\\\n    local rc\\\\n    res=$(cibadmin --query --scope crm_config --xpath \\\\\\\"//cluster_property_set/nvpair[@name=\'$lockname\']\\\\\\\" 2>/dev/null)\\\\n    rc=$?\\\\n    if [ $rc -eq 0 ]; then\\\\n        echo \\\\\\\"$res\\\\\\\" | sed -n \'s/.*value=\\\\\\\"\\\\\\\\([^\\\\\\\"]*\\\\\\\\)\\\\\\\".*/\\\\\\\\1/p\'\\\\n    fi\\\\n    return $rc\\\\n}\\\\n\\\\nlock_owner() {\\\\n    local lock=$1\\\\n    echo \\\\\\\"$lock\\\\\\\" | cut -d\':\' -f1\\\\n}\\\\n\\\\nlock_has_expired() {\\\\n    local lock=$1\\\\n    local expiry=$(echo \\\\\\\"$lock\\\\\\\" | cut -d\':\' -f2)\\\\n    local now=$(date +%s)\\\\n    test $now -ge $expiry\\\\n}\\\\n\\\\n\\\\n# Perform a lock action and restart if the CIB has been modified before\\\\n# committing the lock action\\\\ntry_action() {\\\\n    local fun=$1\\\\n    local lock=$2\\\\n    local requester=$3\\\\n    local args=${4:-}\\\\n    local tries=$MAX_RETRIES\\\\n    local rc=1\\\\n    if [ \\\\\\\"$fun\\\\\\\" = \\\\\\\"lock_acquire\\\\\\\" ] || [ \\\\\\\"$fun\\\\\\\" = \\\\\\\"lock_release\\\\\\\" ]; then\\\\n        log \\\\\\\"Try running $fun\\\\\\\"\\\\n    else\\\\n        return 2\\\\n    fi\\\\n    while [ $rc -ne 0 ]; do\\\\n        $fun $lock $requester $args\\\\n        rc=$?\\\\n        if [ $rc -eq 0 ]; then\\\\n            log \\\\\\\"Operation $1 succeeded\\\\\\\"\\\\n            return 0\\\\n        elif [ $rc -eq 3 ]; then\\\\n            # rc == 3 -> CIB changed before push\\\\n            if [ $tries -eq 0 ]; then\\\\n                log \\\\\\\"Failed to commit after $MAX_RETRIES retries. Bailing out.\\\\\\\"\\\\n                return 2\\\\n            else\\\\n                log \\\\\\\"Failed to commit. Retrying operation.\\\\\\\"\\\\n                tries=$(($tries - 1))\\\\n            fi\\\\n        elif [ $rc -eq 2 ]; then\\\\n            # rc == 2 -> unrecoverable cib error (e.g. pacemaker down)\\\\n            log \\\\\\\"Unexpected failure. Bailing out\\\\\\\"\\\\n            return $rc\\\\n        else\\\\n            # rc == 1 -> lock error (not owner, lock doesn\'t exists)\\\\n            return $rc\\\\n        fi\\\\n    done\\\\n}\\\\n\\\\n# The lock mechanism uses cibadmin\'s atomic creation so cluster-wide\\\\n# state coherency is guaranteed by pacemaker\\\\nlock_acquire() {\\\\n    local lockname=$1\\\\n    local requester=$2\\\\n    local ttl=$3\\\\n    local rc\\\\n    local lock\\\\n    local expiry\\\\n    local owner\\\\n\\\\n    log \\\\\\\"Check whether the lock is already held in the CIB\\\\\\\"\\\\n    lock=$(lock_get $lockname)\\\\n    rc=$?\\\\n    if [ $rc -ne 0 ] && [ $rc -ne $CIB_ENOTFOUND ]; then\\\\n        log \\\\\\\"Could not retrieve info from the CIB\\\\\\\"\\\\n        return 2\\\\n    fi\\\\n\\\\n    if [ -n \\\\\\\"$lock\\\\\\\" ]; then\\\\n        lock_has_expired $lock\\\\n        rc=$?\\\\n        if [ $rc -eq 0 ]; then\\\\n            log \\\\\\\"Lock has expired, now available for being held\\\\\\\"\\\\n        else\\\\n            # lock is still held. check whether we\'re the owner\\\\n            owner=$(lock_owner $lock)\\\\n            if [ \\\\\\\"$owner\\\\\\\" = \\\\\\\"$requester\\\\\\\" ];then\\\\n                log \\\\\\\"Requester already owns the lock, acquiring attempt will just reconfigure the TTL\\\\\\\"\\\\n            else\\\\n                log \\\\\\\"Lock is held by someone else ($owner)\\\\\\\"\\\\n                return 1\\\\n            fi\\\\n        fi\\\\n    else\\\\n        log \\\\\\\"Lock is not held yet\\\\\\\"\\\\n    fi\\\\n\\\\n    # prepare the lock info\\\\n    expiry=$(($(date +%s) + $ttl))\\\\n\\\\n    if [ -n \\\\\\\"$lock\\\\\\\" ]; then\\\\n        log \\\\\\\"Attempting to update the lock\\\\\\\"\\\\n        lock_update $lockname \\\\\\\"$lock\\\\\\\" \\\\\\\"$requester:$expiry\\\\\\\"\\\\n        rc=$?\\\\n    else\\\\n        log \\\\\\\"Attempting to acquire the lock\\\\\\\"\\\\n        lock_create $lockname \\\\\\\"$requester:$expiry\\\\\\\"\\\\n        rc=$?\\\\n    fi\\\\n\\\\n    if [ $rc -eq 0 ]; then\\\\n        log \\\\\\\"Lock \'$lockname\' acquired by \'$requester\', valid until $(date -d @$expiry)\\\\\\\"\\\\n        return 0\\\\n    else\\\\n        log \\\\\\\"CIB changed, lock cannot be acquired\\\\\\\"\\\\n        return 3\\\\n    fi\\\\n}\\\\n\\\\n\\\\n# The lock mechanism uses the CIB\'s num_updates tag to implement\\\\n# a conditional store. Cluster-wide locking is guaranteed by pacemaker\\\\nlock_release() {\\\\n    local lockname=$1\\\\n    local requester=$2\\\\n    local rc\\\\n    local lock\\\\n    local owner\\\\n\\\\n    log \\\\\\\"Check whether the lock is already held in the CIB\\\\\\\"\\\\n    lock=$(lock_get $lockname)\\\\n    rc=$?\\\\n    if [ $rc -ne 0 ] && [ $rc -ne $CIB_ENOTFOUND ]; then\\\\n        log \\\\\\\"Could not retrieve info from the CIB\\\\\\\"\\\\n        return 2\\\\n    fi\\\\n\\\\n    if [ -z \\\\\\\"$lock\\\\\\\" ]; then\\\\n        log \\\\\\\"Lock doesn\'t exist. Nothing to release\\\\\\\"\\\\n        return 0\\\\n    else\\\\n        log \\\\\\\"Lock exists, check whether we\'re the owner\\\\\\\"\\\\n        owner=$(lock_owner $lock)\\\\n        if [ \\\\\\\"$owner\\\\\\\" != \\\\\\\"$requester\\\\\\\" ];then\\\\n            log \\\\\\\"Lock is held by someone else ($owner), will not unlock\\\\\\\"\\\\n            return 1\\\\n        fi\\\\n    fi\\\\n\\\\n    lock_delete $lockname \\\\\\\"$lock\\\\\\\"\\\\n    rc=$?\\\\n\\\\n    if [ $rc -eq 0 ]; then\\\\n        log \\\\\\\"Lock \'$lockname\' released by \'$requester\'\\\\\\\"\\\\n        return 0\\\\n    else\\\\n        log \\\\\\\"CIB deletion error, lock cannot be released\\\\\\\"\\\\n        return 3\\\\n    fi\\\\n}\\\\n\\\\n\\\\n# Retrieve the owner of a lock from the CIB\\\\n# this is a read-only operation, so no need to log debug info\\\\nlock_get_owner() {\\\\n    local lockname=$1\\\\n    local rc\\\\n    local lock\\\\n    local owner\\\\n\\\\n    lock=$(lock_get $lockname)\\\\n    rc=$?\\\\n    if [ $rc -ne 0 ] && [ $rc -ne $CIB_ENOTFOUND ]; then\\\\n        return 2\\\\n    fi\\\\n\\\\n    if [ -z \\\\\\\"$lock\\\\\\\" ]; then\\\\n        return 1\\\\n    else\\\\n        lock_owner $lock\\\\n        return 0\\\\n    fi\\\\n}\\\\n\\\\n\\\\nACTION=$1\\\\nLOCKNAME=$2\\\\nREQUESTER=$3\\\\nTTL=${4:-60}\\\\n\\\\nif [ -z \\\\\\\"$ACTION\\\\\\\" ]; then\\\\n    error \\\\\\\"Action must be specified\\\\\\\"\\\\nfi\\\\n\\\\nif [ $ACTION != \\\\\\\"--help\\\\\\\" ]; then\\\\n    if [ -z \\\\\\\"$LOCKNAME\\\\\\\" ]; then\\\\n        error \\\\\\\"You must specific a lock name\\\\\\\"\\\\n    fi\\\\n    if [ $ACTION != \\\\\\\"--owner\\\\\\\" ] && [ $ACTION != \\\\\\\"-o\\\\\\\" ]; then\\\\n        if [ -z \\\\\\\"$REQUESTER\\\\\\\" ]; then\\\\n            error \\\\\\\"You must specific a lock requester\\\\\\\"\\\\n        fi\\\\n    fi\\\\nfi\\\\n\\\\ncase $ACTION in\\\\n    --help) usage; exit 0;;\\\\n    --acquire|-a) try_action lock_acquire $LOCKNAME $REQUESTER $TTL;;\\\\n    --release|-r) try_action lock_release $LOCKNAME $REQUESTER;;\\\\n    --acquire-once|-A) lock_acquire $LOCKNAME $REQUESTER $TTL;;\\\\n    --owner|-o) lock_get_owner $LOCKNAME;;\\\\n    *) error \\\\\\\"Invalid action\\\\\\\";;\\\\nesac\\\\nexit $?\\\\n\\\"}, \\\"pacemaker_mutex_restart_bundle.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\n# pacemaker_mutex_restart_bundle.sh --lock mysql galera galera-bundle Master _\\\\n# pacemaker_mutex_restart_bundle.sh --lock ovn_dbs ovndb_servers ovn-dbs-bundle Slave Master\\\\n\\\\nset -u\\\\n\\\\nusage() {\\\\n    echo \\\\\\\"Restart a clustered resource in a coordinated way across the cluster\\\\\\\"\\\\n    echo \\\\\\\"Usage:\\\\\\\"\\\\n    echo \\\\\\\"   $0 --lock <tripleo-service> <pcmk-resource> <pcmk-bundle> <target-state-local> <target-state-cluster>\\\\\\\"\\\\n    echo\\\\n}\\\\n\\\\nlog() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\"\\\\n}\\\\n\\\\nerror() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\" 1>&2\\\\n    exit 1\\\\n}\\\\n\\\\npacemaker_supports_promoted() {\\\\n    # The Promoted token is only matched in recent pacemaker versions\\\\n    grep -wq \\\\\\\"<value>Promoted</value>\\\\\\\" /usr/share/pacemaker/resources-*.rng\\\\n}\\\\n\\\\nACTION=$1\\\\ncase $ACTION in\\\\n    --help) usage; exit 0;;\\\\n    --lock) ;;\\\\n    *) error \\\\\\\"Unknown action \'$ACTION\'\\\\\\\";;\\\\nesac\\\\n\\\\nTRIPLEO_SERVICE=$2\\\\nLOCK_NAME=${TRIPLEO_SERVICE}-restart-lock\\\\nLOCK_OWNER=$(crm_node -n 2>/dev/null)\\\\nrc=$?\\\\nif [ $rc -ne 0 ]; then\\\\n    if [ $rc -eq 102 ]; then\\\\n        log \\\\\\\"Cluster is not running locally, no need to restart resource $TRIPLEO_SERVICE\\\\\\\"\\\\n        exit 0\\\\n    else\\\\n        error \\\\\\\"Unexpected error while connecting to the cluster (rc: $rc), bailing out\\\\\\\"\\\\n    fi\\\\nfi\\\\n\\\\nRESOURCE_NAME=$3\\\\nBUNDLE_NAME=$4\\\\nWAIT_TARGET_LOCAL=$5\\\\nWAIT_TARGET_ANYWHERE=${6:-_}\\\\n\\\\nif pacemaker_supports_promoted; then\\\\n    WAIT_TARGET_LOCAL=$(echo \\\\\\\"$5\\\\\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\\\n    WAIT_TARGET_ANYWHERE=$(echo \\\\\\\"${6:-_}\\\\\\\" | sed -e \'s/Master/Promoted/\' -e \'s/Slave/Unpromoted/\')\\\\n    promoted_role=\\\\\\\"Promoted\\\\\\\"\\\\nelse\\\\n    promoted_role=\\\\\\\"Master\\\\\\\"\\\\nfi\\\\n\\\\n# The lock TTL should accomodate for the resource start/promote timeout\\\\nif [ \\\\\\\"$RESOURCE_NAME\\\\\\\" != \\\\\\\"$BUNDLE_NAME\\\\\\\" ]; then\\\\n    if [ \\\\\\\"$WAIT_TARGET_LOCAL\\\\\\\" = \\\\\\\"$promoted_role\\\\\\\" ] || [ \\\\\\\"$WAIT_TARGET_ANYWHERE\\\\\\\" = \\\\\\\"$promoted_role\\\\\\\" ]; then\\\\n        rsc_op=\\\\\\\"promote\\\\\\\"\\\\n    else\\\\n        rsc_op=\\\\\\\"start\\\\\\\"\\\\n    fi\\\\n    # <op id=\\\\\\\"galera-promote-interval-0s\\\\\\\" interval=\\\\\\\"0s\\\\\\\" name=\\\\\\\"promote\\\\\\\" on-fail=\\\\\\\"block\\\\\\\" timeout=\\\\\\\"300s\\\\\\\"/>\\\\n    PCMK_TTL=$(cibadmin -Q | xmllint -xpath \\\\\\\"string(//primitive[@id=\'${RESOURCE_NAME}\']/operations/op[@name=\'${rsc_op}\']/@timeout)\\\\\\\" - | sed \'s/s$//\')\\\\n    LOCK_TTL=$((PCMK_TTL + 30))\\\\nelse\\\\n    # The podman RA\'s default start timeout\\\\n    LOCK_TTL=90\\\\nfi\\\\n\\\\nlog \\\\\\\"Acquire a ${LOCK_TTL}s restart lock for service $TRIPLEO_SERVICE before restarting it\\\\\\\"\\\\n# Loop until we hold the lock. The lock has a TTL, so we\'re guaranteed to get it eventually\\\\nrc=1\\\\nwhile [ $rc -ne 0 ]; do\\\\n    /var/lib/container-config-scripts/pacemaker_resource_lock.sh --acquire $LOCK_NAME $LOCK_OWNER $LOCK_TTL\\\\n    rc=$?\\\\n    if [ $rc != 0 ]; then\\\\n        if [ $rc -gt 1 ]; then\\\\n            error \\\\\\\"Could not acquire lock due to unrecoverable error (rc: $rc), bailing out\\\\\\\"\\\\n        else\\\\n            log \\\\\\\"Could not acquire lock, retrying\\\\\\\"\\\\n            sleep 10\\\\n        fi\\\\n    fi\\\\ndone\\\\n\\\\nlog \\\\\\\"Restart the service $TRIPLEO_SERVICE locally\\\\\\\"\\\\n# Reuse the local restart script in t-h-t (driven by env var TRIPLEO_MINOR_UPDATE)\\\\nTRIPLEO_MINOR_UPDATE=true /var/lib/container-config-scripts/pacemaker_restart_bundle.sh $TRIPLEO_SERVICE $RESOURCE_NAME $BUNDLE_NAME $WAIT_TARGET_LOCAL $WAIT_TARGET_ANYWHERE\\\\n\\\\n# If we reached this point, always try to release the lock\\\\nlog \\\\\\\"Release the restart lock for service $TRIPLEO_SERVICE\\\\\\\"\\\\n/var/lib/container-config-scripts/pacemaker_resource_lock.sh --release $LOCK_NAME $LOCK_OWNER\\\\nrc=$?\\\\nif [ $rc -ne 0 ] && [ $rc -ne 1 ]; then\\\\n    error \\\\\\\"Could not release held lock (rc: $rc)\\\\\\\"\\\\nfi\\\\n\\\"}, \\\"pacemaker_mutex_shutdown.sh\\\": {\\\"mode\\\": \\\"0755\\\", \\\"content\\\": \\\"#!/usr/bin/bash\\\\n\\\\n# pacemaker_mutex_shutdown.sh --acquire\\\\n# pacemaker_mutex_shutdown.sh --release\\\\n\\\\nset -u\\\\n\\\\nusage() {\\\\n    echo \\\\\\\"Shutdown a cluster node in a coordinated way across the cluster\\\\\\\"\\\\n    echo \\\\\\\"Usage:\\\\\\\"\\\\n    echo \\\\\\\"   $0 --acquire # prevent other node from shutting down until we hold the lock\\\\\\\"\\\\n    echo \\\\\\\"   $0 --release # release the lock, other node can compete for the shutdown lock\\\\\\\"\\\\n    echo\\\\n}\\\\n\\\\nlog() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\"\\\\n}\\\\n\\\\nerror() {\\\\n    echo \\\\\\\"$(date -u): $1\\\\\\\" 1>&2\\\\n    exit 1\\\\n}\\\\n\\\\n# Loop until we hold the lock. The lock has a TTL, so we\'re guaranteed to get it eventually\\\\nshutdown_lock_acquire() {\\\\n    local lockname=$1\\\\n    local requester=$2\\\\n    local ttl=$3\\\\n    local rc=1\\\\n    local current_owner\\\\n    local owner_stopped\\\\n    local owner_rc\\\\n\\\\n    log \\\\\\\"Acquiring the shutdown lock\\\\\\\"\\\\n    while [ $rc -ne 0 ]; do\\\\n        /var/lib/container-config-scripts/pacemaker_resource_lock.sh --acquire-once $lockname $requester $ttl\\\\n        rc=$?\\\\n        if [ $rc -ne 0 ]; then\\\\n            if [ $rc -eq 2 ]; then\\\\n                error \\\\\\\"Could not acquire the shutdown lock due to unrecoverable error (rc: $rc), bailing out\\\\\\\"\\\\n            else\\\\n                # The lock is held by another node.\\\\n                current_owner=$(/var/lib/container-config-scripts/pacemaker_resource_lock.sh --owner $lockname)\\\\n                owner_rc=$?\\\\n                if [ $owner_rc -eq 2 ]; then\\\\n                    error \\\\\\\"Could not get the shutdown lock owner due to unrecoverable error (rc: $owner_rc), bailing out\\\\\\\"\\\\n                fi\\\\n                if [ $owner_rc -eq 0 ]; then\\\\n                    # If the owner is marked as offline, that means it has shutdown and\\\\n                    # we can clean the lock preemptively and try to acquire it.\\\\n                    owner_stopped=$(crm_mon -1X | xmllint --xpath \'count(//nodes/node[@name=\\\\\\\"\'${current_owner}\'\\\\\\\" and @online=\\\\\\\"false\\\\\\\" and @unclean=\\\\\\\"false\\\\\\\"])\' -)\\\\n                    if [ \\\\\\\"${owner_stopped}\\\\\\\" = \\\\\\\"1\\\\\\\" ]; then\\\\n                        log \\\\\\\"Shutdown lock held by stopped node \'${current_owner}\', lock can be released\\\\\\\"\\\\n                        /var/lib/container-config-scripts/pacemaker_resource_lock.sh --release $lockname $current_owner\\\\n                        continue\\\\n                    fi\\\\n                fi\\\\n                log \\\\\\\"Shutdown lock held by another node (rc: $rc), retrying\\\\\\\"\\\\n                sleep 10\\\\n            fi\\\\n        fi\\\\n    done\\\\n    log \\\\\\\"Shutdown lock acquired\\\\\\\"\\\\n    return 0\\\\n}\\\\n\\\\n\\\\n# Release the lock if we still own it. Not owning it anymore is not fatal\\\\nshutdown_lock_release() {\\\\n    local lockname=$1\\\\n    local requester=$2\\\\n    local rc\\\\n\\\\n    log \\\\\\\"Releasing the shutdown lock\\\\\\\"\\\\n    /var/lib/container-config-scripts/pacemaker_resource_lock.sh --release $lockname $requester\\\\n    rc=$?\\\\n    if [ $rc -ne 0 ]; then\\\\n        if [ $rc -gt 1 ]; then\\\\n            error \\\\\\\"Could not release the shutdown lock due to unrecoverable error (rc: $rc), bailing out\\\\\\\"\\\\n        else\\\\n            log \\\\\\\"Shutdown lock no longer held, nothing to do\\\\\\\"\\\\n        fi\\\\n    else\\\\n        log \\\\\\\"Shutdown lock released\\\\\\\"\\\\n    fi\\\\n    return 0\\\\n}\\\\n\\\\n\\\\nACTION=$1\\\\nif [ -z \\\\\\\"$ACTION\\\\\\\" ]; then\\\\n    error \\\\\\\"Action must be specified\\\\\\\"\\\\nfi\\\\n\\\\nLOCK_NAME=tripleo-shutdown-lock\\\\nLOCK_OWNER=$(crm_node -n 2>/dev/null)\\\\nrc=$?\\\\nif [ $rc -ne 0 ]; then\\\\n    if [ $rc -eq 102 ]; then\\\\n        log \\\\\\\"Cluster is not running locally, no need to aquire the shutdown lock\\\\\\\"\\\\n        exit 0\\\\n    else\\\\n        error \\\\\\\"Unexpected error while connecting to the cluster (rc: $rc), bailing out\\\\\\\"\\\\n    fi\\\\nfi\\\\n\\\\n# We start with a very high TTL, that long enough to accomodate a cluster stop.\\\\n# As soon as the node will get offline, the other competing node will be entitled\\\\n# to steal the lock, so they should never wait that long in practice.\\\\nLOCK_TTL=600\\\\n\\\\n\\\\ncase $ACTION in\\\\n    --help) usage; exit 0;;\\\\n    --acquire|-a) shutdown_lock_acquire ${LOCK_NAME} ${LOCK_OWNER} ${LOCK_TTL};;\\\\n    --release|-r) shutdown_lock_release ${LOCK_NAME} ${LOCK_OWNER};;\\\\n    *) error \\\\\\\"Invalid action\\\\\\\";;\\\\nesac\\\\nexit $?\\\\n\\\"}}, \\\"docker_config\\\": {\\\"step_2\\\": {\\\"create_haproxy_wrapper\\\": {\\\"start_order\\\": 1, \\\"detach\\\": false, \\\"net\\\": \\\"host\\\", \\\"pid\\\": \\\"host\\\", \\\"user\\\": \\\"root\\\", \\\"command\\\": [\\\"/container_puppet_apply.sh\\\", \\\"4\\\", \\\"file\\\", \\\"include ::tripleo::profile::base::neutron::ovn_metadata_agent_wrappers\\\"], \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\\\", \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\\\", \\\"/etc/puppet:/tmp/puppet-etc:ro\\\", \\\"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\\\", \\\"/run/openvswitch:/run/openvswitch:shared,z\\\", \\\"/var/lib/neutron:/var/lib/neutron:shared,z\\\"]}}, \\\"step_4\\\": {\\\"setup_ovs_manager\\\": {\\\"start_order\\\": 0, \\\"detach\\\": false, \\\"net\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"user\\\": \\\"root\\\", \\\"command\\\": [\\\"/container_puppet_apply.sh\\\", \\\"4\\\", \\\"exec\\\", \\\"include tripleo::profile::base::neutron::ovn_metadata\\\"], \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\\\", \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\\\", \\\"/etc/puppet:/tmp/puppet-etc:ro\\\", \\\"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/run/openvswitch:/run/openvswitch:shared,z\\\"], \\\"environment\\\": {\\\"TRIPLEO_DEPLOY_IDENTIFIER\\\": \\\"1780992067\\\"}}, \\\"ovn_metadata_agent\\\": {\\\"start_order\\\": 1, \\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\\\", \\\"net\\\": \\\"host\\\", \\\"pid\\\": \\\"host\\\", \\\"cgroupns\\\": \\\"host\\\", \\\"privileged\\\": true, \\\"restart\\\": \\\"always\\\", \\\"healthcheck\\\": {\\\"test\\\": \\\"/openstack/healthcheck\\\"}, \\\"volumes\\\": [\\\"/etc/hosts:/etc/hosts:ro\\\", \\\"/etc/localtime:/etc/localtime:ro\\\", \\\"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\\\", \\\"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\\\", \\\"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\\\", \\\"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\\\", \\\"/dev/log:/dev/log\\\", \\\"/etc/ipa/ca.crt:/etc/ipa/ca.crt:ro\\\", \\\"/etc/puppet:/etc/puppet:ro\\\", \\\"/var/log/containers/neutron:/var/log/neutron:z\\\", \\\"/var/lib/kolla/config_files/ovn_metadata_agent.json:/var/lib/kolla/config_files/config.json:ro\\\", \\\"/var/lib/config-data/puppet-generated/neutron:/var/lib/kolla/config_files/src:ro\\\", \\\"/lib/modules:/lib/modules:ro\\\", \\\"/run/openvswitch:/run/openvswitch:shared,z\\\", \\\"/var/lib/neutron:/var/lib/neutron:shared,z\\\", \\\"/run/netns:/run/netns:shared\\\", \\\"/var/lib/neutron/kill_scripts:/etc/neutron/kill_scripts:shared,z\\\", \\\"/var/lib/neutron/ovn_metadata_haproxy_wrapper:/usr/local/bin/haproxy:ro\\\", \\\"/etc/pki/tls/certs/ovn_metadata.crt:/etc/pki/tls/certs/ovn_metadata.crt\\\", \\\"/etc/pki/tls/private/ovn_metadata.key:/etc/pki/tls/private/ovn_metadata.key\\\"], \\\"environment\\\": {\\\"KOLLA_CONFIG_STRATEGY\\\": \\\"COPY_ALWAYS\\\"}}}}, \\\"metadata_settings\\\": [{\\\"service\\\": \\\"ovn_metadata\\\", \\\"network\\\": \\\"internal_api\\\", \\\"type\\\": \\\"node\\\"}], \\\"deploy_steps_tasks\\\": [{\\\"name\\\": \\\"Certificate generation\\\", \\\"when\\\": [\\\"step|int == 1\\\", \\\"enable_internal_tls\\\"], \\\"block\\\": [{\\\"include_role\\\": {\\\"name\\\": \\\"linux-system-roles.certificate\\\"}, \\\"vars\\\": {\\\"certificate_requests\\\": [{\\\"name\\\": \\\"ovn_metadata\\\", \\\"dns\\\": \\\"{{fqdn_internal_api}}\\\", \\\"principal\\\": \\\"ovn_metadata/{{fqdn_internal_api}}@{{idm_realm}}\\\", \\\"run_after\\\": \\\"systemctl restart tripleo_ovn_metadata_agent\\\\n\\\", \\\"key_size\\\": \\\"2048\\\", \\\"ca\\\": \\\"ipa\\\"}]}}]}], \\\"host_prep_tasks\\\": [{\\\"name\\\": \\\"create persistent directories\\\", \\\"file\\\": {\\\"path\\\": \\\"{{ item.path }}\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"{{ item.setype }}\\\", \\\"mode\\\": \\\"{{ item.mode }}\\\"}, \\\"with_items\\\": [{\\\"path\\\": \\\"/var/log/containers/neutron\\\", \\\"setype\\\": \\\"container_file_t\\\", \\\"mode\\\": \\\"0750\\\"}]}, {\\\"name\\\": \\\"create /run/netns with temp namespace\\\", \\\"command\\\": \\\"ip netns add ns_temp\\\", \\\"register\\\": \\\"ipnetns_add_result\\\", \\\"failed_when\\\": false}, {\\\"name\\\": \\\"remove temp namespace\\\", \\\"command\\\": \\\"ip netns delete ns_temp\\\", \\\"failed_when\\\": false, \\\"when\\\": [\\\"ipnetns_add_result.rc is defined\\\", \\\"ipnetns_add_result.rc == 0\\\"]}, {\\\"name\\\": \\\"create /var/lib/neutron\\\", \\\"file\\\": {\\\"path\\\": \\\"/var/lib/neutron\\\", \\\"state\\\": \\\"directory\\\", \\\"setype\\\": \\\"container_file_t\\\"}}, {\\\"name\\\": \\\"set conditions\\\", \\\"set_fact\\\": {\\\"haproxy_wrapper_enabled\\\": true, \\\"debug_enabled\\\": true, \\\"docker_additional_sockets\\\": [\\\"/var/lib/openstack/docker.sock\\\"]}}, {\\\"name\\\": \\\"create kill_scripts directory within /var/lib/neutron\\\", \\\"file\\\": {\\\"state\\\": \\\"directory\\\", \\\"path\\\": \\\"/var/lib/neutron/kill_scripts\\\"}}, {\\\"name\\\": \\\"create haproxy kill script\\\", \\\"when\\\": \\\"haproxy_wrapper_enabled|bool\\\", \\\"copy\\\": {\\\"dest\\\": \\\"/var/lib/neutron/kill_scripts/haproxy-kill\\\", \\\"mode\\\": 493, \\\"content\\\": \\\"#!/bin/bash\\\\n{% if debug_enabled|bool -%}\\\\nset -x\\\\n{% endif -%}\\\\nadd_date() {\\\\n  echo \\\\\\\"$(date) $@\\\\\\\"\\\\n}\\\\n\\\\n# Set up script logging for debugging purpose.\\\\n# It will be taken care of by logrotate since there is the .log\\\\n# suffix.\\\\nexec 3>&1 4>&2\\\\ntrap \'exec 2>&4 1>&3\' 0 1 2 3\\\\nexec 1>>/var/log/neutron/kill-script.log 2>&1\\\\n\\\\nSIG=$1\\\\nPID=$2\\\\nNETNS=$(ip netns identify ${PID})\\\\n\\\\nif [ \\\\\\\"x${NETNS}\\\\\\\" == \\\\\\\"x\\\\\\\" ]; then\\\\n  CLI=\\\\\\\"nsenter --all --preserve-credentials -t 1 podman\\\\\\\"\\\\n  SIG=9\\\\nelse\\\\n  CLI=\\\\\\\"nsenter --net=/run/netns/${NETNS} --preserve-credentials -m -t 1 podman\\\\\\\"\\\\nfi\\\\n\\\\nkill_container() {\\\\n  add_date \\\\\\\"Killing container $1 ($2)\\\\\\\"\\\\n  signal_container $1 $2 9\\\\n}\\\\n\\\\nstop_container() {\\\\n  add_date \\\\\\\"Stopping container $1 ($2)\\\\\\\"\\\\n  $CLI stop $2\\\\n}\\\\n\\\\nsignal_container() {\\\\n  SIGNAL=$3\\\\n  if [ -z \\\\\\\"$SIGNAL\\\\\\\" ]; then\\\\n      SIGNAL=\\\\\\\"HUP\\\\\\\"\\\\n  fi\\\\n  add_date \\\\\\\"Sending signal \'$SIGNAL\' to $1 ($2)\\\\\\\"\\\\n  $CLI kill --signal $SIGNAL $2\\\\n}\\\\n\\\\ndelete_container() {\\\\n  add_date \\\\\\\"Deleting container $1 ($2)\\\\\\\"\\\\n  $CLI rm $2 || echo \\\\\\\"Deleting container $1 ($2) failed\\\\\\\"\\\\n}\\\\n\\\\n\\\\n{% raw -%}\\\\nif [ -f /proc/$PID/cgroup ]; then\\\\n  # Get container ID based on process cgroups\\\\n  CT_ID=$(awk \'BEGIN {FS=\\\\\\\".scope|-\\\\\\\"} /\\\\\\\\/libpod-/ {if ($(NF-1)) print $(NF-1);exit}\' /proc/$PID/cgroup)\\\\n  CT_NAME=$($CLI inspect -f \'{{.Name}}\' $CT_ID)\\\\n\\\\n  case $SIG in\\\\n    HUP)\\\\n      signal_container $CT_NAME $CT_ID\\\\n      ;;\\\\n    9)\\\\n      kill_container $CT_NAME $CT_ID\\\\n      delete_container $CT_NAME $CT_ID\\\\n      ;;\\\\n    15)\\\\n      stop_container $CT_NAME $CT_ID\\\\n      delete_container $CT_NAME $CT_ID\\\\n      ;;\\\\n    *)\\\\n      add_date \\\\\\\"Unknown action ${SIG} for ${CT_NAME} ${CT_ID}\\\\\\\"\\\\n      exit 1\\\\n      ;;\\\\n  esac\\\\n\\\\nelse\\\\n  add_date \\\\\\\"No such PID: ${PID}\\\\\\\"\\\\n  exit 1\\\\nfi\\\\n{% endraw %}\\\\n\\\"}}], \\\"upgrade_tasks\\\": [], \\\"external_update_tasks\\\": [{\\\"name\\\": \\\"Check if python3-openvswitch3.1 workaround is needed\\\", \\\"delegate_to\\\": \\\"{{ item }}\\\", \\\"become\\\": true, \\\"tags\\\": [\\\"ovn\\\", \\\"ovn_image\\\"], \\\"when\\\": \\\"step|int == 1\\\", \\\"shell\\\": \\\"if podman exec ovn_metadata_agent rpm -q python3-openvswitch3.1 > /dev/null ; then echo REQUIRED; else echo OK ; fi\\\\n\\\", \\\"register\\\": \\\"metadata_python_ovs_3_1\\\", \\\"failed_when\\\": false, \\\"loop\\\": \\\"{{ groups[\'ovn_metadata\'] | difference(groups[\'excluded_overcloud\']) }}\\\"}, {\\\"name\\\": \\\"Update ovn_metadata_agents\\\", \\\"vars\\\": {\\\"hosts_to_update_metadata\\\": \\\"{{ metadata_python_ovs_3_1.results | selectattr(\'stdout\', \'eq\', \'REQUIRED\') | map(attribute=\'item\') | list }}\\\"}, \\\"tags\\\": [\\\"ovn\\\", \\\"ovn_image\\\"], \\\"when\\\": [\\\"step|int == 1\\\", \\\"hosts_to_update_metadata | length > 0\\\"], \\\"block\\\": [{\\\"name\\\": \\\"Force pull image in case image name doesn\'t change.\\\", \\\"become\\\": true, \\\"loop\\\": \\\"{{ hosts_to_update_metadata }}\\\", \\\"delegate_to\\\": \\\"{{ item }}\\\", \\\"async\\\": 600, \\\"poll\\\": 0, \\\"register\\\": \\\"ovn_metadata_image_update\\\", \\\"containers.podman.podman_image\\\": {\\\"name\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\\\", \\\"validate_certs\\\": false, \\\"force\\\": true}}, {\\\"name\\\": \\\"Was the ovn_metadata_agent image pull successful.\\\", \\\"when\\\": [\\\"\'results\' in ovn_metadata_image_update\\\"], \\\"become\\\": true, \\\"delegate_to\\\": \\\"{{ async_result_item.item }}\\\", \\\"async_status\\\": {\\\"jid\\\": \\\"{{ async_result_item.ansible_job_id }}\\\"}, \\\"loop\\\": \\\"{{ovn_metadata_image_update.results }}\\\", \\\"loop_control\\\": {\\\"loop_var\\\": \\\"async_result_item\\\"}, \\\"register\\\": \\\"async_poll_results\\\", \\\"until\\\": \\\"async_poll_results.finished\\\", \\\"retries\\\": 600, \\\"delay\\\": 1}, {\\\"name\\\": \\\"Now rotate all ovn_metadata_agents\\\", \\\"tags\\\": [\\\"ovn_metadata_parallel\\\"], \\\"delegate_to\\\": \\\"{{ item }}\\\", \\\"become\\\": true, \\\"tripleo_container_manage\\\": {\\\"config_dir\\\": \\\"/var/lib/tripleo-config/container-startup-config/step_4\\\", \\\"config_id\\\": [\\\"ovn_metadata_agent\\\"], \\\"config_patterns\\\": \\\"*ovn_metadata_agent.json\\\", \\\"config_overrides\\\": {\\\".*ovn_metadata_agent\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\\\", \\\"name\\\": \\\"ovn_metadata_agent\\\"}}}, \\\"loop\\\": \\\"{{ hosts_to_update_metadata }}\\\", \\\"async\\\": 600, \\\"poll\\\": 0}]}, {\\\"name\\\": \\\"Now rotate all ovn_metadata_agents\\\", \\\"vars\\\": {\\\"hosts_to_update_metadata\\\": \\\"{{ metadata_python_ovs_3_1.results | selectattr(\'stdout\', \'eq\', \'REQUIRED\') | map(attribute=\'item\') | list }}\\\"}, \\\"tags\\\": [\\\"never\\\", \\\"ovn_metadata_serial\\\"], \\\"when\\\": [\\\"step|int == 1\\\", \\\"hosts_to_update_metadata | length > 0\\\"], \\\"delegate_to\\\": \\\"{{ item }}\\\", \\\"become\\\": true, \\\"tripleo_container_manage\\\": {\\\"config_dir\\\": \\\"/var/lib/tripleo-config/container-startup-config/step_4\\\", \\\"config_id\\\": [\\\"ovn_metadata_agent\\\"], \\\"config_patterns\\\": \\\"*ovn_metadata_agent.json\\\", \\\"config_overrides\\\": {\\\".*ovn_metadata_agent\\\": {\\\"image\\\": \\\"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\\\", \\\"name\\\": \\\"ovn_metadata_agent\\\"}}}, \\\"loop\\\": \\\"{{ hosts_to_update_metadata }}\\\", \\\"loop_control\\\": {\\\"pause\\\": 1}}]}]\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(195,'2026-06-09 08:02:24',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"HAProxy deployment with TLS enabled, powered by certmonger\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"HAProxyInternalTLSCertsDirectory\": {\"default\": \"/etc/pki/tls/certs/haproxy\", \"type\": \"string\"}, \"HAProxyInternalTLSKeysDirectory\": {\"default\": \"/etc/pki/tls/private/haproxy\", \"type\": \"string\"}, \"DeployedSSLCertificatePath\": {\"default\": \"/etc/pki/tls/private/overcloud_endpoint.pem\", \"description\": \"The filepath of the certificate as it will be stored in the controller.\\n\", \"type\": \"string\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"HAProxyCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"CertmongerCA\": {\"type\": \"string\", \"default\": \"\", \"description\": \"CA to use for certmonger\"}, \"HAProxyCertificateDNSNames\": {\"type\": \"comma_delimited_list\", \"default\": [], \"description\": \"Override the default HAProxy Certificate DNS Names\"}, \"HAProxyCertificatePrincipal\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the default HAProxy Certificate Principal\"}}, \"conditions\": {\"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"HAProxyCertificateKeySize\"}, \"\"]}}, \"principal_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"HAProxyCertificatePrincipal\"}, \"\"]}}, \"dnsnames_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"HAProxyCertificateDNSNames\"}, []]}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the HAProxy public TLS via certmonger role.\", \"value\": {\"service_name\": \"haproxy_public_tls_certmonger\", \"config_settings\": {\"tripleo::haproxy::service_certificate\": {\"get_param\": \"DeployedSSLCertificatePath\"}}, \"certificates_specs\": {\"haproxy-external\": {\"service_pem\": {\"get_param\": \"DeployedSSLCertificatePath\"}}}, \"metadata_settings\": [{\"service\": \"haproxy\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"type\": \"vip\"}], \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": \"step|int == 1\", \"vars\": {\"certmonger_ca\": {\"get_param\": \"CertmongerCA\"}}, \"block\": [{\"name\": \"make sure certmonger is installed\", \"package\": {\"name\": \"certmonger\", \"state\": \"present\"}}, {\"name\": \"make sure certmonger service is started\", \"systemd\": {\"state\": \"started\", \"enabled\": true, \"masked\": false, \"name\": \"certmonger.service\"}}, {\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [{\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}, {\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}]}, {\"name\": \"Extract and trust certmonger\'s local CA\", \"shell\": \"set -e\\nca_pem=\'/etc/pki/ca-trust/source/anchors/cm-local-ca.pem\'\\nopenssl pkcs12 -in /var/lib/certmonger/local/creds -out ${ca_pem} -nokeys -nodes -passin pass:\'\'\\nchmod 0644 ${ca_pem}\\nupdate-ca-trust extract\\ntest -e ${ca_pem} && openssl x509 -checkend 0 -noout -in ${ca_pem}\\n\", \"retries\": 5, \"delay\": 1, \"register\": \"local_ca_extract_result\", \"until\": \"local_ca_extract_result.rc == 0\", \"when\": \"certmonger_ca != \'IPA\' and (ipa_realm is not defined)\"}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"haproxy-external-cert\", \"dns\": {\"if\": [\"dnsnames_override_set\", {\"get_param\": \"HAProxyCertificateDNSNames\"}, {\"str_replace\": {\"template\": \"{{cloud_names.cloud_name_NETWORK}}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}}}]}, \"ip\": {\"if\": [\"dnsnames_override_set\", {\"str_replace\": {\"template\": \"{{DNSNAMES|ipaddr}}\", \"params\": {\"DNSNAMES\": {\"get_param\": \"HAProxyCertificateDNSNames\"}}}}, {\"str_replace\": {\"template\": \"{{[cloud_names.cloud_name_NETWORK]|ipaddr}}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}}}]}, \"principal\": {\"if\": [\"principal_override_set\", {\"get_param\": \"HAProxyCertificatePrincipal\"}, {\"str_replace\": {\"template\": \"haproxy/{{cloud_names.cloud_name_NETWORK}}@{{idm_realm|default(\'UNDERCLOUD\')}}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}}}]}, \"run_after\": {\"str_replace\": {\"template\": \"# Copy crt and key for backward compatibility\\ncp \\\"/etc/pki/tls/certs/haproxy-external-cert.crt\\\" \\\"CERTSDIR/overcloud-haproxy-external.crt\\\"\\ncp \\\"/etc/pki/tls/private/haproxy-external-cert.key\\\" \\\"KEYSDIR/overcloud-haproxy-external.key\\\"\\n\\nca_type=CATYPE\\nif [ \\\"$ca_type\\\" = \\\"self-sign\\\" ]; then\\n  # refresh the ca cert just in case the ca cert has been renewed\\n  ca_pem=\'/etc/pki/ca-trust/source/anchors/cm-local-ca.pem\'\\n  openssl pkcs12 -in /var/lib/certmonger/local/creds -out ${ca_pem} -nokeys -nodes -passin pass:\'\'\\n  chmod 0644 ${ca_pem}\\n  update-ca-trust extract\\n  test -e ${ca_pem} && openssl x509 -checkend 0 -noout -in ${ca_pem}\\n  openssl x509 -in ${ca_pem} -out /tmp/cm-local-ca.pem\\n  ca_path=\\\"/tmp/cm-local-ca.pem\\\"\\nelse\\n  ca_path=\\\"/etc/ipa/ca.crt\\\"\\nfi\\n\\nservice_crt=\\\"CERTSDIR/overcloud-haproxy-external.crt\\\"\\nservice_key=\\\"KEYSDIR/overcloud-haproxy-external.key\\\"\\nservice_pem=\\\"PEMPATH\\\"\\n\\ncat \\\"$service_crt\\\" \\\"$ca_path\\\" \\\"$service_key\\\" > \\\"$service_pem\\\"\\n\\ncontainer_name=$({{container_cli}} ps --format=\\\\{\\\\{.Names\\\\}\\\\} | grep -w -E \'haproxy(-bundle-.*-[0-9]+)?\')\\n# Inject the new pem into the running container\\nif echo \\\"$container_name\\\" | grep -q \\\"^haproxy-bundle\\\"; then\\n  # lp#1917868: Do not use podman cp with HA containers as they get\\n  # frozen temporarily and that can make pacemaker operation fail.\\n  tar -c \\\"$service_pem\\\" | {{container_cli}} exec -i \\\"$container_name\\\" tar -C / -xv\\n  # no need to update the mount point, because pacemaker\\n  # recreates the container when it\'s restarted\\nelse\\n  # Refresh the pem at the mount-point\\n  {{container_cli}} cp $service_pem \\\"$container_name:/var/lib/kolla/config_files/src-tls/$service_pem\\\"\\n  # Copy the new pem from the mount-point to the real path\\n  {{container_cli}} exec \\\"$container_name\\\" cp \\\"/var/lib/kolla/config_files/src-tls$service_pem\\\" \\\"$service_pem\\\"\\nfi\\n# Set appropriate permissions\\n{{container_cli}} exec \\\"$container_name\\\" chown haproxy:haproxy \\\"$service_pem\\\"\\n# Trigger a reload for HAProxy to read the new certificates\\n{{container_cli}} kill --signal HUP \\\"$container_name\\\"\\n\", \"params\": {\"CATYPE\": \"{{ (certmonger_ca == \'IPA\' or idm_realm is defined) | ternary(\'ipa\', \'self-sign\') }}\", \"CERTSDIR\": {\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}, \"KEYSDIR\": {\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}, \"PEMPATH\": {\"get_param\": \"DeployedSSLCertificatePath\"}}}}, \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"HAProxyCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"{{ (certmonger_ca == \'IPA\' or idm_realm is defined) | ternary(\'ipa\', \'self-sign\') }}\"}]}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(196,'2026-06-09 08:02:24',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Add services and subhosts to IPA server\", \"parameters\": {\"RoleNetIpMap\": {\"default\": {}, \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"PythonInterpreter\": {\"type\": \"string\", \"description\": \"The python interpreter to use for python and ansible actions\", \"default\": \"$(command -v python3 || command -v python)\"}, \"IdMDomain\": {\"default\": \"ooo.test\", \"description\": \"IDM domain to register IDM client. Typically, this is discovered through DNS and does not have to be set explicitly.\", \"type\": \"string\"}, \"IdMServer\": {\"default\": \"ipa.ooo.test\", \"description\": \"FQDN for the FreeIPA server.  If you set this value, IdMDomain also has to be provided.  Typically, this is discovered through DNS and does not have to be set explicitly.\", \"type\": \"comma_delimited_list\"}, \"IdMNovaKeytab\": {\"default\": \"FILE:/etc/novajoin/krb5.keytab\", \"description\": \"keytab for the nova/[host fqdn] user on the FreeIPA server.\", \"type\": \"string\"}, \"IdMNovaCredentialCache\": {\"default\": \"/etc/novajoin/krb5.cache\", \"description\": \"credential cache for nova/[host fqdn] user\", \"type\": \"string\"}, \"MakeHomeDir\": {\"type\": \"boolean\", \"description\": \"Configure PAM to create a users home directory if it does not exist.\", \"default\": false}, \"IdMNoNtpSetup\": {\"default\": false, \"description\": \"Set to true to add --no-ntp to the IDM client install call. This will cause IDM client install not to set up NTP.\", \"type\": \"boolean\"}, \"IdMEnrollBaseServer\": {\"default\": true, \"description\": \"Set to true to enroll the base server (computes, controllers)\", \"type\": \"boolean\"}, \"IdMInstallClientPackages\": {\"default\": false, \"description\": \"Set to True to have ansible-freeipa install ipa client packages on the overcloud node.\", \"type\": \"boolean\"}, \"IdMModifyDNS\": {\"default\": true, \"description\": \"Set to false to disable DNS records manipulation in the FreeIPA server.\", \"type\": \"boolean\"}, \"IdMZoneSplitIPv4\": {\"default\": 1, \"description\": \"The level by which the PTR DNS record is split when creating zones.\", \"type\": \"string\"}, \"IdMZoneSplitIPv6\": {\"default\": 1, \"description\": \"The level by which the PTR DNS record is split when creating zones.\", \"type\": \"string\"}}, \"conditions\": {\"idm_server_provided\": {\"not\": {\"equals\": [{\"get_param\": \"IdMServer\"}, []]}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the ipaservice service\", \"value\": {\"service_name\": \"ipaservice\", \"upgrade_tasks\": [], \"step_config\": \"\", \"ipa_registration_tasks\": [{\"name\": \"Get undercloud FQDN\", \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"set_fact\": {\"undercloud_fqdn\": \"{{ ansible_facts[\'fqdn\'] }}\"}}, {\"include_role\": {\"name\": \"tripleo_ipa_registration\", \"apply\": {\"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"environment\": {\"map_merge\": [{\"IPA_USER\": \"nova/{{ undercloud_fqdn }}\", \"KRB5_CLIENT_KTNAME\": {\"get_param\": \"IdMNovaKeytab\"}, \"KRB5CCNAME\": {\"get_param\": \"IdMNovaCredentialCache\"}}, {\"if\": [\"idm_server_provided\", {\"IPA_HOST\": {\"get_param\": [\"IdMServer\", 0]}}]}]}}}, \"vars\": {\"tripleo_ipa_enroll_base_server\": {\"get_param\": \"IdMEnrollBaseServer\"}, \"tripleo_ipa_delegate_server\": \"{{ inventory_hostname }}\", \"tripleo_ipa_base_server_fqdn\": \"{{ fqdn_canonical }}\", \"tripleo_ipa_server_metadata\": \"{{ service_metadata_settings | to_json }}\"}, \"when\": \"\'ipaservice\' in group_names and \'excluded_overcloud\' not in group_names\"}, {\"name\": \"Enroll the node as an ipa client\", \"vars\": {\"ipaclient_install_packages\": {\"get_param\": \"IdMInstallClientPackages\"}, \"idm_enroll_base_server\": {\"get_param\": \"IdMEnrollBaseServer\"}}, \"block\": [{\"name\": \"check if default.conf exists\", \"stat\": {\"path\": \"/etc/ipa/default.conf\"}, \"register\": \"ipa_conf_exists\"}, {\"name\": \"install openssl-perl\", \"become\": true, \"package\": {\"name\": \"openssl-perl\", \"state\": \"present\"}, \"when\": [\"ipaclient_install_packages|bool\"]}, {\"name\": \"register as an ipa client\", \"include_role\": {\"name\": \"ipaclient\", \"apply\": {\"become\": true}}, \"vars\": {\"map_merge\": [{\"state\": \"present\", \"ipaclient_otp\": \"{{ ipa_host_otp }}\", \"ipaclient_mkhomedir\": {\"get_param\": \"MakeHomeDir\"}, \"ipaclient_no_ntp\": {\"get_param\": \"IdMNoNtpSetup\"}, \"ipaclient_force\": true, \"ipaclient_hostname\": \"{{ fqdn_canonical }}\", \"ansible_fqdn\": \"{{ ipaclient_hostname }}\", \"ipaclients\": [\"ipaclient_hostname\"], \"ansible_distribution\": \"{{ ansible_facts[\'distribution\'] }}\", \"ansible_distribution_major_version\": \"{{ ansible_facts[\'distribution_major_version\'] }}\", \"ansible_distribution_release\": \"{{ ansible_facts[\'distribution_release\'] }}\", \"ansible_distribution_version\": \"{{ ansible_facts[\'distribution_version\'] }}\", \"ansible_os_family\": \"{{ ansible_facts[\'os_family\'] }}\"}, {\"if\": [\"idm_server_provided\", {\"ipaclient_servers\": {\"get_param\": \"IdMServer\"}, \"ipaclient_domain\": {\"get_param\": \"IdMDomain\"}}]}]}, \"when\": [\"idm_enroll_base_server|bool\", \"not ipa_conf_exists.stat.exists\"]}, {\"name\": \"restart certmonger service\", \"become\": true, \"systemd\": {\"state\": \"restarted\", \"daemon_reload\": true, \"name\": \"certmonger.service\"}, \"when\": [\"idm_enroll_base_server|bool\", \"not ipa_conf_exists.stat.exists\"]}, {\"name\": \"set discovered ipa realm\", \"set_fact\": {\"idm_realm\": {\"str_replace\": {\"template\": \"{{ lookup(\'ini\', \'realm default=DEFAULT section=global file=/etc/ipa/default.conf\')}}\", \"params\": {\"DEFAULT\": {\"yaql\": {\"expression\": \"$.data.toUpper()\", \"data\": {\"get_param\": \"IdMDomain\"}}}}}}}}], \"when\": \"\'ipaservice\' in group_names and \'excluded_overcloud\' not in group_names\"}], \"external_deploy_tasks\": [{\"name\": \"add the DNS entries into IPA in step 1\", \"when\": \"step|int == 1\", \"block\": [{\"include_role\": {\"name\": \"tripleo_ipa_dns\"}, \"vars\": {\"tripleo_ipa_ptr_zone_split_ipv4\": {\"get_param\": \"IdMZoneSplitIPv4\"}, \"tripleo_ipa_ptr_zone_split_ipv6\": {\"get_param\": \"IdMZoneSplitIPv6\"}}, \"when\": {\"get_param\": \"IdMModifyDNS\"}}], \"environment\": {\"map_merge\": [{\"IPA_USER\": \"nova/{{ ansible_facts[\'fqdn\'] }}\", \"KRB5_CLIENT_KTNAME\": {\"get_param\": \"IdMNovaKeytab\"}, \"KRB5CCNAME\": {\"get_param\": \"IdMNovaCredentialCache\"}}, {\"if\": [\"idm_server_provided\", {\"IPA_HOST\": {\"get_param\": [\"IdMServer\", 0]}}]}]}}], \"scale_tasks\": [{\"when\": \"step|int == 1\", \"tags\": \"down\", \"block\": [{\"name\": \"unregister node from ipa server\", \"import_role\": {\"name\": \"tripleo_ipa_cleanup\"}, \"delegate_to\": \"{{ groups[\'Undercloud\'] | first }}\", \"vars\": {\"tripleo_ipa_keytab\": {\"get_param\": \"IdMNovaKeytab\"}, \"tripleo_ipa_hosts_to_delete\": [\"{{ fqdn_canonical }}\"]}}]}], \"external_upgrade_tasks\": [{\"when\": \"step|int == 1\", \"block\": [{\"name\": \"check if ipa server has required permissions\", \"import_role\": {\"name\": \"tls_everywhere\", \"tasks_from\": \"ipa-server-check\"}, \"tags\": [\"opendev-validation\", \"opendev-validation-tls-everywhere\"]}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(197,'2026-06-09 08:02:24',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(198,'2026-06-09 08:02:24',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"HAProxy deployment with TLS enabled, powered by certmonger\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"HAProxyInternalTLSCertsDirectory\": {\"default\": \"/etc/pki/tls/certs/haproxy\", \"type\": \"string\"}, \"HAProxyInternalTLSKeysDirectory\": {\"default\": \"/etc/pki/tls/private/haproxy\", \"type\": \"string\"}, \"DeployedSSLCertificatePath\": {\"default\": \"/etc/pki/tls/private/overcloud_endpoint.pem\", \"description\": \"The filepath of the certificate as it will be stored in the controller.\\n\", \"type\": \"string\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"HAProxyCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"CertmongerCA\": {\"type\": \"string\", \"default\": \"\", \"description\": \"CA to use for certmonger\"}, \"HAProxyCertificateDNSNames\": {\"type\": \"comma_delimited_list\", \"default\": [], \"description\": \"Override the default HAProxy Certificate DNS Names\"}, \"HAProxyCertificatePrincipal\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the default HAProxy Certificate Principal\"}}, \"conditions\": {\"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"HAProxyCertificateKeySize\"}, \"\"]}}, \"principal_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"HAProxyCertificatePrincipal\"}, \"\"]}}, \"dnsnames_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"HAProxyCertificateDNSNames\"}, []]}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the HAProxy public TLS via certmonger role.\", \"value\": {\"service_name\": \"haproxy_public_tls_certmonger\", \"config_settings\": {\"tripleo::haproxy::service_certificate\": {\"get_param\": \"DeployedSSLCertificatePath\"}}, \"certificates_specs\": {\"haproxy-external\": {\"service_pem\": {\"get_param\": \"DeployedSSLCertificatePath\"}}}, \"metadata_settings\": [{\"service\": \"haproxy\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}, \"type\": \"vip\"}], \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": \"step|int == 1\", \"vars\": {\"certmonger_ca\": {\"get_param\": \"CertmongerCA\"}}, \"block\": [{\"name\": \"make sure certmonger is installed\", \"package\": {\"name\": \"certmonger\", \"state\": \"present\"}}, {\"name\": \"make sure certmonger service is started\", \"systemd\": {\"state\": \"started\", \"enabled\": true, \"masked\": false, \"name\": \"certmonger.service\"}}, {\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [{\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}, {\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}]}, {\"name\": \"Extract and trust certmonger\'s local CA\", \"shell\": \"set -e\\nca_pem=\'/etc/pki/ca-trust/source/anchors/cm-local-ca.pem\'\\nopenssl pkcs12 -in /var/lib/certmonger/local/creds -out ${ca_pem} -nokeys -nodes -passin pass:\'\'\\nchmod 0644 ${ca_pem}\\nupdate-ca-trust extract\\ntest -e ${ca_pem} && openssl x509 -checkend 0 -noout -in ${ca_pem}\\n\", \"retries\": 5, \"delay\": 1, \"register\": \"local_ca_extract_result\", \"until\": \"local_ca_extract_result.rc == 0\", \"when\": \"certmonger_ca != \'IPA\' and (ipa_realm is not defined)\"}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"haproxy-external-cert\", \"dns\": {\"if\": [\"dnsnames_override_set\", {\"get_param\": \"HAProxyCertificateDNSNames\"}, {\"str_replace\": {\"template\": \"{{cloud_names.cloud_name_NETWORK}}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}}}]}, \"ip\": {\"if\": [\"dnsnames_override_set\", {\"str_replace\": {\"template\": \"{{DNSNAMES|ipaddr}}\", \"params\": {\"DNSNAMES\": {\"get_param\": \"HAProxyCertificateDNSNames\"}}}}, {\"str_replace\": {\"template\": \"{{[cloud_names.cloud_name_NETWORK]|ipaddr}}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}}}]}, \"principal\": {\"if\": [\"principal_override_set\", {\"get_param\": \"HAProxyCertificatePrincipal\"}, {\"str_replace\": {\"template\": \"haproxy/{{cloud_names.cloud_name_NETWORK}}@{{idm_realm|default(\'UNDERCLOUD\')}}\", \"params\": {\"NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"PublicNetwork\"]}}}}]}, \"run_after\": {\"str_replace\": {\"template\": \"# Copy crt and key for backward compatibility\\ncp \\\"/etc/pki/tls/certs/haproxy-external-cert.crt\\\" \\\"CERTSDIR/overcloud-haproxy-external.crt\\\"\\ncp \\\"/etc/pki/tls/private/haproxy-external-cert.key\\\" \\\"KEYSDIR/overcloud-haproxy-external.key\\\"\\n\\nca_type=CATYPE\\nif [ \\\"$ca_type\\\" = \\\"self-sign\\\" ]; then\\n  # refresh the ca cert just in case the ca cert has been renewed\\n  ca_pem=\'/etc/pki/ca-trust/source/anchors/cm-local-ca.pem\'\\n  openssl pkcs12 -in /var/lib/certmonger/local/creds -out ${ca_pem} -nokeys -nodes -passin pass:\'\'\\n  chmod 0644 ${ca_pem}\\n  update-ca-trust extract\\n  test -e ${ca_pem} && openssl x509 -checkend 0 -noout -in ${ca_pem}\\n  openssl x509 -in ${ca_pem} -out /tmp/cm-local-ca.pem\\n  ca_path=\\\"/tmp/cm-local-ca.pem\\\"\\nelse\\n  ca_path=\\\"/etc/ipa/ca.crt\\\"\\nfi\\n\\nservice_crt=\\\"CERTSDIR/overcloud-haproxy-external.crt\\\"\\nservice_key=\\\"KEYSDIR/overcloud-haproxy-external.key\\\"\\nservice_pem=\\\"PEMPATH\\\"\\n\\ncat \\\"$service_crt\\\" \\\"$ca_path\\\" \\\"$service_key\\\" > \\\"$service_pem\\\"\\n\\ncontainer_name=$({{container_cli}} ps --format=\\\\{\\\\{.Names\\\\}\\\\} | grep -w -E \'haproxy(-bundle-.*-[0-9]+)?\')\\n# Inject the new pem into the running container\\nif echo \\\"$container_name\\\" | grep -q \\\"^haproxy-bundle\\\"; then\\n  # lp#1917868: Do not use podman cp with HA containers as they get\\n  # frozen temporarily and that can make pacemaker operation fail.\\n  tar -c \\\"$service_pem\\\" | {{container_cli}} exec -i \\\"$container_name\\\" tar -C / -xv\\n  # no need to update the mount point, because pacemaker\\n  # recreates the container when it\'s restarted\\nelse\\n  # Refresh the pem at the mount-point\\n  {{container_cli}} cp $service_pem \\\"$container_name:/var/lib/kolla/config_files/src-tls/$service_pem\\\"\\n  # Copy the new pem from the mount-point to the real path\\n  {{container_cli}} exec \\\"$container_name\\\" cp \\\"/var/lib/kolla/config_files/src-tls$service_pem\\\" \\\"$service_pem\\\"\\nfi\\n# Set appropriate permissions\\n{{container_cli}} exec \\\"$container_name\\\" chown haproxy:haproxy \\\"$service_pem\\\"\\n# Trigger a reload for HAProxy to read the new certificates\\n{{container_cli}} kill --signal HUP \\\"$container_name\\\"\\n\", \"params\": {\"CATYPE\": \"{{ (certmonger_ca == \'IPA\' or idm_realm is defined) | ternary(\'ipa\', \'self-sign\') }}\", \"CERTSDIR\": {\"get_param\": \"HAProxyInternalTLSCertsDirectory\"}, \"KEYSDIR\": {\"get_param\": \"HAProxyInternalTLSKeysDirectory\"}, \"PEMPATH\": {\"get_param\": \"DeployedSSLCertificatePath\"}}}}, \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"HAProxyCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"{{ (certmonger_ca == \'IPA\' or idm_realm is defined) | ternary(\'ipa\', \'self-sign\') }}\"}]}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (199,'2026-06-09 08:02:25',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Manila API service\\n\", \"parameters\": {\"ContainerManilaApiImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\"}, \"ContainerManilaConfigImage\": {\"description\": \"The container image to use for the manila config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"ManilaWorkers\": {\"type\": \"string\", \"description\": \"Set the number of workers for manila::wsgi::apache\", \"default\": \"%{::os_workers}\"}, \"ManilaPassword\": {\"description\": \"The password for the manila service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"ManilaApiPolicies\": {\"description\": \"A hash of policies to configure for Manila API.\\ne.g. { manila-context_is_admin: { key: context_is_admin, value: \'role:admin\' } }\\n\", \"default\": {}, \"type\": \"json\"}, \"MonitoringSubscriptionManilaApi\": {\"default\": \"overcloud-manila-api\", \"type\": \"string\"}, \"ManilaEnabledShareProtocols\": {\"default\": \"\", \"description\": \"List of protocols to be allowed for share creation in manila. When not set, the list is inferred via the storage back end/s enabled.\", \"type\": \"comma_delimited_list\"}, \"ManilaCronDbPurgeMinute\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Minute\\n\", \"default\": \"1\"}, \"ManilaCronDbPurgeHour\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Hour\\n\", \"default\": \"0\"}, \"ManilaCronDbPurgeMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month Day\\n\", \"default\": \"*\"}, \"ManilaCronDbPurgeMonth\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month\\n\", \"default\": \"*\"}, \"ManilaCronDbPurgeWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Week Day\\n\", \"default\": \"*\"}, \"ManilaCronDbPurgeUser\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - User\\n\", \"default\": \"manila\"}, \"ManilaCronDbPurgeAge\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age\\n\", \"default\": \"30\"}, \"ManilaCronDbPurgeDestination\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Log destination\\n\", \"default\": \"/var/log/manila/manila-rowsflush.log\"}, \"ManilaCronDbPurgeMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Delay\\n\", \"default\": \"3600\"}, \"MemcacheUseAdvancedPool\": {\"type\": \"boolean\", \"description\": \"Use the advanced (eventlet safe) memcached client pool.\\n\", \"default\": true}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"ManilaBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-base.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"ApacheServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"EnableInternalTLS\": {\"get_param\": \"EnableInternalTLS\"}}}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerManilaApiImage\": \"ContainerManilaApiImage\", \"ContainerManilaConfigImage\": \"ContainerManilaConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerManilaApiImage\": {\"get_param\": \"ContainerManilaApiImage\"}, \"ContainerManilaConfigImage\": {\"get_param\": \"ContainerManilaConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Manila API role.\", \"value\": {\"service_name\": \"manila_api\", \"firewall_rules\": {\"150 manila\": {\"dport\": [8786]}}, \"firewall_frontend_rules\": {\"100 manila_haproxy_frontend\": {\"dport\": [8786]}}, \"firewall_ssl_frontend_rules\": {\"100 manila_haproxy_frontend_ssl\": {\"dport\": [13786]}}, \"keystone_resources\": {\"manila\": {\"endpoints\": {\"public\": {\"get_param\": [\"EndpointMap\", \"ManilaV1Public\", \"uri\"]}, \"internal\": {\"get_param\": [\"EndpointMap\", \"ManilaV1Internal\", \"uri\"]}, \"admin\": {\"get_param\": [\"EndpointMap\", \"ManilaV1Admin\", \"uri\"]}}, \"users\": {\"manila\": {\"password\": {\"get_param\": \"ManilaPassword\"}}}, \"region\": {\"get_param\": \"KeystoneRegion\"}, \"service\": \"share\"}, \"manilav2\": {\"endpoints\": {\"public\": {\"get_param\": [\"EndpointMap\", \"ManilaPublic\", \"uri\"]}, \"internal\": {\"get_param\": [\"EndpointMap\", \"ManilaInternal\", \"uri\"]}, \"admin\": {\"get_param\": [\"EndpointMap\", \"ManilaAdmin\", \"uri\"]}}, \"users\": {\"manilav2\": {\"password\": {\"get_param\": \"ManilaPassword\"}}}, \"region\": {\"get_param\": \"KeystoneRegion\"}, \"service\": \"sharev2\"}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionManilaApi\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"ManilaBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"config_settings\"]}, {\"manila::keystone::authtoken::password\": {\"get_param\": \"ManilaPassword\"}, \"manila::keystone::authtoken::www_authenticate_uri\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"manila::keystone::authtoken::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"manila::keystone::authtoken::project_name\": \"service\", \"manila::keystone::authtoken::user_domain_name\": \"Default\", \"manila::keystone::authtoken::project_domain_name\": \"Default\", \"manila::keystone::authtoken::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"manila::keystone::authtoken::interface\": \"internal\", \"manila::keystone::authtoken::memcache_use_advanced_pool\": {\"get_param\": \"MemcacheUseAdvancedPool\"}, \"manila::api::bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}}}, \"manila::wsgi::apache::bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}}}, \"manila::wsgi::apache::ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"manila::api::service_name\": \"httpd\", \"manila::api::enable_proxy_headers_parsing\": true, \"manila::api::default_share_type\": \"default\", \"manila_enabled_share_protocols\": {\"get_param\": \"ManilaEnabledShareProtocols\"}, \"manila::policy::policies\": {\"get_param\": \"ManilaApiPolicies\"}, \"manila::cron::db_purge::minute\": {\"get_param\": \"ManilaCronDbPurgeMinute\"}, \"manila::cron::db_purge::hour\": {\"get_param\": \"ManilaCronDbPurgeHour\"}, \"manila::cron::db_purge::monthday\": {\"get_param\": \"ManilaCronDbPurgeMonthday\"}, \"manila::cron::db_purge::month\": {\"get_param\": \"ManilaCronDbPurgeMonth\"}, \"manila::cron::db_purge::weekday\": {\"get_param\": \"ManilaCronDbPurgeWeekday\"}, \"manila::cron::db_purge::user\": {\"get_param\": \"ManilaCronDbPurgeUser\"}, \"manila::cron::db_purge::age\": {\"get_param\": \"ManilaCronDbPurgeAge\"}, \"manila::cron::db_purge::destination\": {\"get_param\": \"ManilaCronDbPurgeDestination\"}, \"manila::cron::db_purge::maxdelay\": {\"get_param\": \"ManilaCronDbPurgeMaxDelay\"}, \"manila::wsgi::apache::servername\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ManilaApiNetwork\"]}}}}, \"manila::wsgi::apache::workers\": {\"get_param\": \"ManilaWorkers\"}}]}, \"service_config_settings\": {\"get_attr\": [\"ManilaBase\", \"role_data\", \"service_config_settings\"]}, \"puppet_config\": {\"config_volume\": \"manila\", \"puppet_tags\": \"manila_config,manila_api_paste_ini\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::manila::api\", {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerManilaConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/manila_api.json\": {\"command\": \"/usr/sbin/httpd -DFOREGROUND\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/manila\", \"owner\": \"manila:manila\", \"recurse\": true}]}, \"/var/lib/kolla/config_files/manila_api_db_sync.json\": {\"command\": \"/usr/bin/bootstrap_host_exec manila_api su manila -s /bin/bash -c \'/usr/bin/manila-manage db sync\'\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/manila\", \"owner\": \"manila:manila\", \"recurse\": true}]}, \"/var/lib/kolla/config_files/manila_api_cron.json\": {\"command\": \"/usr/sbin/crond -n\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/manila\", \"owner\": \"manila:manila\", \"recurse\": true}]}}, \"docker_config\": {\"step_2\": {\"manila_init_logs\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerManilaApiImage\"]}, \"net\": \"none\", \"user\": \"root\", \"volumes\": [\"/var/log/containers/manila:/var/log/manila:z\", \"/var/log/containers/httpd/manila-api:/var/log/httpd:z\"], \"command\": [\"/bin/bash\", \"-c\", \"chown -R manila:manila /var/log/manila\"]}}, \"step_3\": {\"manila_api_db_sync\": {\"user\": \"root\", \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerManilaApiImage\"]}, \"cap_add\": [\"AUDIT_WRITE\"], \"net\": \"host\", \"detach\": false, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/manila_api_db_sync.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/manila:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/manila:/var/log/manila:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}, \"step_4\": {\"manila_api\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerManilaApiImage\"]}, \"net\": \"host\", \"restart\": \"always\", \"user\": \"root\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/manila_api.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/manila:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/manila:/var/log/manila:z\", \"/var/log/containers/httpd/manila-api:/var/log/httpd:z\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"manila_api_cron\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerManilaApiImage\"]}, \"net\": \"host\", \"user\": \"root\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/usr/share/openstack-tripleo-common/healthcheck/cron manila\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/manila_api_cron.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/manila:/var/lib/kolla/config_files/src:ro\", \"/var/log/containers/manila:/var/log/manila:z\", \"/var/log/containers/httpd/manila-api:/var/log/httpd:z\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"metadata_settings\": {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"metadata_settings\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"deploy_steps_tasks\"]}, \"host_prep_tasks\": [{\"name\": \"Create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode|default(omit) }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/manila\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/log/containers/httpd/manila-api\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}], \"upgrade_tasks\": [], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop manila api container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"manila_api\"], \"tripleo_delegate_to\": \"{{ groups[\'manila_api\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(200,'2026-06-09 08:02:25',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Apache service configured with Puppet. Note this is typically included automatically via other services which run via Apache.\\n\", \"parameters\": {\"ApacheMaxRequestWorkers\": {\"default\": 100, \"description\": \"Maximum number of simultaneously processed requests.\", \"type\": \"number\"}, \"ApacheServerLimit\": {\"default\": 100, \"description\": \"Maximum number of Apache processes.\", \"type\": \"number\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"ApacheCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"ApacheTimeout\": {\"type\": \"number\", \"default\": 90, \"description\": \"The timeout in seconds for Apache, which defines duration Apache waits for I/O operations\"}}, \"conditions\": {\"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"ApacheCertificateKeySize\"}, \"\"]}}}, \"resources\": {\"ApacheNetworks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"Controller\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"CellController\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"CellControllerCompute\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"Compute\": [\"ctlplane\", \"storage\", \"internal_api\"], \"BlockStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"ObjectStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"CephStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\"], \"Networker\": [\"ctlplane\", \"internal_api\"]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Apache role.\", \"value\": {\"service_name\": \"apache\", \"config_settings\": {\"map_merge\": [{\"apache::ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}}}}, \"apache::default_vhost\": false, \"apache::trace_enable\": \"Off\", \"apache::server_signature\": \"Off\", \"apache::server_tokens\": \"Prod\", \"apache::timeout\": {\"get_param\": \"ApacheTimeout\"}, \"apache::default_mods\": false, \"apache::mod::prefork::maxrequestworkers\": {\"get_param\": \"ApacheMaxRequestWorkers\"}, \"apache::mod::prefork::serverlimit\": {\"get_param\": \"ApacheServerLimit\"}, \"apache::mod::remoteip::proxy_ips\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}]}, \"apache::mod::alias::icons_options\": \"None\"}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"apache::mod::ssl::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}, \"apache::mod::ssl::ssl_protocol\": [\"all\", \"-SSLv2\", \"-SSLv3\", \"-TLSv1\"], \"apache_certificates_specs\": {\"map_merge\": {\"repeat\": {\"template\": {\"httpd-NETWORK\": {\"service_certificate\": \"/etc/pki/tls/certs/httpd/httpd-NETWORK.crt\", \"service_key\": \"/etc/pki/tls/private/httpd/httpd-NETWORK.key\"}}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}, \"metadata_settings\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"repeat\": {\"template\": [{\"service\": \"HTTP\", \"network\": \"$NETWORK\", \"type\": \"node\"}], \"for_each\": {\"$NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}]}, \"upgrade_tasks\": [], \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [\"/etc/pki/tls/certs/httpd\", \"/etc/pki/tls/private/httpd\"]}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": {\"repeat\": {\"template\": {\"name\": \"httpd-NETWORK\", \"dns\": \"{{ fqdn_NETWORK }}\", \"principal\": \"HTTP/{{ fqdn_NETWORK }}@{{ idm_realm }}\", \"run_after\": \"cp /etc/pki/tls/certs/httpd-NETWORK.crt /etc/pki/tls/certs/httpd/httpd-NETWORK.crt\\ncp /etc/pki/tls/private/httpd-NETWORK.key /etc/pki/tls/private/httpd/httpd-NETWORK.key\\npkill -USR1 httpd\\n\", \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"ApacheCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"EnableInternalTLS\": true}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(201,'2026-06-09 08:02:25',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Manila base service. Shared by manila-api/scheduler/share services\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ManilaIPv6\": {\"default\": false, \"description\": \"Set to True to enable IPv6 access in manila.\", \"type\": \"boolean\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"ManilaDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Manila services.\", \"type\": \"boolean\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"ManilaPassword\": {\"description\": \"The password for the manila service account.\", \"type\": \"string\", \"hidden\": true, \"default\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"ManilaStorageAvailabilityZone\": {\"default\": \"nova\", \"description\": \"The Manila service\'s storage availability zone.\", \"type\": \"string\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Manila Base service.\", \"value\": {\"service_name\": \"manila_base\", \"config_settings\": {\"manila::storage_availability_zone\": {\"get_param\": \"ManilaStorageAvailabilityZone\"}, \"manila::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"manila::logging::debug\": {\"if\": [{\"get_param\": \"ManilaDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"manila::db::database_db_max_retries\": -1, \"manila::db::database_max_retries\": -1, \"manila::sql_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"manila\", \"password\": {\"get_param\": \"ManilaPassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/manila\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"manila\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"manila::network::neutron::network_plugin_ipv6_enabled\": {\"get_param\": \"ManilaIPv6\"}, \"manila::network::neutron::network_plugin_ipv4_enabled\": {\"if\": [{\"get_param\": \"ManilaIPv6\"}, false, true]}, \"manila::rabbit_heartbeat_in_pthread\": false}, \"service_config_settings\": {\"mysql\": {\"manila::db::mysql::password\": {\"get_param\": \"ManilaPassword\"}, \"manila::db::mysql::user\": \"manila\", \"manila::db::mysql::host\": \"%\", \"manila::db::mysql::dbname\": \"manila\"}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(202,'2026-06-09 08:02:25',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized HAProxy API service\\n\", \"outputs\": {\"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": null}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_1\": {}}}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": null}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(203,'2026-06-09 08:02:26',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Keystone service\\n\", \"parameters\": {\"ContainerKeystoneImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\"}, \"ContainerKeystoneConfigImage\": {\"description\": \"The container image to use for the keystone config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"DeployIdentifier\": {\"default\": 1780992067, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"AdminPassword\": {\"description\": \"The password for the keystone admin account, used for monitoring, querying neutron etc.\", \"type\": \"string\", \"hidden\": true, \"default\": \"uvYUJnZlpg4RipBsqnjPENIXa\"}, \"KeystoneTokenProvider\": {\"description\": \"The keystone token format\", \"type\": \"string\", \"default\": \"fernet\", \"constraints\": [{\"allowed_values\": [\"fernet\"]}]}, \"SSLCertificate\": {\"default\": \"\", \"description\": \"The content of the SSL certificate (without Key) in PEM format.\\n\", \"type\": \"string\"}, \"PublicSSLCertificateAutogenerated\": {\"default\": true, \"description\": \"Whether the public SSL certificate was autogenerated or not.\\n\", \"type\": \"boolean\"}, \"EnablePublicTLS\": {\"default\": true, \"description\": \"Whether to enable TLS on the public interface or not.\\n\", \"type\": \"boolean\"}, \"PublicTLSCAFile\": {\"default\": \"\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the public network.\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"MemcachedTLS\": {\"default\": true, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}, \"KeystoneSSLCertificate\": {\"default\": \"\", \"description\": \"Keystone certificate for verifying token validity.\", \"type\": \"string\"}, \"KeystoneSSLCertificateKey\": {\"default\": \"\", \"description\": \"Keystone key for signing tokens.\", \"type\": \"string\", \"hidden\": true}, \"KeystoneNotificationFormat\": {\"description\": \"The Keystone notification format\", \"default\": \"basic\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"basic\", \"cadf\"]}]}, \"KeystoneNotificationTopics\": {\"description\": \"Keystone notification topics to enable\", \"default\": [], \"type\": \"comma_delimited_list\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"Debug\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Set to True to enable debugging on all services.\"}, \"KeystoneDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Keystone service.\", \"type\": \"boolean\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"AdminToken\": {\"description\": \"The keystone auth secret and db password.\", \"type\": \"string\", \"hidden\": true, \"default\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\"}, \"TokenExpiration\": {\"default\": 3600, \"description\": \"Set a token expiration time in seconds.\", \"type\": \"number\"}, \"KeystoneWorkers\": {\"type\": \"string\", \"description\": \"Set the number of workers for keystone::wsgi::apache\", \"default\": 1}, \"MonitoringSubscriptionKeystone\": {\"default\": \"overcloud-keystone\", \"type\": \"string\"}, \"KeystoneCredential0\": {\"type\": \"string\", \"description\": \"The first Keystone credential key. Must be a valid key.\", \"default\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\"}, \"KeystoneCredential1\": {\"type\": \"string\", \"description\": \"The second Keystone credential key. Must be a valid key.\", \"default\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\"}, \"KeystoneFernetKeys\": {\"type\": \"json\", \"description\": \"Mapping containing keystone\'s fernet keys and their paths.\", \"default\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}}, \"KeystoneFernetMaxActiveKeys\": {\"type\": \"number\", \"description\": \"The maximum active keys in the keystone fernet key repository.\", \"default\": 5}, \"ManageKeystoneFernetKeys\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Whether TripleO should manage the keystone fernet keys or not. If set to true, the fernet keys will get the values from the saved keys repository in mistral (the KeystoneFernetKeys variable). If set to false, only the stack creation initializes the keys, but subsequent updates won\'t touch them.\"}, \"KeystoneLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.keystone\", \"file\": \"/var/log/containers/keystone/keystone.log\"}}, \"KeystonePolicies\": {\"description\": \"A hash of policies to configure for Keystone.\\ne.g. { keystone-context_is_admin: { key: context_is_admin, value: \'role:admin\' } }\\n\", \"default\": {}, \"type\": \"json\"}, \"KeystoneLDAPDomainEnable\": {\"description\": \"Trigger to call ldap_backend puppet keystone define.\", \"type\": \"boolean\", \"default\": false}, \"KeystoneLDAPBackendConfigs\": {\"description\": \"Hash containing the configurations for the LDAP backends configured in keystone.\", \"type\": \"json\", \"default\": {}, \"hidden\": true}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"KeystoneNotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": [], \"description\": \"Driver or drivers to handle sending notifications. This parameter is\\nspecific to Keystone.\\n\"}, \"KeystoneEnableDBPurge\": {\"default\": true, \"description\": \"Whether to create cron job for purging soft deleted rows in Keystone database.\\n\", \"type\": \"boolean\"}, \"KeystoneCronTrustFlushEnsure\": {\"type\": \"string\", \"description\": \"Cron to purge expired or soft-deleted trusts - Ensure\\n\", \"default\": \"present\"}, \"KeystoneCronTrustFlushMinute\": {\"type\": \"string\", \"description\": \"Cron to purge expired or soft-deleted trusts - Minute\\n\", \"default\": \"1\"}, \"KeystoneCronTrustFlushHour\": {\"type\": \"string\", \"description\": \"Cron to purge expired or soft-deleted trusts - Hour\\n\", \"default\": \"*\"}, \"KeystoneCronTrustFlushMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge expired or soft-deleted trusts - Month Day\\n\", \"default\": \"*\"}, \"KeystoneCronTrustFlushMonth\": {\"type\": \"string\", \"description\": \"Cron to purge expired or soft-deleted trusts - Month\\n\", \"default\": \"*\"}, \"KeystoneCronTrustFlushWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge expired or soft-deleted trusts - Week Day\\n\", \"default\": \"*\"}, \"KeystoneCronTrustFlushMaxDelay\": {\"type\": \"number\", \"description\": \"Cron to purge expired or soft-deleted trusts - Max Delay\\n\", \"default\": 0}, \"KeystoneCronTrustFlushDestination\": {\"type\": \"string\", \"description\": \"Cron to purge expired or soft-deleted trusts - Log destination\\n\", \"default\": \"/var/log/keystone/keystone-trustflush.log\"}, \"KeystoneCronTrustFlushUser\": {\"type\": \"string\", \"description\": \"Cron to purge expired or soft-deleted trusts - User\\n\", \"default\": \"keystone\"}, \"KeystoneChangePasswordUponFirstUse\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Enabling this option requires users to change their password when the user is created, or upon administrative reset.\", \"constraints\": [{\"allowed_values\": [\"\", \"true\", \"True\", \"TRUE\", \"false\", \"False\", \"FALSE\"]}]}, \"KeystoneDisableUserAccountDaysInactive\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The maximum number of days a user can go without authenticating before being considered \\\"inactive\\\" and automatically disabled (locked).\"}, \"KeystoneLockoutDuration\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The number of seconds a user account will be locked when the maximum number of failed authentication attempts (as specified by KeystoneLockoutFailureAttempts) is exceeded.\"}, \"KeystoneLockoutFailureAttempts\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The maximum number of times that a user can fail to authenticate before the user account is locked for the number of seconds specified by KeystoneLockoutDuration.\"}, \"KeystoneMinimumPasswordAge\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The number of days that a password must be used before the user can change it. This prevents users from changing their passwords immediately in order to wipe out their password history and reuse an old password.\"}, \"KeystonePasswordExpiresDays\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The number of days for which a password will be considered valid before requiring it to be changed.\"}, \"KeystonePasswordRegex\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The regular expression used to validate password strength requirements.\"}, \"KeystonePasswordRegexDescription\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Describe your password regular expression here in language for humans.\"}, \"KeystoneUniqueLastPasswordCount\": {\"type\": \"string\", \"default\": \"\", \"description\": \"This controls the number of previous user password iterations to keep in history, in order to enforce that newly created passwords are unique.\"}, \"KeystoneCorsAllowedOrigin\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Indicate whether this resource may be shared with the domain received in the request \\\"origin\\\" header.\"}, \"KeystoneEnableMember\": {\"description\": \"Create the _member_ role, useful for undercloud deployment.\", \"type\": \"boolean\", \"default\": false}, \"KeystoneFederationEnable\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Enable support for federated authentication.\"}, \"KeystoneTrustedDashboards\": {\"type\": \"comma_delimited_list\", \"default\": [], \"description\": \"A list of dashboard URLs trusted for single sign-on.\"}, \"KeystoneAuthMethods\": {\"type\": \"comma_delimited_list\", \"default\": [], \"description\": \"A list of methods used for authentication.\"}, \"KeystoneOpenIdcEnable\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Enable support for OpenIDC federation.\"}, \"KeystoneOpenIdcIdpName\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The name associated with the IdP in Keystone.\"}, \"KeystoneOpenIdcProviderMetadataUrl\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The url that points to your OpenID Connect provider metadata\"}, \"KeystoneOpenIdcClientId\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The client ID to use when handshaking with your OpenID Connect provider\"}, \"KeystoneOpenIdcClientSecret\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The client secret to use when handshaking with your OpenID Connect provider\"}, \"KeystoneOpenIdcCryptoPassphrase\": {\"type\": \"string\", \"default\": \"openstack\", \"description\": \"Passphrase to use when encrypting data for OpenID Connect handshake.\"}, \"KeystoneOpenIdcOutgoingProxy\": {\"type\": \"string\", \"default\": \"\", \"description\": \"The outgoing proxy to use for OpenID connections.\"}, \"KeystoneOpenIdcResponseType\": {\"type\": \"string\", \"default\": \"id_token\", \"description\": \"Response type to be expected from the OpenID Connect provider.\"}, \"KeystoneOpenIdcRemoteIdAttribute\": {\"type\": \"string\", \"default\": \"OIDC-iss\", \"description\": \"Attribute to be used to obtain the entity ID of the Identity Provider from the environment.\"}, \"KeystoneOpenIdcEnableOAuth\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Enable OAuth 2.0 integration.\"}, \"KeystoneOpenIdcIntrospectionEndpoint\": {\"type\": \"string\", \"default\": \"\", \"description\": \"OAuth 2.0 introspection endpoint for mod_auth_openidc\"}, \"KeystoneOpenIdcClaimDelimiter\": {\"type\": \"string\", \"default\": \";\", \"description\": \"The delimiter to use when setting multi-valued claims.\"}, \"KeystoneOpenIdcPassUserInfoAs\": {\"type\": \"string\", \"default\": \"claims\", \"description\": \"Define the way(s) in which the claims resolved from the userinfo endpoint are passed to the application according to OIDCPassClaimsAs.\", \"constraints\": [{\"allowed_values\": [\"claims\", \"json\", \"jwt\"]}]}, \"KeystoneOpenIdcPassClaimsAs\": {\"type\": \"string\", \"default\": \"both\", \"description\": \"Define the way in which the claims and tokens are passed to the application environment: \\\"none\\\": no claims/tokens are passed \\\"environment\\\": claims/tokens are passed as environment variables \\\"headers\\\": claims/tokens are passed in headers (also useful in reverse proxy scenario\'s) \\\"both\\\": claims/tokens are passed as both headers as well as environment variables (default)\", \"constraints\": [{\"allowed_values\": [\"none\", \"environment\", \"headers\", \"both\"]}]}, \"RootStackName\": {\"description\": \"The name of the stack/plan.\", \"type\": \"string\", \"default\": \"overcloud\"}, \"EnforceSecureRbac\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Setting this option to True will configure each OpenStack service to enforce Secure RBAC by setting `[oslo_policy] enforce_new_defaults` and `[oslo_policy] enforce_scope` to True. This introduces a consistent set of RBAC personas across OpenStack services that include support for system and project scope, as well as keystone\'s default roles, admin, member, and reader. Do not enable this functionality until all services in your deployment actually support secure RBAC.\"}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"ApacheServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"EnableInternalTLS\": {\"get_param\": \"EnableInternalTLS\"}}}, \"KeystoneLogging\": {\"type\": \"OS::TripleO::Services::Logging::Keystone\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerKeystoneImage\": \"ContainerKeystoneImage\", \"ContainerKeystoneConfigImage\": \"ContainerKeystoneConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerKeystoneImage\": {\"get_param\": \"ContainerKeystoneImage\"}, \"ContainerKeystoneConfigImage\": {\"get_param\": \"ContainerKeystoneConfigImage\"}}}]}}}}, \"conditions\": {\"public_tls_enabled\": {\"and\": [{\"get_param\": \"EnablePublicTLS\"}, {\"or\": [{\"not\": {\"equals\": [{\"get_param\": \"SSLCertificate\"}, \"\"]}}, {\"get_param\": \"PublicSSLCertificateAutogenerated\"}]}]}, \"keystone_fernet_tokens\": {\"equals\": [{\"get_param\": \"KeystoneTokenProvider\"}, \"fernet\"]}, \"nontls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"not\": {\"get_param\": \"MemcachedTLS\"}}]}, \"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}, \"keystone_outgoing_proxy\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": \"KeystoneOpenIdcOutgoingProxy\"}, \"\"]}}, {\"get_param\": \"KeystoneOpenIdcEnable\"}]}, \"change_password_upon_first_use_set\": {\"not\": {\"equals\": [{\"get_param\": \"KeystoneChangePasswordUponFirstUse\"}, \"\"]}}, \"disable_user_account_days_inactive_set\": {\"not\": {\"equals\": [{\"get_param\": \"KeystoneDisableUserAccountDaysInactive\"}, \"\"]}}, \"lockout_duration_set\": {\"not\": {\"equals\": [{\"get_param\": \"KeystoneLockoutDuration\"}, \"\"]}}, \"lockout_failure_attempts_set\": {\"not\": {\"equals\": [{\"get_param\": \"KeystoneLockoutFailureAttempts\"}, \"\"]}}, \"minimum_password_age_set\": {\"not\": {\"equals\": [{\"get_param\": \"KeystoneMinimumPasswordAge\"}, \"\"]}}, \"password_expires_days_set\": {\"not\": {\"equals\": [{\"get_param\": \"KeystonePasswordExpiresDays\"}, \"\"]}}, \"password_regex_set\": {\"not\": {\"equals\": [{\"get_param\": \"KeystonePasswordRegex\"}, \"\"]}}, \"password_regex_description_set\": {\"not\": {\"equals\": [{\"get_param\": \"KeystonePasswordRegexDescription\"}, \"\"]}}, \"unique_last_password_count_set\": {\"not\": {\"equals\": [{\"get_param\": \"KeystoneUniqueLastPasswordCount\"}, \"\"]}}, \"cors_allowed_origin_set\": {\"not\": {\"equals\": [{\"get_param\": \"KeystoneCorsAllowedOrigin\"}, \"\"]}}, \"keystone_notification_driver_set\": {\"not\": {\"equals\": [{\"get_param\": \"KeystoneNotificationDriver\"}, []]}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Keystone API role.\", \"value\": {\"service_name\": \"keystone\", \"firewall_rules\": {\"111 keystone\": {\"dport\": [5000, {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}]}}, \"firewall_frontend_rules\": {\"100 keystone_public_haproxy_frontend\": {\"dport\": [5000]}, \"100 keystone_admin_haproxy_frontend\": {\"dport\": [{\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}]}}, \"firewall_ssl_frontend_rules\": {\"100 keystone_public_haproxy_frontend_ssl\": {\"dport\": [13000]}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionKeystone\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"config_settings\"]}, {\"if\": [\"cors_allowed_origin_set\", {\"keystone::cors::allowed_origin\": {\"get_param\": \"KeystoneCorsAllowedOrigin\"}}]}, {\"keystone::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"keystone\", \"password\": {\"get_param\": \"AdminToken\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/keystone\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"keystone\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"keystone::token_expiration\": {\"get_param\": \"TokenExpiration\"}, \"keystone::policy::policies\": {\"get_param\": \"KeystonePolicies\"}, \"keystone_ssl_certificate\": {\"get_param\": \"KeystoneSSLCertificate\"}, \"keystone_ssl_certificate_key\": {\"get_param\": \"KeystoneSSLCertificateKey\"}, \"keystone::token_provider\": {\"get_param\": \"KeystoneTokenProvider\"}, \"keystone::enable_fernet_setup\": {\"if\": [\"keystone_fernet_tokens\", true, false]}, \"keystone::fernet_max_active_keys\": {\"get_param\": \"KeystoneFernetMaxActiveKeys\"}, \"keystone::enable_proxy_headers_parsing\": true, \"keystone::enable_credential_setup\": true, \"keystone::credential_keys\": {\"/etc/keystone/credential-keys/0\": {\"content\": {\"get_param\": \"KeystoneCredential0\"}}, \"/etc/keystone/credential-keys/1\": {\"content\": {\"get_param\": \"KeystoneCredential1\"}}}, \"keystone::fernet_keys\": {\"get_param\": \"KeystoneFernetKeys\"}, \"keystone::fernet_replace_keys\": {\"get_param\": \"ManageKeystoneFernetKeys\"}, \"keystone::logging::debug\": {\"if\": [{\"get_param\": \"KeystoneDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"keystone::notification_driver\": {\"if\": [\"keystone_notification_driver_set\", {\"get_param\": \"KeystoneNotificationDriver\"}, {\"get_param\": \"NotificationDriver\"}]}, \"keystone::notification_format\": {\"get_param\": \"KeystoneNotificationFormat\"}, \"tripleo::profile::base::keystone::extra_notification_topics\": {\"get_param\": \"KeystoneNotificationTopics\"}, \"keystone_enable_db_purge\": {\"get_param\": \"KeystoneEnableDBPurge\"}, \"keystone::cron::trust_flush::ensure\": {\"get_param\": \"KeystoneCronTrustFlushEnsure\"}, \"keystone::cron::trust_flush::minute\": {\"get_param\": \"KeystoneCronTrustFlushMinute\"}, \"keystone::cron::trust_flush::hour\": {\"get_param\": \"KeystoneCronTrustFlushHour\"}, \"keystone::cron::trust_flush::monthday\": {\"get_param\": \"KeystoneCronTrustFlushMonthday\"}, \"keystone::cron::trust_flush::month\": {\"get_param\": \"KeystoneCronTrustFlushMonth\"}, \"keystone::cron::trust_flush::weekday\": {\"get_param\": \"KeystoneCronTrustFlushWeekday\"}, \"keystone::cron::trust_flush::maxdelay\": {\"get_param\": \"KeystoneCronTrustFlushMaxDelay\"}, \"keystone::cron::trust_flush::destination\": {\"get_param\": \"KeystoneCronTrustFlushDestination\"}, \"keystone::cron::trust_flush::user\": {\"get_param\": \"KeystoneCronTrustFlushUser\"}, \"keystone::rabbit_heartbeat_timeout_threshold\": 60, \"keystone::rabbit_heartbeat_in_pthread\": false, \"keystone::service_name\": \"httpd\", \"keystone::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"keystone::wsgi::apache::api_port\": [5000, {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"port\"]}], \"keystone::wsgi::apache::ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"keystone::wsgi::apache::servername\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}}}}, \"keystone::wsgi::apache::workers\": {\"get_param\": \"KeystoneWorkers\"}, \"keystone::wsgi::apache::threads\": 1, \"keystone::db::database_db_max_retries\": -1, \"keystone::db::database_max_retries\": -1, \"keystone::wsgi::apache::bind_host\": [{\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystonePublicApiNetwork\"]}}}}, {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"KeystoneAdminApiNetwork\"]}}}}]}, {\"keystone::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"keystone::cache::backend_argument\": [{\"str_replace\": {\"template\": \"memcached_expire_time: $EXPIRATION\", \"params\": {\"$EXPIRATION\": {\"get_param\": \"TokenExpiration\"}}}}], \"keystone::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}}, {\"if\": [\"tls_cache_enabled\", {\"keystone::cache::backend\": \"dogpile.cache.pymemcache\", \"keystone::token_caching\": true}, {\"keystone::cache::backend\": \"dogpile.cache.memcached\"}]}, {\"if\": [{\"get_param\": \"KeystoneFederationEnable\"}, {\"keystone_federation_enabled\": true, \"keystone::federation::trusted_dashboards\": {\"get_param\": \"KeystoneTrustedDashboards\"}}]}, {\"if\": [{\"get_param\": \"KeystoneOpenIdcEnable\"}, {\"keystone_openidc_enabled\": true, \"keystone::federation::openidc::methods\": {\"get_param\": \"KeystoneAuthMethods\"}, \"keystone::federation::openidc::keystone_url\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"keystone::federation::openidc::idp_name\": {\"get_param\": \"KeystoneOpenIdcIdpName\"}, \"keystone::federation::openidc::openidc_provider_metadata_url\": {\"get_param\": \"KeystoneOpenIdcProviderMetadataUrl\"}, \"keystone::federation::openidc::openidc_client_id\": {\"get_param\": \"KeystoneOpenIdcClientId\"}, \"keystone::federation::openidc::openidc_client_secret\": {\"get_param\": \"KeystoneOpenIdcClientSecret\"}, \"keystone::federation::openidc::openidc_crypto_passphrase\": {\"get_param\": \"KeystoneOpenIdcCryptoPassphrase\"}, \"keystone::federation::openidc::openidc_response_type\": {\"get_param\": \"KeystoneOpenIdcResponseType\"}, \"keystone::federation::openidc::remote_id_attribute\": {\"get_param\": \"KeystoneOpenIdcRemoteIdAttribute\"}, \"keystone::federation::openidc::openidc_enable_oauth\": {\"get_param\": \"KeystoneOpenIdcEnableOAuth\"}, \"keystone::federation::openidc::openidc_introspection_endpoint\": {\"get_param\": \"KeystoneOpenIdcIntrospectionEndpoint\"}, \"keystone::federation::openidc::openidc_pass_userinfo_as\": {\"get_param\": \"KeystoneOpenIdcPassUserInfoAs\"}, \"keystone::federation::openidc::openidc_pass_claim_as\": {\"get_param\": \"KeystoneOpenIdcPassClaimsAs\"}, \"keystone::federation::openidc::openidc_claim_delimiter\": {\"get_param\": \"KeystoneOpenIdcClaimDelimiter\"}, \"keystone::federation::openidc::openidc_cache_type\": {\"if\": [\"nontls_cache_enabled\", \"memcache\"]}}]}, {\"if\": [\"keystone_outgoing_proxy\", {\"keystone::federation::openidc::openidc_outgoing_proxy\": {\"get_param\": \"KeystoneOpenIdcOutgoingProxy\"}}]}, {\"if\": [{\"get_param\": \"KeystoneLDAPDomainEnable\"}, {\"tripleo::profile::base::keystone::ldap_backend_enable\": true, \"keystone::using_domain_config\": true, \"tripleo::profile::base::keystone::ldap_backends_config\": {\"get_param\": \"KeystoneLDAPBackendConfigs\"}}]}, {\"if\": [\"change_password_upon_first_use_set\", {\"keystone::security_compliance::change_password_upon_first_use\": {\"get_param\": \"KeystoneChangePasswordUponFirstUse\"}}]}, {\"if\": [\"disable_user_account_days_inactive_set\", {\"keystone::security_compliance::disable_user_account_days_inactive\": {\"get_param\": \"KeystoneDisableUserAccountDaysInactive\"}}]}, {\"if\": [\"lockout_duration_set\", {\"keystone::security_compliance::lockout_duration\": {\"get_param\": \"KeystoneLockoutDuration\"}}]}, {\"if\": [\"lockout_failure_attempts_set\", {\"keystone::security_compliance::lockout_failure_attempts\": {\"get_param\": \"KeystoneLockoutFailureAttempts\"}}]}, {\"if\": [\"minimum_password_age_set\", {\"keystone::security_compliance::minimum_password_age\": {\"get_param\": \"KeystoneMinimumPasswordAge\"}}]}, {\"if\": [\"password_expires_days_set\", {\"keystone::security_compliance::password_expires_days\": {\"get_param\": \"KeystonePasswordExpiresDays\"}}]}, {\"if\": [\"password_regex_set\", {\"keystone::security_compliance::password_regex\": {\"get_param\": \"KeystonePasswordRegex\"}}]}, {\"if\": [\"password_regex_description_set\", {\"keystone::security_compliance::password_regex_description\": {\"get_param\": \"KeystonePasswordRegexDescription\"}}]}, {\"if\": [\"unique_last_password_count_set\", {\"keystone::security_compliance::unique_last_password_count\": {\"get_param\": \"KeystoneUniqueLastPasswordCount\"}}]}, {\"apache::default_vhost\": false}, {\"get_attr\": [\"KeystoneLogging\", \"config_settings\"]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_keystone\": {\"get_param\": \"KeystoneLoggingSource\"}}, \"mysql\": {\"keystone::db::mysql::password\": {\"get_param\": \"AdminToken\"}, \"keystone::db::mysql::user\": \"keystone\", \"keystone::db::mysql::host\": \"%\", \"keystone::db::mysql::dbname\": \"keystone\"}, \"pacemaker\": {\"keystone::endpoint::public_url\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"keystone::endpoint::internal_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"keystone::endpoint::admin_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"uri_no_suffix\"]}, \"keystone::endpoint::region\": {\"get_param\": \"KeystoneRegion\"}, \"keystone::admin_password\": {\"get_param\": \"AdminPassword\"}}, \"horizon\": {\"if\": [{\"get_param\": \"KeystoneLDAPDomainEnable\"}, {\"horizon::keystone_multidomain_support\": true, \"horizon::keystone_default_domain\": \"Default\"}]}}, \"puppet_config\": {\"config_volume\": \"keystone\", \"puppet_tags\": \"keystone_config,keystone_domain_config\", \"step_config\": {\"list_join\": [\"\\n\", [\"[\'Keystone_user\', \'Keystone_endpoint\', \'Keystone_domain\', \'Keystone_tenant\', \'Keystone_user_role\', \'Keystone_role\', \'Keystone_service\'].each |String $val| { noop_resource($val) }\", \"include tripleo::profile::base::keystone\\n\", {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerKeystoneConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/keystone.json\": {\"command\": \"/usr/sbin/httpd\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/keystone/fernet-keys\", \"dest\": \"/etc/keystone/fernet-keys\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}, \"/var/lib/kolla/config_files/keystone_cron.json\": {\"command\": \"/usr/sbin/crond -n\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}]}}, \"docker_config\": {\"step_2\": {\"get_attr\": [\"KeystoneLogging\", \"docker_config\", \"step_2\"]}, \"step_3\": {\"keystone_db_sync\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerKeystoneImage\"]}, \"net\": \"host\", \"user\": \"root\", \"privileged\": false, \"detach\": false, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"KeystoneLogging\", \"volumes\"]}, [\"/etc/openldap:/etc/openldap:ro\", \"/var/lib/kolla/config_files/keystone.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/keystone:/var/lib/kolla/config_files/src:ro\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}]}, \"environment\": {\"map_merge\": [{\"get_attr\": [\"KeystoneLogging\", \"environment\"]}, {\"KOLLA_BOOTSTRAP\": true, \"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}]}, \"command\": [\"/usr/bin/bootstrap_host_exec\", \"keystone\", \"/usr/local/bin/kolla_start\"]}, \"keystone\": {\"start_order\": 2, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerKeystoneImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"KeystoneLogging\", \"volumes\"]}, [\"/etc/openldap:/etc/openldap:ro\", \"/var/lib/kolla/config_files/keystone.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/keystone:/var/lib/kolla/config_files/src:ro\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}, \"keystone_bootstrap\": {\"start_order\": 3, \"action\": \"exec\", \"user\": \"root\", \"command\": [\"keystone\", \"/usr/bin/bootstrap_host_exec\", \"keystone\", \"keystone-manage\", \"bootstrap\"], \"environment\": {\"KOLLA_BOOTSTRAP\": true, \"OS_BOOTSTRAP_PASSWORD\": {\"get_param\": \"AdminPassword\"}, \"OS_BOOTSTRAP_USERNAME\": \"admin\", \"OS_BOOTSTRAP_PROJECT_NAME\": \"admin\", \"OS_BOOTSTRAP_ROLE_NAME\": \"admin\", \"OS_BOOTSTRAP_SERVICE_NAME\": \"keystone\", \"OS_BOOTSTRAP_ADMIN_URL\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"uri_no_suffix\"]}, \"OS_BOOTSTRAP_PUBLIC_URL\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"OS_BOOTSTRAP_INTERNAL_URL\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"OS_BOOTSTRAP_REGION_ID\": {\"get_param\": \"KeystoneRegion\"}}}, \"keystone_cron\": {\"start_order\": 4, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerKeystoneImage\"]}, \"user\": \"root\", \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/usr/share/openstack-tripleo-common/healthcheck/cron keystone\"}, \"command\": [\"/bin/bash\", \"-c\", \"/usr/local/bin/kolla_set_configs && /usr/sbin/crond -n\"], \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"KeystoneLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/keystone_cron.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/keystone:/var/lib/kolla/config_files/src:ro\"]]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}, \"step_4\": {\"keystone_refresh\": {\"start_order\": 1, \"action\": \"exec\", \"user\": \"root\", \"command\": [\"keystone\", \"pkill\", \"--signal\", \"USR1\", \"httpd\"]}}}, \"external_deploy_tasks\": [{\"name\": \"Manage clouds.yaml files\", \"when\": [\"step|int == 1\", \"not ansible_check_mode|bool\"], \"block\": [{\"name\": \"Create /etc/openstack directory if it does not exist\", \"become\": true, \"file\": {\"mode\": \"0755\", \"owner\": \"root\", \"path\": \"/etc/openstack\", \"state\": \"directory\"}}, {\"name\": \"Configure /etc/openstack/clouds.yaml\", \"include_role\": {\"name\": \"tripleo_keystone_resources\", \"tasks_from\": \"clouds\"}, \"vars\": {\"tripleo_keystone_resources_cloud_name\": {\"get_param\": \"RootStackName\"}, \"tripleo_keystone_resources_cloud_config\": {\"auth\": {\"auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"password\": {\"get_param\": \"AdminPassword\"}, \"project_domain_name\": \"Default\", \"project_name\": \"admin\", \"user_domain_name\": \"Default\", \"username\": \"admin\"}, \"cacert\": {\"if\": [\"public_tls_enabled\", {\"get_param\": \"PublicTLSCAFile\"}, \"\"]}, \"identity_api_version\": \"3\", \"volume_api_version\": \"3\", \"region_name\": {\"get_param\": \"KeystoneRegion\"}}}}]}, {\"name\": \"Manage Keystone resources\", \"become\": true, \"when\": [\"step|int == 4\", \"not ansible_check_mode|bool\"], \"block\": [{\"name\": \"Manage Keystone resources for OpenStack services\", \"include_role\": {\"name\": \"tripleo_keystone_resources\"}, \"vars\": {\"tripleo_keystone_resources_catalog_config\": \"{{ keystone_resources }}\", \"tripleo_keystone_resources_service_project\": \"service\", \"tripleo_keystone_resources_cloud_name\": {\"get_param\": \"RootStackName\"}, \"tripleo_keystone_resources_region\": {\"get_param\": \"KeystoneRegion\"}, \"tripleo_keystone_resources_admin_endpoint\": {\"get_param\": [\"EndpointMap\", \"KeystoneAdmin\", \"uri_no_suffix\"]}, \"tripleo_keystone_resources_public_endpoint\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"tripleo_keystone_resources_internal_endpoint\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"tripleo_keystone_resources_admin_password\": {\"get_param\": \"AdminPassword\"}, \"tripleo_keystone_resources_member_role_enabled\": {\"get_param\": \"KeystoneEnableMember\"}}}, {\"name\": \"is Keystone LDAP enabled\", \"set_fact\": {\"keystone_ldap_domain_enabled\": {\"get_param\": \"KeystoneLDAPDomainEnable\"}}}, {\"name\": \"Set fact for tripleo_keystone_ldap_domains\", \"set_fact\": {\"tripleo_keystone_ldap_domains\": {\"get_param\": \"KeystoneLDAPBackendConfigs\"}}, \"when\": \"keystone_ldap_domain_enabled|bool\"}, {\"name\": \"Manage Keystone domains from LDAP config\", \"when\": \"keystone_ldap_domain_enabled|bool\", \"include_role\": {\"name\": \"tripleo_keystone_resources\", \"tasks_from\": \"domains\"}, \"vars\": {\"tripleo_keystone_resources_catalog_config\": \"{{ keystone_resources }}\", \"tripleo_keystone_resources_cloud_name\": {\"get_param\": \"RootStackName\"}, \"batched_tripleo_keystone_resources_domains\": \"{{ tripleo_keystone_ldap_domains | list }}\"}}]}], \"deploy_steps_tasks\": {\"list_concat\": [{\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"deploy_steps_tasks\"]}, [{\"name\": \"validate keystone container state\", \"containers.podman.podman_container_info\": {\"name\": \"keystone\"}, \"register\": \"keystone_infos\", \"failed_when\": [\"keystone_infos.containers.0.Healthcheck.Status is defined\", \"\'healthy\' not in keystone_infos.containers.0.Healthcheck.Status\"], \"retries\": 10, \"delay\": 30, \"tags\": [\"opendev-validation\", \"opendev-validation-keystone\"], \"when\": [\"container_cli == \'podman\'\", \"not container_healthcheck_disabled\", \"step|int == 4\"]}]]}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"KeystoneLogging\", \"host_prep_tasks\"]}, [{\"name\": \"Check if file certs_valid exist\", \"stat\": {\"path\": \"/etc/openldap/certs/certs_valid\"}, \"register\": \"certs_valid_stat\"}, {\"name\": \"Check if file cert9.db exist\", \"stat\": {\"path\": \"/etc/openldap/certs/cert9.db\"}, \"register\": \"cert9_stat\", \"when\": \"not certs_valid_stat.stat.exists\"}, {\"name\": \"Check if file key4.db exist\", \"stat\": {\"path\": \"/etc/openldap/certs/key4.db\"}, \"register\": \"key4_stat\", \"when\": \"not certs_valid_stat.stat.exists\"}, {\"fail\": {\"msg\": \"Keys and/or certificates were found in /etc/openldap/certs but these conflicts with keystone python LDAP calls.  If you know those certificates are valid and not causing any conflicts, you can touch /etc/openldap/certs/certs_valid in order to skip this failure and retry or you can delete the files located in /etc/openldap/certs and retry.\\n\"}, \"when\": \"( cert9_stat.stat.exists or key4_stat.stat.exists ) and not certs_valid_stat.stat.exists\"}]]}, \"metadata_settings\": {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"metadata_settings\"]}, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop keystone container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"keystone\", \"keystone_cron\"], \"tripleo_delegate_to\": \"{{ groups[\'keystone\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(204,'2026-06-09 08:02:27',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Apache service configured with Puppet. Note this is typically included automatically via other services which run via Apache.\\n\", \"parameters\": {\"ApacheMaxRequestWorkers\": {\"default\": 100, \"description\": \"Maximum number of simultaneously processed requests.\", \"type\": \"number\"}, \"ApacheServerLimit\": {\"default\": 100, \"description\": \"Maximum number of Apache processes.\", \"type\": \"number\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"ApacheCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"ApacheTimeout\": {\"type\": \"number\", \"default\": 90, \"description\": \"The timeout in seconds for Apache, which defines duration Apache waits for I/O operations\"}}, \"conditions\": {\"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"ApacheCertificateKeySize\"}, \"\"]}}}, \"resources\": {\"ApacheNetworks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"Controller\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"CellController\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"CellControllerCompute\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"Compute\": [\"ctlplane\", \"storage\", \"internal_api\"], \"BlockStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"ObjectStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"CephStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\"], \"Networker\": [\"ctlplane\", \"internal_api\"]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Apache role.\", \"value\": {\"service_name\": \"apache\", \"config_settings\": {\"map_merge\": [{\"apache::ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}}}}, \"apache::default_vhost\": false, \"apache::trace_enable\": \"Off\", \"apache::server_signature\": \"Off\", \"apache::server_tokens\": \"Prod\", \"apache::timeout\": {\"get_param\": \"ApacheTimeout\"}, \"apache::default_mods\": false, \"apache::mod::prefork::maxrequestworkers\": {\"get_param\": \"ApacheMaxRequestWorkers\"}, \"apache::mod::prefork::serverlimit\": {\"get_param\": \"ApacheServerLimit\"}, \"apache::mod::remoteip::proxy_ips\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}]}, \"apache::mod::alias::icons_options\": \"None\"}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"apache::mod::ssl::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}, \"apache::mod::ssl::ssl_protocol\": [\"all\", \"-SSLv2\", \"-SSLv3\", \"-TLSv1\"], \"apache_certificates_specs\": {\"map_merge\": {\"repeat\": {\"template\": {\"httpd-NETWORK\": {\"service_certificate\": \"/etc/pki/tls/certs/httpd/httpd-NETWORK.crt\", \"service_key\": \"/etc/pki/tls/private/httpd/httpd-NETWORK.key\"}}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}, \"metadata_settings\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"repeat\": {\"template\": [{\"service\": \"HTTP\", \"network\": \"$NETWORK\", \"type\": \"node\"}], \"for_each\": {\"$NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}]}, \"upgrade_tasks\": [], \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [\"/etc/pki/tls/certs/httpd\", \"/etc/pki/tls/private/httpd\"]}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": {\"repeat\": {\"template\": {\"name\": \"httpd-NETWORK\", \"dns\": \"{{ fqdn_NETWORK }}\", \"principal\": \"HTTP/{{ fqdn_NETWORK }}@{{ idm_realm }}\", \"run_after\": \"cp /etc/pki/tls/certs/httpd-NETWORK.crt /etc/pki/tls/certs/httpd/httpd-NETWORK.crt\\ncp /etc/pki/tls/private/httpd-NETWORK.key /etc/pki/tls/private/httpd/httpd-NETWORK.key\\npkill -USR1 httpd\\n\", \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"ApacheCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"EnableInternalTLS\": true}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(205,'2026-06-09 08:02:27',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Apache service configured with Puppet. Note this is typically included automatically via other services which run via Apache.\\n\", \"parameters\": {\"ApacheMaxRequestWorkers\": {\"default\": 100, \"description\": \"Maximum number of simultaneously processed requests.\", \"type\": \"number\"}, \"ApacheServerLimit\": {\"default\": 100, \"description\": \"Maximum number of Apache processes.\", \"type\": \"number\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"ApacheCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}, \"ApacheTimeout\": {\"type\": \"number\", \"default\": 90, \"description\": \"The timeout in seconds for Apache, which defines duration Apache waits for I/O operations\"}}, \"conditions\": {\"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"ApacheCertificateKeySize\"}, \"\"]}}}, \"resources\": {\"ApacheNetworks\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"Controller\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"CellController\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"CellControllerCompute\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\", \"external\"], \"Compute\": [\"ctlplane\", \"storage\", \"internal_api\"], \"BlockStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"ObjectStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\", \"internal_api\"], \"CephStorage\": [\"ctlplane\", \"storage\", \"storage_mgmt\"], \"Networker\": [\"ctlplane\", \"internal_api\"]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Apache role.\", \"value\": {\"service_name\": \"apache\", \"config_settings\": {\"map_merge\": [{\"apache::ip\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}}}}, \"apache::default_vhost\": false, \"apache::trace_enable\": \"Off\", \"apache::server_signature\": \"Off\", \"apache::server_tokens\": \"Prod\", \"apache::timeout\": {\"get_param\": \"ApacheTimeout\"}, \"apache::default_mods\": false, \"apache::mod::prefork::maxrequestworkers\": {\"get_param\": \"ApacheMaxRequestWorkers\"}, \"apache::mod::prefork::serverlimit\": {\"get_param\": \"ApacheServerLimit\"}, \"apache::mod::remoteip::proxy_ips\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"ApacheNetwork\"]}]}, \"apache::mod::alias::icons_options\": \"None\"}, {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"apache::mod::ssl::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}, \"apache::mod::ssl::ssl_protocol\": [\"all\", \"-SSLv2\", \"-SSLv3\", \"-TLSv1\"], \"apache_certificates_specs\": {\"map_merge\": {\"repeat\": {\"template\": {\"httpd-NETWORK\": {\"service_certificate\": \"/etc/pki/tls/certs/httpd/httpd-NETWORK.crt\", \"service_key\": \"/etc/pki/tls/private/httpd/httpd-NETWORK.key\"}}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}, \"metadata_settings\": {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, {\"repeat\": {\"template\": [{\"service\": \"HTTP\", \"network\": \"$NETWORK\", \"type\": \"node\"}], \"for_each\": {\"$NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}]}, \"upgrade_tasks\": [], \"deploy_steps_tasks\": [{\"name\": \"Certificate generation\", \"when\": [\"step|int == 1\", \"enable_internal_tls\"], \"block\": [{\"name\": \"Create dirs for certificates and keys\", \"file\": {\"path\": \"{{ item }}\", \"state\": \"directory\", \"serole\": \"object_r\", \"setype\": \"cert_t\", \"seuser\": \"system_u\"}, \"with_items\": [\"/etc/pki/tls/certs/httpd\", \"/etc/pki/tls/private/httpd\"]}, {\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": {\"repeat\": {\"template\": {\"name\": \"httpd-NETWORK\", \"dns\": \"{{ fqdn_NETWORK }}\", \"principal\": \"HTTP/{{ fqdn_NETWORK }}@{{ idm_realm }}\", \"run_after\": \"cp /etc/pki/tls/certs/httpd-NETWORK.crt /etc/pki/tls/certs/httpd/httpd-NETWORK.crt\\ncp /etc/pki/tls/private/httpd-NETWORK.key /etc/pki/tls/private/httpd/httpd-NETWORK.key\\npkill -USR1 httpd\\n\", \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"ApacheCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}, \"for_each\": {\"NETWORK\": {\"get_attr\": [\"ApacheNetworks\", \"value\", {\"get_param\": \"RoleName\"}]}}}}}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"EnableInternalTLS\": true}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(206,'2026-06-09 08:02:28',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Keystone service\\n\", \"parameters\": {\"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"ContainerKeystoneImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\"}}, \"resources\": {\"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerKeystoneImage\": \"ContainerKeystoneImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerKeystoneImage\": {\"get_param\": \"ContainerKeystoneImage\"}}}]}}}}, \"outputs\": {\"config_settings\": {\"description\": \"Extra hieradata needed to log to files in the host.\", \"value\": null}, \"volumes\": {\"description\": \"The volumes needed to log to files in the host.\", \"value\": [\"/var/log/containers/keystone:/var/log/keystone:z\", \"/var/log/containers/httpd/keystone:/var/log/httpd:z\"]}, \"docker_config\": {\"description\": \"Extra containers needed for logging to files in the host.\", \"value\": {\"step_2\": {\"keystone_init_log\": {\"start_order\": 1, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerKeystoneImage\"]}, \"net\": \"none\", \"user\": \"root\", \"command\": [\"/bin/bash\", \"-c\", \"chown -R keystone:keystone /var/log/keystone\"], \"volumes\": [\"/var/log/containers/keystone:/var/log/keystone:z\", \"/var/log/containers/httpd/keystone:/var/log/httpd:z\"]}}}}, \"environment\": {\"description\": \"Extra environment variables needed for the service to log to files.\", \"value\": null}, \"host_prep_tasks\": {\"description\": \"Extra ansible tasks needed for logging to files in the host.\", \"value\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/keystone\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}, {\"path\": \"/var/log/containers/httpd/keystone\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}]}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (207,'2026-06-09 08:02:28',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(208,'2026-06-09 08:02:29',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Heat Engine service\\n\", \"parameters\": {\"ContainerHeatEngineImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\"}, \"ContainerHeatConfigImage\": {\"description\": \"The container image to use for the heat config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\"}, \"HeatEngineLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.heat.engine\", \"file\": \"/var/log/containers/heat/heat-engine.log\"}}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"DeployIdentifier\": {\"default\": 1780992067, \"type\": \"string\", \"description\": \"Setting this to a unique value will re-run any deployment tasks which perform configuration on a Heat stack-update.\\n\"}, \"HeatEngineOptVolumes\": {\"default\": [], \"description\": \"list of optional volumes to be mounted\", \"type\": \"comma_delimited_list\"}, \"HeatEngineOptEnvVars\": {\"default\": {}, \"description\": \"hash of optional environment variables\", \"type\": \"json\"}, \"HeatEnableDBPurge\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Whether to create cron job for purging soft deleted rows in the Heat database.\\n\"}, \"EnableSQLAlchemyCollectd\": {\"type\": \"boolean\", \"description\": \"Set to true to enable the SQLAlchemy-collectd server plugin\\n\", \"default\": false}, \"HeatWorkers\": {\"default\": 1, \"description\": \"Number of workers for Heat service.\", \"type\": \"number\"}, \"HeatMaxNestedStackDepth\": {\"default\": 6, \"description\": \"Maximum number of nested stack depth.\", \"type\": \"number\"}, \"HeatReauthenticationAuthMethod\": {\"description\": \"Allow reauthentication on token expiry, such that long-running tasks may complete. Note this defeats the expiry of any provided user tokens.\", \"type\": \"string\", \"default\": \"\", \"constraints\": [{\"allowed_values\": [\"\", \"trusts\"]}]}, \"HeatPassword\": {\"description\": \"The password for the Heat service and db account, used by the Heat services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"IWxKbYHIBwLTomkhalUwDCUxO\"}, \"HeatStackDomainAdminPassword\": {\"description\": \"Password for heat_stack_domain_admin user.\", \"type\": \"string\", \"hidden\": true, \"default\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\"}, \"HeatAuthEncryptionKey\": {\"description\": \"Auth encryption key for heat-engine\", \"type\": \"string\", \"hidden\": true, \"default\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\"}, \"MonitoringSubscriptionHeatEngine\": {\"default\": \"overcloud-heat-engine\", \"type\": \"string\"}, \"HeatConvergenceEngine\": {\"type\": \"boolean\", \"default\": true, \"description\": \"Enables the heat engine with the convergence architecture.\"}, \"HeatMaxResourcesPerStack\": {\"type\": \"number\", \"default\": 1000, \"description\": \"Maximum resources allowed per top-level stack. -1 stands for unlimited.\"}, \"HeatEnginePluginDirs\": {\"type\": \"comma_delimited_list\", \"default\": [], \"description\": \"An array of directories to search for plug-ins.\"}, \"HeatConfigureDelegatedRoles\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Create delegated roles\"}, \"ClientRetryLimit\": {\"type\": \"number\", \"default\": 2, \"description\": \"Client retries for transient errors.\"}}, \"conditions\": {\"heat_workers_set\": {\"not\": {\"equals\": [{\"get_param\": \"HeatWorkers\"}, 0]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"MySQLClient\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\"}, \"HeatBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-base-puppet.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"HeatEngineLogging\": {\"type\": \"OS::TripleO::Services::Logging::HeatEngine\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerHeatEngineImage\": \"ContainerHeatEngineImage\", \"ContainerHeatConfigImage\": \"ContainerHeatConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerHeatEngineImage\": {\"get_param\": \"ContainerHeatEngineImage\"}, \"ContainerHeatConfigImage\": {\"get_param\": \"ContainerHeatConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Heat Engine role.\", \"value\": {\"service_name\": \"heat_engine\", \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionHeatEngine\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"HeatBase\", \"role_data\", \"config_settings\"]}, {\"apache::default_vhost\": false, \"heat::engine::configure_delegated_roles\": {\"get_param\": \"HeatConfigureDelegatedRoles\"}, \"heat::engine::trusts_delegated_roles\": [], \"heat::engine::max_nested_stack_depth\": {\"get_param\": \"HeatMaxNestedStackDepth\"}, \"heat::engine::max_resources_per_stack\": {\"get_param\": \"HeatMaxResourcesPerStack\"}, \"heat::engine::reauthentication_auth_method\": {\"get_param\": \"HeatReauthenticationAuthMethod\"}, \"heat::engine::heat_metadata_server_url\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"protocol\"]}, \"host\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"host\"]}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"port\"]}}}, \"heat::engine::heat_waitcondition_server_url\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"protocol\"]}, \"host\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"host\"]}, \"port\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"port\"]}, \"path\": \"/v1/waitcondition\"}}, \"heat::engine::convergence_engine\": {\"get_param\": \"HeatConvergenceEngine\"}, \"heat::engine::client_retry_limit\": {\"get_param\": \"ClientRetryLimit\"}, \"tripleo::profile::base::heat::manage_db_purge\": {\"get_param\": \"HeatEnableDBPurge\"}, \"heat::database_connection\": {\"make_url\": {\"scheme\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"protocol\"]}, \"username\": \"heat\", \"password\": {\"get_param\": \"HeatPassword\"}, \"host\": {\"get_param\": [\"EndpointMap\", \"MysqlInternal\", \"host\"]}, \"path\": \"/heat\", \"query\": {\"if\": [{\"get_param\": \"EnableSQLAlchemyCollectd\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\", \"plugin\": \"collectd\", \"collectd_program_name\": \"heat\", \"collectd_host\": \"localhost\"}, {\"read_default_file\": \"/etc/my.cnf.d/tripleo.cnf\", \"read_default_group\": \"tripleo\"}]}}}, \"heat::keystone_ec2_uri\": {\"list_join\": [\"\", [{\"get_param\": [\"EndpointMap\", \"KeystoneV3Internal\", \"uri\"]}, \"/ec2tokens\"]]}, \"heat::keystone::domain::domain_password\": {\"get_param\": \"HeatStackDomainAdminPassword\"}, \"heat::engine::auth_encryption_key\": {\"get_param\": \"HeatAuthEncryptionKey\"}, \"heat::engine::plugin_dirs\": {\"get_param\": \"HeatEnginePluginDirs\"}}, {\"if\": [\"heat_workers_set\", {\"heat::engine::num_engine_workers\": {\"get_param\": \"HeatWorkers\"}}]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_heat_engine\": [{\"get_param\": \"HeatEngineLoggingSource\"}]}, \"mysql\": {\"heat::db::mysql::password\": {\"get_param\": \"HeatPassword\"}, \"heat::db::mysql::user\": \"heat\", \"heat::db::mysql::host\": \"%\", \"heat::db::mysql::dbname\": \"heat\"}}, \"puppet_config\": {\"config_volume\": \"heat\", \"puppet_tags\": \"heat_config,file,concat,file_line\", \"step_config\": {\"list_join\": [\"\\n\", [\"include tripleo::profile::base::heat::engine\", {\"get_attr\": [\"MySQLClient\", \"role_data\", \"step_config\"]}]]}, \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHeatConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/heat_engine.json\": {\"command\": {\"list_join\": [\" \", [\"/usr/bin/heat-engine --config-file /usr/share/heat/heat-dist.conf --config-file /etc/heat/heat.conf\", {\"get_attr\": [\"HeatEngineLogging\", \"cmd_extra_args\"]}]]}, \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/heat\", \"owner\": \"heat:heat\", \"recurse\": true}]}, \"/var/lib/kolla/config_files/heat_engine_db_sync.json\": {\"command\": \"/usr/bin/bootstrap_host_exec heat_engine su heat -s /bin/bash -c \'heat-manage db_sync\'\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/heat\", \"owner\": \"heat:heat\", \"recurse\": true}]}}, \"docker_config\": {\"step_2\": {\"get_attr\": [\"HeatEngineLogging\", \"docker_config\", \"step_2\"]}, \"step_3\": {\"heat_engine_db_sync\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHeatEngineImage\"]}, \"cap_add\": [\"AUDIT_WRITE\"], \"net\": \"host\", \"privileged\": false, \"detach\": false, \"user\": \"root\", \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"HeatEngineLogging\", \"volumes\"]}, {\"get_param\": \"HeatEngineOptVolumes\"}, [\"/var/lib/kolla/config_files/heat_engine_db_sync.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/heat:/var/lib/kolla/config_files/src:ro\"]]}, \"environment\": {\"map_merge\": [{\"get_param\": \"HeatEngineOptEnvVars\"}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\", \"TRIPLEO_DEPLOY_IDENTIFIER\": {\"get_param\": \"DeployIdentifier\"}}]}}}, \"step_4\": {\"heat_engine\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHeatEngineImage\"]}, \"net\": \"host\", \"privileged\": false, \"stop_grace_period\": 60, \"restart\": \"always\", \"healthcheck\": {\"get_attr\": [\"ContainersCommon\", \"healthcheck_rpc_port\"]}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"HeatEngineLogging\", \"volumes\"]}, {\"get_param\": \"HeatEngineOptVolumes\"}, [\"/var/lib/kolla/config_files/heat_engine.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/heat:/var/lib/kolla/config_files/src:ro\"]]}, \"environment\": {\"map_merge\": [{\"get_param\": \"HeatEngineOptEnvVars\"}, {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}]}}}}, \"host_prep_tasks\": {\"list_concat\": [{\"get_attr\": [\"HeatEngineLogging\", \"host_prep_tasks\"]}, [{\"name\": \"enable virt_sandbox_use_netlink for healthcheck\", \"seboolean\": {\"name\": \"virt_sandbox_use_netlink\", \"persistent\": true, \"state\": true}, \"when\": [\"ansible_facts.selinux is defined\", \"ansible_facts.selinux.status == \\\"enabled\\\"\"]}]]}, \"upgrade_tasks\": [], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop heat engine container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"heat_engine\"], \"tripleo_delegate_to\": \"{{ groups[\'heat_engine\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(209,'2026-06-09 08:02:29',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(210,'2026-06-09 08:02:29',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Heat API CFN service\\n\", \"parameters\": {\"ContainerHeatApiCfnImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\"}, \"ContainerHeatApiCfnConfigImage\": {\"description\": \"The container image to use for the heat_api_cfn config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\"}, \"HeatApiCfnLoggingSource\": {\"type\": \"json\", \"default\": {\"tag\": \"openstack.heat.api.cfn\", \"file\": \"/var/log/containers/heat/heat_api_cfn.log\"}}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"HeatWorkers\": {\"default\": 1, \"description\": \"Number of workers for Heat service.\", \"type\": \"number\"}, \"HeatPassword\": {\"description\": \"The password for the Heat service and db account, used by the Heat services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"IWxKbYHIBwLTomkhalUwDCUxO\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"MonitoringSubscriptionHeatApiCnf\": {\"default\": \"overcloud-heat-api-cfn\", \"type\": \"string\"}}, \"conditions\": {\"heat_workers_set\": {\"not\": {\"equals\": [{\"get_param\": \"HeatWorkers\"}, 0]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"ApacheServiceBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"properties\": {\"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"EnableInternalTLS\": {\"get_param\": \"EnableInternalTLS\"}}}, \"HeatBase\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-base-puppet.yaml\", \"properties\": {\"EndpointMap\": {\"get_param\": \"EndpointMap\"}, \"ServiceData\": {\"get_param\": \"ServiceData\"}, \"ServiceNetMap\": {\"get_param\": \"ServiceNetMap\"}, \"RoleName\": {\"get_param\": \"RoleName\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}}}, \"HeatApiCfnLogging\": {\"type\": \"OS::TripleO::Services::Logging::HeatApiCfn\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerHeatApiCfnImage\": \"ContainerHeatApiCfnImage\", \"ContainerHeatApiCfnConfigImage\": \"ContainerHeatApiCfnConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerHeatApiCfnImage\": {\"get_param\": \"ContainerHeatApiCfnImage\"}, \"ContainerHeatApiCfnConfigImage\": {\"get_param\": \"ContainerHeatApiCfnConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Heat API CFN role.\", \"value\": {\"service_name\": \"heat_api_cfn\", \"firewall_rules\": {\"125 heat_cfn\": {\"dport\": [8000]}}, \"firewall_frontend_rules\": {\"100 heat_api_cfn_haproxy_frontend\": {\"dport\": [8000]}}, \"firewall_ssl_frontend_rules\": {\"100 heat_api_cfn_haproxy_frontend_ssl\": {\"dport\": [13005]}}, \"keystone_resources\": {\"heat-cfn\": {\"endpoints\": {\"public\": {\"get_param\": [\"EndpointMap\", \"HeatCfnPublic\", \"uri\"]}, \"internal\": {\"get_param\": [\"EndpointMap\", \"HeatCfnInternal\", \"uri\"]}, \"admin\": {\"get_param\": [\"EndpointMap\", \"HeatCfnAdmin\", \"uri\"]}}, \"users\": {\"heat-cfn\": {\"password\": {\"get_param\": \"HeatPassword\"}}}, \"region\": {\"get_param\": \"KeystoneRegion\"}, \"service\": \"cloudformation\"}}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionHeatApiCnf\"}, \"config_settings\": {\"map_merge\": [{\"get_attr\": [\"HeatBase\", \"role_data\", \"config_settings\"]}, {\"get_attr\": [\"HeatApiCfnLogging\", \"config_settings\"]}, {\"apache::default_vhost\": false, \"heat::api_cfn::bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiCfnNetwork\"]}}}}, \"heat::wsgi::apache_api_cfn::ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"heat::api_cfn::service_name\": \"httpd\", \"heat::wsgi::apache_api_cfn::bind_host\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiCfnNetwork\"]}}}}, \"heat::wsgi::apache_api_cfn::servername\": {\"str_replace\": {\"template\": \"%{hiera(\'fqdn_$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"HeatApiCfnNetwork\"]}}}}}, {\"if\": [\"heat_workers_set\", {\"heat::wsgi::apache_api_cfn::workers\": {\"get_param\": \"HeatWorkers\"}}]}]}, \"service_config_settings\": {\"rsyslog\": {\"tripleo_logging_sources_heat_api_cfn\": [{\"get_param\": \"HeatApiCfnLoggingSource\"}]}}, \"puppet_config\": {\"config_volume\": \"heat_api_cfn\", \"puppet_tags\": \"heat_config,file,concat,file_line\", \"step_config\": \"include tripleo::profile::base::heat::api_cfn\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHeatApiCfnConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/heat_api_cfn.json\": {\"command\": \"/usr/sbin/httpd -DFOREGROUND\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.d\", \"dest\": \"/etc/httpd/conf.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/etc/httpd/conf.modules.d\", \"dest\": \"/etc/httpd/conf.modules.d\", \"merge\": false, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}], \"permissions\": [{\"path\": \"/var/log/heat\", \"owner\": \"heat:heat\", \"recurse\": true}]}}, \"docker_config\": {\"step_2\": {\"get_attr\": [\"HeatApiCfnLogging\", \"docker_config\", \"step_2\"]}, \"step_4\": {\"heat_api_cfn\": {\"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerHeatApiCfnImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"user\": \"root\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, {\"get_attr\": [\"HeatApiCfnLogging\", \"volumes\"]}, [\"/var/lib/kolla/config_files/heat_api_cfn.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/heat_api_cfn:/var/lib/kolla/config_files/src:ro\"], {\"if\": [{\"get_param\": \"EnableInternalTLS\"}, [\"/etc/pki/tls/certs/httpd:/etc/pki/tls/certs/httpd:ro\", \"/etc/pki/tls/private/httpd:/etc/pki/tls/private/httpd:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"host_prep_tasks\": {\"get_attr\": [\"HeatApiCfnLogging\", \"host_prep_tasks\"]}, \"upgrade_tasks\": [], \"metadata_settings\": {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"metadata_settings\"]}, \"deploy_steps_tasks\": {\"get_attr\": [\"ApacheServiceBase\", \"role_data\", \"deploy_steps_tasks\"]}, \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop heat cfn container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"heat_api_cfn\"], \"tripleo_delegate_to\": \"{{ groups[\'heat_api_cfn\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(211,'2026-06-09 08:02:30',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(212,'2026-06-09 08:02:30',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Heat base service. Shared for all Heat services.\\n\", \"parameters\": {\"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"HeatDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Heat services.\", \"type\": \"boolean\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"HeatPassword\": {\"description\": \"The password for the Heat service and db account, used by the Heat services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"IWxKbYHIBwLTomkhalUwDCUxO\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"HeatCronPurgeDeletedEnsure\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Ensure\\n\", \"default\": \"present\"}, \"HeatCronPurgeDeletedMinute\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Minute\\n\", \"default\": \"1\"}, \"HeatCronPurgeDeletedHour\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Hour\\n\", \"default\": \"0\"}, \"HeatCronPurgeDeletedMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month Day\\n\", \"default\": \"*\"}, \"HeatCronPurgeDeletedMonth\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month\\n\", \"default\": \"*\"}, \"HeatCronPurgeDeletedWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Week Day\\n\", \"default\": \"*\"}, \"HeatCronPurgeDeletedMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Delay\\n\", \"default\": \"3600\"}, \"HeatCronPurgeDeletedUser\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - User\\n\", \"default\": \"heat\"}, \"HeatCronPurgeDeletedAge\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age\\n\", \"default\": \"30\"}, \"HeatCronPurgeDeletedAgeType\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age type\\n\", \"default\": \"days\"}, \"HeatCronPurgeDeletedDestination\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Log destination\\n\", \"default\": \"/dev/null\"}, \"HeatYaqlLimitIterators\": {\"type\": \"number\", \"description\": \"The maximum number of elements in collection yaql expressions can take for its evaluation.\\n\", \"default\": 1000}, \"HeatYaqlMemoryQuota\": {\"type\": \"number\", \"description\": \"The maximum size of memory in bytes that yaql exrpessions can take for its evaluation.\\n\", \"default\": 100000}, \"HeatMaxJsonBodySize\": {\"default\": 4194304, \"description\": \"Maximum raw byte size of the Heat API JSON request body.\", \"type\": \"number\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"HeatCorsAllowedOrigin\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Indicate whether this resource may be shared with the domain received in the request \\\"origin\\\" header.\"}, \"MemcachedTLS\": {\"default\": true, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}, \"MemcacheUseAdvancedPool\": {\"type\": \"boolean\", \"description\": \"Use the advanced (eventlet safe) memcached client pool.\\n\", \"default\": true}, \"HeatApiPolicies\": {\"description\": \"A hash of policies to configure for Heat API.\\ne.g. { heat-context_is_admin: { key: context_is_admin, value: \'role:admin\' } }\\n\", \"default\": {}, \"type\": \"json\"}, \"EnforceSecureRbac\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Setting this option to True will configure each OpenStack service to enforce Secure RBAC by setting `[oslo_policy] enforce_new_defaults` and `[oslo_policy] enforce_scope` to True. This introduces a consistent set of RBAC personas across OpenStack services that include support for system and project scope, as well as keystone\'s default roles, admin, member, and reader. Do not enable this functionality until all services in your deployment actually support secure RBAC.\"}}, \"conditions\": {\"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}, \"cors_allowed_origin_set\": {\"not\": {\"equals\": [{\"get_param\": \"HeatCorsAllowedOrigin\"}, \"\"]}}}, \"outputs\": {\"role_data\": {\"description\": \"Shared role data for the Heat services.\", \"value\": {\"service_name\": \"heat_base\", \"config_settings\": {\"map_merge\": [{\"if\": [{\"get_param\": \"EnforceSecureRbac\"}, {\"heat::policy::enforce_scope\": true, \"heat::policy::enforce_new_defaults\": true}]}, {\"if\": [\"cors_allowed_origin_set\", {\"heat::cors::allowed_origin\": {\"get_param\": \"HeatCorsAllowedOrigin\"}}]}, {\"heat::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"heat::logging::debug\": {\"if\": [{\"get_param\": \"HeatDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"heat::policy::policies\": {\"get_param\": \"HeatApiPolicies\"}, \"heat::enable_proxy_headers_parsing\": true, \"heat::rpc_response_timeout\": 600, \"heat::rabbit_heartbeat_timeout_threshold\": 60, \"heat::rabbit_heartbeat_in_pthread\": false, \"heat::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"heat::keystone::authtoken::project_name\": \"service\", \"heat::keystone::authtoken::user_domain_name\": \"Default\", \"heat::keystone::authtoken::project_domain_name\": \"Default\", \"heat::keystone::authtoken::www_authenticate_uri\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"heat::keystone::authtoken::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"heat::keystone::authtoken::password\": {\"get_param\": \"HeatPassword\"}, \"heat::keystone::authtoken::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"heat::keystone::authtoken::interface\": \"internal\", \"heat::keystone::authtoken::memcache_use_advanced_pool\": {\"get_param\": \"MemcacheUseAdvancedPool\"}, \"heat::keystone::domain::domain_name\": \"heat_stack\", \"heat::keystone::domain::domain_admin\": \"heat_stack_domain_admin\", \"heat::keystone::domain::domain_admin_email\": \"heat_stack_domain_admin@localhost\", \"heat::db::database_db_max_retries\": -1, \"heat::db::database_max_retries\": -1, \"heat::yaql_memory_quota\": {\"get_param\": \"HeatYaqlMemoryQuota\"}, \"heat::yaql_limit_iterators\": {\"get_param\": \"HeatYaqlLimitIterators\"}, \"heat::cors::max_age\": 3600, \"heat::cors::allow_headers\": \"Content-Type,Cache-Control,Content-Language,Expires,Last-Modified,Pragma,X-Auth-Token\", \"heat::cors::expose_headers\": \"Content-Type,Cache-Control,Content-Language,Expires,Last-Modified,Pragma\", \"heat::cron::purge_deleted::ensure\": {\"get_param\": \"HeatCronPurgeDeletedEnsure\"}, \"heat::cron::purge_deleted::minute\": {\"get_param\": \"HeatCronPurgeDeletedMinute\"}, \"heat::cron::purge_deleted::hour\": {\"get_param\": \"HeatCronPurgeDeletedHour\"}, \"heat::cron::purge_deleted::monthday\": {\"get_param\": \"HeatCronPurgeDeletedMonthday\"}, \"heat::cron::purge_deleted::month\": {\"get_param\": \"HeatCronPurgeDeletedMonth\"}, \"heat::cron::purge_deleted::weekday\": {\"get_param\": \"HeatCronPurgeDeletedWeekday\"}, \"heat::cron::purge_deleted::maxdelay\": {\"get_param\": \"HeatCronPurgeDeletedMaxDelay\"}, \"heat::cron::purge_deleted::user\": {\"get_param\": \"HeatCronPurgeDeletedUser\"}, \"heat::cron::purge_deleted::age\": {\"get_param\": \"HeatCronPurgeDeletedAge\"}, \"heat::cron::purge_deleted::age_type\": {\"get_param\": \"HeatCronPurgeDeletedAgeType\"}, \"heat::cron::purge_deleted::destination\": {\"get_param\": \"HeatCronPurgeDeletedDestination\"}, \"heat::max_json_body_size\": {\"get_param\": \"HeatMaxJsonBodySize\"}}, {\"heat::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"heat::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}, \"heat::cache::resource_finder_caching\": false}, {\"if\": [\"tls_cache_enabled\", {\"heat::cache::backend\": \"dogpile.cache.pymemcache\"}, {\"heat::cache::backend\": \"dogpile.cache.memcached\"}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(213,'2026-06-09 08:02:30',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Openstack Heat base service. Shared for all Heat services.\\n\", \"parameters\": {\"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"HeatDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Heat services.\", \"type\": \"boolean\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"HeatPassword\": {\"description\": \"The password for the Heat service and db account, used by the Heat services.\", \"type\": \"string\", \"hidden\": true, \"default\": \"IWxKbYHIBwLTomkhalUwDCUxO\"}, \"KeystoneRegion\": {\"type\": \"string\", \"default\": \"regionOne\", \"description\": \"Keystone region for endpoint\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableCache\": {\"description\": \"Enable caching with memcached\", \"type\": \"boolean\", \"default\": true}, \"HeatCronPurgeDeletedEnsure\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Ensure\\n\", \"default\": \"present\"}, \"HeatCronPurgeDeletedMinute\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Minute\\n\", \"default\": \"1\"}, \"HeatCronPurgeDeletedHour\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Hour\\n\", \"default\": \"0\"}, \"HeatCronPurgeDeletedMonthday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month Day\\n\", \"default\": \"*\"}, \"HeatCronPurgeDeletedMonth\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Month\\n\", \"default\": \"*\"}, \"HeatCronPurgeDeletedWeekday\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Week Day\\n\", \"default\": \"*\"}, \"HeatCronPurgeDeletedMaxDelay\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Max Delay\\n\", \"default\": \"3600\"}, \"HeatCronPurgeDeletedUser\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - User\\n\", \"default\": \"heat\"}, \"HeatCronPurgeDeletedAge\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age\\n\", \"default\": \"30\"}, \"HeatCronPurgeDeletedAgeType\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Age type\\n\", \"default\": \"days\"}, \"HeatCronPurgeDeletedDestination\": {\"type\": \"string\", \"description\": \"Cron to purge db entries marked as deleted and older than $age - Log destination\\n\", \"default\": \"/dev/null\"}, \"HeatYaqlLimitIterators\": {\"type\": \"number\", \"description\": \"The maximum number of elements in collection yaql expressions can take for its evaluation.\\n\", \"default\": 1000}, \"HeatYaqlMemoryQuota\": {\"type\": \"number\", \"description\": \"The maximum size of memory in bytes that yaql exrpessions can take for its evaluation.\\n\", \"default\": 100000}, \"HeatMaxJsonBodySize\": {\"default\": 4194304, \"description\": \"Maximum raw byte size of the Heat API JSON request body.\", \"type\": \"number\"}, \"NotificationDriver\": {\"type\": \"comma_delimited_list\", \"default\": \"noop\", \"description\": \"Driver or drivers to handle sending notifications.\"}, \"HeatCorsAllowedOrigin\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Indicate whether this resource may be shared with the domain received in the request \\\"origin\\\" header.\"}, \"MemcachedTLS\": {\"default\": true, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}, \"MemcacheUseAdvancedPool\": {\"type\": \"boolean\", \"description\": \"Use the advanced (eventlet safe) memcached client pool.\\n\", \"default\": true}, \"HeatApiPolicies\": {\"description\": \"A hash of policies to configure for Heat API.\\ne.g. { heat-context_is_admin: { key: context_is_admin, value: \'role:admin\' } }\\n\", \"default\": {}, \"type\": \"json\"}, \"EnforceSecureRbac\": {\"type\": \"boolean\", \"default\": false, \"description\": \"Setting this option to True will configure each OpenStack service to enforce Secure RBAC by setting `[oslo_policy] enforce_new_defaults` and `[oslo_policy] enforce_scope` to True. This introduces a consistent set of RBAC personas across OpenStack services that include support for system and project scope, as well as keystone\'s default roles, admin, member, and reader. Do not enable this functionality until all services in your deployment actually support secure RBAC.\"}}, \"conditions\": {\"tls_cache_enabled\": {\"and\": [{\"get_param\": \"EnableCache\"}, {\"get_param\": \"MemcachedTLS\"}]}, \"cors_allowed_origin_set\": {\"not\": {\"equals\": [{\"get_param\": \"HeatCorsAllowedOrigin\"}, \"\"]}}}, \"outputs\": {\"role_data\": {\"description\": \"Shared role data for the Heat services.\", \"value\": {\"service_name\": \"heat_base\", \"config_settings\": {\"map_merge\": [{\"if\": [{\"get_param\": \"EnforceSecureRbac\"}, {\"heat::policy::enforce_scope\": true, \"heat::policy::enforce_new_defaults\": true}]}, {\"if\": [\"cors_allowed_origin_set\", {\"heat::cors::allowed_origin\": {\"get_param\": \"HeatCorsAllowedOrigin\"}}]}, {\"heat::notification_driver\": {\"get_param\": \"NotificationDriver\"}, \"heat::logging::debug\": {\"if\": [{\"get_param\": \"HeatDebug\"}, true, {\"get_param\": \"Debug\"}]}, \"heat::policy::policies\": {\"get_param\": \"HeatApiPolicies\"}, \"heat::enable_proxy_headers_parsing\": true, \"heat::rpc_response_timeout\": 600, \"heat::rabbit_heartbeat_timeout_threshold\": 60, \"heat::rabbit_heartbeat_in_pthread\": false, \"heat::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"heat::keystone::authtoken::project_name\": \"service\", \"heat::keystone::authtoken::user_domain_name\": \"Default\", \"heat::keystone::authtoken::project_domain_name\": \"Default\", \"heat::keystone::authtoken::www_authenticate_uri\": {\"get_param\": [\"EndpointMap\", \"KeystonePublic\", \"uri_no_suffix\"]}, \"heat::keystone::authtoken::auth_url\": {\"get_param\": [\"EndpointMap\", \"KeystoneInternal\", \"uri_no_suffix\"]}, \"heat::keystone::authtoken::password\": {\"get_param\": \"HeatPassword\"}, \"heat::keystone::authtoken::region_name\": {\"get_param\": \"KeystoneRegion\"}, \"heat::keystone::authtoken::interface\": \"internal\", \"heat::keystone::authtoken::memcache_use_advanced_pool\": {\"get_param\": \"MemcacheUseAdvancedPool\"}, \"heat::keystone::domain::domain_name\": \"heat_stack\", \"heat::keystone::domain::domain_admin\": \"heat_stack_domain_admin\", \"heat::keystone::domain::domain_admin_email\": \"heat_stack_domain_admin@localhost\", \"heat::db::database_db_max_retries\": -1, \"heat::db::database_max_retries\": -1, \"heat::yaql_memory_quota\": {\"get_param\": \"HeatYaqlMemoryQuota\"}, \"heat::yaql_limit_iterators\": {\"get_param\": \"HeatYaqlLimitIterators\"}, \"heat::cors::max_age\": 3600, \"heat::cors::allow_headers\": \"Content-Type,Cache-Control,Content-Language,Expires,Last-Modified,Pragma,X-Auth-Token\", \"heat::cors::expose_headers\": \"Content-Type,Cache-Control,Content-Language,Expires,Last-Modified,Pragma\", \"heat::cron::purge_deleted::ensure\": {\"get_param\": \"HeatCronPurgeDeletedEnsure\"}, \"heat::cron::purge_deleted::minute\": {\"get_param\": \"HeatCronPurgeDeletedMinute\"}, \"heat::cron::purge_deleted::hour\": {\"get_param\": \"HeatCronPurgeDeletedHour\"}, \"heat::cron::purge_deleted::monthday\": {\"get_param\": \"HeatCronPurgeDeletedMonthday\"}, \"heat::cron::purge_deleted::month\": {\"get_param\": \"HeatCronPurgeDeletedMonth\"}, \"heat::cron::purge_deleted::weekday\": {\"get_param\": \"HeatCronPurgeDeletedWeekday\"}, \"heat::cron::purge_deleted::maxdelay\": {\"get_param\": \"HeatCronPurgeDeletedMaxDelay\"}, \"heat::cron::purge_deleted::user\": {\"get_param\": \"HeatCronPurgeDeletedUser\"}, \"heat::cron::purge_deleted::age\": {\"get_param\": \"HeatCronPurgeDeletedAge\"}, \"heat::cron::purge_deleted::age_type\": {\"get_param\": \"HeatCronPurgeDeletedAgeType\"}, \"heat::cron::purge_deleted::destination\": {\"get_param\": \"HeatCronPurgeDeletedDestination\"}, \"heat::max_json_body_size\": {\"get_param\": \"HeatMaxJsonBodySize\"}}, {\"heat::cache::enabled\": {\"get_param\": \"EnableCache\"}, \"heat::cache::tls_enabled\": {\"get_param\": \"MemcachedTLS\"}, \"heat::cache::resource_finder_caching\": false}, {\"if\": [\"tls_cache_enabled\", {\"heat::cache::backend\": \"dogpile.cache.pymemcache\"}, {\"heat::cache::backend\": \"dogpile.cache.memcached\"}]}]}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceData\": {\"net_cidr_map\": {\"ctlplane\": [\"192.168.122.0/24\"], \"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_vip_map\": {\"ctlplane\": \"192.168.122.99\", \"ctlplane_subnet\": \"192.168.122.99/24\", \"ctlplane_uri\": \"192.168.122.99\", \"storage\": \"172.18.0.129\", \"storage_subnet\": \"\", \"storage_uri\": \"172.18.0.129\", \"storage_mgmt\": \"172.20.0.181\", \"storage_mgmt_subnet\": \"\", \"storage_mgmt_uri\": \"172.20.0.181\", \"internal_api\": \"172.17.0.205\", \"internal_api_subnet\": \"\", \"internal_api_uri\": \"172.17.0.205\", \"tenant\": \"\", \"tenant_subnet\": \"\", \"tenant_uri\": \"\", \"external\": \"172.21.0.163\", \"external_subnet\": \"\", \"external_uri\": \"172.21.0.163\"}, \"net_ip_version_map\": {\"ctlplane\": 4, \"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}, \"vip_subnet_map\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"RoleName\": \"Controller\", \"RoleParameters\": {\"OVNCMSOptions\": \"enable-chassis-as-gw\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(215,'2026-06-09 08:02:31',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1);
INSERT INTO `raw_template` VALUES (216,'2026-06-09 08:02:31',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Contains a static list of common things necessary for containers\\n\", \"parameters\": {\"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}, \"RpcPort\": {\"default\": 5672, \"description\": \"The network port for messaging backend\", \"type\": \"number\"}, \"PcmkConfigRestartTimeout\": {\"default\": 600, \"description\": \"Time in seconds to wait for a pacemaker resource to restart when a config change is detected and the resource is being restarted\", \"type\": \"number\"}, \"ContainerCli\": {\"type\": \"string\", \"default\": \"podman\", \"description\": \"CLI tool used to manage containers.\", \"constraints\": [{\"allowed_values\": [\"docker\", \"podman\"]}]}}, \"conditions\": {\"internal_tls_enabled\": {\"equals\": [{\"get_param\": \"EnableInternalTLS\"}, true]}, \"docker_enabled\": {\"equals\": [{\"get_param\": \"ContainerCli\"}, \"docker\"]}}, \"outputs\": {\"container_config_scripts\": {\"description\": \"Shared container config scripts\", \"value\": {\"container_puppet_apply.sh\": {\"mode\": \"0700\", \"content\": \"#!/bin/bash\\nset -eux\\nSTEP=$1\\nTAGS=$2\\nCONFIG=$3\\nEXTRA_ARGS=${4:-\'\'}\\nif [ -d /tmp/puppet-etc ]; then\\n  # ignore copy failures as these may be the same file depending on docker mounts\\n  cp -a /tmp/puppet-etc/* /etc/puppet || true\\nfi\\necho \\\"{\\\\\\\"step\\\\\\\": ${STEP}}\\\" > /etc/puppet/hieradata/docker_puppet.json\\n# $::deployment_type in puppet-tripleo\\nexport FACTER_deployment_type=containers\\nset +e\\npuppet apply $EXTRA_ARGS \\\\\\n    --verbose \\\\\\n    --detailed-exitcodes \\\\\\n    --summarize \\\\\\n    --color=false \\\\\\n    --modulepath /etc/puppet/modules:/opt/stack/puppet-modules:/usr/share/openstack-puppet/modules \\\\\\n    --tags $TAGS \\\\\\n    -e \\\"noop_resource(\'package\'); ${CONFIG}\\\"\\nrc=$?\\nset -e\\nset +ux\\nif [ $rc -eq 2 -o $rc -eq 0 ]; then\\n    exit 0\\nfi\\nexit $rc\\n\"}, \"pyshim.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pyshim.sh\"}}, \"pacemaker_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_restart_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"pacemaker_wait_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"str_replace\": {\"template\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_wait_bundle.sh\"}, \"params\": {\"__PCMKTIMEOUT__\": {\"get_param\": \"PcmkConfigRestartTimeout\"}}}}}, \"wait-port-and-run.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/wait-port-and-run.sh\"}}, \"pacemaker_resource_lock.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_resource_lock.sh\"}}, \"pacemaker_mutex_restart_bundle.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_restart_bundle.sh\"}}, \"pacemaker_mutex_shutdown.sh\": {\"mode\": \"0755\", \"content\": {\"get_file\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/container_config_scripts/pacemaker_mutex_shutdown.sh\"}}}}, \"volumes_base\": {\"description\": \"Base volume list\", \"value\": {\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}}, \"volumes\": {\"description\": \"Common volumes for the containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/etc/puppet:/etc/puppet:ro\"]]}}, \"pacemaker_restart_volumes\": {\"description\": \"Common volumes for the pacemaker restart containers.\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts:/var/lib/container-config-scripts:ro\", \"/dev/shm:/dev/shm:rw\", \"/etc/puppet:/etc/puppet:ro\"], {\"if\": [\"docker_enabled\", [\"/etc/corosync/corosync.conf:/etc/corosync/corosync.conf:ro\"], null]}]}}, \"container_puppet_apply_volumes\": {\"description\": \"Common volumes needed to run the container_puppet_apply.sh from container_config_scripts\", \"value\": {\"list_concat\": [{\"list_concat\": [[\"/etc/hosts:/etc/hosts:ro\", \"/etc/localtime:/etc/localtime:ro\", \"/etc/pki/ca-trust/extracted:/etc/pki/ca-trust/extracted:ro\", \"/etc/pki/ca-trust/source/anchors:/etc/pki/ca-trust/source/anchors:ro\", \"/etc/pki/tls/certs/ca-bundle.crt:/etc/pki/tls/certs/ca-bundle.crt:ro\", \"/etc/pki/tls/certs/ca-bundle.trust.crt:/etc/pki/tls/certs/ca-bundle.trust.crt:ro\", \"/etc/pki/tls/cert.pem:/etc/pki/tls/cert.pem:ro\", \"/dev/log:/dev/log\"], {\"if\": [\"internal_tls_enabled\", [{\"list_join\": [\":\", [{\"get_param\": \"InternalTLSCAFile\"}, {\"get_param\": \"InternalTLSCAFile\"}, \"ro\"]]}], null]}]}, [\"/var/lib/container-config-scripts/container_puppet_apply.sh:/container_puppet_apply.sh:ro\", \"/etc/puppet:/tmp/puppet-etc:ro\", \"/usr/share/openstack-puppet/modules:/usr/share/openstack-puppet/modules:ro\"]]}}, \"healthcheck_rpc_port\": {\"description\": \"healthcheck command that probes the RpcPort\", \"value\": {\"test\": {\"str_replace\": {\"template\": \"/openstack/healthcheck RPCPORT\", \"params\": {\"RPCPORT\": {\"get_param\": \"RpcPort\"}}}}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(217,'2026-06-09 08:02:31',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"Mysql client settings\\n\", \"parameters\": {\"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EnableInternalTLS\": {\"type\": \"boolean\", \"default\": true}, \"InternalTLSCAFile\": {\"default\": \"/etc/ipa/ca.crt\", \"type\": \"string\", \"description\": \"Specifies the default CA cert to use if TLS is used for services in the internal network.\"}}, \"outputs\": {\"role_data\": {\"description\": \"Role for setting mysql client parameters\", \"value\": {\"service_name\": \"mysql_client\", \"config_settings\": {\"tripleo::profile::base::database::mysql::client::mysql_client_bind_address\": {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MysqlNetwork\"]}}}}, \"tripleo::profile::base::database::mysql::client::enable_ssl\": {\"get_param\": \"EnableInternalTLS\"}, \"tripleo::profile::base::database::mysql::client::ssl_ca\": {\"get_param\": \"InternalTLSCAFile\"}}, \"step_config\": \"include tripleo::profile::base::database::mysql::client\"}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(218,'2026-06-09 08:02:31',NULL,'{\"heat_template_version\": \"2015-04-30\", \"resources\": {\"0\": {\"type\": \"OS::TripleO::Compute\", \"properties\": {\"CloudDomain\": \"ooo.test\", \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"Hostname\": \"overcloud-novacompute-0\", \"NodeIndex\": \"0\", \"ComputeSchedulerHints\": {}, \"ServiceNames\": [\"boot_params_service\", \"ca_certs\", \"collectd\", \"ceilometer_agent_compute\", \"ceilometer_agent_ipmi\", \"ipaservice\", \"iscsid\", \"kernel\", \"metrics_qdr\", \"mysql_client\", \"nova_compute\", \"nova_libvirt\", \"nova_libvirt_guests\", \"nova_migration_target\", \"logrotate_crond\", \"podman\", \"rsyslog\", \"snmp\", \"sshd\", \"chrony\", \"timezone\", \"tripleo_firewall\", \"tripleo_packages\", \"tuned\", \"ovn_controller\", \"ovn_metadata\"], \"ServiceMetadataSettings\": {\"compact_service_metrics_qdr\": [\"internalapi\"], \"compact_service_libvirt\": [\"internalapi\"], \"compact_service_qemu\": [\"internalapi\"], \"compact_service_libvirt-vnc\": [\"internalapi\"], \"compact_service_ovn_controller\": [\"internalapi\"], \"compact_service_ovn_metadata\": [\"internalapi\"]}, \"OVNBridgeMappings\": [\"datacentre:br-ex\"], \"DeploymentServerBlacklistDict\": {}, \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"UserData\": \"760f3ad1-1a88-4792-87fe-934d5912fd27\"}}, \"1\": {\"type\": \"OS::TripleO::Compute\", \"properties\": {\"CloudDomain\": \"ooo.test\", \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"Hostname\": \"overcloud-novacompute-1\", \"NodeIndex\": \"1\", \"ComputeSchedulerHints\": {}, \"ServiceNames\": [\"boot_params_service\", \"ca_certs\", \"collectd\", \"ceilometer_agent_compute\", \"ceilometer_agent_ipmi\", \"ipaservice\", \"iscsid\", \"kernel\", \"metrics_qdr\", \"mysql_client\", \"nova_compute\", \"nova_libvirt\", \"nova_libvirt_guests\", \"nova_migration_target\", \"logrotate_crond\", \"podman\", \"rsyslog\", \"snmp\", \"sshd\", \"chrony\", \"timezone\", \"tripleo_firewall\", \"tripleo_packages\", \"tuned\", \"ovn_controller\", \"ovn_metadata\"], \"ServiceMetadataSettings\": {\"compact_service_metrics_qdr\": [\"internalapi\"], \"compact_service_libvirt\": [\"internalapi\"], \"compact_service_qemu\": [\"internalapi\"], \"compact_service_libvirt-vnc\": [\"internalapi\"], \"compact_service_ovn_controller\": [\"internalapi\"], \"compact_service_ovn_metadata\": [\"internalapi\"]}, \"OVNBridgeMappings\": [\"datacentre:br-ex\"], \"DeploymentServerBlacklistDict\": {}, \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"UserData\": \"760f3ad1-1a88-4792-87fe-934d5912fd27\"}}, \"2\": {\"type\": \"OS::TripleO::Compute\", \"properties\": {\"CloudDomain\": \"ooo.test\", \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"Hostname\": \"overcloud-novacompute-2\", \"NodeIndex\": \"2\", \"ComputeSchedulerHints\": {}, \"ServiceNames\": [\"boot_params_service\", \"ca_certs\", \"collectd\", \"ceilometer_agent_compute\", \"ceilometer_agent_ipmi\", \"ipaservice\", \"iscsid\", \"kernel\", \"metrics_qdr\", \"mysql_client\", \"nova_compute\", \"nova_libvirt\", \"nova_libvirt_guests\", \"nova_migration_target\", \"logrotate_crond\", \"podman\", \"rsyslog\", \"snmp\", \"sshd\", \"chrony\", \"timezone\", \"tripleo_firewall\", \"tripleo_packages\", \"tuned\", \"ovn_controller\", \"ovn_metadata\"], \"ServiceMetadataSettings\": {\"compact_service_metrics_qdr\": [\"internalapi\"], \"compact_service_libvirt\": [\"internalapi\"], \"compact_service_qemu\": [\"internalapi\"], \"compact_service_libvirt-vnc\": [\"internalapi\"], \"compact_service_ovn_controller\": [\"internalapi\"], \"compact_service_ovn_metadata\": [\"internalapi\"]}, \"OVNBridgeMappings\": [\"datacentre:br-ex\"], \"DeploymentServerBlacklistDict\": {}, \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"UserData\": \"760f3ad1-1a88-4792-87fe-934d5912fd27\"}}}, \"outputs\": {\"ip_address\": {\"value\": [{\"get_attr\": [\"0\", \"ip_address\"]}, {\"get_attr\": [\"1\", \"ip_address\"]}, {\"get_attr\": [\"2\", \"ip_address\"]}]}, \"internal_api_ip_address\": {\"value\": [{\"get_attr\": [\"0\", \"internal_api_ip_address\"]}, {\"get_attr\": [\"1\", \"internal_api_ip_address\"]}, {\"get_attr\": [\"2\", \"internal_api_ip_address\"]}]}, \"ansible_host_vars_map\": {\"value\": [{\"get_attr\": [\"0\", \"ansible_host_vars_map\"]}, {\"get_attr\": [\"1\", \"ansible_host_vars_map\"]}, {\"get_attr\": [\"2\", \"ansible_host_vars_map\"]}]}, \"tenant_ip_address\": {\"value\": [{\"get_attr\": [\"0\", \"tenant_ip_address\"]}, {\"get_attr\": [\"1\", \"tenant_ip_address\"]}, {\"get_attr\": [\"2\", \"tenant_ip_address\"]}]}, \"hostname\": {\"value\": [{\"get_attr\": [\"0\", \"hostname\"]}, {\"get_attr\": [\"1\", \"hostname\"]}, {\"get_attr\": [\"2\", \"hostname\"]}]}, \"nova_server_resource\": {\"value\": [{\"get_attr\": [\"0\", \"nova_server_resource\"]}, {\"get_attr\": [\"1\", \"nova_server_resource\"]}, {\"get_attr\": [\"2\", \"nova_server_resource\"]}]}, \"hosts_entry\": {\"value\": [{\"get_attr\": [\"0\", \"hosts_entry\"]}, {\"get_attr\": [\"1\", \"hosts_entry\"]}, {\"get_attr\": [\"2\", \"hosts_entry\"]}]}, \"hostname_map\": {\"value\": [{\"get_attr\": [\"0\", \"hostname_map\"]}, {\"get_attr\": [\"1\", \"hostname_map\"]}, {\"get_attr\": [\"2\", \"hostname_map\"]}]}, \"blacklist_ip_address\": {\"value\": [{\"get_attr\": [\"0\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"1\", \"blacklist_ip_address\"]}, {\"get_attr\": [\"2\", \"blacklist_ip_address\"]}]}, \"attributes, nova_server_resource\": {\"value\": {\"0\": {\"get_attr\": [\"0\", \"nova_server_resource\"]}, \"1\": {\"get_attr\": [\"1\", \"nova_server_resource\"]}, \"2\": {\"get_attr\": [\"2\", \"nova_server_resource\"]}}}, \"blacklist_hostname\": {\"value\": [{\"get_attr\": [\"0\", \"blacklist_hostname\"]}, {\"get_attr\": [\"1\", \"blacklist_hostname\"]}, {\"get_attr\": [\"2\", \"blacklist_hostname\"]}]}, \"storage_ip_address\": {\"value\": [{\"get_attr\": [\"0\", \"storage_ip_address\"]}, {\"get_attr\": [\"1\", \"storage_ip_address\"]}, {\"get_attr\": [\"2\", \"storage_ip_address\"]}]}, \"refs_map\": {\"value\": {\"0\": {\"get_resource\": \"0\"}, \"1\": {\"get_resource\": \"1\"}, \"2\": {\"get_resource\": \"2\"}}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(219,'2026-06-09 08:02:32',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack Compute node configured by Puppet\", \"parameters\": {\"OvercloudComputeFlavor\": {\"description\": \"Flavor for the Compute node.\", \"default\": \"baremetal\", \"type\": \"string\"}, \"NovaImage\": {\"type\": \"string\", \"default\": \"overcloud-full\", \"description\": \"DEPRECATED Use ComputeImage instead\"}, \"ComputeImage\": {\"type\": \"string\", \"default\": \"overcloud-full\", \"description\": \"The disk image file to use for the role.\"}, \"ImageUpdatePolicy\": {\"default\": \"REBUILD_PRESERVE_EPHEMERAL\", \"description\": \"What policy to use when reconstructing instances. REBUILD for rebuilds, REBUILD_PRESERVE_EPHEMERAL to preserve /mnt.\", \"type\": \"string\"}, \"KeyName\": {\"description\": \"Name of an existing Nova key pair to enable SSH access to the instances\", \"type\": \"string\", \"default\": \"default\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"UpdateIdentifier\": {\"default\": \"\", \"type\": \"string\", \"description\": \"Setting to a previously unused value during stack-update will trigger package update on all nodes\\n\"}, \"Hostname\": {\"type\": \"string\", \"default\": \"\"}, \"HostnameMap\": {\"type\": \"json\", \"default\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"description\": \"Optional mapping to override hostnames\"}, \"ComputeIPs\": {\"default\": {}, \"type\": \"json\"}, \"NovaComputeIPs\": {\"default\": {}, \"description\": \"DEPRECATED - use ComputeIPs instead\", \"type\": \"json\"}, \"SoftwareConfigTransport\": {\"default\": \"POLL_SERVER_HEAT\", \"description\": \"How the server should receive the metadata required for software configuration.\\n\", \"type\": \"string\", \"constraints\": [{\"allowed_values\": [\"POLL_SERVER_CFN\", \"POLL_SERVER_HEAT\", \"POLL_TEMP_URL\", \"ZAQAR_MESSAGE\"]}]}, \"CloudDomain\": {\"default\": \"ooo.test\", \"type\": \"string\", \"description\": \"The DNS domain used for the hosts. This must match the overcloud_domain_name configured on the undercloud.\\n\"}, \"ComputeServerMetadata\": {\"default\": {}, \"description\": \"Extra properties or metadata passed to Nova for the created nodes in the overcloud. It\'s accessible via the Nova metadata API. This option is role-specific and is merged with the values given to the ServerMetadata parameter.\\n\", \"type\": \"json\"}, \"NovaComputeServerMetadata\": {\"default\": {}, \"description\": \"DEPRECATED - use ComputeServerMetadata instead\", \"type\": \"json\"}, \"ServerMetadata\": {\"default\": {\"ipa_enroll\": true}, \"description\": \"Extra properties or metadata passed to Nova for the created nodes in the overcloud. It\'s accessible via the Nova metadata API. This applies to all roles and is merged with a role-specific metadata parameter.\\n\", \"type\": \"json\"}, \"ComputeSchedulerHints\": {\"type\": \"json\", \"description\": \"Optional scheduler hints to pass to nova\", \"default\": {}}, \"NodeIndex\": {\"type\": \"number\", \"default\": 0}, \"ServiceNames\": {\"type\": \"comma_delimited_list\", \"default\": []}, \"MonitoringSubscriptions\": {\"type\": \"comma_delimited_list\", \"default\": []}, \"ServiceMetadataSettings\": {\"type\": \"json\", \"default\": {}}, \"OVNBridgeMappings\": {\"type\": \"comma_delimited_list\", \"default\": []}, \"ConfigCommand\": {\"type\": \"string\", \"description\": \"Command which will be run whenever configuration data changes\", \"default\": \"os-refresh-config --timeout 14400\"}, \"ConfigCollectSplay\": {\"type\": \"number\", \"default\": 30, \"description\": \"Maximum amount of time to possibly to delay configuration collection\\npolling. Defaults to 30 seconds. Set to 0 to disable it which will cause\\nthe configuration collection to occur as soon as the collection process\\nstarts.  This setting is used to prevent the configuration collection\\nprocesses from polling all at the exact same time.\\n\"}, \"UpgradeInitCommand\": {\"type\": \"string\", \"description\": \"Command or script snippet to run on all overcloud nodes to\\ninitialize the upgrade process. E.g. a repository switch.\\n\", \"default\": \"\", \"tags\": [\"role_specific\"]}, \"UpgradeInitCommonCommand\": {\"type\": \"string\", \"description\": \"Common commands required by the upgrades process. This should not\\nnormally be modified by the operator and is set and unset in the\\nmajor-upgrade-composable-steps.yaml and major-upgrade-converge.yaml\\nenvironment files.\\n\", \"default\": \"\"}, \"DeploymentServerBlacklistDict\": {\"default\": {}, \"type\": \"json\", \"description\": \"Map of server hostnames to blacklist from any triggered deployments. If the value is 1, the server will be blacklisted. This parameter is generated from the parent template.\\n\"}, \"RoleParameters\": {\"type\": \"json\", \"description\": \"Parameters specific to the role\", \"default\": {}}, \"ComputeControlPlaneSubnet\": {\"default\": \"ctlplane-subnet\", \"description\": \"Name of the subnet on ctlplane network for this role.\\n\", \"type\": \"string\"}, \"ControlPlaneSubnetCidr\": {\"default\": \"\", \"description\": \"The subnet CIDR of the control plane network. (The parameter is automatically resolved from the ctlplane subnet\'s cidr attribute.)\\n\", \"type\": \"string\"}, \"ServerDeletionPolicy\": {\"description\": \"Whether to retain or delete servers on deletion of the stack\", \"type\": \"string\", \"default\": \"delete\", \"constraints\": [{\"allowed_values\": [\"delete\", \"retain\"]}]}, \"UserData\": {\"type\": \"string\"}}, \"parameter_groups\": [{\"label\": \"deprecated\", \"description\": \"Do not use deprecated params, they will be removed.\", \"parameters\": [\"NovaImage\", \"NovaComputeServerMetadata\", \"NovaComputeIPs\"]}], \"conditions\": {\"server_blacklisted\": {\"or\": [{\"equals\": [{\"get_param\": [\"DeploymentServerBlacklistDict\", {\"get_param\": \"Hostname\"}]}, 1]}, {\"equals\": [{\"get_param\": [\"DeploymentServerBlacklistDict\", {\"get_param\": [\"HostnameMap\", {\"get_param\": \"Hostname\"}]}]}, 1]}]}, \"server_not_blacklisted\": {\"and\": [{\"not\": {\"equals\": [{\"get_param\": [\"DeploymentServerBlacklistDict\", {\"get_param\": \"Hostname\"}]}, 1]}}, {\"not\": {\"equals\": [{\"get_param\": [\"DeploymentServerBlacklistDict\", {\"get_param\": [\"HostnameMap\", {\"get_param\": \"Hostname\"}]}]}, 1]}}]}, \"deprecated_param_image_set\": {\"not\": {\"equals\": [{\"get_param\": \"NovaImage\"}, \"overcloud-full\"]}}, \"ctlplane_fixed_ip_set\": {\"or\": [{\"not\": {\"equals\": [{\"get_param\": [\"ComputeIPs\", \"ctlplane\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}, {\"not\": {\"equals\": [{\"get_param\": [\"NovaComputeIPs\", \"ctlplane\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}, false]}, \"Compute_Storage_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": [\"ComputeIPs\", \"storage\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}, \"Compute_InternalApi_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": [\"ComputeIPs\", \"internal_api\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}, \"Compute_Tenant_fixed_ip_set\": {\"not\": {\"equals\": [{\"get_param\": [\"ComputeIPs\", \"tenant\", {\"get_param\": \"NodeIndex\"}]}, \"\"]}}}, \"resources\": {\"NovaCompute\": {\"type\": \"OS::TripleO::ComputeServer\", \"deletion_policy\": {\"get_param\": \"ServerDeletionPolicy\"}, \"properties\": {\"image\": {\"if\": [\"deprecated_param_image_set\", {\"get_param\": \"NovaImage\"}, {\"get_param\": \"ComputeImage\"}]}, \"image_update_policy\": {\"get_param\": \"ImageUpdatePolicy\"}, \"flavor\": {\"get_param\": \"OvercloudComputeFlavor\"}, \"key_name\": {\"get_param\": \"KeyName\"}, \"networks\": [{\"if\": [\"ctlplane_fixed_ip_set\", {\"network\": \"ctlplane\", \"subnet\": {\"get_param\": \"ComputeControlPlaneSubnet\"}, \"fixed_ip\": {\"yaql\": {\"expression\": \"$.data.where(not isEmpty($)).first()\", \"data\": [{\"get_param\": [\"ComputeIPs\", \"ctlplane\", {\"get_param\": \"NodeIndex\"}]}, {\"get_param\": [\"NovaComputeIPs\", \"ctlplane\", {\"get_param\": \"NodeIndex\"}]}]}}}, {\"network\": \"ctlplane\", \"subnet\": {\"get_param\": \"ComputeControlPlaneSubnet\"}}]}], \"user_data_format\": \"SOFTWARE_CONFIG\", \"user_data\": {\"get_param\": \"UserData\"}, \"name\": {\"yaql\": {\"expression\": \"$.data.hostname_map.get($.data.hostname, $.data.hostname).toLower()\", \"data\": {\"hostname\": {\"get_param\": \"Hostname\"}, \"hostname_map\": {\"get_param\": \"HostnameMap\"}}}}, \"software_config_transport\": {\"get_param\": \"SoftwareConfigTransport\"}, \"metadata\": {\"map_merge\": [{\"get_param\": \"ServerMetadata\"}, {\"get_param\": \"NovaComputeServerMetadata\"}, {\"get_param\": \"ComputeServerMetadata\"}, {\"get_param\": \"ServiceMetadataSettings\"}]}, \"scheduler_hints\": {\"get_param\": \"ComputeSchedulerHints\"}}}, \"StoragePort\": {\"type\": \"OS::TripleO::Compute::Ports::StoragePort\", \"properties\": {\"PortName\": {\"list_join\": [\"_\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"Storage\"]]}, \"DnsName\": {\"get_attr\": [\"NovaCompute\", \"name\"]}, \"ControlPlaneIP\": {\"get_attr\": [\"NovaCompute\", \"networks\", \"ctlplane\", 0]}, \"FixedIPs\": {\"if\": [\"Compute_Storage_fixed_ip_set\", [{\"ip_address\": {\"get_param\": [\"ComputeIPs\", \"storage\", {\"get_param\": \"NodeIndex\"}]}}], [{\"subnet\": \"storage_subnet\"}]]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"NovaCompute\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}, -1]}, \"IPPool\": {\"map_merge\": [{\"get_param\": \"NovaComputeIPs\"}, {\"get_param\": \"ComputeIPs\"}]}, \"NodeIndex\": {\"get_param\": \"NodeIndex\"}, \"Role\": \"Compute\"}}, \"InternalApiPort\": {\"type\": \"OS::TripleO::Compute::Ports::InternalApiPort\", \"properties\": {\"PortName\": {\"list_join\": [\"_\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"InternalApi\"]]}, \"DnsName\": {\"get_attr\": [\"NovaCompute\", \"name\"]}, \"ControlPlaneIP\": {\"get_attr\": [\"NovaCompute\", \"networks\", \"ctlplane\", 0]}, \"FixedIPs\": {\"if\": [\"Compute_InternalApi_fixed_ip_set\", [{\"ip_address\": {\"get_param\": [\"ComputeIPs\", \"internal_api\", {\"get_param\": \"NodeIndex\"}]}}], [{\"subnet\": \"internal_api_subnet\"}]]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"NovaCompute\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}, -1]}, \"IPPool\": {\"map_merge\": [{\"get_param\": \"NovaComputeIPs\"}, {\"get_param\": \"ComputeIPs\"}]}, \"NodeIndex\": {\"get_param\": \"NodeIndex\"}, \"Role\": \"Compute\"}}, \"TenantPort\": {\"type\": \"OS::TripleO::Compute::Ports::TenantPort\", \"properties\": {\"PortName\": {\"list_join\": [\"_\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"Tenant\"]]}, \"DnsName\": {\"get_attr\": [\"NovaCompute\", \"name\"]}, \"ControlPlaneIP\": {\"get_attr\": [\"NovaCompute\", \"networks\", \"ctlplane\", 0]}, \"FixedIPs\": {\"if\": [\"Compute_Tenant_fixed_ip_set\", [{\"ip_address\": {\"get_param\": [\"ComputeIPs\", \"tenant\", {\"get_param\": \"NodeIndex\"}]}}], [{\"subnet\": \"tenant_subnet\"}]]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"NovaCompute\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}, -1]}, \"IPPool\": {\"map_merge\": [{\"get_param\": \"NovaComputeIPs\"}, {\"get_param\": \"ComputeIPs\"}]}, \"NodeIndex\": {\"get_param\": \"NodeIndex\"}, \"Role\": \"Compute\"}}, \"NetIpMap\": {\"type\": \"OS::TripleO::Network::Ports::NetIpMap\", \"properties\": {\"ControlPlaneIp\": {\"get_attr\": [\"NovaCompute\", \"networks\", \"ctlplane\", 0]}, \"ControlPlaneSubnetCidr\": {\"str_split\": [\"/\", {\"get_attr\": [\"NovaCompute\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}, -1]}, \"StorageIp\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}, \"StorageIpSubnet\": {\"get_attr\": [\"StoragePort\", \"ip_subnet\"]}, \"StorageIpUri\": {\"get_attr\": [\"StoragePort\", \"ip_address_uri\"]}, \"InternalApiIp\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}, \"InternalApiIpSubnet\": {\"get_attr\": [\"InternalApiPort\", \"ip_subnet\"]}, \"InternalApiIpUri\": {\"get_attr\": [\"InternalApiPort\", \"ip_address_uri\"]}, \"TenantIp\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}, \"TenantIpSubnet\": {\"get_attr\": [\"TenantPort\", \"ip_subnet\"]}, \"TenantIpUri\": {\"get_attr\": [\"TenantPort\", \"ip_address_uri\"]}}}, \"NetHostMap\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"storage\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"storage\", {\"get_param\": \"CloudDomain\"}]]}, \"short\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"storage\"]]}}, \"internal_api\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"internalapi\", {\"get_param\": \"CloudDomain\"}]]}, \"short\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"internalapi\"]]}}, \"tenant\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"tenant\", {\"get_param\": \"CloudDomain\"}]]}, \"short\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"tenant\"]]}}, \"ctlplane\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"ctlplane\", {\"get_param\": \"CloudDomain\"}]]}, \"short\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, \"ctlplane\"]]}}, \"canonical\": {\"fqdn\": {\"list_join\": [\".\", [{\"get_attr\": [\"NovaCompute\", \"name\"]}, {\"get_param\": \"CloudDomain\"}]]}, \"short\": [{\"get_attr\": [\"NovaCompute\", \"name\"]}]}}}}, \"PreNetworkConfig\": {\"type\": \"OS::TripleO::Compute::PreNetworkConfig\", \"condition\": \"server_not_blacklisted\", \"properties\": {\"server\": {\"get_resource\": \"NovaCompute\"}, \"RoleParameters\": {\"get_param\": \"RoleParameters\"}, \"ServiceNames\": {\"get_param\": \"ServiceNames\"}, \"deployment_actions\": {\"get_attr\": [\"DeploymentActions\", \"value\"]}}}, \"NodeTLSCAData\": {\"type\": \"OS::TripleO::NodeTLSCAData\", \"properties\": {\"server\": {\"get_resource\": \"NovaCompute\"}}}, \"ComputeExtraConfigPre\": {\"type\": \"OS::TripleO::ComputeExtraConfigPre\", \"condition\": \"server_not_blacklisted\", \"properties\": {\"server\": {\"get_resource\": \"NovaCompute\"}}}, \"NodeExtraConfig\": {\"depends_on\": [\"ComputeExtraConfigPre\", \"NodeTLSCAData\"], \"type\": \"OS::TripleO::NodeExtraConfig\", \"condition\": \"server_not_blacklisted\", \"properties\": {\"server\": {\"get_resource\": \"NovaCompute\"}}}, \"DeploymentActions\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"value\": {\"if\": [\"server_not_blacklisted\", [\"CREATE\", \"UPDATE\"], []]}}}, \"NovaComputeAnsibleHostVars\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"fqdn_storage\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"fqdn\"]}, \"fqdn_internal_api\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"fqdn\"]}, \"fqdn_tenant\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"fqdn\"]}, \"fqdn_ctlplane\": {\"get_attr\": [\"NetHostMap\", \"value\", \"ctlplane\", \"fqdn\"]}, \"fqdn_canonical\": {\"get_attr\": [\"NetHostMap\", \"value\", \"canonical\", \"fqdn\"]}, \"hostname_resolve_network\": {\"get_param\": [\"ServiceNetMap\", \"ComputeHostnameResolveNetwork\"]}}}}}, \"outputs\": {\"ansible_host_vars_map\": {\"description\": \"Map of Ansible variables specific per host.\\nThis map is used to construct the AnsibleHostVarsMap output for the\\nansible vars per host in config-download.\\n\", \"value\": {\"map_replace\": [{\"host\": {\"get_attr\": [\"NovaComputeAnsibleHostVars\", \"value\"]}}, {\"keys\": {\"host\": {\"get_attr\": [\"NovaCompute\", \"name\"]}}}]}}, \"ip_address\": {\"description\": \"IP address of the server in the ctlplane network\", \"value\": {\"get_attr\": [\"NovaCompute\", \"networks\", \"ctlplane\", 0]}}, \"blacklist_ip_address\": {\"description\": \"IP address of the server if the server is blacklisted, otherwise this output will be an empty string\", \"value\": {\"if\": [\"server_blacklisted\", {\"get_attr\": [\"NovaCompute\", \"networks\", \"ctlplane\", 0]}, \"\"]}}, \"blacklist_hostname\": {\"description\": \"Hostname of the server if the server is blacklisted, otherwise this output will be an empty string\", \"value\": {\"if\": [\"server_blacklisted\", {\"get_attr\": [\"NovaCompute\", \"name\"]}, \"\"]}}, \"hostname\": {\"description\": \"Hostname of the server\", \"value\": {\"get_attr\": [\"NovaCompute\", \"name\"]}}, \"hostname_map\": {\"description\": \"Mapping of network names to hostnames\", \"value\": {\"storage\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"fqdn\"]}, \"internal_api\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"fqdn\"]}, \"tenant\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"fqdn\"]}, \"ctlplane\": {\"get_attr\": [\"NetHostMap\", \"value\", \"ctlplane\", \"fqdn\"]}, \"canonical\": {\"get_attr\": [\"NetHostMap\", \"value\", \"canonical\", \"fqdn\"]}}}, \"hosts_entry\": {\"value\": [{\"str_replace\": {\"template\": \"PRIMARYIP PRIMARYHOST.DOMAIN PRIMARYHOST\", \"params\": {\"PRIMARYIP\": {\"get_attr\": [\"NetIpMap\", \"net_ip_map\", {\"get_param\": [\"ServiceNetMap\", \"ComputeHostnameResolveNetwork\"]}]}, \"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"PRIMARYHOST\": {\"get_attr\": [\"NovaCompute\", \"name\"]}}}}, {\"str_replace\": {\"template\": \"StorageIP StorageHOST.DOMAIN StorageHOST\", \"params\": {\"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"StorageIP\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}, \"StorageHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"short\"]}, \"InternalApiIP\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}, \"InternalApiHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"short\"]}, \"TenantIP\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}, \"TenantHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"short\"]}}}}, {\"str_replace\": {\"template\": \"InternalApiIP InternalApiHOST.DOMAIN InternalApiHOST\", \"params\": {\"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"StorageIP\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}, \"StorageHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"short\"]}, \"InternalApiIP\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}, \"InternalApiHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"short\"]}, \"TenantIP\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}, \"TenantHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"short\"]}}}}, {\"str_replace\": {\"template\": \"TenantIP TenantHOST.DOMAIN TenantHOST\", \"params\": {\"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"StorageIP\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}, \"StorageHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"storage\", \"short\"]}, \"InternalApiIP\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}, \"InternalApiHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"internal_api\", \"short\"]}, \"TenantIP\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}, \"TenantHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"tenant\", \"short\"]}}}}, {\"str_replace\": {\"template\": \"CTLPLANEIP CTLPLANEHOST.DOMAIN CTLPLANEHOST\", \"params\": {\"DOMAIN\": {\"get_param\": \"CloudDomain\"}, \"CTLPLANEIP\": {\"get_attr\": [\"NovaCompute\", \"networks\", \"ctlplane\", 0]}, \"CTLPLANEHOST\": {\"get_attr\": [\"NetHostMap\", \"value\", \"ctlplane\", \"short\"]}}}}]}, \"nova_server_resource\": {\"description\": \"Heat resource handle for Compute server\", \"value\": {\"get_resource\": \"NovaCompute\"}, \"condition\": \"server_not_blacklisted\"}, \"deployed_server_port_map\": {\"description\": \"Map of Heat created hostname of the server to ip address. This is the\\nhostname before it has been mapped with the HostnameMap parameter, and\\nthe IP address from the ctlplane network. This map can be used to construct\\nthe DeployedServerPortMap parameter when using split-stack.\\n\", \"value\": {\"map_replace\": [{\"hostname\": {\"fixed_ips\": [{\"ip_address\": {\"get_attr\": [\"NovaCompute\", \"networks\", \"ctlplane\", 0]}}], \"subnets\": [{\"cidr\": {\"get_attr\": [\"NovaCompute\", \"addresses\", \"ctlplane\", 0, \"subnets\", 0, \"cidr\"]}}]}}, {\"keys\": {\"hostname\": {\"list_join\": [\"-\", [{\"get_param\": \"Hostname\"}, \"ctlplane\"]]}}}]}}, \"storage_ip_address\": {\"description\": \"IP address of the server in the Storage network\", \"value\": {\"get_attr\": [\"StoragePort\", \"ip_address\"]}}, \"internal_api_ip_address\": {\"description\": \"IP address of the server in the InternalApi network\", \"value\": {\"get_attr\": [\"InternalApiPort\", \"ip_address\"]}}, \"tenant_ip_address\": {\"description\": \"IP address of the server in the Tenant network\", \"value\": {\"get_attr\": [\"TenantPort\", \"ip_address\"]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::ControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/controller-role.yaml\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Memcached\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/memcached/memcached-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-compute-container-puppet.yaml\", \"OS::TripleO::Services::NovaConductor\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-conductor-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-modular-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtLegacy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/deprecated/nova/nova-libvirt-container-puppet.yaml\", \"OS::TripleO::Services::NovaLibvirtGuests\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-libvirt-guests-container-puppet.yaml\", \"OS::TripleO::Services::NovaManager\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-manager-container-puppet.yaml\", \"OS::TripleO::Services::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NovaMigrationTarget\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-migration-target-container-puppet.yaml\", \"OS::TripleO::Services::NovaPlacement\": \"OS::Heat::None\", \"OS::TripleO::Services::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/placement/placement-api-container-puppet.yaml\", \"OS::TripleO::Services::NovaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::NovaVncProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-vnc-proxy-container-puppet.yaml\", \"OS::TripleO::Services::Novajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaAZConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainersLogrotateCrond\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/logrotate-crond-container-puppet.yaml\", \"OS::TripleO::Services::SwiftProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-proxy-container-puppet.yaml\", \"OS::TripleO::Services::SwiftDispersion\": \"OS::Heat::None\", \"OS::TripleO::Services::ExternalSwiftProxy\": \"OS::Heat::None\", \"OS::TripleO::Services::SwiftStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-storage-container-puppet.yaml\", \"OS::TripleO::Services::SwiftRingBuilder\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/swift/swift-ringbuilder-container-puppet.yaml\", \"OS::TripleO::Services::Snmp\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/snmp/snmp-baremetal-puppet.yaml\", \"OS::TripleO::Services::Timezone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/time/timezone-baremetal-ansible.yaml\", \"OS::TripleO::Services::UndercloudRemoveNovajoin\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudTLS\": \"OS::Heat::None\", \"OS::TripleO::Services::CeilometerAgentCentral\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-central-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentIpmi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-ipmi-container-puppet.yaml\", \"OS::TripleO::Services::CeilometerAgentNotification\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-notification-container-puppet.yaml\", \"OS::TripleO::Services::ComputeCeilometerAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ceilometer/ceilometer-agent-compute-container-puppet.yaml\", \"OS::TripleO::Services::Horizon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/horizon/horizon-container-puppet.yaml\", \"OS::TripleO::Services::GnocchiApi\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiMetricd\": \"OS::Heat::None\", \"OS::TripleO::Services::GnocchiStatsd\": \"OS::Heat::None\", \"OS::TripleO::Services::Xinetd\": \"OS::Heat::None\", \"OS::TripleO::Services::Chrony\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timesync/chrony-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ptp\": \"OS::Heat::None\", \"OS::TripleO::Services::Timesync\": \"OS::TripleO::Services::Chrony\", \"OS::TripleO::Services::TimeMaster\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/timemaster/timemaster-baremetal-ansible.yaml\", \"OS::TripleO::Services::IpaClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ipa/ipaservices-baremetal-ansible.yaml\", \"OS::TripleO::Services::Ipsec\": \"OS::Heat::None\", \"OS::TripleO::Services::Rhsm\": \"OS::Heat::None\", \"OS::TripleO::Services::MasqueradeNetworks\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoValidations\": \"OS::Heat::None\", \"OS::TripleO::Services::UndercloudUpgrade\": \"OS::Heat::None\", \"OS::TripleO::Services::Collectd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/collectd-container-puppet.yaml\", \"OS::TripleO::Services::ManilaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-api-container-puppet.yaml\", \"OS::TripleO::Services::ManilaScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::ManilaShare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-share-pacemaker-puppet.yaml\", \"OS::TripleO::Services::ManilaBackendFlashBlade\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendIsilon\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendNetapp\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendPowerMax\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendVMAX\": \"OS::Heat::None\", \"OS::TripleO::Services::ManilaBackendCephFs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/manila/manila-backend-cephfs.yaml\", \"OS::TripleO::Services::ManilaBackendVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanApi\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendSimpleCrypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendDogtag\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendKmip\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanBackendPkcs11Crypto\": \"OS::Heat::None\", \"OS::TripleO::Services::BarbicanClient\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhApi\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhEvaluator\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhListener\": \"OS::Heat::None\", \"OS::TripleO::Services::AodhNotifier\": \"OS::Heat::None\", \"OS::TripleO::Services::MetricsQdr\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/metrics/qdr-container-puppet.yaml\", \"OS::TripleO::Services::IronicApi\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicConductor\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicInspector\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicPxe\": \"OS::Heat::None\", \"OS::TripleO::Services::IronicNeutronAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NovaIronic\": \"OS::Heat::None\", \"OS::TripleO::Services::TripleoFirewall\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-firewall/tripleo-firewall-baremetal-ansible.yaml\", \"OS::TripleO::Services::TripleoPackages\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tripleo-packages/tripleo-packages-baremetal-puppet.yaml\", \"OS::TripleO::Services::OpenStackClients\": \"OS::Heat::None\", \"OS::TripleO::Services::TLSProxyBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CinderBackendDellSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCSc\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerFlex\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowermax\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCPowerStore\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCUnity\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVMAXISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVNX\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCVxFlexOS\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendDellEMCXtremio\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNetApp\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendPure\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendScaleIO\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderBackendNVMeOF\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderHPELeftHandISCSI\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderVolumeEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Etcd\": \"OS::Heat::None\", \"OS::TripleO::Services::AuditD\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaApi\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHealthManager\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaHousekeeping\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::OctaviaDeploymentConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::LiquidioCompute\": \"OS::Heat::None\", \"OS::TripleO::Services::MySQLClient\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-client.yaml\", \"OS::TripleO::Services::Vpp\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronVppAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Podman\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/podman/podman-baremetal-ansible.yaml\", \"OS::TripleO::Services::Docker\": \"OS::Heat::None\", \"OS::TripleO::Services::DockerRegistry\": \"OS::Heat::None\", \"OS::TripleO::Services::ContainerImagePrepare\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/container-image-prepare/container-image-prepare-baremetal-ansible.yaml\", \"OS::TripleO::Services::CertmongerUser\": \"OS::Heat::None\", \"OS::TripleO::Services::Clustercheck\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/clustercheck-container-puppet.yaml\", \"OS::TripleO::Services::Rsyslog\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/rsyslog-container-puppet.yaml\", \"OS::TripleO::Services::RsyslogSidecar\": \"OS::Heat::None\", \"OS::TripleO::Services::LoginDefs\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeInstanceHA\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateApi\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateCentral\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateProducer\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateWorker\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateMDNS\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateSink\": \"OS::Heat::None\", \"OS::TripleO::Services::DesignateBind\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMl2PluginBase\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::Multipathd\": \"OS::Heat::None\", \"OS::TripleO::Services::GlanceApiEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxyEdge\": \"OS::Heat::None\", \"OS::TripleO::Services::Frr\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNBgpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::Unbound\": \"OS::Heat::None\", \"OS::TripleO::Services::Tmpwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logrotate/tmpwatch-install.yaml\", \"OS::TripleO::Services::Logging::BarbicanApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/barbican-api.yaml\", \"OS::TripleO::Services::Logging::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/glance-api.yaml\", \"OS::TripleO::Services::Logging::HAProxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/haproxy.yaml\", \"OS::TripleO::Services::Logging::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api.yaml\", \"OS::TripleO::Services::Logging::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-api-cfn.yaml\", \"OS::TripleO::Services::Logging::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/heat-engine.yaml\", \"OS::TripleO::Services::Logging::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/keystone.yaml\", \"OS::TripleO::Services::Logging::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-api.yaml\", \"OS::TripleO::Services::Logging::NeutronCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/neutron-common.yaml\", \"OS::TripleO::Services::Logging::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-api.yaml\", \"OS::TripleO::Services::Logging::NovaMetadata\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-metadata.yaml\", \"OS::TripleO::Services::Logging::NovaCommon\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-common.yaml\", \"OS::TripleO::Services::Logging::NovaLibvirt\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/nova-libvirt.yaml\", \"OS::TripleO::Services::Logging::PlacementApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/logging/files/placement-api.yaml\", \"OS::TripleO::Services::Tempest\": \"OS::Heat::None\", \"OS::TripleO::Services::BootParams\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-boot-params-baremetal-ansible.yaml\", \"OS::TripleO::Compute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::Compute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::DeployedServer::ControlPlanePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-neutron-port.yaml\", \"OS::TripleO::OVNMacAddressNetwork\": \"OS::Heat::None\", \"OS::TripleO::OVNMacAddressPort\": \"OS::Heat::None\"}, \"parameters\": {\"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\", \"NovaVncProxyNetwork\": \"internal_api\"}, \"EndpointMap\": {\"AodhAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8042\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8042\"}, \"AodhPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13042\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13042\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13042\"}, \"BarbicanAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9311\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9311\"}, \"BarbicanPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13311\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13311\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13311\"}, \"CephDashboardInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8444\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8444\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8444\"}, \"CephGrafanaInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"3100\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:3100\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:3100\"}, \"CephRgwAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"CephRgwPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/swift/v1/AUTH_%(project_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"CinderAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV2Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV2Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v2/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"CinderV3Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8776\"}, \"CinderV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13776\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13776/v3/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13776\"}, \"DesignateAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignateInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9001/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9001\"}, \"DesignatePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13001\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13001/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13001\"}, \"DockerRegistryInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"8787\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:8787\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:8787\"}, \"GaneshaInternal\": {\"host\": \"172.21.0.163\", \"host_nobrackets\": \"172.21.0.163\", \"port\": \"2049\", \"protocol\": \"nfs\", \"uri\": \"nfs://172.21.0.163:2049\", \"uri_no_suffix\": \"nfs://172.21.0.163:2049\"}, \"GlanceAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlanceInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9293\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9293\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9293\"}, \"GlancePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13292\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13292\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13292\"}, \"GnocchiAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8041\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8041\"}, \"GnocchiPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13041\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13041\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13041\"}, \"HeatAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8004\"}, \"HeatPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13004\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13004/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13004\"}, \"HeatCfnAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8000/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8000\"}, \"HeatCfnPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13005\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13005/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13005\"}, \"HorizonPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"443\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:443/dashboard\", \"uri_no_suffix\": \"https://overcloud.ooo.test:443\"}, \"IronicAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"6385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:6385/v1\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:6385\"}, \"IronicPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13385\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13385/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13385\"}, \"IronicInspectorAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorInternal\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"5050\", \"protocol\": \"http\", \"uri\": \"http://overcloud.ctlplane.ooo.test:5050\", \"uri_no_suffix\": \"http://overcloud.ctlplane.ooo.test:5050\"}, \"IronicInspectorPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13050\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13050\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13050\"}, \"KeystoneAdmin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystonePublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"KeystoneV3Admin\": {\"host\": \"overcloud.ctlplane.ooo.test\", \"host_nobrackets\": \"overcloud.ctlplane.ooo.test\", \"port\": \"35357\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ctlplane.ooo.test:35357/v3\", \"uri_no_suffix\": \"https://overcloud.ctlplane.ooo.test:35357\"}, \"KeystoneV3Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"5000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:5000/v3\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:5000\"}, \"KeystoneV3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13000\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13000/v3\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13000\"}, \"ManilaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v2\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v2\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"ManilaV1Admin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Internal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8786\"}, \"ManilaV1Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13786\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13786/v1/%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13786\"}, \"MetricsQdrPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"5666\", \"protocol\": \"amqp\", \"uri\": \"amqp://overcloud.ooo.test:5666\", \"uri_no_suffix\": \"amqp://overcloud.ooo.test:5666\"}, \"MysqlInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NeutronAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9696\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9696\"}, \"NeutronPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13696\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13696\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13696\"}, \"NovaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8774/v2.1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8774\"}, \"NovaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13774\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13774/v2.1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13774\"}, \"NovaMetadataInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}, \"NovaVNCProxyAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"6080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:6080\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:6080\"}, \"NovaVNCProxyPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovajoinAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9090/v1\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9090\"}, \"NovajoinPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13090\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13090/v1\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13090\"}, \"OctaviaAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"9876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:9876\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:9876\"}, \"OctaviaPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13876\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13876\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13876\"}, \"PlacementAdmin\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8778/placement\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8778\"}, \"PlacementPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13778\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13778/placement\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13778\"}, \"SwiftAdmin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftInternal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808/v1/AUTH_%(tenant_id)s\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"SwiftS3Admin\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Internal\": {\"host\": \"overcloud.storage.ooo.test\", \"host_nobrackets\": \"overcloud.storage.ooo.test\", \"port\": \"8080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.storage.ooo.test:8080\", \"uri_no_suffix\": \"https://overcloud.storage.ooo.test:8080\"}, \"SwiftS3Public\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13808\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13808\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13808\"}, \"MysqlCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"3306\", \"protocol\": \"mysql+pymysql\", \"uri\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\", \"uri_no_suffix\": \"mysql+pymysql://overcloud.internalapi.ooo.test:3306\"}, \"NovaVNCProxyCellPublic\": {\"host\": \"overcloud.ooo.test\", \"host_nobrackets\": \"overcloud.ooo.test\", \"port\": \"13080\", \"protocol\": \"https\", \"uri\": \"https://overcloud.ooo.test:13080\", \"uri_no_suffix\": \"https://overcloud.ooo.test:13080\"}, \"NovaMetadataCellInternal\": {\"host\": \"overcloud.internalapi.ooo.test\", \"host_nobrackets\": \"overcloud.internalapi.ooo.test\", \"port\": \"8775\", \"protocol\": \"https\", \"uri\": \"https://overcloud.internalapi.ooo.test:8775\", \"uri_no_suffix\": \"https://overcloud.internalapi.ooo.test:8775\"}}, \"Hostname\": \"overcloud-novacompute-2\", \"CloudDomain\": \"ooo.test\", \"ComputeSchedulerHints\": {}, \"NodeIndex\": 2, \"ServiceNames\": \"boot_params_service,ca_certs,collectd,ceilometer_agent_compute,ceilometer_agent_ipmi,ipaservice,iscsid,kernel,metrics_qdr,mysql_client,nova_compute,nova_libvirt,nova_libvirt_guests,nova_migration_target,logrotate_crond,podman,rsyslog,snmp,sshd,chrony,timezone,tripleo_firewall,tripleo_packages,tuned,ovn_controller,ovn_metadata\", \"ServiceMetadataSettings\": {\"compact_service_metrics_qdr\": [\"internalapi\"], \"compact_service_libvirt\": [\"internalapi\"], \"compact_service_qemu\": [\"internalapi\"], \"compact_service_libvirt-vnc\": [\"internalapi\"], \"compact_service_ovn_controller\": [\"internalapi\"], \"compact_service_ovn_metadata\": [\"internalapi\"]}, \"OVNBridgeMappings\": \"datacentre:br-ex\", \"DeploymentServerBlacklistDict\": {}, \"RoleParameters\": {\"FsAioMaxNumber\": 1048576, \"TunedProfileName\": \"throughput-performance\"}, \"UserData\": \"760f3ad1-1a88-4792-87fe-934d5912fd27\"}, \"parameter_defaults\": {\"NeutronMechanismDrivers\": \"ovn\", \"ContainerCli\": \"podman\", \"EnablePackageInstall\": true, \"SoftwareConfigTransport\": \"POLL_SERVER_HEAT\", \"OVNIntegrationBridge\": \"br-int\", \"ExtraConfig\": {}, \"ControllerServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::CeilometerAgentCentral\", \"OS::TripleO::Services::CeilometerAgentNotification\", \"OS::TripleO::Services::CinderApi\", \"OS::TripleO::Services::CinderBackup\", \"OS::TripleO::Services::CinderScheduler\", \"OS::TripleO::Services::CinderVolume\", \"OS::TripleO::Services::Clustercheck\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ContainerImagePrepare\", \"OS::TripleO::Services::GlanceApi\", \"OS::TripleO::Services::GlanceApiInternal\", \"OS::TripleO::Services::HAproxy\", \"OS::TripleO::Services::HeatApi\", \"OS::TripleO::Services::HeatApiCloudwatch\", \"OS::TripleO::Services::HeatApiCfn\", \"OS::TripleO::Services::HeatEngine\", \"OS::TripleO::Services::Horizon\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::Keystone\", \"OS::TripleO::Services::ManilaApi\", \"OS::TripleO::Services::ManilaBackendCephFs\", \"OS::TripleO::Services::ManilaScheduler\", \"OS::TripleO::Services::ManilaShare\", \"OS::TripleO::Services::Memcached\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQL\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NeutronApi\", \"OS::TripleO::Services::NeutronCorePlugin\", \"OS::TripleO::Services::NovaApi\", \"OS::TripleO::Services::NovaConductor\", \"OS::TripleO::Services::NovaMetadata\", \"OS::TripleO::Services::NovaScheduler\", \"OS::TripleO::Services::NovaVncProxy\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::OVNDBs\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::Pacemaker\", \"OS::TripleO::Services::PlacementApi\", \"OS::TripleO::Services::OsloMessagingRpc\", \"OS::TripleO::Services::OsloMessagingNotify\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Redis\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::SwiftProxy\", \"OS::TripleO::Services::SwiftRingBuilder\", \"OS::TripleO::Services::SwiftStorage\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\"], \"ControllerParameters\": {}, \"ControllerExtraConfig\": {\"nova::network::neutron::timeout\": \"60\", \"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ControllerExtraGroupVars\": {}, \"CellControllerServices\": [], \"CellControllerParameters\": {}, \"CellControllerExtraConfig\": {}, \"CellControllerExtraGroupVars\": {}, \"CellControllerComputeServices\": [], \"CellControllerComputeParameters\": {}, \"CellControllerComputeExtraConfig\": {}, \"CellControllerComputeExtraGroupVars\": {}, \"ComputeServices\": [\"OS::TripleO::Services::BootParams\", \"OS::TripleO::Services::CACerts\", \"OS::TripleO::Services::Collectd\", \"OS::TripleO::Services::ComputeCeilometerAgent\", \"OS::TripleO::Services::CeilometerAgentIpmi\", \"OS::TripleO::Services::IpaClient\", \"OS::TripleO::Services::Iscsid\", \"OS::TripleO::Services::Kernel\", \"OS::TripleO::Services::MetricsQdr\", \"OS::TripleO::Services::MySQLClient\", \"OS::TripleO::Services::NovaCompute\", \"OS::TripleO::Services::NovaLibvirt\", \"OS::TripleO::Services::NovaLibvirtGuests\", \"OS::TripleO::Services::NovaMigrationTarget\", \"OS::TripleO::Services::ContainersLogrotateCrond\", \"OS::TripleO::Services::Podman\", \"OS::TripleO::Services::Rsyslog\", \"OS::TripleO::Services::Snmp\", \"OS::TripleO::Services::Sshd\", \"OS::TripleO::Services::Timesync\", \"OS::TripleO::Services::Timezone\", \"OS::TripleO::Services::TripleoFirewall\", \"OS::TripleO::Services::TripleoPackages\", \"OS::TripleO::Services::Tuned\", \"OS::TripleO::Services::OVNController\", \"OS::TripleO::Services::OVNMetadataAgent\"], \"ComputeParameters\": {}, \"ComputeExtraConfig\": {\"nova::compute::libvirt::services::libvirt_virt_type\": \"qemu\", \"nova::compute::libvirt::virt_type\": \"qemu\"}, \"ComputeExtraGroupVars\": {}, \"BlockStorageServices\": [], \"BlockStorageParameters\": {}, \"BlockStorageExtraConfig\": {}, \"BlockStorageExtraGroupVars\": {}, \"ObjectStorageServices\": [], \"ObjectStorageParameters\": {}, \"ObjectStorageExtraConfig\": {}, \"ObjectStorageExtraGroupVars\": {}, \"CephStorageServices\": [], \"CephStorageParameters\": {}, \"CephStorageExtraConfig\": {}, \"CephStorageExtraGroupVars\": {}, \"NetworkerServices\": [], \"NetworkerParameters\": {}, \"NetworkerExtraConfig\": {}, \"NetworkerExtraGroupVars\": {}, \"ServiceNetMap\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"VipSubnetMap\": {\"ctlplane\": \"ctlplane-subnet\", \"Storage\": \"storage_subnet\", \"StorageMgmt\": \"storage_mgmt_subnet\", \"InternalApi\": \"internal_api_subnet\", \"External\": \"external_subnet\", \"redis\": \"internal_api_subnet\", \"ovn_dbs\": \"internal_api_subnet\"}, \"SshServerOptions\": {\"HostKey\": [\"/etc/ssh/ssh_host_rsa_key\", \"/etc/ssh/ssh_host_ecdsa_key\", \"/etc/ssh/ssh_host_ed25519_key\"], \"SyslogFacility\": \"AUTHPRIV\", \"AuthorizedKeysFile\": \".ssh/authorized_keys\", \"ChallengeResponseAuthentication\": \"no\", \"GSSAPIAuthentication\": \"no\", \"GSSAPICleanupCredentials\": \"no\", \"UsePAM\": \"yes\", \"UseDNS\": \"no\", \"PrintMotd\": \"no\", \"X11Forwarding\": \"yes\", \"AcceptEnv\": [\"LANG LC_CTYPE LC_NUMERIC LC_TIME LC_COLLATE LC_MONETARY LC_MESSAGES\", \"LC_PAPER LC_NAME LC_ADDRESS LC_TELEPHONE LC_MEASUREMENT\", \"LC_IDENTIFICATION LC_ALL LANGUAGE\", \"XMODIFIERS\"], \"Subsystem\": \"sftp  /usr/libexec/openssh/sftp-server\"}, \"HostnameMap\": {\"overcloud-controller-0\": \"np0000068146\", \"overcloud-controller-1\": \"np0000068147\", \"overcloud-controller-2\": \"np0000068148\", \"overcloud-novacompute-0\": \"np0000068149\", \"overcloud-novacompute-1\": \"np0000068150\", \"overcloud-novacompute-2\": \"np0000068151\"}, \"ClusterFullTag\": true, \"ContainerImagePrepare\": [{\"set\": {\"ceph_alertmanager_image\": \"ose-prometheus-alertmanager\", \"ceph_alertmanager_namespace\": \"registry.redhat.io/openshift4\", \"ceph_alertmanager_tag\": \"v4.12\", \"ceph_grafana_image\": \"rhceph-6-dashboard-rhel9\", \"ceph_grafana_namespace\": \"registry.redhat.io/rhceph\", \"ceph_grafana_tag\": \"latest\", \"ceph_image\": \"rhceph-7-rhel9\", \"ceph_namespace\": \"registry.redhat.io/rhceph\", \"ceph_node_exporter_image\": \"ose-prometheus-node-exporter\", \"ceph_node_exporter_namespace\": \"registry.redhat.io/openshift4\", \"ceph_node_exporter_tag\": \"v4.12\", \"ceph_prometheus_image\": \"ose-prometheus\", \"ceph_prometheus_namespace\": \"registry.redhat.io/openshift4\", \"ceph_prometheus_tag\": \"v4.12\", \"ceph_tag\": \"latest\", \"name_prefix\": \"openstack-\", \"name_suffix\": \"\", \"namespace\": \"registry.redhat.io/rhosp-rhel9\", \"neutron_driver\": \"ovn\", \"rhel_containers\": false, \"tag\": \"17.1\"}, \"tag_from_label\": \"{version}-{release}\"}], \"CinderWorkers\": 1, \"GlanceWorkers\": 1, \"HeatWorkers\": 1, \"KeystoneWorkers\": 1, \"NeutronWorkers\": 1, \"NeutronMetadataWorkers\": 1, \"NovaWorkers\": 1, \"NovaSchedulerWorkers\": 1, \"SwiftWorkers\": 1, \"PlacementWorkers\": 1, \"ApacheMaxRequestWorkers\": 100, \"ApacheServerLimit\": 100, \"DatabaseSyncTimeout\": 900, \"NovaReservedHostMemory\": 512, \"MysqlInnodbBufferPoolSize\": \"128M\", \"Debug\": true, \"ManilaCephFSBackendName\": \"cephfs\", \"ManilaCephFSDriverHandlesShareServers\": false, \"ManilaCephFSCephFSAuthId\": \"manila\", \"ManilaCephFSCephVolumeMode\": \"0755\", \"ManilaCephFSCephFSProtocolHelperType\": \"CEPHFS\", \"EndpointMap\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"PublicSSLCertificateAutogenerated\": true, \"EnableInternalTLS\": true, \"RpcUseSSL\": true, \"ServerMetadata\": {\"ipa_enroll\": true}, \"MemcachedTLS\": true, \"MemcachedPort\": 11212, \"CloudDomain\": \"ooo.test\", \"CloudName\": \"overcloud.ooo.test\", \"CloudNameInternal\": \"overcloud.internalapi.ooo.test\", \"CloudNameStorage\": \"overcloud.storage.ooo.test\", \"CloudNameStorageManagement\": \"overcloud.storagemgmt.ooo.test\", \"CloudNameCtlplane\": \"overcloud.ctlplane.ooo.test\", \"IdMServer\": \"ipa.ooo.test\", \"IdMDomain\": \"ooo.test\", \"NeutronDnsDomain\": \"ooo.test\", \"PasswordAuthentication\": \"yes\", \"DnsSearchDomains\": [\"ooo.test\"], \"AddVipsToEtcHosts\": true, \"BlockStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"BlockStorageNetworkConfigUpdate\": false, \"CellControllerComputeCount\": 0, \"CellControllerComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerComputeNetworkConfigUpdate\": false, \"CellControllerCount\": 0, \"CellControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CellControllerNetworkConfigUpdate\": false, \"CephStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"CephStorageNetworkConfigUpdate\": false, \"CinderLVMLoopDeviceSize\": 20480, \"ComputeCount\": 3, \"ComputeNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ComputeNetworkConfigUpdate\": false, \"ControllerCount\": 3, \"ControllerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ControllerNetworkConfigUpdate\": false, \"DockerPuppetDebug\": true, \"NetworkConfigWithAnsible\": false, \"NetworkerNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"NetworkerNetworkConfigUpdate\": false, \"NeutronGlobalPhysnetMtu\": 1350, \"ObjectStorageNetworkConfigTemplate\": \"templates/single_nic_vlans/single_nic_vlans.j2\", \"ObjectStorageNetworkConfigUpdate\": false, \"RedisVirtualFixedIPs\": [{\"ip_address\": \"192.168.122.110\", \"use_neutron\": false}], \"SshFirewallAllowAll\": true, \"CtlplaneNetworkAttributes\": {\"network\": {\"dns_domain\": \"ooo.test\", \"mtu\": 1500, \"name\": \"ctlplane\", \"tags\": [\"192.168.122.0/24\"]}, \"subnets\": {\"ctlplane-subnet\": {\"cidr\": \"192.168.122.0/24\", \"dns_nameservers\": [\"192.168.122.10\", \"192.168.122.1\"], \"gateway_ip\": \"192.168.122.10\", \"host_routes\": [], \"ip_version\": 4, \"name\": \"ctlplane-subnet\"}}}, \"DeployedServerPortMap\": {\"np0000068146-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.103\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068147-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.104\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068148-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.105\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068149-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.106\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068150-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.107\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}, \"np0000068151-ctlplane\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.108\"}], \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"cidr\": \"192.168.122.0/24\"}]}}, \"NodePortMap\": {\"np0000068146\": {\"ctlplane\": {\"ip_address\": \"192.168.122.103\", \"ip_address_uri\": \"192.168.122.103\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.103\", \"ip_address_uri\": \"172.21.0.103\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.103\", \"ip_address_uri\": \"172.17.0.103\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.103\", \"ip_address_uri\": \"172.18.0.103\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.103\", \"ip_address_uri\": \"172.20.0.103\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.103\", \"ip_address_uri\": \"172.19.0.103\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068147\": {\"ctlplane\": {\"ip_address\": \"192.168.122.104\", \"ip_address_uri\": \"192.168.122.104\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.104\", \"ip_address_uri\": \"172.21.0.104\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.104\", \"ip_address_uri\": \"172.17.0.104\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.104\", \"ip_address_uri\": \"172.18.0.104\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.104\", \"ip_address_uri\": \"172.20.0.104\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.104\", \"ip_address_uri\": \"172.19.0.104\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068148\": {\"ctlplane\": {\"ip_address\": \"192.168.122.105\", \"ip_address_uri\": \"192.168.122.105\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.105\", \"ip_address_uri\": \"172.21.0.105\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.105\", \"ip_address_uri\": \"172.17.0.105\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.105\", \"ip_address_uri\": \"172.18.0.105\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.105\", \"ip_address_uri\": \"172.20.0.105\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.105\", \"ip_address_uri\": \"172.19.0.105\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068149\": {\"ctlplane\": {\"ip_address\": \"192.168.122.106\", \"ip_address_uri\": \"192.168.122.106\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.106\", \"ip_address_uri\": \"172.21.0.106\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.106\", \"ip_address_uri\": \"172.17.0.106\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.106\", \"ip_address_uri\": \"172.18.0.106\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.106\", \"ip_address_uri\": \"172.20.0.106\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.106\", \"ip_address_uri\": \"172.19.0.106\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068150\": {\"ctlplane\": {\"ip_address\": \"192.168.122.107\", \"ip_address_uri\": \"192.168.122.107\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.107\", \"ip_address_uri\": \"172.21.0.107\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.107\", \"ip_address_uri\": \"172.17.0.107\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.107\", \"ip_address_uri\": \"172.18.0.107\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.107\", \"ip_address_uri\": \"172.20.0.107\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.107\", \"ip_address_uri\": \"172.19.0.107\", \"ip_subnet\": \"172.19.0.0/24\"}}, \"np0000068151\": {\"ctlplane\": {\"ip_address\": \"192.168.122.108\", \"ip_address_uri\": \"192.168.122.108\", \"ip_subnet\": \"192.168.122.0/24\"}, \"external\": {\"ip_address\": \"172.21.0.108\", \"ip_address_uri\": \"172.21.0.108\", \"ip_subnet\": \"172.21.0.0/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.108\", \"ip_address_uri\": \"172.17.0.108\", \"ip_subnet\": \"172.17.0.0/24\"}, \"storage\": {\"ip_address\": \"172.18.0.108\", \"ip_address_uri\": \"172.18.0.108\", \"ip_subnet\": \"172.18.0.0/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.108\", \"ip_address_uri\": \"172.20.0.108\", \"ip_subnet\": \"172.20.0.0/24\"}, \"tenant\": {\"ip_address\": \"172.19.0.108\", \"ip_address_uri\": \"172.19.0.108\", \"ip_subnet\": \"172.19.0.0/24\"}}}, \"ControlPlaneVipData\": {\"fixed_ips\": [{\"ip_address\": \"192.168.122.99\"}], \"name\": \"ctlplane_vip\", \"network\": {\"tags\": [\"192.168.122.0/24\"]}, \"subnets\": [{\"ip_version\": 4}]}, \"VipPortMap\": {\"external\": {\"ip_address\": \"172.21.0.163\", \"ip_address_uri\": \"172.21.0.163\", \"ip_subnet\": \"172.21.0.163/24\"}, \"internal_api\": {\"ip_address\": \"172.17.0.205\", \"ip_address_uri\": \"172.17.0.205\", \"ip_subnet\": \"172.17.0.205/24\"}, \"storage\": {\"ip_address\": \"172.18.0.129\", \"ip_address_uri\": \"172.18.0.129\", \"ip_subnet\": \"172.18.0.129/24\"}, \"storage_mgmt\": {\"ip_address\": \"172.20.0.181\", \"ip_address_uri\": \"172.20.0.181\", \"ip_subnet\": \"172.20.0.181/24\"}}, \"DeployedNetworkEnvironment\": {\"net_attributes_map\": {\"external\": {\"network\": {\"dns_domain\": \"external.ooo.test.\", \"mtu\": 1500, \"name\": \"external\", \"tags\": [\"tripleo_network_name=External\", \"tripleo_net_idx=4\", \"tripleo_service_net_map_replace=external\", \"tripleo_vip=true\"]}, \"subnets\": {\"external_subnet\": {\"cidr\": \"172.21.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"external_subnet\", \"tags\": [\"tripleo_vlan_id=44\"]}}}, \"internal_api\": {\"network\": {\"dns_domain\": \"internal-api.ooo.test.\", \"mtu\": 1500, \"name\": \"internal_api\", \"tags\": [\"tripleo_network_name=InternalApi\", \"tripleo_net_idx=2\", \"tripleo_service_net_map_replace=internal_api\", \"tripleo_vip=true\"]}, \"subnets\": {\"internal_api_subnet\": {\"cidr\": \"172.17.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"internal_api_subnet\", \"tags\": [\"tripleo_vlan_id=20\"]}}}, \"storage\": {\"network\": {\"dns_domain\": \"storage.ooo.test.\", \"mtu\": 1500, \"name\": \"storage\", \"tags\": [\"tripleo_network_name=Storage\", \"tripleo_net_idx=0\", \"tripleo_service_net_map_replace=storage\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_subnet\": {\"cidr\": \"172.18.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_subnet\", \"tags\": [\"tripleo_vlan_id=21\"]}}}, \"storage_mgmt\": {\"network\": {\"dns_domain\": \"storagemgmt.ooo.test.\", \"mtu\": 1500, \"name\": \"storage_mgmt\", \"tags\": [\"tripleo_network_name=StorageMgmt\", \"tripleo_net_idx=1\", \"tripleo_service_net_map_replace=storage_mgmt\", \"tripleo_vip=true\"]}, \"subnets\": {\"storage_mgmt_subnet\": {\"cidr\": \"172.20.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"storage_mgmt_subnet\", \"tags\": [\"tripleo_vlan_id=23\"]}}}, \"tenant\": {\"network\": {\"dns_domain\": \"tenant.ooo.test.\", \"mtu\": 1500, \"name\": \"tenant\", \"tags\": [\"tripleo_network_name=Tenant\", \"tripleo_net_idx=3\", \"tripleo_service_net_map_replace=tenant\"]}, \"subnets\": {\"tenant_subnet\": {\"cidr\": \"172.19.0.0/24\", \"dns_nameservers\": [], \"gateway_ip\": null, \"host_routes\": [], \"ip_version\": 4, \"name\": \"tenant_subnet\", \"tags\": [\"tripleo_vlan_id=22\"]}}}}, \"net_cidr_map\": {\"external\": [\"172.21.0.0/24\"], \"internal_api\": [\"172.17.0.0/24\"], \"storage\": [\"172.18.0.0/24\"], \"storage_mgmt\": [\"172.20.0.0/24\"], \"tenant\": [\"172.19.0.0/24\"]}, \"net_ip_version_map\": {\"external\": 4, \"internal_api\": 4, \"storage\": 4, \"storage_mgmt\": 4, \"tenant\": 4}}, \"AdminPassword\": \"uvYUJnZlpg4RipBsqnjPENIXa\", \"AdminToken\": \"2R1sIKsEJ0f3dljEeCMrJZCgx\", \"CeilometerMeteringSecret\": \"jRuRaXv8Ar7kg4X44CLZE5d2r\", \"CeilometerPassword\": \"6GBzmfESOACPjM70aXaIF8M8d\", \"CephClientKey\": \"AQBDyCdqAAAAABAA4BEOhYWLHdpESd2hK1PPPw==\", \"CephClusterFSID\": \"141c0b27-2417-411f-ad72-876254cd4eac\", \"CinderPassword\": \"1qmMnIFxlEBPP6HhUjwy6zBNn\", \"ContainerBarbicanApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-barbican-api:17.1\", \"ContainerCeilometerCentralImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-compute:17.1\", \"ContainerCeilometerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-central:17.1\", \"ContainerCeilometerIpmiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-ipmi:17.1\", \"ContainerCeilometerNotificationImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ceilometer-notification:17.1\", \"ContainerCinderApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderBackupImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-backup:17.1\", \"ContainerCinderConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-api:17.1\", \"ContainerCinderSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-scheduler:17.1\", \"ContainerCinderVolumeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cinder-volume:17.1\", \"ContainerClustercheckConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerClustercheckImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerCollectdConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCollectdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-collectd:17.1\", \"ContainerCrondConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerCrondImage\": \"registry.redhat.io/rhosp-rhel9/openstack-cron:17.1\", \"ContainerGlanceApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerGlanceApiInternalConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-glance-api:17.1\", \"ContainerHAProxyConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHAProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-haproxy:17.1\", \"ContainerHeatApiCfnConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiCfnImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api-cfn:17.1\", \"ContainerHeatApiConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-api:17.1\", \"ContainerHeatEngineImage\": \"registry.redhat.io/rhosp-rhel9/openstack-heat-engine:17.1\", \"ContainerHorizonConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerHorizonImage\": \"registry.redhat.io/rhosp-rhel9/openstack-horizon:17.1\", \"ContainerIscsidConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerIscsidImage\": \"registry.redhat.io/rhosp-rhel9/openstack-iscsid:17.1\", \"ContainerKeystoneConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerKeystoneImage\": \"registry.redhat.io/rhosp-rhel9/openstack-keystone:17.1\", \"ContainerManilaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-api:17.1\", \"ContainerManilaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-scheduler:17.1\", \"ContainerManilaShareImage\": \"registry.redhat.io/rhosp-rhel9/openstack-manila-share:17.1\", \"ContainerMemcachedConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMemcachedImage\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\", \"ContainerMetricsQdrConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMetricsQdrImage\": \"registry.redhat.io/rhosp-rhel9/openstack-qdrouterd:17.1\", \"ContainerMysqlConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerMysqlImage\": \"registry.redhat.io/rhosp-rhel9/openstack-mariadb:17.1\", \"ContainerNeutronApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNeutronConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-server:17.1\", \"ContainerNovaApiImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaComputeImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-compute:17.1\", \"ContainerNovaConductorImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-conductor:17.1\", \"ContainerNovaConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaLibvirtConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaLibvirtImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-libvirt:17.1\", \"ContainerNovaMetadataConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-api:17.1\", \"ContainerNovaSchedulerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-scheduler:17.1\", \"ContainerNovaVncProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-nova-novncproxy:17.1\", \"ContainerOvnControllerConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnControllerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-controller:17.1\", \"ContainerOvnMetadataImage\": \"registry.redhat.io/rhosp-rhel9/openstack-neutron-metadata-agent-ovn:17.1\", \"ContainerOvnNbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-nb-db-server:17.1\", \"ContainerOvnNorthdImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-northd:17.1\", \"ContainerOvnSbDbImage\": \"registry.redhat.io/rhosp-rhel9/openstack-ovn-sb-db-server:17.1\", \"ContainerPlacementConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerPlacementImage\": \"registry.redhat.io/rhosp-rhel9/openstack-placement-api:17.1\", \"ContainerRabbitmqConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRabbitmqImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rabbitmq:17.1\", \"ContainerRedisConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRedisImage\": \"registry.redhat.io/rhosp-rhel9/openstack-redis:17.1\", \"ContainerRsyslogConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerRsyslogImage\": \"registry.redhat.io/rhosp-rhel9/openstack-rsyslog:17.1\", \"ContainerSwiftAccountImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-account:17.1\", \"ContainerSwiftConfigImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"ContainerSwiftContainerImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-container:17.1\", \"ContainerSwiftObjectImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-object:17.1\", \"ContainerSwiftProxyImage\": \"registry.redhat.io/rhosp-rhel9/openstack-swift-proxy-server:17.1\", \"DeployIdentifier\": 1780992067, \"GlancePassword\": \"cjUKwpQUAKsA4fym1vJsXs888\", \"HAProxyStatsPassword\": \"UfhE8R9DggTnnqHWkS53kenTr\", \"HeatAuthEncryptionKey\": \"yYlmuyUF8ihE7Narz9Mp0zg31WwUfjZL\", \"HeatPassword\": \"IWxKbYHIBwLTomkhalUwDCUxO\", \"HeatStackDomainAdminPassword\": \"6Vx9jLPJfLByfaQ6jfxpBtH9b\", \"HorizonSecret\": \"EnFZnXQGEH\", \"KeystoneCredential0\": \"VK3b3OMA6Q_XZf52mI394ftP-BWeoGYqqs_dJWQDZmU=\", \"KeystoneCredential1\": \"dQF8j9R9barplpGUYhl2yUVJwOGLbcq6qeNJiq-bwNg=\", \"KeystoneFernetKeys\": {\"/etc/keystone/fernet-keys/0\": {\"content\": \"GGS9H4rMnvdsbhBQU7csGXDbW8qJCWQQqvQe8l_bx28=\"}, \"/etc/keystone/fernet-keys/1\": {\"content\": \"3N5yNkfntFAoRJlL1bJ_5SgKm6agtoukXuCcYy8pf8Q=\"}}, \"LibvirtTLSPassword\": \"bkbQ5iHPPbgRmMbCp8YibZ8gy\", \"ManilaPassword\": \"nfv0OPxp9SeiZWxMe7AjmQ4E2\", \"MigrationSshKey\": {\"private_key\": \"-----BEGIN RSA PRIVATE KEY-----\\nMIIEogIBAAKCAQEAwgEu+EtHL7yqXs0ZYsUx5HksgbxTus2eomQDlKpaAr4NDBIr\\nsh1MmhF7ACDBmm7YrVZIxppXICV2y+1i2pcHeIJqtURyPIL4XAbhBl+BvDvbK1nx\\nZZpx48e/qDoZWzqFkr30fpKuc4TuqFggc+2qwecPsN5hE8nvbmFc57hGd1BU9cjh\\nhMzqSb8CxosgBQIlkmJ44TmyhxRaUWhON1Xytq6S9nVN2vWIGe2l7EQ0lZpfdwWh\\nkrxzgMr5g7XP0gnpeSzxw/62hFrYJP4o10dPUL7e1YEjxPp8CaNpc7bQa7w1XnP3\\nDpEu+bLdjvsUwKbZIvXiXCIR1G16RG63S/WKtQIDAQABAoIBACcS1PJ2Ouqu7YN1\\nfJDrlY5mJ2Qj2ZtMkZA0Y5I8My/NNlSBjmJry0NWlPbkIgooHCThNXwmlrinQwN0\\nls3e0EbhwXsrw3RTjpD+Y7EEaF1QkuZq0Zc8oYaWcw//T58TrNZuwsEBavhiRC0M\\nvtCKhDNUhdECIPw61indmzgiYbLi1SFRCFruV2y+C1NYGEHAH1P2CkvHlRZdP8Eu\\nfSmV4VFSs1LZoEBBM6trQJ+iuyffm5xx1dmaQglq402v0yYekkg6MpmzyNymqMer\\nQHo3/2cWgsmJ/8DttqOP5s4gQAranlelfRZkxnLZR4Qh3P9PICueyF0kI6FAfJM+\\ngOnuohECgYEAxUOuwrn9m1NW6e3kl4kZeS440vV2dofWz202L4MsnmfcABPxHnbm\\nkQd7R5KADrjTCreD33ZltqKn+y0FUZ8S453cmIfBwEkwSdSomSvvLd3uqb0rwCtv\\nt8MUNKFZD3/exjNrsnwT8YwypfsnpaBYrRTHWJ1PqVRcp38CI37qW20CgYEA+8UH\\nMBBa8/ES3afpyrrCeVy8sY0yUeeDofF8cX+Ifb2dQUVkMQ+k4LKtZ7XzsDPdhNOS\\nWrgJg+H87VttzryOYX2g1v4ILZC8MR20LN+YEBauOvh93C2IpEThh5QKVXaQGBwm\\ncQH487JMjWQRoVrk795z0O9d4Tb+eDkBUl1UV2kCgYAaQkw9N6z+xDVJppVLZsCx\\nVOnTi0Fdve9mZU9VO8zwuTqb+Auc1o8St0A94s6RJyFQx+USFhysFzLtSKzwlJBb\\nJGR9GXU9N4DqExjuat7H6Ecg6UGtrxqMB7fk2aWVXpw1Hhs0AzhUaylC1xAMCDBF\\nugJfVXGJROWgllOejgJ8cQKBgCidJAew27s2TGDNUX2OmwiQ2S+bI17rBeT926FD\\nfXUrPU7mLr9rUqGcsTRluaXW+AkRSC6yOXa44eA4O4J6EE3RwjxsRk1zZ6hUrlf+\\nybzuq7R/mW4HOl+lbOw+CVy3/46kG99m/g3x2T+FwQJSc1PugqhVtMM759jk+T2c\\nKJrhAoGAfSHwjdamec0aoBta6fG7GN40vtfiDhI/FJYEfOOxsC7fMLFX6n7zXjYv\\nqSXpCqCXbSCVmF2IueihVDiwMZEvVd+NJFyNAd2R6EWwdr47HCPKE0HmufonJelP\\nQ6Y8dc6zITr0oq0HGBBi3FJUBqxxffCkGV1+rKczrch8MdKbEI0=\\n-----END RSA PRIVATE KEY-----\\n\", \"public_key\": \"ssh-rsa AAAAB3NzaC1yc2EAAAADAQABAAABAQDCAS74S0cvvKpezRlixTHkeSyBvFO6zZ6iZAOUqloCvg0MEiuyHUyaEXsAIMGabtitVkjGmlcgJXbL7WLalwd4gmq1RHI8gvhcBuEGX4G8O9srWfFlmnHjx7+oOhlbOoWSvfR+kq5zhO6oWCBz7arB5w+w3mETye9uYVznuEZ3UFT1yOGEzOpJvwLGiyAFAiWSYnjhObKHFFpRaE43VfK2rpL2dU3a9YgZ7aXsRDSVml93BaGSvHOAyvmDtc/SCel5LPHD/raEWtgk/ijXR09Qvt7VgSPE+nwJo2lzttBrvDVec/cOkS75st2O+xTAptki9eJcIhHUbXpEbrdL9Yq1 Generated by TripleO\"}, \"MysqlClustercheckPassword\": \"aNliMndyyYkYXXmrEs48JOHfH\", \"MysqlMariabackupPassword\": \"v37DXivQZPH0c9WJEo2d76ZZ3\", \"MysqlRootPassword\": \"CEwojbg8cQ\", \"NeutronMetadataProxySharedSecret\": \"WlxpFDSY9t6h6Jb7QWOpi1RBB\", \"NeutronPassword\": \"qzvItA1K3MLllVvkiCWVVbIpy\", \"NovaComputeLibvirtType\": \"qemu\", \"NovaPassword\": \"E43sBALvNAsJYgcBpWfsAoz9C\", \"NtpServer\": \"pool.ntp.org\", \"PacemakerRemoteAuthkey\": \" \", \"PcsdPassword\": \"fPwS1wapX08BOB8s\", \"PlacementPassword\": \"qMFVkTRvhZKx21tsfFHzUpJTe\", \"RabbitCookie\": \"kbd1xqCJjQV1It9K3RCs\", \"RabbitPassword\": \"Q6lTa0mZmM9cucieqvDlYS6UV\", \"RedisPassword\": \"Qw5poqjrA95kbXlQw5cMcjZDa\", \"RootStackName\": \"overcloud\", \"RpcPassword\": \"PS0bGQjSBLcCmxTXExXAz6dDb\", \"SnmpdReadonlyUserPassword\": \"IUqJgJKOidh20dco1DYKnuQ1\", \"SwiftHashSuffix\": \"MYRGmb3GEmxccEg8fTxn6rbWp\", \"SwiftPassword\": \"4TPvzE0suBWTyRwI1JbXImF8b\", \"UndercloudHostsEntries\": [\"192.168.122.100 undercloud.ctlplane.ooo.test undercloud.ctlplane\"]}, \"event_sinks\": [], \"encrypted_param_names\": []}',1),(220,'2026-06-09 08:02:32',NULL,'{\"heat_template_version\": \"wallaby\", \"description\": \"OpenStack containerized Memcached services\\n\", \"parameters\": {\"ContainerMemcachedImage\": {\"description\": \"image\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\"}, \"ContainerMemcachedConfigImage\": {\"description\": \"The container image to use for the memcached config_volume\", \"type\": \"string\", \"tags\": [\"role_specific\"], \"default\": \"registry.redhat.io/rhosp-rhel9/openstack-memcached:17.1\"}, \"EndpointMap\": {\"default\": {\"AodhAdmin\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhInternal\": {\"protocol\": \"https\", \"port\": \"8042\", \"host\": \"CLOUDNAME\"}, \"AodhPublic\": {\"protocol\": \"https\", \"port\": \"13042\", \"host\": \"CLOUDNAME\"}, \"BarbicanAdmin\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanInternal\": {\"protocol\": \"https\", \"port\": \"9311\", \"host\": \"CLOUDNAME\"}, \"BarbicanPublic\": {\"protocol\": \"https\", \"port\": \"13311\", \"host\": \"CLOUDNAME\"}, \"CephDashboardInternal\": {\"protocol\": \"https\", \"port\": \"8444\", \"host\": \"CLOUDNAME\"}, \"CephGrafanaInternal\": {\"protocol\": \"https\", \"port\": \"3100\", \"host\": \"CLOUDNAME\"}, \"CephRgwAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"CephRgwPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}, \"CinderAdmin\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderInternal\": {\"protocol\": \"https\", \"port\": \"8776\", \"host\": \"CLOUDNAME\"}, \"CinderPublic\": {\"protocol\": \"https\", \"port\": \"13776\", \"host\": \"CLOUDNAME\"}, \"DesignateAdmin\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignateInternal\": {\"protocol\": \"https\", \"port\": \"9001\", \"host\": \"CLOUDNAME\"}, \"DesignatePublic\": {\"protocol\": \"https\", \"port\": \"13001\", \"host\": \"CLOUDNAME\"}, \"DockerRegistryInternal\": {\"protocol\": \"https\", \"port\": \"8787\", \"host\": \"CLOUDNAME\"}, \"GaneshaInternal\": {\"protocol\": \"nfs\", \"port\": \"2049\", \"host\": \"IP_ADDRESS\"}, \"GlanceAdmin\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlanceInternal\": {\"protocol\": \"https\", \"port\": \"9293\", \"host\": \"CLOUDNAME\"}, \"GlancePublic\": {\"protocol\": \"https\", \"port\": \"13292\", \"host\": \"CLOUDNAME\"}, \"GnocchiAdmin\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiInternal\": {\"protocol\": \"https\", \"port\": \"8041\", \"host\": \"CLOUDNAME\"}, \"GnocchiPublic\": {\"protocol\": \"https\", \"port\": \"13041\", \"host\": \"CLOUDNAME\"}, \"HeatAdmin\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatInternal\": {\"protocol\": \"https\", \"port\": \"8004\", \"host\": \"CLOUDNAME\"}, \"HeatPublic\": {\"protocol\": \"https\", \"port\": \"13004\", \"host\": \"CLOUDNAME\"}, \"HeatCfnAdmin\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnInternal\": {\"protocol\": \"https\", \"port\": \"8000\", \"host\": \"CLOUDNAME\"}, \"HeatCfnPublic\": {\"protocol\": \"https\", \"port\": \"13005\", \"host\": \"CLOUDNAME\"}, \"HorizonPublic\": {\"protocol\": \"https\", \"port\": \"443\", \"host\": \"CLOUDNAME\"}, \"IronicAdmin\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicInternal\": {\"protocol\": \"https\", \"port\": \"6385\", \"host\": \"CLOUDNAME\"}, \"IronicPublic\": {\"protocol\": \"https\", \"port\": \"13385\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorAdmin\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorInternal\": {\"protocol\": \"http\", \"port\": \"5050\", \"host\": \"CLOUDNAME\"}, \"IronicInspectorPublic\": {\"protocol\": \"https\", \"port\": \"13050\", \"host\": \"CLOUDNAME\"}, \"KeystoneAdmin\": {\"protocol\": \"https\", \"port\": \"35357\", \"host\": \"CLOUDNAME\"}, \"KeystoneInternal\": {\"protocol\": \"https\", \"port\": \"5000\", \"host\": \"CLOUDNAME\"}, \"KeystonePublic\": {\"protocol\": \"https\", \"port\": \"13000\", \"host\": \"CLOUDNAME\"}, \"ManilaAdmin\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaInternal\": {\"protocol\": \"https\", \"port\": \"8786\", \"host\": \"CLOUDNAME\"}, \"ManilaPublic\": {\"protocol\": \"https\", \"port\": \"13786\", \"host\": \"CLOUDNAME\"}, \"MetricsQdrPublic\": {\"protocol\": \"amqp\", \"port\": \"5666\", \"host\": \"CLOUDNAME\"}, \"MysqlInternal\": {\"protocol\": \"mysql+pymysql\", \"port\": \"3306\", \"host\": \"CLOUDNAME\"}, \"NeutronAdmin\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronInternal\": {\"protocol\": \"https\", \"port\": \"9696\", \"host\": \"CLOUDNAME\"}, \"NeutronPublic\": {\"protocol\": \"https\", \"port\": \"13696\", \"host\": \"CLOUDNAME\"}, \"NovaAdmin\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaInternal\": {\"protocol\": \"https\", \"port\": \"8774\", \"host\": \"CLOUDNAME\"}, \"NovaPublic\": {\"protocol\": \"https\", \"port\": \"13774\", \"host\": \"CLOUDNAME\"}, \"NovajoinAdmin\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinInternal\": {\"protocol\": \"https\", \"port\": \"9090\", \"host\": \"CLOUDNAME\"}, \"NovajoinPublic\": {\"protocol\": \"https\", \"port\": \"13090\", \"host\": \"CLOUDNAME\"}, \"NovaMetadataInternal\": {\"protocol\": \"https\", \"port\": \"8775\", \"host\": \"CLOUDNAME\"}, \"PlacementAdmin\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementInternal\": {\"protocol\": \"https\", \"port\": \"8778\", \"host\": \"CLOUDNAME\"}, \"PlacementPublic\": {\"protocol\": \"https\", \"port\": \"13778\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyAdmin\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyInternal\": {\"protocol\": \"https\", \"port\": \"6080\", \"host\": \"CLOUDNAME\"}, \"NovaVNCProxyPublic\": {\"protocol\": \"https\", \"port\": \"13080\", \"host\": \"CLOUDNAME\"}, \"OctaviaAdmin\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaInternal\": {\"protocol\": \"https\", \"port\": \"9876\", \"host\": \"CLOUDNAME\"}, \"OctaviaPublic\": {\"protocol\": \"https\", \"port\": \"13876\", \"host\": \"CLOUDNAME\"}, \"SwiftAdmin\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftInternal\": {\"protocol\": \"https\", \"port\": \"8080\", \"host\": \"CLOUDNAME\"}, \"SwiftPublic\": {\"protocol\": \"https\", \"port\": \"13808\", \"host\": \"CLOUDNAME\"}}, \"description\": \"Mapping of service endpoint -> protocol. Typically set via parameter_defaults in the resource registry.\", \"type\": \"json\"}, \"ServiceData\": {\"default\": {}, \"description\": \"Dictionary packing service data\", \"type\": \"json\"}, \"ServiceNetMap\": {\"default\": {\"ApacheNetwork\": \"internal_api\", \"NeutronTenantNetwork\": \"tenant\", \"AodhApiNetwork\": \"internal_api\", \"BarbicanApiNetwork\": \"internal_api\", \"GnocchiApiNetwork\": \"internal_api\", \"MongodbNetwork\": \"internal_api\", \"CinderApiNetwork\": \"internal_api\", \"CinderIscsiNetwork\": \"storage\", \"GlanceApiNetwork\": \"internal_api\", \"GlanceApiEdgeNetwork\": \"internal_api\", \"GlanceApiInternalNetwork\": \"internal_api\", \"IronicApiNetwork\": \"ctlplane\", \"IronicNetwork\": \"ctlplane\", \"IronicInspectorNetwork\": \"ctlplane\", \"KeystoneAdminApiNetwork\": \"ctlplane\", \"KeystonePublicApiNetwork\": \"internal_api\", \"ManilaApiNetwork\": \"internal_api\", \"NeutronApiNetwork\": \"internal_api\", \"OctaviaApiNetwork\": \"internal_api\", \"HeatApiNetwork\": \"internal_api\", \"HeatApiCfnNetwork\": \"internal_api\", \"HeatApiCloudwatchNetwork\": \"internal_api\", \"NovaApiNetwork\": \"internal_api\", \"PlacementNetwork\": \"internal_api\", \"NovaMetadataNetwork\": \"internal_api\", \"NovaLibvirtNetwork\": \"internal_api\", \"NovajoinNetwork\": \"internal_api\", \"SwiftStorageNetwork\": \"storage_mgmt\", \"SwiftProxyNetwork\": \"storage\", \"HorizonNetwork\": \"internal_api\", \"MemcachedNetwork\": \"internal_api\", \"OsloMessagingRpcNetwork\": \"internal_api\", \"OsloMessagingNotifyNetwork\": \"internal_api\", \"RabbitmqNetwork\": \"internal_api\", \"RabbitmqManagementNetwork\": \"internal_api\", \"QdrNetwork\": \"internal_api\", \"RedisNetwork\": \"internal_api\", \"GaneshaNetwork\": \"external\", \"MysqlNetwork\": \"internal_api\", \"SnmpdNetwork\": \"ctlplane\", \"CephClusterNetwork\": \"storage_mgmt\", \"CephDashboardNetwork\": \"ctlplane\", \"CephGrafanaNetwork\": \"storage\", \"CephMonNetwork\": \"storage\", \"CephRgwNetwork\": \"storage\", \"PublicNetwork\": \"external\", \"InternalApiNetwork\": \"internal_api\", \"OpendaylightApiNetwork\": \"internal_api\", \"OvnDbsNetwork\": \"internal_api\", \"DockerRegistryNetwork\": \"ctlplane\", \"PacemakerNetwork\": \"internal_api\", \"PacemakerRemoteNetwork\": \"internal_api\", \"DesignateApiNetwork\": \"internal_api\", \"DesignateMdnsNetwork\": \"internal_api\", \"DesignateWorkerNetwork\": \"external\", \"DesignateBindNetwork\": \"external\", \"BINDNetwork\": \"external\", \"EtcdNetwork\": \"internal_api\", \"HaproxyNetwork\": \"ctlplane\", \"UnboundNetwork\": \"external\", \"ControllerHostnameResolveNetwork\": \"internal_api\", \"ControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerHostnameResolveNetwork\": \"internal_api\", \"CellControllerMetricsQdrNetwork\": \"internal_api\", \"CellControllerComputeHostnameResolveNetwork\": \"internal_api\", \"CellControllerComputeMetricsQdrNetwork\": \"internal_api\", \"ComputeHostnameResolveNetwork\": \"internal_api\", \"ComputeMetricsQdrNetwork\": \"internal_api\", \"BlockStorageHostnameResolveNetwork\": \"internal_api\", \"BlockStorageMetricsQdrNetwork\": \"internal_api\", \"ObjectStorageHostnameResolveNetwork\": \"internal_api\", \"ObjectStorageMetricsQdrNetwork\": \"internal_api\", \"CephStorageHostnameResolveNetwork\": \"storage\", \"CephStorageMetricsQdrNetwork\": \"storage\", \"NetworkerHostnameResolveNetwork\": \"internal_api\", \"NetworkerMetricsQdrNetwork\": \"internal_api\"}, \"description\": \"Mapping of service_name -> network name. Typically set via parameter_defaults in the resource registry. Use parameter_merge_strategies to merge it with the defaults.\", \"type\": \"json\"}, \"RoleName\": {\"default\": \"\", \"description\": \"Role name on which the service is applied\", \"type\": \"string\"}, \"RoleParameters\": {\"default\": {}, \"description\": \"Parameters specific to the role\", \"type\": \"json\"}, \"MemcachedMaxMemory\": {\"default\": \"50%\", \"description\": \"The maximum amount of memory for memcached to be configured to use when installed. This can be either a percentage (\'50%\') or a fixed value (\'2048\').\", \"type\": \"string\"}, \"MemcachedMaxConnections\": {\"default\": 8192, \"description\": \"The maximum number of connections to be accepted by memcached\", \"type\": \"number\"}, \"MonitoringSubscriptionMemcached\": {\"default\": \"overcloud-memcached\", \"type\": \"string\"}, \"Debug\": {\"default\": true, \"description\": \"Set to True to enable debugging on all services.\", \"type\": \"boolean\"}, \"MemcachedDebug\": {\"default\": false, \"description\": \"Set to True to enable debugging Memcached service.\", \"type\": \"boolean\"}, \"MemcachedIpSubnet\": {\"default\": \"\", \"description\": \"IP address/subnet on the memcached network. If empty (default), MemcachedNetwork will be taken. Useful in the case where an operator wants to open Memcached outside of the internal network. Use this parameter with caution and be aware of opening memcached to external network can be dangerous.\", \"type\": \"string\"}, \"MemcachedPort\": {\"default\": 11212, \"description\": \"Port to have Memcached listening at. When using MemcachedTLS, this has to be set to a different port then the default - see below.\", \"type\": \"number\"}, \"MemcachedTLS\": {\"default\": true, \"description\": \"Set to True to enable TLS on Memcached service. Because not all services support Memcached TLS, during the migration period, Memcached will listen on 2 ports - on the port set with MemcachedPort parameter (above) and on 11211, without TLS.\", \"type\": \"boolean\"}, \"CertificateKeySize\": {\"type\": \"string\", \"default\": \"2048\", \"description\": \"Specifies the private key size used when creating the certificate.\"}, \"MemcachedCertificateKeySize\": {\"type\": \"string\", \"default\": \"\", \"description\": \"Override the private key size used when creating the certificate for this service\"}}, \"conditions\": {\"enable_non_tls_port\": {\"and\": [{\"get_param\": \"MemcachedTLS\"}, {\"not\": {\"equals\": [{\"get_param\": \"MemcachedPort\"}, 11211]}}]}, \"memcached_network_set\": {\"not\": {\"equals\": [{\"get_param\": \"MemcachedIpSubnet\"}, \"\"]}}, \"memcached_debug\": {\"or\": [{\"get_param\": \"Debug\"}, {\"get_param\": \"MemcachedDebug\"}]}, \"is_ipv6\": {\"equals\": [{\"get_param\": [\"ServiceData\", \"net_ip_version_map\", {\"get_param\": [\"ServiceNetMap\", \"MemcachedNetwork\"]}]}, 6]}, \"key_size_override_set\": {\"not\": {\"equals\": [{\"get_param\": \"MemcachedCertificateKeySize\"}, \"\"]}}}, \"resources\": {\"ContainersCommon\": {\"type\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/containers-common.yaml\"}, \"RoleParametersValue\": {\"type\": \"OS::Heat::Value\", \"properties\": {\"type\": \"json\", \"value\": {\"map_replace\": [{\"map_replace\": [{\"ContainerMemcachedImage\": \"ContainerMemcachedImage\", \"ContainerMemcachedConfigImage\": \"ContainerMemcachedConfigImage\"}, {\"values\": {\"get_param\": [\"RoleParameters\"]}}]}, {\"values\": {\"ContainerMemcachedImage\": {\"get_param\": \"ContainerMemcachedImage\"}, \"ContainerMemcachedConfigImage\": {\"get_param\": \"ContainerMemcachedConfigImage\"}}}]}}}}, \"outputs\": {\"role_data\": {\"description\": \"Role data for the Memcached API role.\", \"value\": {\"service_name\": \"memcached\", \"firewall_rules\": {\"if\": [\"memcached_network_set\", {\"121 memcached\": {\"dport\": {\"list_concat\": [[{\"get_param\": \"MemcachedPort\"}], {\"if\": [\"enable_non_tls_port\", [11211]]}]}, \"proto\": \"tcp\", \"source\": {\"get_param\": \"MemcachedIpSubnet\"}}}, {\"map_merge\": {\"repeat\": {\"for_each\": {\"<%net_cidr%>\": {\"get_param\": [\"ServiceData\", \"net_cidr_map\", {\"get_param\": [\"ServiceNetMap\", \"MemcachedNetwork\"]}]}}, \"template\": {\"121 memcached <%net_cidr%>\": {\"dport\": {\"list_concat\": [[{\"get_param\": \"MemcachedPort\"}], {\"if\": [\"enable_non_tls_port\", [11211]]}]}, \"proto\": \"tcp\", \"source\": \"<%net_cidr%>\"}}}}}]}, \"monitoring_subscription\": {\"get_param\": \"MonitoringSubscriptionMemcached\"}, \"config_settings\": {\"map_merge\": [{\"memcached::listen\": {\"list_concat\": [[{\"if\": [\"is_ipv6\", \"::1\", \"127.0.0.1\"]}, {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MemcachedNetwork\"]}}}}], {\"if\": [\"enable_non_tls_port\", [{\"str_replace\": {\"template\": \"notls:%{hiera(\'$NETWORK_uri\')}:11211\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MemcachedNetwork\"]}}}}, {\"if\": [\"is_ipv6\", \"notls:[::1]:11211\", \"notls:127.0.0.1:11211\"]}]]}]}, \"memcached::listen_ip\": [{\"if\": [\"is_ipv6\", \"::1\", \"127.0.0.1\"]}, {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MemcachedNetwork\"]}}}}], \"memcached::listen_ip_uri\": [{\"if\": [\"is_ipv6\", \"::1\", \"127.0.0.1\"]}, {\"str_replace\": {\"template\": \"%{hiera(\'$NETWORK_uri\')}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MemcachedNetwork\"]}}}}], \"memcached::tcp_port\": {\"get_param\": \"MemcachedPort\"}, \"memcached::max_connections\": {\"get_param\": \"MemcachedMaxConnections\"}, \"memcached::max_memory\": {\"get_param\": \"MemcachedMaxMemory\"}, \"memcached::udp_port\": 0, \"memcached::verbosity\": {\"list_join\": [\"\", [\"v\", {\"if\": [\"memcached_debug\", \"v\", \"\"]}]]}, \"memcached::disable_cachedump\": true, \"memcached::logstdout\": true, \"tripleo::profile::base::memcached::enable_internal_memcached_tls\": {\"get_param\": \"MemcachedTLS\"}}, {\"if\": [{\"get_param\": \"MemcachedTLS\"}, {\"tripleo::memcached::service_certificate\": \"/etc/pki/tls/certs/memcached.crt\", \"tripleo::profile::base::memcached::certificate_specs\": {\"service_certificate\": \"/etc/pki/tls/certs/memcached.crt\", \"service_key\": \"/etc/pki/tls/private/memcached.key\"}}]}]}, \"service_config_settings\": {\"collectd\": {\"tripleo.collectd.plugins.memcached\": [\"memcached\"], \"collectd::plugin::memcached::instances\": {\"local\": {\"host\": \"%{hiera(\'memcached::listen_ip_uri\')}\", \"port\": [{\"if\": [\"enable_non_tls_port\", 11211, {\"get_param\": \"MemcachedPort\"}]}]}}}}, \"global_config_settings\": {\"map_merge\": [{\"if\": [\"enable_non_tls_port\", {\"memcached_port\": {\"get_param\": \"MemcachedPort\"}, \"memcached_authtoken_port\": 11211}, {\"memcached_port\": {\"get_param\": \"MemcachedPort\"}, \"memcached_authtoken_port\": {\"get_param\": \"MemcachedPort\"}}]}, {\"if\": [\"is_ipv6\", {\"memcached_ipv6\": true}]}]}, \"puppet_config\": {\"config_volume\": \"memcached\", \"puppet_tags\": \"file\", \"step_config\": \"include tripleo::profile::base::memcached\\n\", \"config_image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMemcachedConfigImage\"]}}, \"kolla_config\": {\"/var/lib/kolla/config_files/memcached.json\": {\"command\": \"bash -c $* -- eval source /etc/sysconfig/memcached; exec /usr/bin/memcached -p ${PORT} -u ${USER} -m ${CACHESIZE} -c ${MAXCONN} $OPTIONS >> /var/log/memcached/memcached.log 2>&1\", \"config_files\": [{\"source\": \"/var/lib/kolla/config_files/src/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true}, {\"source\": \"/var/lib/kolla/config_files/src-tls/*\", \"dest\": \"/\", \"merge\": true, \"preserve_properties\": true, \"optional\": true}], \"permissions\": [{\"path\": \"/var/log/memcached\", \"owner\": \"memcached:memcached\", \"recurse\": true}, {\"path\": \"/etc/pki/tls/certs/memcached.crt\", \"owner\": \"memcached:memcached\", \"optional\": true}, {\"path\": \"/etc/pki/tls/private/memcached.key\", \"owner\": \"memcached:memcached\", \"optional\": true}]}}, \"docker_config\": {\"step_1\": {\"memcached\": {\"start_order\": 0, \"image\": {\"get_attr\": [\"RoleParametersValue\", \"value\", \"ContainerMemcachedImage\"]}, \"net\": \"host\", \"privileged\": false, \"restart\": \"always\", \"healthcheck\": {\"test\": \"/openstack/healthcheck\"}, \"volumes\": {\"list_concat\": [{\"get_attr\": [\"ContainersCommon\", \"volumes\"]}, [\"/var/lib/kolla/config_files/memcached.json:/var/lib/kolla/config_files/config.json:ro\", \"/var/lib/config-data/puppet-generated/memcached:/var/lib/kolla/config_files/src:rw,z\", \"/var/log/containers/memcached:/var/log/memcached:rw\"], {\"if\": [{\"get_param\": \"MemcachedTLS\"}, [\"/etc/pki/tls/certs/memcached.crt:/var/lib/kolla/config_files/src-tls/etc/pki/tls/certs/memcached.crt:ro\", \"/etc/pki/tls/private/memcached.key:/var/lib/kolla/config_files/src-tls/etc/pki/tls/private/memcached.key:ro\"]]}]}, \"environment\": {\"KOLLA_CONFIG_STRATEGY\": \"COPY_ALWAYS\"}}}}, \"metadata_settings\": {\"if\": [{\"get_param\": \"MemcachedTLS\"}, [{\"service\": \"memcached\", \"network\": {\"get_param\": [\"ServiceNetMap\", \"MemcachedNetwork\"]}, \"type\": \"node\"}]]}, \"deploy_steps_tasks\": {\"if\": [{\"get_param\": \"MemcachedTLS\"}, [{\"name\": \"Certificate generation\", \"when\": \"step|int == 1\", \"block\": [{\"include_role\": {\"name\": \"linux-system-roles.certificate\"}, \"vars\": {\"certificate_requests\": [{\"name\": \"memcached\", \"dns\": {\"str_replace\": {\"template\": \"{{fqdn_$NETWORK}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MemcachedNetwork\"]}}}}, \"principal\": {\"str_replace\": {\"template\": \"memcached/{{fqdn_$NETWORK}}@{{idm_realm}}\", \"params\": {\"$NETWORK\": {\"get_param\": [\"ServiceNetMap\", \"MemcachedNetwork\"]}}}}, \"run_after\": \"container_name=$({{container_cli}} ps --format=\\\\{\\\\{.Names\\\\}\\\\} | grep memcached)\\nservice_crt=\\\"/etc/pki/tls/certs/memcached.crt\\\"\\nservice_key=\\\"/etc/pki/tls/private/memcached.key\\\"\\n# Copy the new cert from the mount-point to the real path\\n{{container_cli}} exec -u root \\\"$container_name\\\" cp \\\"/var/lib/kolla/config_files/src-tls$service_crt\\\" \\\"$service_crt\\\"\\n# Copy the new key from the mount-point to the real path\\n{{container_cli}} exec -u root \\\"$container_name\\\" cp \\\"/var/lib/kolla/config_files/src-tls$service_key\\\" \\\"$service_key\\\"\\n# Set appropriate permissions\\n{{container_cli}} exec -u root \\\"$container_name\\\" chown memcached:memcached \\\"$service_crt\\\"\\n{{container_cli}} exec -u root \\\"$container_name\\\" chown memcached:memcached \\\"$service_key\\\"\\n# Send refresh_certs command to memcached to read the new certificate\\nmemcached_ip=\\\"$(hiera -c /etc/puppet/hiera.yaml memcached::listen_ip.0 127.0.0.1)\\\"\\nmemcached_port=\\\"$(hiera -c /etc/puppet/hiera.yaml memcached::tcp_port 11211)\\\"\\necho refresh_certs | openssl s_client -connect $memcached_ip:$memcached_port\\n\", \"key_size\": {\"if\": [\"key_size_override_set\", {\"get_param\": \"MemcachedCertificateKeySize\"}, {\"get_param\": \"CertificateKeySize\"}]}, \"ca\": \"ipa\"}]}}]}]]}, \"host_prep_tasks\": [{\"name\": \"create persistent directories\", \"file\": {\"path\": \"{{ item.path }}\", \"state\": \"directory\", \"setype\": \"{{ item.setype }}\", \"mode\": \"{{ item.mode }}\"}, \"with_items\": [{\"path\": \"/var/log/containers/memcached\", \"setype\": \"container_file_t\", \"mode\": \"0750\"}]}], \"upgrade_tasks\": [], \"external_upgrade_tasks\": [{\"when\": [\"step|int == 1\"], \"tags\": [\"never\", \"system_upgrade_transfer_data\", \"system_upgrade_stop_services\"], \"block\": [{\"name\": \"Stop memcached container\", \"import_role\": {\"name\": \"tripleo_container_stop\"}, \"vars\": {\"tripleo_containers_to_stop\": [\"memcached\"], \"tripleo_delegate_to\": \"{{ groups[\'memcached\'] | difference(groups[\'excluded_overcloud\']) }}\"}}]}]}}}}','null','{\"resource_registry\": {\"resources\": {}, \"OS::TripleO::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::Heat::SoftwareDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-software.yaml\", \"OS::Heat::StructuredDeployment\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/config-download-structured.yaml\", \"OS::TripleO::PostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::AllNodesDeployment\": \"OS::Heat::None\", \"OS::TripleO::DefaultPasswords\": \"OS::Heat::None\", \"OS::TripleO::RandomString\": \"OS::Heat::None\", \"OS::TripleO::Controller::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Controller\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/controller-role.yaml\", \"OS::TripleO::Tasks::ControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::ControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Controller::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Controller::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Controller::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage_mgmt.yaml\", \"OS::TripleO::Controller::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Controller::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::Controller::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_external.yaml\", \"OS::TripleO::CellController::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontroller-role.yaml\", \"OS::TripleO::Tasks::CellControllerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellController::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellController::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellController::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CellControllerCompute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cellcontrollercompute-role.yaml\", \"OS::TripleO::Tasks::CellControllerComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CellControllerComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CellControllerCompute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CellControllerCompute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CellControllerCompute::Ports::ExternalPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Compute::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Compute\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/compute-role.yaml\", \"OS::TripleO::Tasks::ComputePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ComputePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ComputeExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Compute::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Compute::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_storage.yaml\", \"OS::TripleO::Compute::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_internal_api.yaml\", \"OS::TripleO::Compute::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_tenant.yaml\", \"OS::TripleO::BlockStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::BlockStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/blockstorage-role.yaml\", \"OS::TripleO::Tasks::BlockStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::BlockStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::BlockStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::BlockStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::BlockStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::ObjectStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/objectstorage-role.yaml\", \"OS::TripleO::Tasks::ObjectStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::ObjectStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::ObjectStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::ObjectStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ObjectStorage::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStoragePostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::CephStorage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/cephstorage-role.yaml\", \"OS::TripleO::Tasks::CephStoragePreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::CephStoragePostConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorageExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::CephStorage::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::CephStorage::Ports::StoragePort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::CephStorage::Ports::StorageMgmtPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::PreNetworkConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerPostDeploySteps\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/post.yaml\", \"OS::TripleO::Networker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/networker-role.yaml\", \"OS::TripleO::Tasks::NetworkerPreConfig\": \"OS::Heat::None\", \"OS::TripleO::Tasks::NetworkerPostConfig\": \"OS::Heat::None\", \"OS::TripleO::NetworkerExtraConfigPre\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::Networker::Net::SoftwareConfig\": \"OS::Heat::None\", \"OS::TripleO::Networker::Ports::InternalApiPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::Networker::Ports::TenantPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/noop.yaml\", \"OS::TripleO::ControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/controller-role.yaml\", \"OS::TripleO::CellControllerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/compute-role.yaml\", \"OS::TripleO::BlockStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServiceServerMetadataHook\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/nova_metadata/krb-service-principals/networker-role.yaml\", \"OS::TripleO::Server\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployed-server/deployed-server.yaml\", \"OS::TripleO::ControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerServer\": \"OS::TripleO::Server\", \"OS::TripleO::CellControllerComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::ComputeServer\": \"OS::TripleO::Server\", \"OS::TripleO::BlockStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::ObjectStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::CephStorageServer\": \"OS::TripleO::Server\", \"OS::TripleO::NetworkerServer\": \"OS::TripleO::Server\", \"OS::TripleO::NodeAdminUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_heat_admin.yaml\", \"OS::TripleO::NodeTimesyncUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_timesync.yaml\", \"OS::TripleO::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Controller::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellController::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CellControllerCompute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Compute::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::BlockStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::ObjectStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::CephStorage::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::Networker::NodeUserData\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/firstboot/userdata_default.yaml\", \"OS::TripleO::NodeTLSCAData\": \"OS::Heat::None\", \"OS::TripleO::NodeTLSData\": \"OS::Heat::None\", \"OS::TripleO::NodeExtraConfig\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/puppet/extraconfig/pre_deploy/default.yaml\", \"OS::TripleO::NodeExtraConfigPost\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/extraconfig/post_deploy/default.yaml\", \"OS::TripleO::AllNodesExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network\": \"file:///usr/share/openstack-tripleo-heat-templates/network/deployed_networks.yaml\", \"OS::TripleO::Network::Storage\": \"OS::Heat::None\", \"OS::TripleO::Network::StorageMgmt\": \"OS::Heat::None\", \"OS::TripleO::Network::InternalApi\": \"OS::Heat::None\", \"OS::TripleO::Network::Tenant\": \"OS::Heat::None\", \"OS::TripleO::Network::External\": \"OS::Heat::None\", \"OS::TripleO::Network::ExtraConfig\": \"OS::Heat::None\", \"OS::TripleO::Network::Ports::NetVipMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_map.yaml\", \"OS::TripleO::Network::Ports::NetIpListMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/net_ip_list_map.yaml\", \"OS::TripleO::Network::Ports::StorageVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage.yaml\", \"OS::TripleO::Network::Ports::StorageMgmtVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_storage_mgmt.yaml\", \"OS::TripleO::Network::Ports::InternalApiVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_internal_api.yaml\", \"OS::TripleO::Network::Ports::ExternalVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_external.yaml\", \"OS::TripleO::Network::Ports::ControlPlaneVipPort\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/ports/deployed_vip_ctlplane.yaml\", \"OS::TripleO::ServiceNetMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/service_net_map.yaml\", \"OS::TripleO::EndpointMap\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/network/endpoints/endpoint_map.yaml\", \"OS::TripleO::DeployedServerEnvironment\": \"OS::Heat::None\", \"OS::TripleO::DeploymentSteps\": \"OS::Heat::None\", \"OS::TripleO::WorkflowSteps\": \"OS::Heat::None\", \"OS::TripleO::CellControllerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontroller-role.yaml\", \"OS::TripleO::CellControllerComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cellcontrollercompute-role.yaml\", \"OS::TripleO::ComputeServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/compute-role.yaml\", \"OS::TripleO::BlockStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/blockstorage-role.yaml\", \"OS::TripleO::ObjectStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/objectstorage-role.yaml\", \"OS::TripleO::CephStorageServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/cephstorage-role.yaml\", \"OS::TripleO::NetworkerServices\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/common/services/networker-role.yaml\", \"OS::TripleO::Services::Aide\": \"OS::Heat::None\", \"OS::TripleO::Services::Apache\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/apache/apache-baremetal-puppet.yaml\", \"OS::TripleO::Services::CACerts\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/certs/ca-certs-baremetal-puppet.yaml\", \"OS::TripleO::Services::CephMds\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMgr\": \"OS::Heat::None\", \"OS::TripleO::Services::CephMon\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRbdMirror\": \"OS::Heat::None\", \"OS::TripleO::Services::CephRgw\": \"OS::Heat::None\", \"OS::TripleO::Services::CephOSD\": \"OS::Heat::None\", \"OS::TripleO::Services::CephGrafana\": \"OS::Heat::None\", \"OS::TripleO::Services::CephClient\": \"OS::Heat::None\", \"OS::TripleO::Services::CephNfs\": \"OS::Heat::None\", \"OS::TripleO::Services::CephExternal\": \"OS::Heat::None\", \"OS::TripleO::Services::CinderApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-api-container-puppet.yaml\", \"OS::TripleO::Services::CinderBackup\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-backup-pacemaker-puppet.yaml\", \"OS::TripleO::Services::CinderScheduler\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-scheduler-container-puppet.yaml\", \"OS::TripleO::Services::CinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-pacemaker-puppet.yaml\", \"OS::TripleO::Services::BlockStorageCinderVolume\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/cinder/cinder-volume-container-puppet.yaml\", \"OS::TripleO::Services::Keystone\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/keystone/keystone-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-container-puppet.yaml\", \"OS::TripleO::Services::GlanceApiInternal\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/glance/glance-api-internal-container-puppet.yaml\", \"OS::TripleO::Services::HeatApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCfn\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cfn-container-puppet.yaml\", \"OS::TripleO::Services::HeatApiCloudwatch\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-api-cloudwatch-disabled-puppet.yaml\", \"OS::TripleO::Services::HeatEngine\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/heat/heat-engine-container-puppet.yaml\", \"OS::TripleO::Services::HeatEphemeral\": \"OS::Heat::None\", \"OS::TripleO::Services::Kernel\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/kernel/kernel-baremetal-ansible.yaml\", \"OS::TripleO::Services::MySQL\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/mysql-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NeutronBgpVpnApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronBgpVpnBagpipe\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronSfcApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronDhcpAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwApi\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL3Agent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronL2gwAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMetadataAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::OVNMetadataAgent\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-metadata-container-puppet.yaml\", \"OS::TripleO::Services::NeutronApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-api-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePlugin\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-container-puppet.yaml\", \"OS::TripleO::Services::ComputeNeutronCorePlugin\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-compute-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2OVN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ovn.yaml\", \"OS::TripleO::Services::NeutronCorePluginNuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Nuage\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-nuage.yaml\", \"OS::TripleO::Services::NeutronCorePluginNSX\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-nsx-container-puppet.yaml\", \"OS::TripleO::Services::OVNDBs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-dbs-cluster-ansible.yaml\", \"OS::TripleO::Services::OVNController\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/ovn/ovn-controller-container-puppet.yaml\", \"OS::TripleO::Services::OvsDpdkNetcontrold\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronCorePluginMLNXSDN\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-mlnx-sdn-assist-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginVTS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-cisco-vts-container-puppet.yaml\", \"OS::TripleO::Services::NeutronCorePluginML2Ansible\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-plugin-ml2-ansible-container-puppet.yaml\", \"OS::TripleO::Services::NeutronNuageVrs\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/neutron/neutron-controller-plugin-nuage.yaml\", \"OS::TripleO::Services::NeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronLinuxbridgeAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::ComputeNeutronOvsDpdk\": \"OS::Heat::None\", \"OS::TripleO::Services::Pacemaker\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-baremetal-puppet.yaml\", \"OS::TripleO::Services::PacemakerRemote\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/pacemaker/pacemaker-remote-baremetal-puppet.yaml\", \"OS::TripleO::Services::NeutronSriovAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronMlnxAgent\": \"OS::Heat::None\", \"OS::TripleO::Services::NeutronAgentsIBConfig\": \"OS::Heat::None\", \"OS::TripleO::Services::OsloMessagingRpc\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-rpc-pacemaker-puppet.yaml\", \"OS::TripleO::Services::OsloMessagingNotify\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/rabbitmq/rabbitmq-messaging-notify-shared-puppet.yaml\", \"OS::TripleO::Services::RabbitMQ\": \"OS::Heat::None\", \"OS::TripleO::Services::Qdr\": \"OS::Heat::None\", \"OS::TripleO::Services::HAproxy\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-pacemaker-puppet.yaml\", \"OS::TripleO::Services::HAProxyPublicTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-public-tls-certmonger.yaml\", \"OS::TripleO::Services::HAProxyInternalTLS\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/haproxy/haproxy-internal-tls-certmonger.yaml\", \"OS::TripleO::Services::Iscsid\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/iscsid/iscsid-container-puppet.yaml\", \"OS::TripleO::Services::Tuned\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/tuned/tuned-baremetal-ansible.yaml\", \"OS::TripleO::Services::Securetty\": \"OS::Heat::None\", \"OS::TripleO::Services::SELinux\": \"OS::Heat::None\", \"OS::TripleO::Services::Sshd\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/sshd/sshd-baremetal-ansible.yaml\", \"OS::TripleO::Services::Redis\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/database/redis-pacemaker-puppet.yaml\", \"OS::TripleO::Services::NovaApi\": \"file:///home/zuul/overcloud-deploy/overcloud/tripleo-heat-templates/deployment/nova/nova-ap